(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10943,        324]*)
(*NotebookOutlinePosition[     11615,        347]*)
(*  CellTagsIndexPosition[     11571,        343]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Constant system parameters", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["General values", "Subsubsection",
  InitializationCell->True],

Cell[TextData[StyleBox["All values are given in standard SI units!",
  FontWeight->"Bold"]], "Text",
  InitializationCell->True],

Cell["Permeability of Vacuum (w/o units):", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(val0 = {\[IndentingNewLine]\[Mu]0 -> 
          VacuumPermeability/\((Volt\ Second/\((Ampere\ Meter)\))\)}\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \({\[Mu]0 \[Rule] \[Pi]\/2500000}\)], "Output"]
}, Open  ]],

Cell["Properties of the rod (radius of coil = radius of solenoid).", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(val1o\)\(=\)\({\[IndentingNewLine]ER \[Rule] 
          280*10^9, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*E - 
            modulus\ of\ rod\ in\ Pa*) \[IndentingNewLine]cR \[Rule] 
          5391, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*sound\ velocity\ in\ meter/
              second*) \[IndentingNewLine]\[Theta] \[Rule] \(-5\)*10^6, \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*Magnetostrictive\ constant\ in\ \
xxxxxxxxxx*) \[IndentingNewLine]\[Mu]rR \[Rule] 
          110}\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \)\( (*relative\ permeability\ rod*) \)\)\)], "Input",
  InitializationCell->True,
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \({ER \[Rule] 280000000000, 
      cR \[Rule] 5391, \[Theta] \[Rule] \(-5000000\), \[Mu]rR \[Rule] 
        110}\)], "Output"]
}, Open  ]],

Cell["Properties of the function generator:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(val2o = {\[IndentingNewLine]U0d \[Rule] 
            4, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*Amplitude\
\ in\ Volt\ \((NOT\ peak - \(peak!\))\)*) \[IndentingNewLine]Ri \[Rule] \ 
            50}\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*Internal\ resistance\ in\ Ohm*) ;\)\)], "Input",
  InitializationCell->True,
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(val3o = {\[IndentingNewLine]A \[Rule] \[Pi]\ r\^2, \
\[IndentingNewLine]\[Mu]R \[Rule] \[Mu]0*\[Mu]rR} /. 
          Flatten[{val0, val1o}];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(valueso = Flatten[{val0, val1o, val2o, val3o}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({\[Mu]0 \[Rule] \[Pi]\/2500000, ER \[Rule] 280000000000, 
      cR \[Rule] 5391, \[Theta] \[Rule] \(-5000000\), \[Mu]rR \[Rule] 110, 
      U0d \[Rule] 4, Ri \[Rule] 50, 
      A \[Rule] \[Pi]\ r\^2, \[Mu]R \[Rule] \(11\ \[Pi]\)\/250000}\)], \
"Output"]
}, Open  ]],

Cell["\<\
Now the values are applied onto the coefficients a1 and a2, generating new \
rules:\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(valuerulea1o = rulea1 /. valueso;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(valuerulea2o = rulea2 /. valueso;\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(generalruleao = Flatten[{valuerulea1o, valuerulea2o}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({a1 \[Rule] \(-\(\((5391\ dd\ Ud\ \((\(-280000000000\)\ \[Pi]\ r\^2 + 
                    280000000000\ \[Pi]\ r\^2\ Cos[\(lRod\ w\)\/5391] + 
                    5391\ \[ImaginaryI]\ ZC\ Sin[\(lRod\ \
w\)\/5391])\))\)/\((56000\ N\ \[Pi]\ r\^2\ w\^2\ \((5391\ ZC\ Cos[\(lRod\ w\)\
\/5391] + 
                    280000000000\ \[ImaginaryI]\ \[Pi]\ r\^2\ Sin[\(lRod\ w\)\
\/5391])\))\)\)\), 
      a2 \[Rule] \(5391\ \[ImaginaryI]\ dd\ Ud\)\/\(56000\ N\ \[Pi]\ r\^2\ \
w\^2\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["HP FGen", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(generalruleUd = ruleUd /. valueso;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
The following rule sets a1 and a2 for the HP funktion generator. Open is: Zc, \
w, N, x1, lCoil1, lRod, r\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(generala = 
        Simplify[\(generalruleao /. ruleUd\) /. valueso];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Magnetostrictive Rod properties:", "Subsubsection",
  InitializationCell->True],

Cell[BoxData[
    \(\(rod = {lRod \[Rule] 40.8/1000, r \[Rule] 1/1000};\)\)], "Input",
  InitializationCell->True,
  Background->RGBColor[1, 1, 0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coil properties", "Subsubsection"],

Cell[BoxData[
    \(\(coils = {lCoil1 \[Rule] 12/1000, N \[Rule] 450, K1 \[Rule] 10/10, 
          x1 \[Rule] 14/137*lRod, lCoil2 \[Rule] 12/1000, N2 \[Rule] 140, 
          K2 \[Rule] 0.002379*1/10, x2 \[Rule] 76/137*lRod};\)\)], "Input",
  InitializationCell->True,
  Background->RGBColor[1, 1, 0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["General rule", "Subsection"],

Cell[BoxData[
    \(\(general = 
        Flatten[{coils, rod, generala, \ generalruleUd, valueso, 
            w \[Rule] 2\ \[Pi]\ \ f}];\)\)], "Input",
  InitializationCell->True,
  Background->RGBColor[1, 1, 0]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculating natural resonance frequencies for rod ", "Section",
  InitializationCell->True],

Cell["free-free", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(f1 = cR/\((2*lRod)\) //. general\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(66066.17647058824`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f2 = 2*cR/\((2*lRod)\) //. general\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(132132.35294117648`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((66090 - 200)\)*\((2*lRod)\) //. general\)], "Input"],

Cell[BoxData[
    \(5376.624`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sqrt[ER/9100. ] //. general\)], "Input"],

Cell[BoxData[
    \(5547.001962252291`\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["test the power", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(P2as\)], "Input"],

Cell[BoxData[
    \(\((\@A\^2\ dd\^2\ \@ER\^2\ K1\^2\ \@K2\^2\ N\^2\ U0d\^2\ w\^2\ \@\[Mu]R\
\^2\ \[Sqrt]\((cR\^2\ ZCr\^2\ Cos[\(lRod\ w\)\/cR]\^2 + \((cR\ ZCi\ \
Cos[\(lRod\ w\)\/cR] + A\ ER\ Sin[\(lRod\ w\)\/cR])\)\^2)\)\ \[Sqrt]\((\((cR\ \
ER\ lCoil2\ w\ ZCi\ Cos[\(lRod\ w\)\/cR] + A\ cR\ ER\ \[Theta]\^2\ \[Mu]R\ \
Cos[\(w\ \((lRod - x2)\)\)\/cR] - A\ cR\ ER\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ x2\
\)\/cR] + A\ cR\ ER\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ \((lCoil2 + x2)\)\)\/cR] - \
A\ cR\ ER\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ \((lCoil2 - lRod + x2)\)\)\/cR] + A\ \
ER\^2\ lCoil2\ w\ Sin[\(lRod\ w\)\/cR] - cR\^2\ ZCi\ \[Theta]\^2\ \[Mu]R\ \
Sin[\(w\ \((lRod - x2)\)\)\/cR] - cR\^2\ ZCi\ \[Theta]\^2\ \[Mu]R\ Sin[\(w\ \
\((lCoil2 - lRod + x2)\)\)\/cR])\)\^2 + \((cR\ ER\ lCoil2\ w\ ZCr\ Cos[\(lRod\
\ w\)\/cR] - cR\^2\ ZCr\ \[Theta]\^2\ \[Mu]R\ Sin[\(w\ \((lRod - x2)\)\)\/cR] \
- cR\^2\ ZCr\ \[Theta]\^2\ \[Mu]R\ Sin[\(w\ \((lCoil2 - lRod + \
x2)\)\)\/cR])\)\^2)\))\)/\((2\ \[Sqrt]\((\((\((cR\ dd\ ER\ lCoil1\ Ri\ w\ ZCi \
+ A\ cR\ ER\ K1\ N\^2\ w\^2\ ZCr\ \[Mu]R)\)\ Cos[\(lRod\ w\)\/cR] + A\ cR\ dd\
\ ER\ Ri\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ \((lRod - x1)\)\)\/cR] - A\ cR\ dd\ \
ER\ Ri\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ x1\)\/cR] + A\ cR\ dd\ ER\ Ri\ \[Theta]\
\^2\ \[Mu]R\ Cos[\(w\ \((lCoil1 + x1)\)\)\/cR] - A\ cR\ dd\ ER\ Ri\ \
\[Theta]\^2\ \[Mu]R\ Cos[\(w\ \((lCoil1 - lRod + x1)\)\)\/cR] + A\ dd\ ER\^2\ \
lCoil1\ Ri\ w\ Sin[\(lRod\ w\)\/cR] - cR\^2\ dd\ Ri\ ZCi\ \[Theta]\^2\ \[Mu]R\
\ Sin[\(w\ \((lRod - x1)\)\)\/cR] - cR\^2\ dd\ Ri\ ZCi\ \[Theta]\^2\ \[Mu]R\ \
Sin[\(w\ \((lCoil1 - lRod + x1)\)\)\/cR])\)\^2 + \((\((cR\ dd\ ER\ lCoil1\ Ri\
\ w\ ZCr - A\ cR\ ER\ K1\ N\^2\ w\^2\ ZCi\ \[Mu]R)\)\ Cos[\(lRod\ w\)\/cR] - \
A\^2\ ER\^2\ K1\ N\^2\ w\^2\ \[Mu]R\ Sin[\(lRod\ w\)\/cR] - cR\^2\ dd\ Ri\ \
ZCr\ \[Theta]\^2\ \[Mu]R\ Sin[\(w\ \((lRod - x1)\)\)\/cR] - cR\^2\ dd\ Ri\ \
ZCr\ \[Theta]\^2\ \[Mu]R\ Sin[\(w\ \((lCoil1 - lRod + x1)\)\)\/cR])\)\^2)\)\ \
\[Sqrt]\((\((\((\(-cR\)\ dd\ ER\ lCoil1\ Ri\ w\ ZCi - A\ cR\ ER\ K1\ N\^2\ \
w\^2\ ZCr\ \[Mu]R)\)\ Cos[\(lRod\ w\)\/cR] - A\ cR\ dd\ ER\ Ri\ \[Theta]\^2\ \
\[Mu]R\ Cos[\(w\ \((lRod - x1)\)\)\/cR] + A\ cR\ dd\ ER\ Ri\ \[Theta]\^2\ \
\[Mu]R\ Cos[\(w\ x1\)\/cR] - A\ cR\ dd\ ER\ Ri\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ \
\((lCoil1 + x1)\)\)\/cR] + A\ cR\ dd\ ER\ Ri\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ \
\((lCoil1 - lRod + x1)\)\)\/cR] - A\ dd\ ER\^2\ lCoil1\ Ri\ w\ Sin[\(lRod\ \
w\)\/cR] + cR\^2\ dd\ Ri\ ZCi\ \[Theta]\^2\ \[Mu]R\ Sin[\(w\ \((lRod - \
x1)\)\)\/cR] + cR\^2\ dd\ Ri\ ZCi\ \[Theta]\^2\ \[Mu]R\ Sin[\(w\ \((lCoil1 - \
lRod + x1)\)\)\/cR])\)\^2 + \((\((\(-cR\)\ dd\ ER\ lCoil1\ Ri\ w\ ZCr + A\ cR\
\ ER\ K1\ N\^2\ w\^2\ ZCi\ \[Mu]R)\)\ Cos[\(lRod\ w\)\/cR] + A\^2\ ER\^2\ K1\ \
N\^2\ w\^2\ \[Mu]R\ Sin[\(lRod\ w\)\/cR] + cR\^2\ dd\ Ri\ ZCr\ \[Theta]\^2\ \
\[Mu]R\ Sin[\(w\ \((lRod - x1)\)\)\/cR] + cR\^2\ dd\ Ri\ ZCr\ \[Theta]\^2\ \
\[Mu]R\ Sin[\(w\ \((lCoil1 - lRod + x1)\)\)\/cR])\)\^2)\))\)\)], "Output"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 791}},
AutoGeneratedPackage->None,
WindowSize->{526, 739},
WindowMargins->{{Automatic, -2}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 73, 1, 59, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[1825, 57, 67, 1, 43, "Subsubsection",
  InitializationCell->True],
Cell[1895, 60, 128, 2, 33, "Text",
  InitializationCell->True],
Cell[2026, 64, 79, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2130, 69, 169, 4, 50, "Input",
  InitializationCell->True],
Cell[2302, 75, 65, 1, 40, "Output"]
}, Open  ]],
Cell[2382, 79, 104, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2511, 84, 712, 12, 146, "Input",
  InitializationCell->True],
Cell[3226, 98, 144, 3, 29, "Output"]
}, Open  ]],
Cell[3385, 104, 81, 1, 33, "Text",
  InitializationCell->True],
Cell[3469, 107, 400, 7, 86, "Input",
  InitializationCell->True],
Cell[3872, 116, 205, 4, 72, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4102, 124, 107, 2, 30, "Input",
  InitializationCell->True],
Cell[4212, 128, 273, 5, 74, "Output"]
}, Open  ]],
Cell[4500, 136, 135, 4, 33, "Text",
  InitializationCell->True],
Cell[4638, 142, 98, 2, 30, "Input",
  InitializationCell->True],
Cell[4739, 146, 98, 2, 30, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4862, 152, 114, 2, 30, "Input",
  InitializationCell->True],
Cell[4979, 156, 510, 9, 169, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5538, 171, 60, 1, 43, "Subsubsection",
  InitializationCell->True],
Cell[5601, 174, 99, 2, 30, "Input",
  InitializationCell->True],
Cell[5703, 178, 157, 4, 52, "Text",
  InitializationCell->True],
Cell[5863, 184, 134, 3, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[6034, 192, 85, 1, 43, "Subsubsection",
  InitializationCell->True],
Cell[6122, 195, 147, 3, 46, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[6306, 203, 40, 0, 43, "Subsubsection"],
Cell[6349, 205, 300, 5, 86, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[6686, 215, 34, 0, 47, "Subsection"],
Cell[6723, 217, 213, 5, 86, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6985, 228, 97, 1, 59, "Section",
  InitializationCell->True],
Cell[7085, 231, 53, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[7163, 236, 93, 2, 30, "Input",
  InitializationCell->True],
Cell[7259, 240, 52, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7348, 246, 95, 2, 30, "Input",
  InitializationCell->True],
Cell[7446, 250, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7536, 256, 75, 1, 30, "Input"],
Cell[7614, 259, 43, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7694, 265, 60, 1, 30, "Input"],
Cell[7757, 268, 52, 1, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7858, 275, 33, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[7916, 279, 37, 1, 30, "Input"],
Cell[7956, 282, 2959, 38, 1191, "Output"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

