(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    497745,      16994]*)
(*NotebookOutlinePosition[    498625,      17022]*)
(*  CellTagsIndexPosition[    498581,      17018]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Model  <1>  for Magnetostrictive Rod", "Title"],

Cell["\<\
In this notebook the impedance of an ideal solenoid around a magnetostrictive \
rod is derived. Also derived is the amplitude of oscillations of the rod, \
dependant on the applied coil voltage. The model is only valid for \
steady-state oscillations, no electromechanical losses, and an ideal magnetic \
flux return path (that means the magnetic permeability \[Mu] of the \
surrounding medium has to be significantly higher than the permeability of \
the rod itself).

Additionally this model simulates the electric circuit for a solenoid \
connected to a function generator, a voltage-source with an internal \
resistance.  \
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Initialization for Mathematica", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Remove["\<Global`*\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Remove::"rmnsm" \(\(:\)\(\ \)\) 
      "There are no symbols matching \"\!\(\"Global`*\"\)\"."\)], "Message"]
}, Open  ]],

Cell[BoxData[
    \(\($HistoryLength = 35;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Off[General::spell1]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(<< Miscellaneous`Units`\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(<< Miscellaneous`PhysicalConstants`\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(<< Graphics`Legend`\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(<< Algebra`ReIm`\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Abs[t]\  ^= t; Im[t] ^= 0;\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Abs[f]\  ^= f; Im[f] ^= 0;\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Abs[w]\  ^= w; Im[w] ^= 0;\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Abs[x]\  ^= x; Im[x] ^= 0;\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Abs[\[CurlyPhi]]\  ^= \[CurlyPhi]; Im[\[CurlyPhi]] ^= 0;\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Abs[ZCr]\  ^= ZCr; Im[ZCr] ^= 0;\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Abs[ZCi]\  ^= ZCi; Im[ZCi] ^= 0;\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Abs[U0da]\  ^= U0da;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(cond1 = {\[Lambda] > 0, \[Theta]\ \[Epsilon]\ Reals, w > 0, f > 0, 
          A > 0, ER > 0, cR > 0, lRod > 0, N > 0, N2 > 0, lCoil1 > 0, 
          lCoil2 > 0, x1 > 0, x2 > 0, K1 > 0, K2 > 0, \[Mu]R > 0, 
          ZCr\ \[Epsilon]\ Reals, \ ZCi\ \[Epsilon]\ Reals, \ 
          U0da\ \[Epsilon]\ Reals};\)\)], "Input",
  InitializationCell->True],

Cell["The following functions will definitely be real:", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(RealValued[P2a, P2as, P2axs]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({P2a, P2as, P2axs}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["General equations", "Section",
  InitializationCell->True],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0003RX0@0006`0003ooooo0@000<T1001h0000
00000000000j>000<@l00215CDH00040Z3P005h200040000000000000000000000@0000300100@00
l0000000000000000000003R1020Z@<02P000100001?0000S`0000T0000@0000b`4007`0000D0000
300000d000160000:00001`00017A4U30P0004l0002@00006@8000X1000000009@0000`000050020
9@0000`000080020:`0001P0001`0000j0000:d0000:0@009@0000`0000000209@0000`000070020
DP000701000100000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000001P00004000100P00
@0800?a]Tc0LZKX00P0000<000000000J>XB04BlS7Oooooo000C08SO5`0?3P00A[^<M`004`28gaL0
000C08SO5`002000@0HC05/1003oooooH8^/1527[0AP[/L4000000004`1h0A<00@P00000000001<0
V3lH07P14`0=0P00D;J<MaJeS7L]]Hag00000800002X?aH0000C05H100000000/8V/14b6[0@00<L4
j:O71?cW4P3ljA80;>XB0=cZ4P101Q<0:0`C000000000000d7J/1?Af[0B/jA80c[nB<80000010000
I7H02000000U000030000040000H000030000000008I000030000?ooo`8K00004000000000000000
DP00070100020000j?ooo`000000000000000;`20000000004008T40LP1Y0640K000000000000000
0000000000000000000000000000000000000000000000000000000000000180N><B0200001XhQ80
000007AVS30100000@000:03DP60laD00@0000000000000000000000002Tha80;COdM`0000200000
h><B004000000000BCOdMl1GmgL20000080000@000000000oooo06Af00P000000000000000000000
_08000L000020000i37dMl1GmgL0@000j@L:cIT`m7OY1`[=90P:>mRX^P2hYkX02/d000cS4P0000<`
000:0?100c0?00000P000;BW^P000000X><B03=00c2dYkX0000006RU^P2Pha800dD3<5D00@5e?0<`
I7H02000000U000030000080000X000030000040000H000030000000008I000030000?ooo`8K0000
40000000000000005P0000`0000H00004P0000`000010000E00006@0000[0000FP0005@0001f0000
0@000000nT400?Y1NP00000100040000C00000000000000000000?ooooooooooE00007P0;00P07D0
3@0000L0000700003`0001H0000<000000000180000<00000P000180000<00000P0004H0000X0000
700004M4BD<20000C`0009l0000;0@00b`000000000U0000300000P0080W00006000004000000000
HHom0000000U000030000040000k0000200001/0000@000020400;@0001H0000:000000000000000
ooooooooool30000206Y00<1X03n0:00=P000100001J0000X00005P0000d000000000000003ooooo
ooooo`H0001E0:00D02Y0500]01@0;l0E@3805X0b00f000040000?h000380000F00002P000000000
00000?oooooooooo0`0000<1b0080Kl0206d03d000080000?00000P0000n000060000040000A0000
^@0003T0000U0000300000L0080U000030000000080X000030000040000U0000300000P0080W0000
6000004000000000P:Gn0000000U000030000040000k0000200001/0000@0000oP000:00001H0000
C000000000000000ooooooooool<0000n02P0?@0Z@3d0;@0m02o0?P0b03n0<P00`7800P1_`080K@0
206Y00<1X03n0:00?@0000P0000l0000200003h0000H0000Y@000140002i0000>@0002D0000<0000
1`00P2D0000<00000000P2P0000<00000@0005l0000h00000@0003P000000000>000000000000P40
0@0000000000000000000000000000009@0000`0000100009@0000`000050020>`0000P0000K0000
400000P1002d0000F00002P00000000000000?oooooooooo0`0000P1Z@030J00oP2P03H0000@0000
FP000:00001H0000=000000000000000ooooooooool60000E@2P0500Z@1@0;@0D02o05D0b01J0<P0
=P000100003n0000b00005P0000X000000000000003oooooooooo`<000030LP0206o00P1]00m0000
200003`000080000@00001P0003ooooo3`000;/0000k0000>`0000P0000K000040000?h0002P0000
F00003@00000000000000?oooooooooo1P000?P0X03d0:T0m02d0?@0_`3h0<P0oP3803`000080000
@00001P0002S00003`000;40000k00009@0000`000070020:00000`0000100009@0000`000000020
AP0001@000080000AdA9@`<0000H000030000000008I000030000?ooo`8K00004000000000000000
600000`0000000026@0000`0003oool26`00010000000000000001H0000<000060000180000<0000
0@0005@0001P0000@@0001D0001_0000<@00004000000?Y1003j@I00002k00000`0004`000000000
00000000003ooooooooooe@0001B06l0I0000140000?00003`0001H0000<000000000180000<0000
0P000180000<00000P0004H0000X0000700004M4BD<20000C`000=l0001B00000P400000001O0000
>0000040000h0000000003P00000000000010040000000000000000000000000000002D0000<0000
0@0002D0000<00001@00P5L0000T0000ooooodl000030000L`000080001@0>00D0000BD0000<0000
1`00P2P0000<00000@0002D0000<00000000P4H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80001?0000jP0007X0003g0000000005l0000h00000@0003P000000000>000000000000040
0@0000000000000000000000000000009@0000`0000100009@0000`000050020E`0002@0003ooooo
G`0002<0001S00000P000500l01`0?009@0000`000080020:00000`0000100009`0001P000010000
00000000000000009@0000`000010000EP0002P0000O0000G00002T0001W00000`0006h0mP1h0?00
KP3[02D0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000200004M4BD<30000
9`0001P0000100000000002^000000009@0000`0000100009P0001`0000300000000004000000000
00000RD0000<00000`0002/0000H0000d0400900000H0P00f00002D0000<00000000P2P0000<0000
0@0002D0000<00001`00P2P0000<00000`0001P0000<000000000QT0000<0000oooo0Q/0000@0000
00000000000H000030000000008I000030000?ooo`8K000040000000000000005P0000`0000H0000
4P0000`000010000E00005@0002H0@005@000:D1000a00000@000000nT400?Y1i`400;/000010000
C00000000000000000000?ooooooooooD00005X0000>00005P0000`0000000004P0000`000020000
DP00070100030000l?ooo`000000000000000;`20000000004008T40LP1Y0640K000000000000000
0000000000000000000000000000000000000000000000000000000000000180En^C<;P48@CW0@00
^`00000000000000F>4B00400018lN<10000@>L1001hiA80FP0000000000000000000000H@0001<0
3@80004o600@1000V3lH0040000200004>4B0:A1603HhA80UB^8MaPfR7Ooooooj>4B0000igL001<0
00000:0o60010000P00H083c5@00000000000=lVSS2/hA80]>4B0:A1602<iA80K1?/MfPTigL00?oo
000B0=H]mGNP?aP0X0=B0H3c5@2PlaD000000:0o60010000XT4H0;Sc5@0lhQ80oB_eMeD00@410@00
I7H02000000U0000300000<0000X000030000080000H000030000000008I000030000?ooo`8K0000
40000000000000005P0000`0000H00004P0000`000010000E00005@0002V0@0090000;41000f0000
0@000000nT400?Y1m@400<8000010000C00000000000000000000?ooooooooooD00004<0000<0000
5P0000`0000000004P0000`0000200004P0000`000020000AP0002P0000L0000AdA9@`80003k0000
W`0009l1003;0000000002D0000<00002000P2L0000H00000P000000001QSod0000002D0000<0000
0P0003/0000800006`000100002L0@00]00005P0000X000000000000003oooooooooo`<0002L0JT0
V@6P09@1X00f0000400000D1002P0000F00003@00000000000000?oooooooooo1P000001X03l0:T0
o02d0?`0_`000LP01@7803H0000@0000U0400<P0001H0000:000000000000000ooooooooool30000
V@7809`1_`2L0K@0?@0000P0000l0000200003h0000H0000[@000140001=0@00>@0002D0000<0000
1`00P2D0000<00000000P2P0000<00000P0002D0000<00002000P2L0000H00000P0000000020YOh0
000002D0000<00000P0003/0000800006`000100002D0@00X00005P0001<000000000000003ooooo
ooooo``0002?0J00R`6Y08/1]02;0Kl0S`7809@1b02I0LP0W06o09`1]02L0JT0V@6P09@1X00m0000
200003`000080000?P0001P0000l0@004@0004d1000i00009@0000`0000700209@0000`000000020
:00000`000020000G`0003P000020000>0000000000h0000000000020@0100000000000000000000
00000000000U000030000080000U0000300000D0080k0000200001/0000@0000W0400;@0001H0000
:000000000000000ooooooooool30000W06Y09T1X02D0J00=P00010000050@00X00005P0000d0000
00000000003oooooooooo`H000000J00o02Y0?`0]03l0;l0007800D1b00f0000400009@100380000
F00002P00000000000000?oooooooooo0`0009T1b02L0Kl0W06d03d000080000?00000P000100000
60000:/0000?0000C`4003/0000k0000200001/0000@0000U0400:00001H0000=000000000000000
ooooooooool60000S`6P08/1Z@2;0K@0R`6o08l1b02D0LP0?00000P000100000600003X1000?0000
A`4003/0000U0000300000L0080X000030000080000U00003000000008160000500000P00017A4U3
0`0001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000B00003000008000160000
:00001`00017A4U30P000?L0002O00002P400:8000000000G`0003P000020000>0000000000h0000
000000020@010000000000000000000000000000000U000030000080000U0000300000D0081G0000
90000:L0000?0000^`0001<000020000n02P00P1X00U0000300000L0080X000030000080000U0000
3000000008160000500000P00017A4U30`0004H0000X0000700004M4BD<20000m`000<L0000B0@00
bP000000001O0000>0000080000h0000000003P00000000000810040000000000000000000000000
000002D0000<00000P0002D0000<00001@00P5L0000T0000Y`0003L000330000>`000080003h0<P0
407802D0000<00001`00P2P0000<00000P0002D0000<00000000P4H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80003c0000/@000?H000060@00000005l0000h00000P0003P000000000
>0000000000000400@0000000000000000000000000000009@0000`0000200009@0000`000050020
E`0002@0002S00008@000:L0001g00000P000?@0/P3d00@19@0000`000070020:00000`000020000
9@0000`000000020AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000?`0002b0000
o`0000L100000000G`0003P000020000>0000000000h0000000000000@0100000000000000000000
00000000000U000030000080000U0000300000D0081G000090000:`0000R0000/00007P000020000
o@2c0?d01@4U0000300000L0080X000030000080000U00003000000008160000500000P00017A4U3
0`0004H0000X0000700004M4BD<20000bP000>X0003e0000m`000000001O0000>0000080000h0000
000003P00000000000010040000000000000000000000000000002D0000<00000P0002D0000<0000
1@00P5L0000T0000NP0005l0002N0000H`000080003;0?00j`3`02D0000<00002000P2P0000<0000
0P0002L0000H00000P00000000000000000002D0000<00000P0005H0000X0000VP0005`0002U0000
I`0000<0003Y0?H0m03`0>T0j`0U0000300000L0080U000030000000080X00003000008000160000
500000P00017A4U30`0004H0000X0000700004M4BD<20000o0000>X0000W0@00m`000000001O0000
>0000080000h0000000003P00000000000010040000000000000000000000000000002D0000<0000
0P0002D0000<00001@00P5L0000T0000]00005l0003H0000H`000080000U0O001@7`02D0000<0000
2000P2P0000<00000P0002L0000H00000P00000000000000000002D0000<00000P0005H0000X0000
[`0005`0002i0000I`0000<000080N/0oP3`00P1mP0U0000300000L0080U000030000000080X0000
3000008000160000500000P00017A4U30`0002D0000<00001@00P2D0000<00002000P2/0000H0000
6@400>P000180@002P4002D0000<00000000P2D0000<00001`00P1P0000<000000000QT0000<0000
oooo0Q/0000@000000000000001B0000L0400080003Xoooo0000000000000000_08000000000@00R
@@1b06T0H@1/00000000000000000000000000000000000000000000000000000000000000000000
000000004P010000000006ST4P000000P><B004000010000X0=B0H3c5@0100000000000000000000
00000:CS4P0]=oAg00000800003Pha800@0000000019=oAg`5OgM`800000P00010000<1GmgL0@000
I7H02000003H10[n000:DMRX^P2hYkX02_h00>3R4P3T<OAg`5OgM`10003n20YAVC3dMoh82U7H10[o
f:Rj0;RW^P0:D@003><B00000c0000X0l403<0l000020000]:Nj0000002Pha80<d03<;BW^P000000
3:Bj0:3S4P03A@<`E@010GDl0c1TMP08000002D0000<00000P0002P0000<00000`0001P0000<0000
00000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B000030000040001D0000
F0000=<0001J0000kP0007H000010000003j@@00nT4R0@0000400080001<00000000000000000000
oooooooooom@0000I01h00l0000=00005P0000`0000000004P0000`0000200004P0000`000020000
AP0002P0000L0000AdA9@`80002@0@00/0000=81002i0000000005l0000h00000`0003P000000000
>000000000000P400@0000000000000000000000000000009@0000`0000300009@0000`000050020
E`0002@000130@008`0008<1000W00000P0009@1]03@0K@09@0000`000080020:00000`000030000
9`0001P00003000000000000000000009@0000`000030000:P0001P0002B0@00/P0009P1002h0000
9@0000`0000700209@0000`000000020:00000`000030000AP0001@000080000AdA9@`<0000<0000
40000000000000009@0000`0000500209@0000`000080020:`0001P0001`0000j0000:d0000:0@00
9@0000`0000000209@0000`000070020600000`0000000026@0000`0003oool26`00010000000000
000001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B0000
30000040001D0000I00002/0001J0000E00007H000010000003j@@00nT5j0000004000@0001<0000
0000000000000000oooooooooomD0000N00/0200M@0=00001`0000L0000?00005P0000`000000000
4P0000`0000200004P0000`0000200003000010000000000000004H0000X0000700004M4BD<20000
C`0009l0000;0@00b`000000000U0000300000P0080W0000600000<000000000HHom0000000U0000
300000<0000k0000200001/0000@000020400;@0001H0000:000000000000000ooooooooool30000
206Y00<1X03n0:00=P000100001J0000X00005P0000d000000000000003oooooooooo`H0001E0:00
D02Y0500]01@0;l0E@3805X0b00f000040000?h000380000F00002P00000000000000?oooooooooo
0`0000<1b0080Kl0206d03d000080000?00000P0000n000060000040000A0000^@0003T0000U0000
300000L0080U000030000000080X0000300000<0000U0000300000P0080W0000600000<000000000
P:Gn0000000U0000300000<0000k0000200001/0000@0000oP000:00001H0000C000000000000000
ooooooooool<0000n02P0?@0Z@3d0;@0m02o0?P0b03n0<P00`7800P1_`080K@0206Y00<1X03n0:00
?@0000P0000l0000200003h0000H0000Y@000140002i0000>@0002D0000<00001`00P2D0000<0000
0000P2P0000<00000`0005l0000h00000`0003P000000000>000000000000P400@00000000000000
00000000000000009@0000`0000300009@0000`000050020>`0000P0000K0000400000P1002d0000
F00002P00000000000000?oooooooooo0`0000P1Z@030J00oP2P03H0000@0000FP000:00001H0000
=000000000000000ooooooooool60000E@2P0500Z@1@0;@0D02o05D0b01J0<P0=P000100003n0000
b00005P0000X000000000000003oooooooooo`<000030LP0206o00P1]00m0000200003`000080000
@00001P0003ooooo3`000;/0000k0000>`0000P0000K000040000?h0002P0000F00003@000000000
00000?oooooooooo1P000?P0X03d0:T0m02d0?@0_`3h0<P0oP3803`000080000@00001P0002S0000
3`000;40000k00009@0000`000070020:00000`0000300009@0000`000000020AP0001@000080000
AdA9@`<0000H000030000000008I000030000?ooo`8K00004000000000000000600000`000000002
6@0000`0003oool26`00010000000000000001H0000<000060000180000<00000@0005@0001P0000
@@0001D0001_0000<@00004000000?Y1003j@I00002k00000`0004`00000000000000000003ooooo
oooooe@0001B06l0I0000140000?00003`0001H0000<000000000180000<00000P000180000<0000
0P0000`0000@00000000000000160000:00001`00017A4U30P0004l0003O0000DP00008100000000
G`0003P000030000>0000000000h0000000000000@010000000000000000000000000000000U0000
300000<0000U0000300000D0081G000090000?oooom?00000`0007<000020000D03P0500004U0000
300000L0080X0000300000<0000U00003000000008160000500000P00017A4U30`0000`0000@0000
0000000000160000:00001`00017A4U30P0004l0003Z0000NP000?L000000000G`0003P000030000
>0000000000h0000000000000@010000000000000000000000000000000U0000300000<0000U0000
300000D0081G000090000?oooomO00008`0006<000020000D03`0700l00U0000300000P0080X0000
300000<0000W0000600000<00000000000000000000U0000300000<0001F0000:00001l0001L0000
:@0006L000030000KP3f07P0l01^0>/09@0000`0000700209@0000`000000020:00000`000030000
AP0001@000080000AdA9@`<0000<000040000000000000009`0001P0000300000000002^00000000
9@0000`0000300009P0001`000010000000000400000000000000RD0000<00000@0002/0000H0000
d0400900000H0P00f00002D0000<00000000P2P0000<00000`0002D0000<00001`00P2P0000<0000
0@0001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000H000030000000008I0000
30000?ooo`8K000040000000000000005P0000`0000H00004P0000`000010000E00005@0002H0@00
5@000:D1000a00000@000000nT400?Y1i`400;/000010000C00000000000000000000?oooooooooo
D00005X0000>00005P0000`0000000004P0000`000020000DP00070100010000l?ooo`0000000000
00000;`20000000004008T40LP1Y0640K00000000000000000000000000000000000000000000000
00000000000000000000000000000180En^C<;P48@CW0@00^`00000000000000F>4B00400018lN<1
0000@>L1001hiA80FP0000000000000000000000H@0001<03@80004o600@1000V3lH004000020000
4>4B0:A1603HhA80UB^8MaPfR7Ooooooj>4B0000igL001<000000:0o60010000P00H083c5@000000
00000=lVSS2/hA80]>4B0:A1602<iA80K1?/MfPTigL00?oo000B0=H]mGNP?aP0X0=B0H3c5@2PlaD0
00000:0o60010000XT4H0;Sc5@0lhQ80oB_eMeD00@410@00I7H02000000U000030000040000X0000
30000080000H000030000000008I000030000?ooo`8K000040000000000000005P0000`0000H0000
4P0000`000010000E00005@0002V0@0090000;41000f00000@000000nT400?Y1m@400<8000010000
C00000000000000000000?ooooooooooD00004<0000<00005P0000`0000000004P0000`000020000
4P0000`0000200003000010000000000000004H0000X0000700004M4BD<20000n`0009l0002O0@00
b`000000000U0000300000P0080W00006000008000000000HHom0000000U000030000080000k0000
200001/0000@0000W0400;@0001H0000:000000000000000ooooooooool30000W06Y09T1X02D0J00
=P00010000050@00X00005P0000d000000000000003oooooooooo`H000000J00o02Y0?`0]03l0;l0
007800D1b00f0000400009@100380000F00002P00000000000000?oooooooooo0`0009T1b02L0Kl0
W06d03d000080000?00000P0000n000060000:d0000A0000C@4003T0000U0000300000L0080U0000
30000000080X000030000080000U0000300000P0080W00006000008000000000P:Gn0000000U0000
30000080000k0000200001/0000@0000U0400:00001H0000C000000000000000ooooooooool<0000
S`6P08/1Z@2;0K@0R`6o08l1b02D0LP0V@7809`1_`2L0K@0W06Y09T1X02D0J00?@0000P0000l0000
200003h0000H0000?0400140001=0@00>@0002D0000<00001`00P2D0000<00000000P2P0000<0000
0P0005l0000h00000P0003P000000000>000000000000P400@000000000000000000000000000000
9@0000`0000200009@0000`000050020>`0000P0000K0000400009`1002d0000F00002P000000000
00000?oooooooooo0`0009`1Z@2I0J00U06P03H0000@00001@400:00001H0000=000000000000000
ooooooooool60000006P0?`0Z@3l0;@0o02o0001b0050LP0=P000100002D0@00b00005P0000X0000
00000000003oooooooooo`<0002I0LP0W06o09`1]00m0000200003`000080000@00001P0002[0000
3`0004l1000k0000>`0000P0000K0000400009@1002P0000F00003@00000000000000?oooooooooo
1P0008l1X02;0JT0R`6d08/1_`2?0LP0U07803`000080000@00001P0000j0@003`0004L1000k0000
9@0000`000070020:00000`0000200009@0000`000000020AP0001@000080000AdA9@`<0000H0000
30000000008I000030000?ooo`8K000040000000000000004P0000`0000200003000010000000000
000004H0000X0000700004M4BD<20000m`0009l0000:0@00XP000000001O0000>0000080000h0000
000003P00000000000810040000000000000000000000000000002D0000<00000P0002D0000<0000
1@00P5L0000T0000Y`0000l0002k00004`000080003h0:00206P02D0000<00001`00P2P0000<0000
0P0002D0000<00000000P4H0000D0000200004M4BD<300003000010000000000000004H0000X0000
700004M4BD<20000m`000<L0000B0@00bP000000001O0000>0000080000h0000000003P000000000
00810040000000000000000000000000000002D0000<00000P0002D0000<00001@00P5L0000T0000
Y`0003L000330000>`000080003h0<P0407802D0000<00001`00P2P0000<00000P0002D0000<0000
0000P4H0000D0000200004M4BD<300003000010000000000000004H0000X0000700004M4BD<20000
l`000;40003f00001P400000001O0000>0000080000h0000000003P0000000000001004000000000
0000000000000000000002D0000<00000P0002D0000<00001@00P5L0000T0000X`000240002W0000
M`000080003d0;80m0040BD0000<00001`00P2P0000<00000P0002D0000<00000000P4H0000D0000
200004M4BD<300003000010000000000000004H0000X0000700004M4BD<20000o0000;80003o0000
1`400000001O0000>0000080000h0000000003P00000000000010040000000000000000000000000
000002D0000<00000P0002D0000<00001@00P5L0000T0000[0000280002`0000N0000080003m0;<0
o@050BD0000<00001`00P2P0000<00000P0002D0000<00000000P4H0000D0000200004M4BD<30000
3000010000000000000004H0000X0000700004M4BD<20000bP000>X0003e0000m`000000001O0000
>0000080000h0000000003P00000000000010040000000000000000000000000000002D0000<0000
0P0002D0000<00001@00P5L0000T0000NP0005l0002N0000H`000080003;0?00j`3`02D0000<0000
2000P2P0000<00000P0002L0000H00000P00000000000000000002D0000<00000P0005H0000X0000
VP0005`0002U0000I`0000<0003Y0?H0m03`0>T0j`0U0000300000L0080U000030000000080X0000
3000008000160000500000P00017A4U30`0000`0000@00000000000000160000:00001`00017A4U3
0P000?`0003Z00009`400?L000000000G`0003P000020000>0000000000h0000000000000@010000
000000000000000000000000000U000030000080000U0000300000D0081G000090000;@0001O0000
f00006<0000200009@7`00D1l00U0000300000P0080X000030000080000W00006000008000000000
00000000000U000030000080001F0000:0000:l0001L0000^@0006L000030000207[0?h0l0080OH0
9@0000`0000700209@0000`000000020:00000`000020000AP0001@000080000AdA9@`<0000<0000
40000000000000009@0000`0000500209@0000`000080020:`0001P0000I0@00j00004P1000:0@00
9@0000`0000000209@0000`000070020600000`0000000026@0000`0003oool26`00010000000000
00000580001`0@000P000>Soool0000000000000002l0P000000001002910780J@1Q06`000000000
0000000000000000000000000000000000000000000000000000000000000000000B004000000000
J>@B00000020ha800@000040002P0e81P?<E0040000000000000000000000000Y><B02dgm7L00000
P0000>3S4P010000000004Tgm7O0EoMg0P00002000040000`5OgM`10001TMP0800000>T72]`000Y@
f:Rj0;RW^P0=??Ag`5OgMn@am7O0EoMg040002@82U2I<?Ag90P:D>T72]gHZ;X0^:Nj00Y@000<ha80
0003<0002P3`@0<`3`000080002dYkX000000:3S4P0c@0<`]:Nj0000001XYKX0X><B00=50c1E0041
MC`3<6Af00P000009@0000`000020000:00000`000010000600000`0000000026@0000`0003oool2
6`00010000000000000001H0000<000060000180000<00000@0005@0001H0000d`0005X0003^0000
MP00004000000?Y1003j@B8100000@000P0004`00000000000000000003ooooooooooe00001T07P0
3`0000d0000F000030000000000B000030000080000B000030000080000<00004000000000000000
AP0002P0000L0000AdA9@`80002@0@00/0000=81002i0000000005l0000h00000@0003P000000000
>000000000000P400@0000000000000000000000000000009@0000`0000100009@0000`000050020
E`0002@000130@008`0008<1000W00000P0009@1]03@0K@09@0000`000080020:00000`000010000
9`0001P00001000000000000000000009@0000`000010000:P0001P0002B0@00/P0009P1002h0000
9@0000`0000700209@0000`000000020:00000`000010000AP0001@000080000AdA9@`<0000<0000
40000000000000009@0000`0000800209@0000`0000500209@0000`0000=0020:00000`000020000
3P0001@000000000400001@0
\>"], "Graphics",
  ImageSize->{418, 108.563},
  ImageMargins->{{180, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Newton's second law", "Subsection"],

Cell["Newton's second law, reduced to a one-dimensional problem", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newton2 = \[PartialD]\_x\ \[Sigma][x, 
            t] \[Equal] \[Rho]R*\[PartialD]\_\(t, t\)u[x, t]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["\[Sigma]", 
          TagBox[\((1, 0)\),
            Derivative],
          MultilineFunction->None], "[", \(x, t\), "]"}], "==", 
      RowBox[{"\[Rho]R", " ", 
        RowBox[{
          SuperscriptBox["u", 
            TagBox[\((0, 2)\),
              Derivative],
            MultilineFunction->None], "[", \(x, t\), "]"}]}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Strain \[Epsilon]", "Subsection",
  InitializationCell->True],

Cell["\<\
Strain is the first partial derivative of displacement, with respect to the \
position:\
\>", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Epsilon][x_, t_] = \[PartialD]\_x u[x, t]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["u", 
        TagBox[\((1, 0)\),
          Derivative],
        MultilineFunction->None], "[", \(x, t\), "]"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stress \[Sigma]", "Subsection",
  InitializationCell->True],

Cell[TextData[{
  "The following equation is designated as the ",
  StyleBox["first magnetostrictive equation",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  ". It is based on a linear model of magnetostriction. The classical \
stress-strain relationship is extended by a magnetostrictive relation, hence \
the following expression describes an association between mechanical and \
electromagnetic properties of the system::"
}], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\[Sigma][x_, t_] := ER\ \[Epsilon][x, t] - \[Theta]\ B[t]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["With:",
    FontSlant->"Italic"],
  "\n\[Sigma]:\tstress\n\[Epsilon]:\tstrain\nER:\tE-modulus of the \
magnetostrictive rod (under constant magnetic flux)\n\[Theta]:\t\"classical\" \
magnetostrictive constant, unit ",
  Cell[BoxData[
      \(TraditionalForm\`Pascal\/Tesla\)]],
  "\nB:\tMagnetic flux density (SI unit Tesla) in the rod. Please note that B \
is assumed to be constant over the length of the rod. See Chapter xxx for \
details."
}], "Text",
  InitializationCell->True],

Cell[TextData[StyleBox["Verification:",
  FontSlant->"Italic"]], "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Sigma][x2, t2]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{\(\(-\[Theta]\)\ B[t2]\), "+", 
      RowBox[{"ER", " ", 
        RowBox[{
          SuperscriptBox["u", 
            TagBox[\((1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x2, t2\), "]"}]}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential equation for wave propagation", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(newton2\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"ER", " ", 
        RowBox[{
          SuperscriptBox["u", 
            TagBox[\((2, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(x, t\), "]"}]}], "==", 
      RowBox[{"\[Rho]R", " ", 
        RowBox[{
          SuperscriptBox["u", 
            TagBox[\((0, 2)\),
              Derivative],
            MultilineFunction->None], "[", \(x, t\), "]"}]}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution u for displacement in magnetostrictive rod", "Subsection",
  InitializationCell->True],

Cell["\<\
The displacement is assumed to be function of position multiplied by function \
of time:\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(u[x_, t_] := X[x]*T[t]\)], "Input",
  InitializationCell->True],

Cell["Function of time:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(T[t_] := \[ExponentialE]\^\(\[ImaginaryI]\ w\ t\)\)], "Input",
  InitializationCell->True],

Cell[TextData[StyleBox["Verification:",
  FontSlant->"Italic"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[newton2]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\), " ", 
        RowBox[{"(", 
          RowBox[{\(w\^2\ \[Rho]R\ X[x]\), "+", 
            RowBox[{"ER", " ", 
              RowBox[{
                SuperscriptBox["X", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], "==",
       "0"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The term with the magnetic flux density disappered because ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_x\ B\)]],
  "=0 and according to Maxwell div(B)=0"
}], "Text"],

Cell["\<\
The function of position is assumed to be standing wave, the coefficients a1 \
and a2 can be complex (?????????)\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(X[x_] := a1*Cos[K\ x] + a2*Sin[K\ x]\)], "Input",
  InitializationCell->True],

Cell["The wave number K:", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(K = w/cR\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(w\/cR\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["With:",
    FontSlant->"Italic"],
  "\nK:\tWave number.\nw:\tCircular frequency of oscillation.\ncR:\tSound \
velocity in magnetostrictive rod."
}], "Text",
  InitializationCell->True],

Cell[TextData[StyleBox["Verification:",
  FontSlant->"Italic"]], "Text"],

Cell["\<\
Newton's second law (equation \"newton2\") will now be verified with the \
solutions defined for u:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[newton2 /. cR -> \@\(ER/\[Rho]R\)]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Velocity v", "Subsection",
  InitializationCell->True],

Cell["\<\
Velocity is the first derivative of the displacement, with respect to time:\
\>", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(v[x_, t_] = \[PartialD]\_t\ u[x, t]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[ImaginaryI]\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ w\ \((a1\ Cos[\
\(w\ x\)\/cR] + a2\ Sin[\(w\ x\)\/cR])\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Electromagnetic relations (part 1)", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["\<\
Relation between Magnetic Flux Density B and properties of the solenoid\
\>", "Subsubsection",
  InitializationCell->True],

Cell[TextData[{
  "Based on ",
  StyleBox["Faraday's law",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  " the following equation is valid for an ",
  StyleBox["ideal solenoid",
    FontWeight->"Bold"],
  ": "
}], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(B[t_] := 1\/\(\[ImaginaryI]\ w\ N\ A\)*U[t]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["With:",
    FontSlant->"Italic"],
  "\nB:\tMagnetic flux density in the rod.\nN:\tNumber of turns of the \
solenoid\nA:\tCross-sectional area of the solenoid."
}], "Text",
  InitializationCell->True],

Cell["\<\
Please note that the magnetic flux density is related to the voltage, not to \
the current going through the solenoid!\
\>", "Text",
  InitializationCell->True],

Cell["\<\
Actually a constant magnetic field for biassing the magnetostrictive rod is \
excluded from this model. Therefore B and H mean just the alternating \
components.\
\>", "Text",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Voltage drop function", "Subsubsection",
  InitializationCell->True],

Cell["\<\
The voltage drop at the solenoid has to be a sine-shaped function when the \
system is in steady state. Therefore the time function T[t] (former used for \
the displacement) is also used for the voltage. However, there may be a phase \
shift between the displacement and the voltage. \
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(U[t_] := Ud*T[t]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "With:",
  StyleBox["\nUd:\tComplex amplitude of the voltage function.\nT:\t",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`T = \[ExponentialE]\^\(\[Iota]\ w\ t\)\)]]
}], "Text",
  InitializationCell->True,
  FontSlant->"Italic"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Boundary conditions for amplitude coefficients ",
  StyleBox["a1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["a2",
    FontSlant->"Italic"]
}], "Section",
  InitializationCell->True],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000:U80@0006`0003ooooo0`000?T1003:0000
00000000000K?P00oAP00215CDH00040B:T003T400040000000000000000000000@0000300100@00
l0000000000000000000003R1020Z@<02P000100001?0000<04000T0000@0000n`400<`0000D0000
300000d000160000:00001`00017A4U30P0004l0000`0@00B@800?/100000000AP0002P0000L0000
AdA9@`8000270000I`4004<1002C0@00000002D0000<00002000P2L0000H00000@000000001QSod0
000002D0000<00000@0003/0000800006`00010000100@00O04005P0000X000000000000003ooooo
ooooo`<000100G41>`5X0CH1J04f000040000980001X0@00F00003@00000000000000?oooooooooo
1P0008d0J0680741R01l0HP0Q`6=0901TP2@0CH0000@0000=P400901001H0000:000000000000000
ooooooooool30000>`6@0D01Q`500G`1?@0000P0000l0000200003h0000H0000>@0003P0003a0000
H00002D0000<00001`00P2D0000<00000000P2P0000<00000@0002D0000<00002000P2L0000H0000
0@0000000020YOh0000002D0000<00000@0003/0000800006`000100000f0@00J04005P0001<0000
00000000003oooooooooo``0000`0FP1;05a0B`1O04/0HL1<06@0CH1T04k0I01@0670D01O0500G41
>`5X0CH1J04m0000200003`000080000?P0001P0003M0000>0000?40001P00009@0000`000070020
9@0000`000000020:00000`000010000G`0003P000010000>0000000000h0000000000020@010000
000000000000000000000000000U000030000040000U0000300000D0080k0000200001/0000@0000
@04007`1001H0000:000000000000000ooooooooool30000@05a0C/1J04f0FP1=P000100002B0000
J04005P0000d000000000000003oooooooooo`H0002=06P1R01a0HP0O06808L1S@2@0I80T04f0000
400003H1002@0@00F00002P00000000000000?oooooooooo0`0003/1T0500HL1@05l0Cd000080000
?00000P000100000600003L0000f0000l`000680000k0000200001/0000@0000=P4006P1001H0000
=000000000000000ooooooooool60000<05X0B`1L@4/0G`1;0670C01T04f0I01?00000P000100000
60000=/0000f0000j@000680000U0000300000L0080X000030000040000U00003000000008160000
500000P00017A4U30`000580001`0@000@0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000<004000000
0@00004000010000000000000000000000010?ooo`00000P00000000000000000000000000000000
000003DU000000P0000000000000000000000000000100000@000040000100000P00008000000000
00000040000100000000000000010000000000000000004000000000000000400000020U^`E49K/5
[>TB0<joTS2000000@0006Af00P000009@0000`000010000600000`0000000026@0000`0003oool2
6`0001000000000000000580001`0@000P000>Soool0000000000000002l0P000000001002910780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000040000@2G80N08F0040000000000000000000000000
Y><B02dgm7L00000P0000>3S4P010000000004Tgm7O0EoMg0P0000200004000000000000001TMP08
000000000000000000000;`2000700000P000>@am7O0EoMg040002`72TZI<?Ag;0L:BTP92V>lJ;X0
W6Nj00Y:000<ha800003<0002P3`@0<`3`000080002HIkX000000:3S4P0c@0<`V6Nj0000003HI;X0
X><B00=50c2e2@41MC`3<6Af00P000009@0000`000020000:00000`000010000600000`000000002
6@0000`0003oool26`00010000000000000001H0000<000060000180000<00000@0005@0001P0000
N@0003`0002W0000F000004000000?Y1003j@LP000230@000`0004`00000000000000000003ooooo
oooooe@0001B06l0I0000140000?00003`0001H0000<000000000180000<00000P000180000<0000
0P0004H0000X0000700004M4BD<20000C`000:41002:0000/0400000001O0000>0000040000h0000
000003P00000000000810040000000000000000000000000000002D0000<00000@0002D0000<0000
1@00P5L0000T0000ooooogH0000b0000NP000080001@0:P1O`2X0BD0000<00002000P2P0000<0000
0@0002L0000H00000@00000000000000000002D0000<00000@0005H0000X0000;P0007<0000i0000
OP0000<0001m0:h1R02X0Gd0X`4U0000300000L0080U000030000000080X00003000004000160000
500000P00017A4U30`0002L0000H00000@0000000000[P00000002D0000<00000@0002H0000L0000
0`0000000001000000000000008U0000300000<0000[000060000>P1001H0@00B0800:01000U0000
30000000080X000030000040000U0000300000L0080X0000300000<0000H000030000000008I0000
30000?ooo`8K00004000000000000000600000`0000000026@0000`0003oool26`00010000000000
000001H0000<000060000180000<00000@0005@0001D0000_04003`000390@00F000004000000?Y1
003j@@/200230@000@0004`00000000000000000003ooooooooooe00001J00003P0001H0000<0000
00000180000<00000P000580001`0@000`000?3oool0000000000000002l0P000000001002910780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
000B05O[Tc1G1B6S2`8008<100000000000005SQ4P010000<:>j0000040;0P00N>DB05X000000000
0000000000000640K000000000000000000000000000000000000000000000000000000000000000
00000000000001800@00023S4P0;]OAg]@T10NSQ4P3T1000N><B0000003O9Xh`]@T10NSQ4P010000
N><B0=QT^P3`ha8000000000mGLHhQ80I04000000000000000000040000`hQ80SBOdMc@000000000
R5LC0Y1H4`8d0000:00006Af00P000009@0000`000030000:00000`000020000600000`000000002
6@0000`0003oool26`00010000000000000001H0000<000060000180000<00000@0005@0001D0000
bP4004/0003E0@00G@00004000000?Y1003j@AT2002:0@000@0004`00000000000000000003ooooo
oooooe0000130000300001H0000<000000000180000<00000P000180000<00000P0004H0000X0000
700004M4BD<20000A`400:4100220@00/0400000001O0000>0000080000h0000000003P000000000
00810040000000000000000000000000000002D0000<00000P0002D0000<00001@00P5L0000T0000
m`0007H0000Z0@00NP00008000180JP1M`6X0BD0000<00002000P2P0000<00000P0002L0000H0000
0P00000000000000000002D0000<00000P0005H0000X00009P4007<0000a0@00OP0000<0001e0Jh1
P06X0GD1X`4U0000300000L0080U000030000000080X00003000008000160000500000P00017A4U3
0`0004H0000X0000700004M4BD<20000E`0007L1001j0000Z0400000000Q0000200001H0000<0000
000001P0000<0000000001T0000<0000oooo0140000<0000200000/0000@00008@0002l0000<0000
400000T0001800002P00010000000000000000T0000@0000P0400202000U000030000000080U0000
300000L0080H000030000000000B000030000040000I000030000?ooo`0F0000300001P0000:0000
40000000000000002@00010000200@0080800580001`0@000P00023oool0000000000000002@0@00
000000@2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP000000000000000000000000000000
000000000000000000000=cE4P0chYD`GG@00?oo003oo`00K=HB0>cQUC3leA80K=HB01GRUC3Xga80
00000?a/4`9o1ooo803ooooooombaiD`6`3H1@00000S0?oo=?bemSX000000000S=LB05cJ4P0l0000
0000f04100000000000005cJ4P0000001T1:G`Pikomod0I0000000004:09000025hF0;3F4P140502
`0KeM`40001G1B6S30800:l8mGMG1B6S0000020200090000bg3dMeL58J>00@000@000000000<0P00
A01@0P40000lea80Z9SdMeL58J>00@00808006Af00P000009@0000`000020000E00005@0000L0000
HP0002@0001f00000@00003P:d1;bba0h0000>0100010000C00000000000000000000?oooooooooo
D0000340001Y0000DP00070100010000P?koo`00000000000000090100010000108045@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^000000000000000000000000000000000000000000000000026S
0000020200090000bg3dMeL58J>00@000@000000000<0P00A01@0P40000lea80Z9SdMeL58J>00@00
808006Af00P00000000002<0ooldo;Gf>P000000002<ea80G=XB03`00000003H0@40000000000000
G=XB00000006@4YO23W_ogo@1T000000000@X0T00008GQH0/=HB04@0D0;01_Eg0@0005L58J<<0P00
[`SeMeL58J<00000808000T0003;L?AgE`DQXh0100010000000002D00008GQH0h=HB04X9002G3?Eg
0@00000000010000I7H02000000U000030000040000X000030000080001D0000E00000d0001;0000
7@000700000100000>0[@4_;;40^0000P0400040001<00000000000000000000oooooooooom@0000
M@000<H0001B0000L04000800020o_oo0000000000000000T040000000840P0@C@1D0200A@1h07@0
LP1Q000000000000000000000000000000000000000000000000000000000000000000005P1HNQH0
808000T0003;L?AgE`DQXh0100010000000002D00008GQH0h=HB04X9002G3?Eg0@00000000010000
I7H02000000000008`3oocCl]OH001<01000003G4P1LfQ80?00000400=P10@00`=DB043/4`28eQ80
0028MaPfR7OoooooV=HB09BBigL001<0000005Qj5P1:2@YjF7XF0<1GmgL10000E`DQX``2002_2?Eg
I=HB00004`3lf180K1?/MfPTigOooooo0@0004mmm7MHNQH0400000QN5P3DeQ80F7XF0<@7mGO0EoMg
00000040001TMP08000002D0000<00000P0002P0000<00000@0005@0001D00004P0004h0000L0000
KP0000400000h2]0Bl//@6h0001^0@000@0004`00000000000000000003ooooooooooe00000Vl000
P0000580001`0@000@0001000007000000000000002l0P00000000@20Q9D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP0000000000000000000000000000000000000000000000000F09Qe5P3lf180
K1?/MfPTigOooooo0@0004mmm7MHNQH0400000QN5P3DeQ80F7XF0<@7mGO0EoMg00000040001TMP08
00000000000S0?oo=?bemP004`0400000=LB05cJ4P0l00000@00f0410030eA80000008SF4P0008Qg
63J8MooooonHeQ80U9;WM`004`000000V7DF04`92T^HMAH0`5OgM`40001G1B6S30800:l8mGMTeQ80
00000?cH4P1/4nagJ2CWMoooool10000CggdMiQe5P08000025hF0=CF4P2HMAH0a0OeMl1GmgL00000
0@0006Af00P000009@0000`000010000:00000`0000200009@0000`0000700209@0000`000000020
<00000`0000?00209@0000`000030000B`000100000000001@0002P0000<00000@0002D0000<0000
0000P2D0000<00001`00P280000<0000ooooodH0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80001?0@00M`4007D1002X0@0000000240000800005P0000`000000000600000`000000000
6@0000`0003oool04@0000`0000800002`000100000T0000;`0000`0000@00000@4004P0000:0000
40000000000000002@000100002P0@00808002D0000<00000000P2D0000<00001`00P1P0000<0000
00000180000<00000@0001T0000<0000oooo01H0000<0000600000X0000@00000000000000090000
40000:01000P0P00DP000701000100008?ooo`00000000000000090100000000108045@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000000000000000000000000000000001H0
F7XF0?cH4P1/4nagJ2CWMoooool10000CggdMiQe5P08000025hF0=CF4P2HMAH0a0OeMl1GmgL00000
0@0006Af00P00000000002<0ooldo;Gf>P000000002<ea80G=XB03`00001003H0@400<3E4P000000
G=XB0000000H=XQgoooooiSF4P2DT^Mg000C00T00008GQH0/=HB04@0A`C01_Eg0@0005L58J<<0P00
[`SeMeL58J<00000808000T0003;L?AgE`DQXj0100010000000000`2001404L40@0003cG4P2XV?Ag
E`DQXj01000P0P00I7H02000000U000030000040001D0000E00001L1001R00007`4007H000010000
/Q<]@4_;;43i0000h0400040001<00000000000000000000oooooooooom@0000<P0006P0001B0000
L04000800020o_oo0000000000000000T040004000040P0@E01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h00000000000000000000000000000000000000000000000008J<00000808000T0003;L?Ag
E`DQXj0100010000000000`2001404L40@0003cG4P2XV?AgE`DQXj01000P0P00I7H0200000000000
8`3oocCl]OHj0000000008cG4P1LfQ80?00000400=P10@00`=DB0000001LfQ80000001PfR7Oooooo
V=HB09BBigL001<02@0000QN5P2`eQ80A0171<06mGL10000E`DQX``2002_2?EgE`DQX`00000P0P00
2@000<]`m7MG1B6SX0400040000000009@0000QN5P3PeQ80C0T009L<mGL1000000000040001TMP08
000002D0000<00000P0002P0000<00000@0005@0001D00001@4004/0000E0@00L0000040002b4be0
Bl//@2h000200@000@0004`00000000000000000003ooooooooooe00001e0000a0000580001`0@00
0@00083nool0000000000000002@0@0000000P@2011=05@0801507P0M01b06400000000000000000
000000000000000000000000000000000000000000000000000F09Qe5P0P0P002@000<]`m7MG1B6S
X0400040000000009@0000QN5P3PeQ80C0T009L<mGL1000000000040001TMP0800000000000S0?oo
=?bemP004`0400000=LB05cJ4P0l00000@00f0410030eA80000008SF4P0008Qg63J8MooooonHeQ80
U9;WM`004`000000V7DF04`92TfHMAH0`5OgM`40001G1B6S30800:l8mGMTeQ8000000?cH4P1/4nag
J2CWMoooool10000CggdMiQe5P08000025hF0=CF4P2HMAH0a0OeMl1GmgL000000@0006Af00P00000
9@0000`000010000:00000`000020000E00005@0000;0@00CP0001D1001^00000@000;8C;D1;bba0
KP0006h100010000C00000000000000000000?ooooooooooD00002K`001o0000DP00070100020000
400000L00000000000000;`20000000010824U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
0000000000000000000000000000000000000000000001H0F7XF0?cH4P1/4nagJ2CWMoooool10000
CggdMiQe5P08000025hF0=CF4P2HMAH0a0OeMl1GmgL000000@0006Af00P00000000002<0ooldo;Gf
000C00@00000ea80G=XB03`00001003H0@400<3E4P10k1<0R=HB0000R7LH=XQgoooooiSF4P2DT^Mg
000C0000001HNQH0BPT:O5Qj5P30EoMg0@0005L58J<<0P00[`SeMfCF4P0001<0o=PB06`Ck7MX9>Mg
ooooo`40001?OOAgF7XF01000008GQH0e=HB05Qj5P341oEg`5OgM`0000010000I7H02000000U0000
30000080000X000030000040000U0000300000L0080U000030000000080`0000300000l0080U0000
300000<0001;00004000000000050000:00000`0000200009@0000`0000000209@0000`000070020
8P0000`0003oooooAP0001@000080000AdA9@`<000160000:00001`00017A4U30P0005L0000_0@00
O@000601000000008@0000P0000F000030000000000H000030000000000I000030000?ooo`0A0000
300000P0000;0000400002@0000_00003000010000090000000000X0000@00000000000000090000
40000:01000P0P009@0000`0000000209@0000`000070020600000`0000000004P0000`000010000
6@0000`0003oool05P0000`0000H00002P00010000000000000000T0000@0000X0400202001B0000
L0400080000Poooo0000000000000000T040000000040P0@E01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h00000000000000000000000000000000000000000000000005P2HMAH0o=PB06`Ck7MX9>Mg
ooooo`40001?OOAgF7XF01000008GQH0e=HB05Qj5P341oEg`5OgM`0000010000I7H0200000000000
8`3oocCl]OHj0000000008cG4P1LfQ80?00000400=P10@00`=DB0000001LfQ80000001PfR7Oooooo
V=HB09BBigL001<02@0000QN5P2`eQ80A01B0/06mGL10000E`DQX``2002_2?EgE`DQX`00000P0P00
2@000<]`m7MG1B6SX040004000000000308004@0DP810000?=LB0:RHm7MG1B6SX0400202001TMP08
000002D0000<00000P0005@0001D00007`0001X0000W0000;P000040002b4be0Bl//@?l0003P0@00
0@0004`00000000000000000003ooooooooooe00000a0000J0000580001`0@000@00083nool00000
00000000002@0@000@0000@2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP00000000000000
00000000000000000000000000000000000QX`00000P0P002@000<]`m7MG1B6SX040004000000000
308004@0DP810000?=LB0:RHm7MG1B6SX0400202001TMP0800000000000S0?oo=?bemSX000000000
S=LB05cJ4P0l00000@00f0410030eA80000005cJ4P00000063J8MooooonHeQ80U9;WM`004`090000
25hF0;3F4P140582`0KeM`40001G1B6S30800:l8mGMG1B6S0000020200090000bg3dMeL58J>P0@00
0@000000000U000025hF0>3F4P1:2@00U`ceM`40000000000@0006Af00P000009@0000`000010000
:00000`000020000E00005@0000=00000`0002@0000X00000@000;8C;D1;bba0AP00080100010000
C00000000000000000000?ooooooooooD00004H0003L0000DP00070100020000400000L000000000
00000;`20000000010824U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
000000000000000000000000000001H0F7XF020200090000bg3dMeL58J>P0@000@000000000U0000
25hF0>3F4P1:2@00U`ceM`40000000000@0006Af00P00000000002<0ooldo;Gf000C00@00000ea80
G=XB03`00001003H0@400<3E4P10k1<0R=HB0000R7LH=XQgoooooiSF4P2DT^Mg000C0000001HNQH0
BPT:OUQj5P30EoMg0@0005L58J<<0P00[`SeMfCF4P0001<0o=PB06`Ck7MX9>Mgooooo`40001?OOAg
F7XF01000008GQH0e=HB05Qj5P341oEg`5OgM`0000010000I7H02000000U000030000080000X0000
30000040000U0000300000L0080U000030000000080`0000300000l0080U0000300000<0001;0000
4000000000050000:00000`0000200009@0000`0000000209@0000`0000700208P0000`0003ooooo
AP0001@000080000AdA9@`<000160000:00001`00017A4U30P0004L1000_0@00K`4005l100000000
8@0000P0000F000030000000000H000030000000000I000030000?ooo`0A0000300000P0000;0000
400002H0000_000030000100003i0000000000X0000@0000000000000009000040000<01000P0P00
9@0000`0000000209@0000`000070020600000`0000000004P0000`0000100006@0000`0003oool0
5P0000`0000H00002P00010000000000000000T0000@0000`0400202001B0000L0400080000Poooo
0000000000000000T040000000040P0@E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000000000
00000000000000000000000000000000000000005P2HMAH0o=PB06`Ck7MX9>Mgooooo`40001?OOAg
F7XF01000008GQH0e=HB05Qj5P341oEg`5OgM`0000010000I7H02000000000008`3oocCl]OHj0000
000008cG4P1LfQ80?00000400=P10@00`=DB0000001LfQ80000001PfR7OoooooV=HB09BBigL001<0
2@0000QN5P2`eQ80A01C0/06mGL10000E`DQX``2002_2?EgE`DQX`00000P0P002@000<]`m7MG1B6S
`040004000000000308004@0D`810000?=LB0:RHm7MG1B6S`0400202001TMP08000002D0000<0000
0P0005@0001D00004@4001X0000I0@00;P000040002BY2U0Bl//@1P1003P0@000@0004`000000000
00000000003ooooooooooe00000b0000JP000580001`0@000@00083nool0000000000000002@0@00
0@0000@2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP000000000000000000000000000000
0000000000000000000QX`00000P0P002@000<]`m7MG1B6S`040004000000000308004@0D`810000
?=LB0:RHm7MG1B6S`0400202001TMP0800000000000S0?oo=?bemSX000000000S=LB05cJ4P0l0000
0@00f0410030eA80000005cJ4P00000063J8MooooonHeQ80U9;WM`004`09000025hF0;3F4P1405<2
`0KeM`40001G1B6S30800:l8mGMG1B6S0000020200090000bg3dMeL58J?00@000@000000000U0000
25hF0>3F4P1:2@00U`ceM`40000000000@0006Af00P000009@0000`000010000:00000`000020000
E00005@0003m00000`0001@1000X00000@0009:T:D1;bba0AP00080100010000C000000000000000
00000?ooooooooooD00004H0003P0000DP00070100020000400000L00000000000000;`200000000
10824U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^000000000000000000000000000000000000
00000000000001H0F7XF020200090000bg3dMeL58J?00@000@000000000U000025hF0>3F4P1:2@00
U`ceM`40000000000@0006Af00P00000000002<0ooldo;Gf000C00@00000ea80G=XB03`00001003H
0@400<3E4P10k1<0R=HB0000R7LH=XQgoooooiSF4P2DT^Mg000C0000001HNQH0BPT:P5Qj5P30EoMg
0@0005L58J<<0P00[`SeMfCF4P0001<0o=PB06`Ck7MX9>Mgooooo`40001?OOAgF7XF01000008GQH0
e=HB05Qj5P341oEg`5OgM`0000010000I7H02000000U000030000080000X000030000040000U0000
300000L0080U000030000000080`0000300000l0080U0000300000<0001;00004000000000050000
:00000`0000200009@0000`0000000209@0000`0000700208P0000`0003oooooAP0001@000080000
AdA9@`<000160000:00001`00017A4U30P0004L1001I0@00PP4006P100000000G`0003P000020000
>0000000000h0000000000020@010000000000000000000000000000000U000030000080000U0000
300000D0081G000090000?L0000^0000:P40038000020000B05P0GL1H04U0000300000P0080X0000
30000080000W0000600000800000000000000000000U000030000080001F0000:00002H1000[0000
<@4003H000030000M@5V0H01H05e0E/19@0000`0000700209@0000`000000020:00000`000020000
AP0001@000080000AdA9@`<000160000:00001`00017A4U30P0004l0001I0@00RP0006P100000000
G`0003P000020000>0000000000h0000000000020@010000000000000000000000000000000U0000
30000080000U0000300000D0081G0000900000P0000^0000>`00038000020000R01P0ET0H04U0000
300000P0080X000030000080000W0000600000800000000000000000000U000030000080001F0000
:0000040000[00003@0003H000030000G01K0E00H05L06H19@0000`0000700209@0000`000000020
:00000`000020000AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000:L1002Q0@00
hP400;0100000000G`0003P000020000>0000000000h0000000000020@0100000000000000000000
00000000000U000030000080000U0000300000D0081G0000900005L1001f0000RP4007X000020000
Z06X0ML1Z04U0000300000P0080X000030000080000W0000600000800000000000000000000U0000
30000080001F0000:00008H1001c0000T@4007h000030000e@6^0N01Z07E0J<19@0000`000070020
9@0000`000000020:00000`000020000AP0001@000080000AdA9@`<000160000:00001`00017A4U3
0P000:l1001g0@00e@400:P1000000008@0000P0000F000030000000000H000030000000000I0000
30000?ooo`0A0000300000P0000;0000400002@0000_000030000100001Q0@00B00000X0000@0000
000000000009000040000:01000P0P009@0000`0000000209@0000`000070020600000`000000000
4P0000`0000100006@0000`0003oool05P0000`0000H00002P00010000000000000000T0000@0000
X0400202001B0000L0400080000Poooo0000000000000000T040000000040P0@E01Y06d0I@1c0200
CP1U07L0801B06l0K@1Q06h00000000000000000000000000000000000000000000000005P2HMAH0
o=PB06`Ck7MX9>Mgooooo`40001?OOAgF7XF01000008GQH0e=HB05Qj5P341oEg`5OgM`0000010000
I7H02000000000008`3oocCl]OHj0000000008cG4P1LfQ80?00000400=P10@00`=DB0000001LfQ80
000001PfR7OoooooV=HB09BBigL001<02@0000QN5P2`eQ80A01A0/06mGL10000E`DQX``2002_2?Eg
E`DQX`00000P0P002@000<]`m7MG1B6SX040004000000000308004@0D@810000?=LB0:RHm7MG1B6S
X0400202001TMP08000002D0000<00000P0005@0001D0000M`400680001o0@00MP000040002b4be0
Bl//@?T0003P0@000@0004`00000000000000000003ooooooooooe00000b0000J0000580001`0@00
0@00083nool0000000000000002@0@000@0000@2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP0000000000000000000000000000000000000000000000000QX`00000P0P002@000<]`m7MG1B6S
X040004000000000308004@0D@810000?=LB0:RHm7MG1B6SX0400202001TMP0800000000000S0?oo
=?bemSX000000000S=LB05cJ4P0l00000@00f0410030eA80000005cJ4P00000063J8MooooonHeQ80
U9;WM`004`09000025hF0;3F4P140542`0KeM`40001G1B6S30800:l8mGMG1B6S0000020200090000
bg3dMeL58J>P0@000@000000000U000025hF0>3F4P1:2@00U`ceM`40000000000@0006Af00P00000
9@0000`000010000:00000`000020000E00005@0001U0@00B`0007D1001`00000@000;8C;D1;bba0
;P00080100010000C00000000000000000000?ooooooooooD00007D000340000DP00070100020000
P?koo`00000000000000090100000002108044d0E00P04D0N01d0780H@0000000000000000000000
0000000000000000000000000000000000000000000001H0F7XF020200090000bg3dMeL58J>P0@00
0@000000000U000025hF0>3F4P1:2@00U`ceM`40000000000@0006Af00P00000000002<0ooldo;Gf
000C00@00000ea80G=XB03`00001003H0@400<3E4P10k1<0R=HB0000R7LH=XQgoooooiSF4P2DT^Mg
000C0000001HNQH0BPT:PUQj5P30EoMg0@0005L58J<<0P00[`SeMfCF4P0001<0o=PB06`Ck7MX9>Mg
ooooo`40001?OOAgF7XF01000008GQH0e=HB05Qj5P341oEg`5OgM`0000010000I7H02000000U0000
30000080000X000030000040001D0000E00006/1001>0000M@4006h000010000/Q<]@4_;;41^0000
KP400040001<00000000000000000000oooooooooom@00009_0007l0001B0000L0400040000@0000
1`00000000000000_080000000040P8BE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000000000
00000000000000000000000000000000000000005P2HMAH0o=PB06`Ck7MX9>Mgooooo`40001?OOAg
F7XF01000008GQH0e=HB05Qj5P341oEg`5OgM`0000010000I7H02000000000008`3oocCl]OH001<0
1000003G4P1LfQ80?00000400=P10@00`=DB00000028eQ800028MaPfR7OoooooV=HB09BBigL001<0
000009Qe5P1<2@YAV7DF0<1GmgL10000E`DQX``2002_2?EgI=HB0000003lf180K1?/MfPTigOooooo
0@0004mmm7NHMAH0200000QN5P3DeQ80V7DF0<@7mGO0EoMg00000040001TMP08000002D0000<0000
0@0002P0000<00000P0002D0000<00001`00P2D0000<00000000P300000<00003`00P2D0000<0000
0`0004/0000@0000000000D0000X000030000040000U000030000000080U0000300000L0080R0000
30000?oooom60000500000P00017A4U30`0004H0000X0000700004M4BD<20000[`4002l1003G0@00
G`400000000Q0000200001H0000<0000000001P0000<0000000001T0000<0000oooo0140000<0000
200000/0000@00009P0002l0000<000040000641000000002P00010000000000000000T0000@0000
`0400202000U000030000000080U0000300000L0080H000030000000000B000030000040000I0000
30000?ooo`0F0000300001P0000:000040000000000000002@00010000300@0080800580001`0@00
0@00023oool0000000000000002@0@00000000@2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP0000000000000000000000000000000000000000000000000F05Qj5P3lf180K1?/MfPTigOooooo
0@0004mmm7NHMAH0200000QN5P3DeQ80V7DF0<@7mGO0EoMg00000040001TMP0800000000000S0?oo
=?bemSX000000000S=LB05cJ4P0l00000@00f0410030eA80000005cJ4P00000063J8MooooonHeQ80
U9;WM`004`09000025hF0;3F4P1405<2`0KeM`40001G1B6S30800:l8mGMG1B6S0000020200090000
bg3dMeL58J?00@000@000000000<0P00A01C0P40000lea80Z9SdMeL58J?00@00808006Af00P00000
9@0000`000010000E00005@0001i0@006P000841000^00000@0009:T:D1;bba060400>0100010000
C00000000000000000000?ooooooooooD0000380001Z0000DP00070100020000P?koo`0000000000
0000090100010000108045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
0000000000000000000000000000026S0000020200090000bg3dMeL58J?00@000@000000000<0P00
A01C0P40000lea80Z9SdMeL58J?00@00808006Af00P00000000002<0ooldo;Gf>P000000002<ea80
G=XB03`00001003H0@400<3E4P000000G=XB0000000H=XQgoooooiSF4P2DT^Mg000C00T00008GQH0
/=HB04@0D`;01_Eg0@0005L58J<<0P00[`SeMeL58J<00000808000T0003;L?AgE`DQXl0100010000
000002D00008GQH0h=HB04`9002G3?Eg0@00000000010000I7H02000000U000030000080000X0000
30000040001D0000E00006D100030000O04002P000010000TZ@Y@4_;;4160000P0400040001<0000
0000000000000000oooooooooom@0000AP000>00001B0000L0400040000@00001`00000000000000
_080000000040P8BE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0000000000000000000000000
0000000000000000000000005P2HMAH0808000T0003;L?AgE`DQXl0100010000000002D00008GQH0
h=HB04`9002G3?Eg0@00000000010000I7H02000000000008`3oocCl]OH001<01000003G4P1LfQ80
?00000400=P10@00`=DB00000028eQ800028MaPfR7OoooooV=HB09BBigL001<0000009Qe5P1<2@YC
V7DF0<1GmgL10000E`DQX``2002_2?EgI=HB0000003lf180K1?/MfPTigOooooo0@0004mmm7NHMAH0
200000QN5P3DeQ80V7DF0<@7mGO0EoMg00000040001TMP08000002D0000<00000@0002P0000<0000
0P0002D0000<00001`00P2D0000<00000000P300000<00003`00P2D0000<00000`0004/0000@0000
000000D0000X000030000040000U000030000000080U0000300000L0080R000030000?oooom60000
500000P00017A4U30`0004H0000X0000700004M4BD<20000Y`4005T1003R0@00J0400000001O0000
>0000040000h0000000003P00000000000810040000000000000000000000000000002D0000<0000
0@0002D0000<00001@00P5L0000T0000H04002h0002C0@00<P000080003P0F01/@5P0BD0000<0000
2000P2P0000<00000@0002L0000H00000@00000000000000000002D0000<00000@0005H0000X0000
F@4002/0001U0@00=P0000<0002d0E/1Z05P0K@1IP4U0000300000L0080U000030000000080X0000
3000004000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000S`0009l1002B0000
dP400000001O0000>0000040000h0000000003P00000000000810040000000000000000000000000
000002D0000<00000@0002D0000<00001@00P5L0000T0000?`0006h000130000XP000080002@0:01
T03@0BD0000<00001`00P2P0000<00000@0002D0000<00000000P4H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80000e0@00W`4003P1003B0@00000005l0000h00000@0003P000000000
>000000000000P400@0000000000000000000000000000009@0000`0000100009@0000`000050020
E`0002@0003U0000KP000>T0002R00000P0003H1X04f0M019@0000`000070020:00000`000010000
9@0000`000000020AP0001@000080000AdA9@`<000160000:00001`00017A4U30P0008L0003?0@00
eP000?L1000000008@0000P0000F000030000000000H000030000000000I000030000?ooo`0A0000
300000P0000;0000400004d0000W000030000100000i0000X00000X0000@00000000000000090000
4000080300300@009@0000`0000000209@0000`000070020600000`0000000004P0000`000010000
6@0000`0003oool05P0000`0000H00002P00010000000000000000T0000@0000P0<00<01001B0000
L04000400020o_oo0000000000000000T040000000040P0@E01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h00000000000000000000000000000000000000000000000005P1HNQH0o=PB00004`1X9>Mg
ooooo`480000OOAgV7DF004H0008GQH0e=HB09Qe5P341oEg`5OgM`000018?QP0F9hH062N6000@000
2<000;3D4P0j0000000008cG4P1LfQ80?000005IR7L10@00`=DB0000001LfQ80000001PfR7Oooooo
V=HB09BBigL001<02@0000QN5P2`eQ80A01I1<06mGL10000E`DQX``2002_2?EgE`DQX`0000300@00
2@000<]`m7MG1B6SP0<0004000000000308004@0F@@10000?=LB0:RHm7MG1B6SP0<00<01001TMP08
000002D0000<00000@0005@0001D0000L0000:8000200000aP0000400000h2]0KQ/^@7X2001P0@00
0@0004`00000000000000000003ooooooooooe00000`0000aP000580001`0@000P00083nool00000
00000000002@0@0000000P@2011C07T0K@1R06l0K000000000000000000000000000000000000000
00000000000000000000000000000000000QX`0000300@002@000<]`m7MG1B6SP0<0004000000000
308004@0F@@10000?=LB0:RHm7MG1B6SP0<00<01001TMP08000000100008`000/=@B03X000000000
S=LB05cJ4P0l00000EV8M`410030eA80000005cJ4P00000063J8MooooonHeQ80U9;WM`004`090000
25hF0;3F4P1405T4`0KeM`40001G1B6S30800:l8mGMG1B6S00000<0100090000bg3dMeL58J>00`00
0@000000000U000025hF0>3F4P0/1`00U`ceM`40000000000@0006Af00P000009@0000`000020000
:00000`000010000E00005@0001F0000WP0006L0003500000@00003P:d1^6bi0E040060100010000
C00000000000000000000?ooooooooooD00003g`003A0000DP00070100010000P?koo`0000000000
0000090100010000108045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
000000000000000000000000000001H0V7DF0<0100090000bg3dMeL58J>00`000@000000000U0000
25hF0>3F4P0/1`00U`ceM`40000000000@0006Af00P00000040000S0002`e180000C00@00000ea80
G=XB03`00001FHQg0@400<3E4P000000R=HB0000R7LH=XQgoooooiSF4P2DT^Mg000C0000002HMAH0
;0L:FIQe5P30EoMg0@0005L58J<<0P00[`SeMfCF4P000000o=PB06`Ck7MX9>Mgooooo`40001?OOAg
V7DF00P00008GQH0e=HB09Qe5P341oEg`5OgM`0000010000I7H02000000U000030000040000X0000
30000080001D0000E00003l0002Q0000CP000<H0000100000>0[@6hK;T1<0000H0400040001<0000
0000000000000000oooooooooom@0000N0000:l0001B0000L0400080000@00001`00000000000000
_080000000040P8BE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0000000000000000000000000
0000000000000000000000005P1HNQH0o=PB06`Ck7MX9>Mgooooo`40001?OOAgV7DF00P00008GQH0
e=HB09Qe5P341oEg`5OgM`0000010000I7H020000000@0002<000;3D4P0001<01000003G4P1LfQ80
?000005IR7L10@00`=DB00000028eQ800028MaPfR7OoooooV=HB09BBigL001<0000005Qj5P2:1@XK
F7XF0<1GmgL10000E`DQX``2002_2?EgI=HB0000003lf180K1?/MfPTigOooooo0@0004mmm7MHNQH0
400000QN5P3DeQ80F7XF0<@7mGO0EoMg00000040001TMP08000002D0000<00000P0002P0000<0000
0@0002D0000<00001`00P2D0000<00000000P300000<00003`00P2D0000<00000`0004/0000@0000
000000D0000X000030000080000U000030000000080U0000300000L0080R000030000?oooom60000
500000P00017A4U30`0004H0000X0000700004M4BD<20000:@400</1001n0@00o0400000000Q0000
200001H0000<0000000001P0000<0000000001T0000<0000oooo0140000<0000200000/0000@0000
D`0002l0000<000040000=/0002L00002P00010000000000000000T0000@0000`0<00202000U0000
30000000080U0000300000L0080H000030000000000B000030000040000I000030000?ooo`0F0000
300001P0000:000040000000000000002@00010000300`0080800580001`0@000P00023oool00000
00000000002@0@000@0000@2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP00000000000000
00000000000000000000000000000000000F09Qe5P3lf180K1?/MfPTigOooooo0@0004mmm7MHNQH0
400000QN5P3DeQ80F7XF0<@7mGO0EoMg00000040001TMP08000000100008`000/=@B03X000000000
S=LB05cJ4P0l00000EV8M`410030eA80000005cJ4P00000063J8MooooonHeQ80U9;WM`004`090000
25hF0;3F4P140=d4`0KeM`40001G1B6S30800:l8mGMG1B6S0000020200090000bg3dMeL58J?00`00
0@000000000<0P00A03M1040000lea80Z9SdMeL58J?00`00808006Af00P000009@0000`000020000
E00005@0000K0@00]P0002L1003:00000@000:_Z;41;bba0j`800>0100010000C000000000000000
00000?ooooooooooD0000580002;0000DP00070100010000P?koo`00000000000000090100010000
108045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^000000000000000000000000000000000000
000000000000026S0000020200090000bg3dMeL58J?00`000@000000000<0P00A03M1040000lea80
Z9SdMeL58J?00`00808006Af00P00000040000S0002`e180>P000000002<ea80G=XB03`00001FHQg
0@400<3E4P000000G=XB0000000H=XQgoooooiSF4P2DT^Mg000C00T00008GQH0/=HB04@0g@C01_Eg
0@0005L58J<<0P00[`SeMeL58J<00000808000T0003;L?AgE`DQXl0300010000000002D00008GQH0
h=HB08X5002G3?Eg0@00000000010000I7H02000000U000030000040000X000030000080001D0000
E0000141002O00006@400<@000010000ZnX/@4_;;41d0P00P0400040001<00000000000000000000
oooooooooom@0000K00006P0001D0000E0000>40002O0000l0000<@000010000ZnX/@4_;;41<0000
P0400040001<00000000000000000000oooooooooom@0000N0000:d0001B0000L04000800020o_oo
0000000000000000T040000000840P0@D`1i06d0HP1_06`000000000000000000000000000000000
00000000000000000000000000000000000000005P1HNQH0808000T0003;L?AgE`DQXl0300010000
000002D00008GQH0h=HB08X5002G3?Eg0@00000000010000I7H020000000@0002<000;3D4P0001<0
1000003G4P1LfQ80?000005IR7L10@00`=DB00000028eQ800028MaPfR7OoooooV=HB09BBigL001<0
000005Qj5P2:1@XMF7XF0<1GmgL10000E`DQX``2002_2?EgI=HB0000003lf180K1?/MfPTigOooooo
0@0004mmm7MHNQH0400000QN5P3DeQ80F7XF0<@7mGO0EoMg00000040001TMP08000002D0000<0000
0P0002P0000<00000@0005@0001D0000n00009`000090@00``000040002[jRa0Bl//@5@100200@00
0@0004`00000000000000000003ooooooooooe00000ml000d0000580001`0@000@00010000070000
00000000002l0P00000000@20Q9D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP00000000000000
00000000000000000000000000000000000F09Qe5P3lf180K1?/MfPTigOooooo0@0004mmm7MHNQH0
400000QN5P3DeQ80F7XF0<@7mGO0EoMg00000040001TMP08000000100008`000/=@B00004`040000
0=LB05cJ4P0l00000EV8M`410030eA80000008SF4P0008Qg63J8MooooonHeQ80U9;WM`004`000000
V7DF02`72U^HMAH0`5OgM`40001G1B6S30800:l8mGMTeQ8000000?cH4P1/4nagJ2CWMoooool10000
CggdMiQe5P08000025hF0=CF4P2HMAH0a0OeMl1GmgL000000@0006Af00P000009@0000`000010000
:00000`0000200009@0000`0000700209@0000`000000020<00000`0000?00209@0000`000030000
B`000100000000001@0002P0000<00000@0002D0000<00000000P2D0000<00001`00P280000<0000
ooooodH0000D0000200004M4BD<300003000010000000000000004H0000X0000700004M4BD<20000
Q`0006L100130@00T`400000000U0000300000P0080W00006000004000000000HHom0000000U0000
30000040000k0000200001/0000@0000@04007`1001H0000:000000000000000ooooooooool30000
@05a0C/1J04f0FP1=P000100002B0000J04005P0000d000000000000003oooooooooo`H0002=06P1
R01a0HP0O06808L1S@2@0I80T04f0000400003H1002@0@00F00002P00000000000000?oooooooooo
0`0003/1T0500HL1@05l0Cd000080000?00000P0000n0000600003T0000h0000l@000600000U0000
300000L0080U000030000000080X000030000040000U0000300000P0080W00006000004000000000
P:Gn0000000U000030000040000k0000200001/0000@0000=P4006P1001H0000C000000000000000
ooooooooool<0000<05X0B`1L@4/0G`1;0670C01T04f0I01>`6@0D01Q`500G`1@05a0C/1J04f0FP1
?@0000P0000l0000200003h0000H0000g@0003P0003a0000H00002D0000<00001`00P2D0000<0000
0000P2P0000<00000@0005l0000h00000@0003P000000000>000000000000P400@00000000000000
00000000000000009@0000`0000100009@0000`000050020>`0000P0000K000040000401001l0@00
F00002P00000000000000?oooooooooo0`000401L@4k0FP1=P5X0CH0000@0000TP0006P1001H0000
=000000000000000ooooooooool60000S@1X0HP0L@6807`1R0270Hd0T06B0901=P000100000f0@00
T04005P0000X000000000000003oooooooooo`<0000k0I01@0670D01O04m0000200003`000080000
@00001P0000g0000=P000?<0001R0000>`0000P0000K0000400003H1001X0@00F00003@000000000
00000?oooooooooo1P000301J04/0G41;05l0B`1Q`4`0I01=P6@0C`000080000@00001P0003K0000
=P000>T0001R00009@0000`000070020:00000`0000100009@0000`000000020AP0001@000080000
AdA9@`<0000H000030000000008I000030000?ooo`8K00004000000000000000DP00070100010000
j?ooo`000000000000000;`20000000004008T40LP1Y0640K0000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0@000109LP1h0QH00@0000000000000000000000002Tha80;COdM`0000200000h><B004000000000
BCOdMl1GmgL20000080000@00030EoMg040006Af00P00000B0T:I@002UnlJ;X0W6Nj00YU003PhQ80
i37dMl1GmgL0@000;0L:GiT`m7L/1`YOB0T:I[aX^P2LIkX02Ul000cS4P0000<`000:0?100c0?0000
0P0009QW^P000000X><B03=00c2HIkX0000004aU^P2Pha800dD3<;D90@5e?0<`I7H02000000U0000
30000040000X0000300000<0000H000030000000008I000030000?ooo`8K00004000000000000000
5P0000`0000H00004P0000`000010000E0000600001i0000?0000:L0001H00000@000000nT400?Y1
b00008<100030000C00000000000000000000?ooooooooooE0000580K`1T00004@0000l0000?0000
5P0000`0000000004P0000`0000200004P0000`0000200003000010000000000000004H0000X0000
700004M4BD<20000C`000:41002:0000/0400000001O0000>00000<0000h0000000003P000000000
00810040000000000000000000000000000002D0000<00000`0002D0000<00001@00P5L0000T0000
ooooogH0000b0000NP000080001@0:P1O`2X0BD0000<00002000P2P0000<00000`0002L0000H0000
0`00000000000000000002D0000<00000`0005H0000X0000;P0007<0000i0000OP0000<0001m0:h1
R02X0Gd0X`4U0000300000L0080U000030000000080X0000300000<000160000500000P00017A4U3
0`0000`0000@000000000000000W0000600000<0000000000:h00000000U0000300000<0000V0000
70000080000000000@000000000000029@0000`000020000:`0001P0003X0@00F04004P2002P0@00
9@0000`000000020:00000`0000300009@0000`000070020:00000`000020000600000`000000002
6@0000`0003oool26`00010000000000000001P0000<000000000QT0000<0000oooo0Q/0000@0000
00000000000F0000300001P0000B000030000040001D0000E0000;`1000l0000b@4005P000010000
003j@@00nT4;0P00P`400040001<00000000000000000000oooooooooom@0000FP0000h0000F0000
30000000000B000030000080001B0000L0400080003`oooo0000000000000000_08000000000@00R
@@1b06T0H@1/00000000000000000000000000000000000000000000000000000000000000000000
000000004P1Gji<`E`DQX`/200230@0000000000001HhA800@00032S^P0000102`8007SU4P1J0000
0000000000000000001Q06`000000000000000000000000000000000000000000000000000000000
0000000000000000000B0040000Pha802kGdMkD90@7XhA80i0@007SS4P000000gbJ><;D90@7XhA80
0@0007SS4P1<IKX0l><B000000000?Eg6>8B06@1000000000000000000010000<>8B08dWm7Ld0000
000008QG4`:@F1<2=00002P0001TMP08000002D0000<00000P0002P0000<00000@0001P0000<0000
00000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B000030000040001D0000
E0000<X1001;0000e@4005d000010000003j@@00nT4I0P00RP400040001<00000000000000000000
oooooooooom@0000@`0000`0000F000030000000000B000030000080000B000030000080000<0000
4000000000000000AP0002P0000L0000AdA9@`8000170@00X@400881002`0@00000005l0000h0000
0@0003P000000000>000000000000P400@0000000000000000000000000000009@0000`000010000
9@0000`000050020E`0002@0003g0000MP0002X1001j00000P0004P1Z05g0JP19@0000`000080020
:00000`0000100009`0001P00001000000000000000000009@0000`000010000EP0002P0000V0@00
L`000341001n00000`0007D1[P600JP1M@6S0BD0000<00001`00P2D0000<00000000P2P0000<0000
0@0004H0000D0000200004M4BD<300003000010000000000000004H0000X0000700004M4BD<20000
E`0007L1001j0000Z0400000000Q0000200001H0000<0000000001P0000<0000000001T0000<0000
oooo0140000<0000200000/0000@00008@0002l0000<0000400000T0001800002P00010000000000
000000T0000@0000P0400202000U000030000000080U0000300000L0080H000030000000000B0000
30000040000I000030000?ooo`0F0000300001P0000:000040000000000000002@00010000200@00
80800580001`0@000@00023oool0000000000000002@0@00000000@2011D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP0000000000000000000000000000000000000000000000000F05Qj5P3lf180
K1?/MfPTigOooooo0@0004mmm7NHMAH0200000QN5P3DeQ80V7DF0<@7mGO0EoMg00000040001TMP08
000000100008`000/=@B03X000000000S=LB05cJ4P0l00000EV8M`410030eA80000005cJ4P000000
63J8MooooonHeQ80U9;WM`004`09000025hF0;3F4P140502`0KeM`40001G1B6S30800:l8mGMG1B6S
0000020200090000bg3dMeL58J>00@000@000000000<0P00A01@0P40000lea80Z9SdMeL58J>00@00
808006Af00P000009@0000`000010000E00005@0000L0000HP0002@0001f00000@00003P:d1;bba0
h0000>0100010000C00000000000000000000?ooooooooooD0000340001Y0000DP00070100030000
P?koo`00000000000000090100010000108045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
00000000000000000000000000000000000000000000026S0000020200090000bg3dMeL58J>00@00
0@000000000<0P00A01@0P40000lea80Z9SdMeL58J>00@00808006Af00P00000040000S0002`e180
>P000000002<ea80G=XB03`00001FHQg0@400<3E4P000000G=XB0000000H=XQgoooooiSF4P2DT^Mg
000C00T00008GQH0/=HB04@0D0;01_Eg0@0005L58J<<0P00[`SeMeL58J<00000808000T0003;L?Ag
E`DQXh0100010000000002D00008GQH0h=HB04L9002G3?Eg0@00000000010000I7H02000000U0000
300000<0000X000030000040001D0000E00000d0001;00007@000700000100000>0[@4_;;40^0000
P0400040001<00000000000000000000oooooooooom@0000M@000<H0001B0000L04000400020o_oo
0000000000000000T040000000840P0@C@1D0200A@1h07@0LP1Q0000000000000000000000000000
00000000000000000000000000000000000000005P2HMAH0808000T0003;L?AgE`DQXh0100010000
000002D00008GQH0h=HB04L9002G3?Eg0@00000000010000I7H020000000@0002<000;3D4P0001<0
1000003G4P1LfQ80?000005IR7L10@00`=DB00000028eQ800028MaPfR7OoooooV=HB09BBigL001<0
000009Qe5P172@X]V7DF0<1GmgL10000E`DQX``2002_2?EgI=HB0000003lf180K1?/MfPTigOooooo
0@0004mmm7NHMAH0200000QN5P3DeQ80V7DF0<@7mGO0EoMg00000040001TMP08000002D0000<0000
0@0002P0000<00000`0005@0001D00004P0004h0000L0000KP0000400000h2]0Bl//@6h0001^0@00
0@0004`00000000000000000003ooooooooooe00000Vl000P0000580001`0@000`00010000070000
00000000002l0P00000000@20Q9D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP00000000000000
00000000000000000000000000000000000Z0[P?:P;lf180K1?/MfPTigOooooo0@0004mmm7NHMAH0
200000QN5P3DeQ80V7DF0<@7mGO0EoMg00000040001TMP08000000100008`000/=@B00004`040000
0=LB05cJ4P0l00000EV8M`410030eA80000008SF4P0008Qg63J8MooooonHeQ80U9;WM`004`000000
^0lZ0XX52Qnh3bX2`5OgM`40001G1B6S30800:l8mGMTeQ8000000?cH4P1/4nagJ2CWMoooool10000
CggdMkP?:P8H000025hF0=CF4P2h3bX2a0OeMl1GmgL000000@0006Af00P000009@0000`000030000
:00000`0000100009@0000`0000700209@0000`000000020<00000`0000?00209@0000`000020000
B`000100000000001@0002P0000<00000`0002D0000<00000000P2D0000<00001`00P280000<0000
ooooodH0000D0000200004M4BD<300003000010000000000000004H0000X0000700004M4BD<20000
C`4007L1001e0@00Z0400000000Q0000200001H0000<0000000001P0000<0000000001T0000<0000
oooo0140000<0000200000/0000@0000900002l0000<000040000041001800002P00010000000000
000000T0000@0000X0400202000U000030000000080U0000300000L0080H000030000000000B0000
30000040000I000030000?ooo`0F0000300001P0000:000040000000000000002@000100002P0@00
80800580001`0@000`00023oool0000000000000002@0@00000000@2011D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP0000000000000000000000000000000000000000000000000F09Qe5P3lf180
K1?/MfPTigOooooo0@0004mmm7Nh3bX2600000QN5P3DeQ80^0lZ0/@7mGO0EoMg00000040001TMP08
000000100008`000/=@B03X000000000S=LB05cJ4P0l00000EV8M`410030eA80000005cJ4P000000
63J8MooooonHeQ80U9;WM`004`09000025hF0;3F4P1404L4`0KeM`40001G1B6S30800:l8mGMG1B6S
0000020200090000bg3dMeL58J>P0@000@000000000<0P00A0171040000lea80Z9SdMeL58J>P0@00
808006Af00P000009@0000`000030000E00005@0000G0@00HP0001l1001f00000@000;8C;D1;bba0
n@000>0100010000C00000000000000000000?ooooooooooD0000380001X0000DP00070100010000
P?koo`00000000000000090100010000108045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
00000000000000000000000000000000000000000000026S0000020200090000bg3dMeL58J>P0@00
0@000000000<0P00A0171040000lea80Z9SdMeL58J>P0@00808006Af00P00000040000S0002`e180
>P000000002<ea80G=XB03`00001FHQg0@400<3E4P000000G=XB0000000H=XQgoooooiSF4P2DT^Mg
000C00T00008GQH0/=HB04@0A`C01_Eg0@0005L58J<<0P00[`SeMeL58J<00000808000T0003;L?Ag
E`DQXj0100010000000002D00008GQH0h=HB08X5002G3?Eg0@00000000010000I7H02000000U0000
30000040000X0000300000<0001D0000E00000D1001;00005@40070000010000/Q<]@4_;;40^0000
P0400040001<00000000000000000000oooooooooom@0000M@000<@0001B0000L04000<00020o_oo
0000000000000000T040000000840P0@C@1D0200A@1h07@0LP1Q0000000000000000000000000000
0000000000000000000000000000000000000000:P:h3bX2808000T0003;L?AgE`DQXj0100010000
000002D00008GQH0h=HB08X5002G3?Eg0@00000000010000I7H020000000@0002<000;3D4P0001<0
1000003G4P1LfQ80?000005IR7L10@00`=DB00000028eQ800028MaPfR7OoooooV=HB09BBigL001<0
00000;P?:P::1@XQ^0lZ0/1GmgL10000E`DQX``2002_2?EgI=HB0000003lf180K1?/MfPTigOooooo
0@0004mmm7Nh3bX2600000QN5P3DeQ80^0lZ0/@7mGO0EoMg00000040001TMP08000002D0000<0000
0`0002P0000<00000@0005@0001D00002`4004h0000E0@00KP000040002b4be0Bl//@6h0001^0@00
0@0004`00000000000000000003ooooooooooe00000Vl000O`000580001`0@000@00010000070000
00000000002l0P00000000@20Q9D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP00000000000000
00000000000000000000000000000000000F09Qe5P3lf180K1?/MfPTigOooooo0@0004mmm7Nh3bX2
600000QN5P3DeQ80^0lZ0/@7mGO0EoMg00000040001TMP08000000100008`000/=@B00004`040000
0=LB05cJ4P0l00000EV8M`410030eA80000008SF4P0008Qg63J8MooooonHeQ80U9;WM`004`000000
V7DF04L92RnHMAH0`5OgM`40001G1B6S30800:l8mGMTeQ8000000?cH4P1/4nagJ2CWMoooool10000
CggdMiQe5P08000025hF0=CF4P2HMAH0a0OeMl1GmgL000000@0006Af00P000009@0000`000010000
:00000`0000300009@0000`0000700209@0000`000000020<00000`0000?00209@0000`000020000
B`000100000000001@0002P0000<00000@0002D0000<00000000P2D0000<00001`00P280000<0000
ooooodH0000D0000200004M4BD<300003000010000000000000004H0000X0000700004M4BD<20000
E`0002l1001m0000H0400000000Q0000200001H0000<0000000001P0000<0000000001T0000<0000
oooo0140000<0000200000/0000@0000900002l0000<0000400000T0000000002P00010000000000
000000T0000@0000X0400202000U000030000000080U0000300000L0080H000030000000000B0000
30000040000I000030000?ooo`0F0000300001P0000:000040000000000000002@000100002P0@00
80800580001`0@000@00023oool0000000000000002@0@00000000@2011D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP0000000000000000000000000000000000000000000000000Z0[P?:P;lf180
K1?/MfPTigOooooo0@0004mmm7NHMAH0200000QN5P3DeQ80V7DF0<@7mGO0EoMg00000040001TMP08
000000100008`000/=@B03X000000000S=LB05cJ4P0l00000EV8M`410030eA80000005cJ4P000000
63J8MooooonHeQ80U9;WM`004`09000025hF0;3F4P140582`0KeM`40001G1B6S30800:l8mGMG1B6S
0000020200090000bg3dMeL58J>P0@000@000000000<0P00A01B0P40000lea80Z9SdMeL58J>P0@00
808006Af00P000009@0000`000010000E00005@0000O00006P0002L0000^00000@000;8C;D1;bba0
o`000>0100010000C00000000000000000000?ooooooooooD0000340001X0000DP00070100030000
P?koo`00000000000000090100010000108045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
00000000000000000000000000000000000000000000026S0000020200090000bg3dMeL58J>P0@00
0@000000000<0P00A01B0P40000lea80Z9SdMeL58J>P0@00808006Af00P00000040000S0002`e180
>P000000002<ea80G=XB03`00001FHQg0@400<3E4P000000G=XB0000000H=XQgoooooiSF4P2DT^Mg
000C00T00008GQH0/=HB04@0DP;01_Eg0@0005L58J<<0P00[`SeMeL58J<00000808000T0003;L?Ag
E`DQXj0100010000000002D00008GQH0h=HB04L9002G3?Eg0@00000000010000I7H02000000U0000
300000<0000X000030000040001D0000E00000d000030000900002P000010000/Q<]@4_;;4160000
P0400040001<00000000000000000000oooooooooom@0000AP000=`0001B0000L0400040000@0000
1`00000000000000_080000000040P8BE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000000000
00000000000000000000000000000000000000005P2HMAH0808000T0003;L?AgE`DQXj0100010000
000002D00008GQH0h=HB04L9002G3?Eg0@00000000010000I7H020000000@0002<000;3D4P0001<0
1000003G4P1LfQ80?000005IR7L10@00`=DB00000028eQ800028MaPfR7OoooooV=HB09BBigL001<0
000009Qe5P172@XaV7DF0<1GmgL10000E`DQX``2002_2?EgI=HB0000003lf180K1?/MfPTigOooooo
0@0004mmm7NHMAH0200000QN5P3DeQ80V7DF0<@7mGO0EoMg00000040001TMP08000002D0000<0000
0@0002P0000<00000`0002D0000<00001`00P2D0000<00000000P300000<00003`00P2D0000<0000
0P0004/0000@0000000000D0000X000030000040000U000030000000080U0000300000L0080R0000
30000?oooom60000500000P00017A4U30`0000`0000@00000000000000160000:00001`00017A4U3
0P0004L1000_0@00K`4005l1000000008@0000P0000F000030000000000H000030000000000I0000
30000?ooo`0A0000300000P0000;0000400002H0000_000030000100003i0000000000X0000@0000
000000000009000040000<01000P0P009@0000`0000000209@0000`000070020600000`000000000
4P0000`0000100006@0000`0003oool05P0000`0000H00002P00010000000000000000T0000@0000
`0400202001B0000L0400040000Poooo0000000000000000T040000000040P0@E01Y06d0I@1c0200
CP1U07L0801B06l0K@1Q06h0000000000000000000000000000000000000000000000000:P:h3bX2
o=PB06`Ck7MX9>Mgooooo`40001?OOAgV7DF00P00008GQH0e=HB09Qe5P341oEg`5OgM`0000010000
I7H020000000@0002<000;3D4P0j0000000008cG4P1LfQ80?000005IR7L10@00`=DB0000001LfQ80
000001PfR7OoooooV=HB09BBigL001<02@0000QN5P2`eQ80A01C0/06mGL10000E`DQX``2002_2?Eg
E`DQX`00000P0P002@000<]`m7MG1B6S`040004000000000308004@0D`810000?=LB0:RHm7MG1B6S
`0400202001TMP08000002D0000<00000@0005@0001D00004@4001X0000I0@00;P000040002BY2U0
Bl//@1P1003P0@000@0004`00000000000000000003ooooooooooe00000b0000JP000580001`0@00
0`00083nool0000000000000002@0@000@0000@2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP0000000000000000000000000000000000000000000000000QX`00000P0P002@000<]`m7MG1B6S
`040004000000000308004@0D`810000?=LB0:RHm7MG1B6S`0400202001TMP08000000100008`000
/=@B03X000000000S=LB05cJ4P0l00000EV8M`410030eA80000005cJ4P00000063J8MooooonHeQ80
U9;WM`004`09000025hF0;3F4P1405<2`0KeM`40001G1B6S30800:l8mGMG1B6S0000020200090000
bg3dMeL58J?00@000@000000000U000025hF0>3F4P172@00U`ceM`40000000000@0006Af00P00000
9@0000`000030000:00000`000010000E00005@0003m00000`0001@1000X00000@0009:T:D1;bba0
AP00080100010000C00000000000000000000?ooooooooooD00004H0003P0000DP00070100010000
400000L00000000000000;`20000000010824U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
0000000000000000000000000000000000000000000001H0V7DF020200090000bg3dMeL58J?00@00
0@000000000U000025hF0>3F4P172@00U`ceM`40000000000@0006Af00P00000040000S0002`e180
000C00@00000ea80G=XB03`00001FHQg0@400<3E4P000000R=HB0000R7LH=XQgoooooiSF4P2DT^Mg
000C0000002HMAH0A`T:<iQe5P30EoMg0@0005L58J<<0P00[`SeMfCF4P000000o=PB06`Ck7MX9>Mg
ooooo`40001?OOAgV7DF00P00008GQH0e=HB09Qe5P341oEg`5OgM`0000010000I7H02000000U0000
30000040000X0000300000<0000U0000300000L0080U000030000000080`0000300000l0080U0000
30000080001;00004000000000050000:00000`0000100009@0000`0000000209@0000`000070020
8P0000`0003oooooAP0001@000080000AdA9@`<0000<00004000000000000000AP0002P0000L0000
AdA9@`8000170@00F@400881001X0@00000005l0000h00000@0003P000000000>000000000000P40
0@0000000000000000000000000000009@0000`0000100009@0000`000050020E`0002@0003g0000
;P0002X1000b00000P0004P1H05g0F019@0000`000080020:00000`0000100009`0001P000010000
00000000000000009@0000`000010000EP0002P0000V0@00:`000341000f00000`0007D1IP600F01
M@5K0BD0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000200004M4BD<30000
3000010000000000000004H0000X0000700004M4BD<20000C`0005T1002:0000J0400000001O0000
>0000040000h0000000003P00000000000810040000000000000000000000000000002D0000<0000
0@0002D0000<00001@00P5L0000T0000200002h0000k0000<P00008000280601F@1P0BD0000<0000
2000P2P0000<00000@0002L0000H00000@00000000000000000002D0000<00000@0005H0000X0000
0@0002/0000=0000=P0000<0001L05/1D01P0E`0IP4U0000300000L0080U000030000000080X0000
3000004000160000500000P00017A4U30`0000`0000@00000000000000160000:00001`00017A4U3
0P000:L1002Q0@00hP400;0100000000G`0003P000010000>0000000000h0000000000020@010000
000000000000000000000000000U000030000040000U0000300000D0081G0000900005L1001f0000
RP4007X000020000Z06X0ML1Z04U0000300000P0080X000030000040000W00006000004000000000
00000000000U000030000040001F0000:00008H1001c0000T@4007h000030000e@6^0N01Z07E0J<1
9@0000`0000700209@0000`000000020:00000`000010000AP0001@000080000AdA9@`<0000<0000
4000000000000000AP0002P0000L0000AdA9@`80002_0@00M`400=D1002X0@000000024000080000
5P0000`000000000600000`0000000006@0000`0003oool04@0000`0000800002`000100000T0000
;`0000`0000@0000H@4004P0000:000040000000000000002@000100002P0@00808002D0000<0000
0000P2D0000<00001`00P1P0000<000000000180000<00000@0001T0000<0000oooo01H0000<0000
600000X0000@0000000000000009000040000:01000P0P00DP000701000100008?ooo`0000000000
0000090100000000108045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
000000000000000000000000000002X2^0lZ0_cH4P1/4nagJ2CWMoooool10000CggdMiQe5P080000
25hF0=CF4P2HMAH0a0OeMl1GmgL000000@0006Af00P00000040000S0002`e180>P000000002<ea80
G=XB03`00001FHQg0@400<3E4P000000G=XB0000000H=XQgoooooiSF4P2DT^Mg000C00T00008GQH0
/=HB04@0D@;01_Eg0@0005L58J<<0P00[`SeMeL58J<00000808000T0003;L?AgE`DQXj0100010000
000000`2001405420@0003cG4P2XV?AgE`DQXj01000P0P00I7H02000000U000030000040001D0000
E00007L1001R0000O`4007H000010000/Q<]@4_;;43i0000h0400040001<00000000000000000000
oooooooooom@0000<P0006P0001B0000L04000<00020o_oo0000000000000000T040004000040P0@
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00000000000000000000000000000000000000000
000000008J<00000808000T0003;L?AgE`DQXj0100010000000000`2001405420@0003cG4P2XV?Ag
E`DQXj01000P0P00I7H020000000@0002<000;3D4P0j0000000008cG4P1LfQ80?000005IR7L10@00
`=DB0000001LfQ80000001PfR7OoooooV=HB09BBigL001<02@0000QN5P2`eQ80A01A0/06mGL10000
E`DQX``2002_2?EgE`DQX`00000P0P002@000<]`m7MG1B6SX0400040000000009@0000QN5P3PeQ80
A`T009L<mGL1000000000040001TMP08000002D0000<00000`0002P0000<00000@0005@0001D0000
I@4004/0001e0@00L0000040002b4be0Bl//@2h000200@000@0004`00000000000000000003ooooo
oooooe00001e0000a0000580001`0@000@00083nool0000000000000002@0@0000000P@2011=05@0
801507P0M01b06400000000000000000000000000000000000000000000000000000000000000000
000F09Qe5P0P0P002@000<]`m7MG1B6SX0400040000000009@0000QN5P3PeQ80A`T009L<mGL10000
00000040001TMP08000000100008`000/=@B00004`0400000=LB05cJ4P0l00000EV8M`410030eA80
000008SF4P0008Qg63J8MooooonHeQ80U9;WM`004`000000V7DF04L92SFHMAH0`5OgM`40001G1B6S
30800:l8mGMTeQ8000000?cH4P1/4nagJ2CWMoooool10000CggdMiQe5P08000025hF0=CF4P2HMAH0
a0OeMl1GmgL000000@0006Af00P000009@0000`000010000:00000`000030000E00005@0001[0@00
CP0007D1001^00000@000;8C;D1;bba0KP0006h100010000C00000000000000000000?oooooooooo
D00002K`001o0000DP00070100030000400000L00000000000000;`20000000010824U@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000000000000000000000000000000002X2
^0lZ0_cH4P1/4nagJ2CWMoooool10000CggdMiQe5P08000025hF0=CF4P2HMAH0a0OeMl1GmgL00000
0@0006Af00P00000040000S0002`e180000C00@00000ea80G=XB03`00001FHQg0@400<3E4P000000
R=HB0000R7LH=XQgoooooiSF4P2DT^Mg000C0000002h3bX2RPD:9KP?:P;0EoMg0@0005L58J<<0P00
[`SeMfCF4P000000o=PB06`Ck7MX9>Mgooooo`40001?OOAg^0lZ0QP00008GQH0e=HB0;P?:P;41oEg
`5OgM`0000010000I7H02000000U0000300000<0000X000030000040000U0000300000L0080U0000
30000000080`0000300000l0080U000030000080001;00004000000000050000:00000`000030000
9@0000`0000000209@0000`0000700208P0000`0003oooooAP0001@000080000AdA9@`<0000<0000
4000000000000000AP0002P0000L0000AdA9@`80002_0@00;`400=L1001O0@000000024000080000
5P0000`000000000600000`0000000006@0000`0003oool04@0000`0000800002`000100000V0000
;`0000`0000@0000H@400000000:000040000000000000002@00010000300@00808002D0000<0000
0000P2D0000<00001`00P1P0000<000000000180000<00000@0001T0000<0000oooo01H0000<0000
600000X0000@0000000000000009000040000<01000P0P00DP000701000300008?ooo`0000000000
0000090100000000108045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
000000000000000000000000000001H0V7DF0?cH4P1/4nagJ2CWMoooool10000CggdMkP?:P8H0000
25hF0=CF4P2h3bX2a0OeMl1GmgL000000@0006Af00P00000040000S0002`e180>P000000002<ea80
G=XB03`00001FHQg0@400<3E4P000000G=XB0000000H=XQgoooooiSF4P2DT^Mg000C00T00008GQH0
/=HB04@0D`;01_Eg0@0005L58J<<0P00[`SeMeL58J<00000808000T0003;L?AgE`DQXl0100010000
000000`2001405<20@0003cG4P2XV?AgE`DQXl01000P0P00I7H02000000U0000300000<0001D0000
E00007T1000J0000P@4002h000010000TZ@Y@4_;;40H0@00h0400040001<00000000000000000000
oooooooooom@0000<P0006X0001B0000L04000400020o_oo0000000000000000T040004000040P0@
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00000000000000000000000000000000000000000
000000008J<00000808000T0003;L?AgE`DQXl0100010000000000`2001405<20@0003cG4P2XV?Ag
E`DQXl01000P0P00I7H020000000@0002<000;3D4P0j0000000008cG4P1LfQ80?000005IR7L10@00
`=DB0000001LfQ80000001PfR7OoooooV=HB09BBigL001<02@0000QN5P2`eQ80A01C0/06mGL10000
E`DQX``2002_2?EgE`DQX`00000P0P002@000<]`m7MG1B6S`0400040000000009@0000QN5P3PeQ80
RPD009L<mGL1000000000040001TMP08000002D0000<00000@0002P0000<00000`0005@0001D0000
I@4000<0001l0@00:0000040002BY2U0Bl//@4H000200@000@0004`00000000000000000003ooooo
oooooe0000160000h0000580001`0@000`0001000007000000000000002l0P00000000@20Q9D06T0
K@1U07<0801>06D0M`0P0580K`1]0640KP0000000000000000000000000000000000000000000000
000Z0[P?:P8P0P002@000<]`m7MG1B6S`0400040000000009@0000QN5P3PeQ80RPD009L<mGL10000
00000040001TMP08000000100008`000/=@B00004`0400000=LB05cJ4P0l00000EV8M`410030eA80
000008SF4P0008Qg63J8MooooonHeQ80U9;WM`004`000000^0lZ0XX52RNh3bX2`5OgM`40001G1B6S
30800:l8mGMTeQ8000000?cH4P1/4nagJ2CWMoooool10000CggdMkP?:P8H000025hF0=CF4P2h3bX2
a0OeMl1GmgL000000@0006Af00P000009@0000`000030000:00000`0000100009@0000`000070020
9@0000`000000020<00000`0000?00209@0000`000020000B`000100000000001@0002P0000<0000
0`0002D0000<00000000P2D0000<00001`00P280000<0000ooooodH0000D0000200004M4BD<30000
3000010000000000000004H0000X0000700004M4BD<20000Y`4005T1003R0@00J0400000001O0000
>00000<0000h0000000003P00000000000810040000000000000000000000000000002D0000<0000
0`0002D0000<00001@00P5L0000T0000H04002h0002C0@00<P000080003P0F01/@5P0BD0000<0000
2000P2P0000<00000`0002L0000H00000`00000000000000000002D0000<00000`0005H0000X0000
F@4002/0001U0@00=P0000<0002d0E/1Z05P0K@1IP4U0000300000L0080U000030000000080X0000
300000<000160000500000P00017A4U30`0000`0000@00000000000000160000:00001`00017A4U3
0P0008l0002O0@00TP000=8100000000G`0003P000030000>0000000000h0000000000020@010000
000000000000000000000000000U0000300000<0000U0000300000D0081G0000900003l0001^0000
@`000:8000020000T02P0I00d04U0000300000L0080X0000300000<0000U00003000000008160000
500000P00017A4U30`0000`0000@00000000000000160000:00001`00017A4U30P0003D1002O0@00
>0400=8100000000G`0003P000030000>0000000000h0000000000020@0100000000000000000000
00000000000U0000300000<0000U0000300000D0081G000090000>D0001^0000j@000:8000020000
=P6P0CH1d04U0000300000L0080X0000300000<0000U00003000000008160000500000P00017A4U3
0`0000`0000@00000000000000160000:00001`00017A4U30P0008L0003?0@00eP000?L100000000
8@0000P0000F000030000000000H000030000000000I000030000?ooo`0A0000300000P0000;0000
400004d0000W000030000100000i0000X00000X0000@000000000000000900004000080300300@00
9@0000`0000000209@0000`000070020600000`0000000004P0000`0000100006@0000`0003oool0
5P0000`0000H00002P00010000000000000000T0000@0000P0<00<01001B0000L04000<00020o_oo
0000000000000000T040000000040P0@E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000000000
00000000000000000000000000000000000000005P2HMAH0o=PB06`Ck7MX9>Mgooooo`40001?OOAg
^0lZ0QP00008GQH0e=HB0;P?:P;41oEg`5OgM`0000010000I7H020000000@0002<000;3D4P0j0000
000008cG4P1LfQ80?000005IR7L10@00`=DB0000001LfQ80000001PfR7OoooooV=HB09BBigL001<0
2@0000QN5P2`eQ80A01I1<06mGL10000E`DQX``2002_2?EgE`DQX`0000300@002@000<]`m7MG1B6S
P0<0004000000000308004@0F@@10000?=LB0:RHm7MG1B6SP0<00<01001TMP08000002D0000<0000
0`0005@0001D0000L0000:8000200000aP0000400000h2]0KQ/^@7X2001P0@000@0004`000000000
00000000003ooooooooooe00000`0000aP000580001`0@000@00083nool0000000000000002@0@00
00000P@2011C07T0K@1R06l0K0000000000000000000000000000000000000000000000000000000
0000000000000000000QX`0000300@002@000<]`m7MG1B6SP0<0004000000000308004@0F@@10000
?=LB0:RHm7MG1B6SP0<00<01001TMP08000000100008`000/=@B03X000000000S=LB05cJ4P0l0000
0EV8M`410030eA80000005cJ4P00000063J8MooooonHeQ80U9;WM`004`09000025hF0;3F4P1405T4
`0KeM`40001G1B6S30800:l8mGMG1B6S00000<0100090000bg3dMeL58J>00`000@000000000U0000
25hF0>3F4P0/1`00U`ceM`40000000000@0006Af00P000009@0000`000010000:00000`000030000
E00005@0001F0000WP0006L0003500000@00003P:d1^6bi0E040060100010000C000000000000000
00000?ooooooooooD00003g`003A0000DP00070100030000P?koo`00000000000000090100010000
108045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^000000000000000000000000000000000000
00000000000002X2^0lZ0/0100090000bg3dMeL58J>00`000@000000000U000025hF0>3F4P0/1`00
U`ceM`40000000000@0006Af00P00000040000S0002`e180000C00@00000ea80G=XB03`00001FHQg
0@400<3E4P000000R=HB0000R7LH=XQgoooooiSF4P2DT^Mg000C0000002h3bX2;0L:K[P?:P;0EoMg
0@0005L58J<<0P00[`SeMfCF4P000000o=PB06`Ck7MX9>Mgooooo`40001?OOAg^0lZ0QP00008GQH0
e=HB0;P?:P;41oEg`5OgM`0000010000I7H02000000U0000300000<0000X000030000040001D0000
E00003l0002Q0000CP000<H0000100000>0[@6hK;T1<0000H0400040001<00000000000000000000
oooooooooom@0000N0000:l0001B0000L0400040000@00001`00000000000000_080000000040P8B
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00000000000000000000000000000000000000000
000000005P2HMAH0o=PB06`Ck7MX9>Mgooooo`40001?OOAg^0lZ0QP00008GQH0e=HB0;P?:P;41oEg
`5OgM`0000010000I7H020000000@0002<000;3D4P0001<01000003G4P1LfQ80?000005IR7L10@00
`=DB00000028eQ800028MaPfR7OoooooV=HB09BBigL001<0000009Qe5P172@XhV7DF0<1GmgL10000
E`DQX``2002_2?EgI=HB0000003lf180K1?/MfPTigOooooo0@0004mmm7NHMAH0200000QN5P3DeQ80
V7DF0<@7mGO0EoMg00000040001TMP08000002D0000<00000@0002P0000<00000`0002D0000<0000
1`00P2D0000<00000000P300000<00003`00P2D0000<00000P0004/0000@0000000000D0000X0000
30000040000U000030000000080U0000300000L0080R000030000?oooom60000500000P00017A4U3
0`0000`0000@00000000000000160000:00001`00017A4U30P0002T1003;0@00OP400?`100000000
8@0000P0000F000030000000000H000030000000000I000030000?ooo`0A0000300000P0000;0000
400005<0000_000030000100003K0000W00000X0000@0000000000000009000040000<03000P0P00
9@0000`0000000209@0000`000070020600000`0000000004P0000`0000100006@0000`0003oool0
5P0000`0000H00002P00010000000000000000T0000@0000`0<00202001B0000L0400040000Poooo
0000000000000000T040004000040P0@E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000000000
0000000000000000000000000000000000000000:P:h3bX2o=PB06`Ck7MX9>Mgooooo`40001?OOAg
V7DF00P00008GQH0e=HB09Qe5P341oEg`5OgM`0000010000I7H020000000@0002<000;3D4P0j0000
000008cG4P1LfQ80?000005IR7L10@00`=DB0000001LfQ80000001PfR7OoooooV=HB09BBigL001<0
2@0000QN5P2`eQ80A03M1<06mGL10000E`DQX``2002_2?EgE`DQX`00000P0P002@000<]`m7MG1B6S
`0<0004000000000308004@0g@@10000?=LB0:RHm7MG1B6S`0<00202001TMP08000002D0000<0000
0@0005@0001D00006`400;H0000W0@00bP000040002[jRa0Bl//@>/2003P0@000@0004`000000000
00000000003ooooooooooe00001B0000R`000580001`0@000`00083nool0000000000000002@0@00
0@0000@2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP000000000000000000000000000000
0000000000000000000QX`00000P0P002@000<]`m7MG1B6S`0<0004000000000308004@0g@@10000
?=LB0:RHm7MG1B6S`0<00202001TMP08000000100008`000/=@B03X000000000S=LB05cJ4P0l0000
0EV8M`410030eA80000005cJ4P00000063J8MooooonHeQ80U9;WM`004`09000025hF0;3F4P140=d4
`0KeM`40001G1B6S30800:l8mGMG1B6S0000020200090000bg3dMeL58J?00`000@000000000U0000
25hF0>3F4P172@00U`ceM`40000000000@0006Af00P000009@0000`000030000:00000`000010000
E00005@0000A0@00W`0001T1003400000@000:_Z;41;bba0M080080100010000C000000000000000
00000?ooooooooooD00006`0001X0000E00005@0003Q0000W`000?00003400000@000:_Z;41;bba0
C000080100010000C00000000000000000000?ooooooooooD00007P0002]0000DP00070100010000
P?koo`00000000000000090100000002108045<0N@1]0680K`1/0000000000000000000000000000
0000000000000000000000000000000000000000000001H0V7DF020200090000bg3dMeL58J?00`00
0@000000000U000025hF0>3F4P172@00U`ceM`40000000000@0006Af00P00000040000S0002`e180
000C00@00000ea80G=XB03`00001FHQg0@400<3E4P000000R=HB0000R7LH=XQgoooooiSF4P2DT^Mg
000C0000002HMAH0A`T:>YQe5P30EoMg0@0005L58J<<0P00[`SeMfCF4P000000o=PB06`Ck7MX9>Mg
ooooo`40001?OOAgV7DF00P00008GQH0e=HB09Qe5P341oEg`5OgM`0000010000I7H02000000U0000
30000040000X0000300000<0001D0000E0000?P0002L00002@400<<000010000ZnX/@4_;;41D0@00
P0400040001<00000000000000000000oooooooooom@0000?O000=00001B0000L04000<0000@0000
1`00000000000000_080000000040P8BE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000000000
0000000000000000000000000000000000000000:P:h3bX2o=PB06`Ck7MX9>Mgooooo`40001?OOAg
V7DF00P00008GQH0e=HB09Qe5P341oEg`5OgM`0000010000I7H020000000@0002<000;3D4P0001<0
1000003G4P1LfQ80?000005IR7L10@00`=DB00000028eQ800028MaPfR7OoooooV=HB09BBigL001<0
00000;P?:P8/1`Y`^0lZ0/1GmgL10000E`DQX``2002_2?EgI=HB0000003lf180K1?/MfPTigOooooo
0@0004mmm7Nh3bX2600000QN5P3DeQ80^0lZ0/@7mGO0EoMg00000040001TMP08000002D0000<0000
0`0002P0000<00000@0002D0000<00001`00P2D0000<00000000P300000<00003`00P2D0000<0000
0P0004/0000@0000000000D0000X0000300000<0000U000030000000080U0000300000L0080R0000
30000?oooom60000500000P00017A4U30`0000`0000@000000000000000U0000300000P0080U0000
300000D0080U0000300000d0080X000030000080000>000050000000000@00005000
\>"], "Graphics",
  ImageSize->{348, 136.75},
  ImageMargins->{{182, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["First boundary condition (determining coefficient a2)", "Subsection",
  InitializationCell->True],

Cell["No stress at free end of rod (x=0)  at all times:", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(BC1 = \ \ \ \[Sigma][0, t] \[Equal] 0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(a2\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ ER\ w\)\/cR + \(\
\[ImaginaryI]\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ Ud\ \[Theta]\)\/\(A\ \
N\ w\) == 0\)], "Output"]
}, Open  ]],

Cell["Solve for coefficient a2 and create a rule:", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(rulea2 = Flatten[Solve[BC1, a2]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({a2 \[Rule] \(-\(\(\[ImaginaryI]\ cR\ Ud\ \[Theta]\)\/\(A\ ER\ N\ \
w\^2\)\)\)}\)], "Output"]
}, Open  ]],

Cell["\<\
a2 is the amplitude of the sine function of the displacement,SI unit meter.\
\>", "Text",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Second boundary condition (determining coefficient a1)", "Subsection",
  InitializationCell->True],

Cell[TextData[{
  "It is assumed that the sealant as well as the polymer is in contact with \
the rod only at the end of the rod ",
  StyleBox["(keen simplification!)",
    FontWeight->"Bold"],
  ". Therefore an overall impedance ZC is defined as a second boundary \
condition:"
}], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(BC2 = \ \(-ZC\) \[Equal] 
          Ac*\[Sigma][lRod, t]\/v[lRod, t];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "With:",
  StyleBox["\nZC:\tComplex mechanical contact impedance of polymer and \
sealant, SI unit ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`\(N\ s\)\/m = \(\(kg\)\(\ \)\)\/s\)]],
  StyleBox["\nAc:\tContact area.",
    FontSlant->"Plain"]
}], "Text",
  InitializationCell->True,
  FontSlant->"Italic"],

Cell[TextData[StyleBox["Model simplifications:",
  FontWeight->"Bold"]], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(Ac = A;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
 Equals cross-sectional area of rod and solenoid in this model.\
\>", "Text",
  InitializationCell->True],

Cell["Derivation of a1:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(BC2 = Simplify[BC2];\)\)], "Input",
  InitializationCell->True],

Cell["Solve for coefficient a1 and create a rule:", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(rulea1 = Simplify[Flatten[Solve[BC2, a1]]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({a1 \[Rule] \(-\(\(cR\ Ud\ \[Theta] - \[ImaginaryI]\ A\ a2\ ER\ N\ w\^2\
\ Cos[\(lRod\ w\)\/cR] + 
                a2\ cR\ N\ w\^2\ ZC\ Sin[\(lRod\ w\)\/cR]\)\/\(N\ w\^2\ \((cR\
\ ZC\ Cos[\(lRod\ w\)\/cR] + \[ImaginaryI]\ A\ ER\ Sin[\(lRod\ \
w\)\/cR])\)\)\)\)}\)], "Output"]
}, Open  ]],

Cell["Apply rule for coefficient a2 on coefficient a1:", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(rulea1 = rulea1 /. rulea2\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({a1 \[Rule] \(-\(\(cR\ Ud\ \[Theta] - 
                cR\ Ud\ \[Theta]\ Cos[\(lRod\ w\)\/cR] - \(\[ImaginaryI]\ \
cR\^2\ Ud\ ZC\ \[Theta]\ Sin[\(lRod\ w\)\/cR]\)\/\(A\ ER\)\)\/\(N\ w\^2\ \
\((cR\ ZC\ Cos[\(lRod\ w\)\/cR] + \[ImaginaryI]\ A\ ER\ Sin[\(lRod\ w\)\/cR])\
\)\)\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rulea1 = Simplify[rulea1]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({a1 \[Rule] \(cR\ Ud\ \[Theta]\ \((\(-A\)\ ER + A\ ER\ Cos[\(lRod\ \
w\)\/cR] + \[ImaginaryI]\ cR\ ZC\ Sin[\(lRod\ w\)\/cR])\)\)\/\(A\ ER\ N\ w\^2\
\ \((cR\ ZC\ Cos[\(lRod\ w\)\/cR] + \[ImaginaryI]\ A\ ER\ Sin[\(lRod\ \
w\)\/cR])\)\)}\)], "Output"]
}, Open  ]],

Cell["\<\
a1 is the amplitude of the cosine function of the displacement,SI unit meter.\
\
\>", "Text",
  InitializationCell->True],

Cell["a1 in case of ZC=0:", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(rulea1ZC0 = Simplify[rulea1 /. ZC \[Rule] 0]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({a1 \[Rule] \(\[ImaginaryI]\ cR\ Ud\ \[Theta]\ Tan[\(lRod\ w\)\/\(2\ cR\
\)]\)\/\(A\ ER\ N\ w\^2\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Verification for the case that ",
    FontSlant->"Italic"],
  "ZC",
  StyleBox["=0 and w is first resonant frequency of rod:",
    FontSlant->"Italic"]
}], "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(rulea1ZC0 /. 
      w \[Rule] \(\(2\)\(\ \)\(\[Pi]\)\(\ \)\(*\)\((cR\/\(2\ lRod\))\)\(\ \
\)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"a1", "\[Rule]", 
        InterpretationBox["ComplexInfinity",
          DirectedInfinity[ ]]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Verification for the case that ",
    FontSlant->"Italic"],
  "ZC",
  StyleBox["=0 and w is second resonant frequency of rod:",
    FontSlant->"Italic"]
}], "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(rulea1ZC0 /. 
      w \[Rule] 2\ \[Pi]\ *\((\(2\ cR\)\/\(2\ lRod\))\)\)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({a1 \[Rule] 0}\)], "Output"]
}, Open  ]],

Cell["Verification for limit values of ZC:", "Text",
  InitializationCell->True,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[Limit[a1 /. rulea1, ZC \[Rule] \[Infinity]]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[ImaginaryI]\ cR\ Ud\ \[Theta]\ Tan[\(lRod\ w\)\/cR]\)\/\(A\ ER\ N\ \
w\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      Limit[a1 /. rulea1, ZC \[Rule] \[ImaginaryI]*\[Infinity]]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[ImaginaryI]\ cR\ Ud\ \[Theta]\ Tan[\(lRod\ w\)\/cR]\)\/\(A\ ER\ N\ \
w\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Absolute amplitude of oscillations:", "Subsection",
  InitializationCell->True],

Cell["This is the absolute amplitude of the oscillations:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(amp[a1_, a2_] := \@\(Abs[a1]^2 + Abs[a2]^2\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Further electromagnetic relations (part 2)", "Section",
  InitializationCell->True],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0005/d0@0006`00004000000000?D1003]0000
00000000001O?@00a1d00215CDH00040=5/004l300040000000000000000000000@0000300100@00
l0000000000000000000003R1020Z@<02P000100000M0000f00000T0000@0000m@400?<0000D0000
300000d000160000:00001`00017A4U30P0001d0003H00004@800<X100000000AP0002P0000L0000
AdA9@`80002m0000o@000=@0001L0@00000005l0000h00000@0003P000000000>000000000000P40
1P000000003ViP0000000000000000009@0000`0000100009@0000`000050020E`0002@0002W0000
;0000:l0001l00000P000<P0207805019@0000`000080020:00000`0000100009`0001P000010000
00000>KV000000009@0000`000010000:P0001P0003300000`400<l0000?0@00:P0001P000330000
B`400<l0001G0@009@0000`0000700209@0000`000000020:00000`000010000AP0001@000080000
AdA9@`<000160000:00001`00017A4U30P0005L0003W00004`8001<1000000009@0000`000080020
9`0001P0000100000000066?o@0000009@0000`000010000>`0000P0000K000040000102003l0000
F00002P00000000000000?oooooooooo0`000102l@0:0^P00`;X03H0000@0000I@000>P0001H0000
=000000000000000ooooooooool60000GP3X05P0l@1H0?`0F0070Eh0405U0101=P00010000030P00
404005P0000X000000000000003oooooooooo`<0000:0Q0140870A02o00m0000200003`000080000
?P0001P0000k000040000?<1000h00009@0000`0000700209@0000`000000020:00000`000010000
9@0000`0000800209`0001P0000100000000082UoP0000009@0000`000010000>`0000P0000K0000
400000<2003X0000F00004`00000000000000?oooooooooo30000?`1j03f0O40mP7l0?H11`7l0A01
0`8@0@X2404@0PL140;l0102l@0:0^P00`;X03d000080000?00000P0000n000060000=T1000@0000
l`4003P0000U0000300000L0080U000030000000080X000030000040001O0000>0000040000h0000
000003P00000000000810040000000000000000000000000000002D0000<00000@0002D0000<0000
1@00P3/0000800006`000100000@0P00o00005P0000X000000000000003oooooooooo`<0000@0_40
2P;X00<2j00f0000400006D0003X0000F00003@00000000000000?oooooooooo1P0005h0j01H0?40
F03l05P01`5N0101I@0@0CH0000@00000`800101001H0000:000000000000000ooooooooool30000
2P8@0A021`4@0_`0?@0000P0000l000020000400000H0000>@0000h0003e0@00>P0003/000080000
6`00010000030P00j00005P0000d000000000000003oooooooooo`H0003l0NP0mP7a0?H1o03f0@L1
o04@0@<2404l000020000400000H0000e`4000h0003X0@00>P0002D0000<00001`00P2P0000<0000
0@0002D0000<00000000P4H0000D0000200004M4BD<30000DP000701000100000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000`00@000000100000@000040000000000000000000000040oooo000002000000
00000000000000000000000000000000=BD000002000000000000000000000000000004000010000
0@000040000200000P000000000000000@000040000000000000004000000000000000000@000000
000000000@000000/35n1=@aOPB/jA80c[nB<80000010000I7H02000000U000030000040000H0000
30000000008I000030000?ooo`8K00004000000000000000DP00070100020000j?ooo`0000000000
00000;`20000000004008T40LP1Y0640K00000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000@000:03E06X^Q@0
0@0000000000000000000000002Tha80;COdM`0000200000h><B004000000000BCOdMl1GmgL20000
080000@000000000000006Af00P000000000000000000000_08000L000020000i37dMl1GmgL0@000
;PH:/IT`m7L^1PZao0D:_?PR]P7H8KH12[4000cS4P0000<`000:0?100c0?00000P000=@Q]P400000
X><B03=00c3D8KH100000:0N]P6Pha800dD3<4/40A5e?0<`I7H02000000U000030000080000X0000
30000040000H000030000000008I000030000?ooo`8K000040000000000000005P0000`0000H0000
4P0000`000010000E0000600003i0000500002L1000`00000@000000nT400?Y15P4000<100030000
C00000000000000000000?ooooooooooE0000580K`1T00004@0000l0000?00005P0000`000000000
4P0000`0000200004P0000`000020000AP0002P0000L0000AdA9@`80001G0000M`4005X0002J0@00
000005l0000h00000@0003P000000000>000000000000P400@000000000000000000000000000000
9@0000`0000100009@0000`000050020E`0002@0000i0000WP0003d0003200000P0005P0N05H09P1
9@0000`000070020:00000`0000100009@0000`000000020AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P0005L000210@00`P00090100000000G`0003P000010000>0000000000h0000
000000020@010000000000000000000000000000000U000030000040000U0000300000D0081G0000
900003T0002^0000W0000;8000020000F0280KL0R04U0000300000P0080X000030000040000W0000
600000400000000000000000000U000030000040001F0000:00009P0002[0000X`000;H000030000
]@2>0L00R06e08<19@0000`0000700209@0000`000000020:00000`000010000AP0001@000080000
AdA9@`<0000U0000300000D0080U0000300000P0080[000060000:00002X0@000`400<X1000U0000
30000000080U0000300000L0080H000030000000008I000030000?ooo`8K00004000000000000000
600000`0000000026@0000`0003oool26`00010000000000000001H0000<000060000180000<0000
0@0005@0001H0000S@000=40002W0000k@00004000000?Y1003j@JX000300@000P0004`000000000
00000000003ooooooooooe00001h03d03@0000h0000F000030000000000B000030000080000H0000
30000000008I000030000?ooo`8K000040000000000000005P0000`0000H00004P0000`000010000
E00006`0002X0000d@000=`0003]00000@000000nT400?Y1a@000<0100050000C000000000000000
00000?ooooooooooF00006`0@`1_06T0K00000L0000A00003`0000L0000700005P0000`000000000
4P0000`0000200004P0000`000020000AP0002P0000L0000AdA9@`80001@0000f0000=00000T0@00
000004H0000X0000700004M4BD<20000D0000=P0001i00009P400000000U0000300000P0080W0000
6000004000000000i^H00000000U000030000040000k0000200001/0000@0000M00001D1001H0000
C000000000000000ooooooooool<0000L@0I0F`0705X01`1GP0L0ED03P5E0?h0E@3^05h0h01X0>00
K03P0740h`1d0>L0=P000100001g0000h@0005P0001<000000000000003oooooooooo``0001c0=/0
KP3H06P0f01K0=P0D03Y0500oP1@01<1F`0T0FP0905^02@1L`0Q0GL06`4m0000200003`000080000
?P0001P0000c0000000005X0001<00009@0000`0000700209@0000`000000020:00000`000010000
AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000600003H0000R@0002H100000000
9@0000`0000800209`0001P00001000000000>KV000000009@0000`000010000>`0000P0000K0000
400008@0000E0@00F00004`00000000000000?oooooooooo300008406@5l01`1N00L0Fh0705U00h1
I@3n06D0kP1^0>00N03P07`0h0210><0Q03W03H0000@0000Q`000>40001H0000C000000000000000
ooooooooool<0000P`3K07h0f01h0=P0J`3H0600j@1P0?h0H00C0F/0905h02@1OP0T0H<08@6701/1
?@0000P0000l0000200003h0000H0000@`000000001Z0000C00002D0000<00001`00P2D0000<0000
0000P2P0000<00000@0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80001`0000
f00009T0000V0@00000002D0000<00002000P2L0000H00000@000000003ViP00000002D0000<0000
0@0003/0000800006`000100002D00005@4005P0001<000000000000003oooooooooo``0002A01T1
S00L0HP0705n01`1M@0>0GD0oP1e0>h0OP3P08P0h02<0>00T@3S09@0i`0f0000400009L0003Q0000
F00004`00000000000000?oooooooooo300009<0f`2>0=P0R03H07/0f01`0>T0L03n07004`5k02@1
R00T0Hh0906C0241U`0K0Cd000080000?00000P0000n0000600005<000000000NP0004`0000U0000
300000L0080U000030000000080X00003000004000160000500000P00017A4U30`0004H0000X0000
700004M4BD<20000P0000=P0002Y00009P400000000U0000300000P0080W00006000004000000000
i^H00000000U000030000040000k0000200001/0000@0000Y00001D1001H0000C000000000000000
ooooooooool<0000X@0I0I`0706H01`1SP0L0HD03P650?h0Q@3^08h0h02H0>00W03P0:40h`2T0>L0
=P000100002W0000h@0005P0001<000000000000003oooooooooo``0002S0=/0WP3H09P0f02;0=P0
P03Y0800oP2001<1R`0T0IP0906N02@1X`0Q0JL06`4m0000200003`000080000?P0001P0001S0000
000008X0001<00009@0000`0000700209@0000`000000020:00000`000010000AP0001@000080000
AdA9@`<000160000:00001`00017A4U30P000900003H0000^@0002H1000000009@0000`000080020
9`0001P00001000000000>KV000000009@0000`000010000>`0000P0000K000040000;@0000E0@00
F00004`00000000000000?oooooooooo30000;406@6/01`1Z00L0Ih0706E00h1U@3n09D0kP2N0>00
Z03P0:`0h02a0><0]03W03H0000@0000]`000>40001H0000C000000000000000ooooooooool<0000
/`3K0:h0f02X0=P0V`3H0900j@2@0?h0T00C0I/0906X02@1[P0T0K<08@6g01/1?@0000P0000l0000
200003h0000H0000L`000000002J0000C00002D0000<00001`00P2D0000<00000000P2P0000<0000
0@0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80002P0000f0000<T0000V0@00
000002D0000<00002000P2L0000H00000@000000003ViP00000002D0000<00000@0003/000080000
6`000100003400005@4005P0001<000000000000003oooooooooo``0003101T1_00L0KP0706^01`1
Y@0>0JD0oP2U0>h0[P3P0;P0h02l0>00`@3S0<@0i`0f000040000<L0003Q0000F00004`000000000
00000?oooooooooo30000<<0f`2n0=P0^03H0:/0f02P0>T0X03n0:004`6[02@1^00T0Kh090730241
a`0K0Cd000080000?00000P0000n0000600008<000000000ZP0004`0000U0000300000L0080U0000
30000000080X00003000004000160000500000P00017A4U30`0004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80001=00003@4006@0001L0@00000005l0000h00000@0003P000000000
>000000000000P401P000000003ViP0000000000000000009@0000`0000100009@0000`000050020
E`0002@0000g0000?00003l0001l00000P0005P0605H05019@0000`000080020:00000`000010000
9`0001P00001000000000>KV000000009@0000`000010000:P0001P0001C00004`4005l0000O0@00
:P0001P0001C0000B`4005l0001G0@009@0000`0000700209@0000`000000020:00000`000010000
AP0001@000080000AdA9@`<000160000:00001`00017A4U30P0001`0000O0@00F@0004/100000000
8@0000P0000F000030000000000H000030000000000I000030000?ooo`0A0000300000P0000;0000
400003/0000Z00003000010000000000B00000X0000@0000000000000009000040000<0200000P00
9@0000`0000000209@0000`000070020600000`0000000004P0000`0000100006@0000`0003oool0
5P0000`0000H00002P00010000000000000000T0000@0000`0800002001B0000L04000400020o_oo
0000000000000000T040000000040P0@E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000000000
000000000000000000000000000000000000000000000000000V=eSV4P2DiQ80000000009SO@ZbXg
c=DB05Ca4P1DlA80K1?/Mnk`S33@ZbXg00000400003n00002@0008SV4P1^01l0T>HB09;_S30j0000
000008cG4P1LfQ80?0000<6m03010@00KP0O0000001LfQ80000000000028iQ80010V=hQZ9SL10000
2@0002RS5@2`eQ80A03a0l06mGL10000j`DQiP`2002_2?Egj`DQiP0000000P002@000<]`m7O[1B7V
`080004000000000308004@0l@<10000?=LB0:RHm7O[1B7V`0800002001TMP08000002D0000<0000
0@0005@0001D0000:P0004T0000c0000J`000040000HWBM0010T@?H1001P0@000@0004`000000000
00000000003ooooooooooe00000Y0000M`0005@0001D0000500004T0000M0000J`000040000HWBM0
010T@?@0001P0@000@0004`00000000000000000003ooooooooooe00000X0000M`000580001`0@00
0`00083nool0000000000000002@0@000@0000@2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP0000000000000000000000000000000000000000000000000QiP0000000P002@000<]`m7O[1B7V
`080004000000000308004@0l@<10000?=LB0:RHm7O[1B7V`0800002001TMP08000006h07`2@iQ80
T^n<<3X000000000S=LB05cJ4P0l0000`Kd0<041001^01l0000005cJ4P000000000008SV4P0042Hg
R6XV=`4000090000::<E0;3F4P140?43`0KeM`40003[1B7V30800:l8mGO[1B7V0000000200090000
bg3dMn/58NK00P000@000000000U0000::<E0>3F4P0_1P00U`ceM`40000000000@0006Af00P00000
9@0000`000030000:00000`000010000E00005@0000O0000B00002P0001[00000@0001RM9d0042A0
LP40060100010000C00000000000000000000?ooooooooooD00007@0001[0000E00005@000040000
B0000100001[00000@0001RM9d0042A0AP00060100010000C00000000000000000000?oooooooooo
D00004T0001g0000DP00070100010000400000L00000000000000;`20000000010824U@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000000000000000000000000000000001@0
`1dD000200090000bg3dMn/58NK00P000@000000000U0000::<E0>3F4P0_1P00U`ceM`4000000000
0@0006Af00P00000KP0O093V4P2Bkh``000C00@00000ea80G=XB03`00001_@0`0@400<3E4P000000
R=HB0000R7LH=XQgoooooiSF4P2DT^Mg000C000000307A@0;`H:Q/0M5030EoMg0@000>/58NH<0P00
[`SeMfCF4P000000o=PB06`Ck7MX9>Mgooooo`40001?OOAg`1dD00P0000XXaD0e=HB0<0M50341oEg
`5OgM`0000010000I7H02000000U000030000040000X0000300000<0000U0000300000L0080U0000
30000000080`0000300000l0080U000030000080001;00004000000000050000:00000`000010000
9@0000`0000000209@0000`0000700208P0000`0003oooooAP0001@000080000AdA9@`<000160000
:00001`00017A4U30P0007L000170@00aP0007<1000000008@0000P0000F000030000000000H0000
30000000000I000030000?ooo`0A0000300000P0000;0000400004d0000Z000030000100001K0000
L00000X0000@0000000000000009000040000:0300000P009@0000`0000000209@0000`000070020
600000`0000000004P0000`0000100006@0000`0003oool05P0000`0000H00002P00010000000000
000000T0000@0000X0<00002001B0000L04000400020o_oo0000000000000000T040000000040P0@
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h00000000000000000000000000000000000000000
00000000502`8a@0o=PB06`Ck7MX9>Mgooooo`40001?OOAg`1dD00P0000XXaD0e=HB0<0M50341oEg
`5OgM`0000010000I7H02000001^01l0T>HB09;_S30j0000000008cG4P1LfQ80?000006m03010@00
`=DB0000001LfQ80000001PfR7OoooooV=HB09BBigL001<02@0002RS5@2`eQ80A03b0l06mGL10000
j`DQiP`2002_2?Egj`DQiP0000000P002@000<]`m7O[1B7VX0<0004000000000308004@0lP<10000
?=LB0:RHm7O[1B7VX0<00002001TMP08000002D0000<00000@0005@0001H0000SP000740002Q0000
T`0000400032lRE0010T@682001P0@000P0004`00000000000000000003ooooooooooe00000Y02T0
N@0007P0001D0000E00007P0001a0000P@0009<000010000`_8U@00@941P0@00H0400040001<0000
0000000000000000oooooooooom@0000:00007T0001B0000L04000<00020o_oo0000000000000000
T040004000040P0@E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0000000000000000000000000
0000000000000000000000008NH00000008000T0003;L?Agj`DQiZ0300010000000000`200140?83
0@0003cG4P2XV?Agj`DQiZ0300000P00I7H02000001^01l0T>HB09;_S30j0000000008cG4P1LfQ80
?000006m03010@00`=DB0000001LfQ80000001PfR7OoooooV=HB09BBigL001<02@0002RS5@2`eQ80
A03b0l06mGL10000j`DQiP`2002_2?Egj`DQiP0000000P002@000<]`m7O[1B7VX0<0004000000000
9@0002RS5@3PeQ80;`H009L<mGL1000000000040001TMP08000002D0000<00000`0002P0000<0000
0@0005@0001D0000P`000700002<0000T`0000400032lRE0010T@=h1001P0@000@0004`000000000
00000000003ooooooooooe00001d0000K00005@0001D0000G@000700001d0000T`0000400032lRE0
010T@1H0001P0@000@0004`00000000000000000003ooooooooooe00001E00002@400580001`0@00
0@0001000007000000000000002l0P00000000@20Q9D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP0000000000000000000000000000000000000000000000000D0<0M50000P002@000<]`m7O[1B7V
X0<00040000000009@0002RS5@3PeQ80;`H009L<mGL1000000000040001TMP08000006h07`2@iQ80
T^n<<0004`0400000=LB05cJ4P0l00000Kd0<0410030eA80000008SF4P0008Qg63J8MooooonHeQ80
U9;WM`004`000000`1dD02l62XS07A@0`5OgM`40003[1B7V30800:l8mGMTeQ8000000?cH4P1/4nag
J2CWMoooool10000CggdMl0M50080000::<E0=CF4P307A@0a0OeMl1GmgL000000@0006Af00P00000
9@0000`000010000:00000`0000300009@0000`0000700209@0000`000000020<00000`0000?0020
9@0000`000020000B`000100000000001@0002P0000<00000@0002D0000<00000000P2D0000<0000
1`00P280000<0000ooooodH0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`8000190000
904006P0001E0@00000005l0000h00000@0003P000000000>000000000000P401P000000003ViP00
00000000000000009@0000`0000100009@0000`000050020E`0002@0000g0000K`0003l0001l0000
0P0005P0B`5H05019@0000`000080020:00000`0000100009`0001P00001000000000>KV00000000
9@0000`000010000EP0002P0000`0000D00004L0001f00000`0006@0CP5H02P1C@1>0BD0000<0000
1`00P2D0000<00000000P2P0000<00000@0004H0000D0000200004M4BD<300009@0000`000050020
9@0000`000080020:`0001P0000j0000Z04007H0003:0@009@0000`0000000209@0000`000070020
600000`0000000026@0000`0003oool26`00010000000000000001P0000<000000000QT0000<0000
oooo0Q/0000@000000000000000F0000300001P0000B000030000040001D0000H00002H0003A0000
C@000>d000010000003j@@00nT530000`04000<0001<00000000000000000000oooooooooomD0000
N00m0300000=00003P0000d0000F000030000000000B000030000080000B00003000008000160000
:00001`00017A4U30P000;l0001g0@00`P0009X100000000G`0003P000010000>0000000000h0000
000000020@010000000000000000000000000000000U000030000040000U0000300000D0081G0000
90000:40002N0000Y@000<8000020000`01h0L00V04U0000300000L0080X000030000040000U0000
3000000008160000500000P00017A4U30`0000`0000@00000000000000160000:00001`00017A4U3
0P000;d0003m0000e00005`100000000G`0003P000010000>0000000000h0000000000020@060000
00000>KV0000000000000000000U000030000040000U0000300000D0081G000090000:L0000/0000
[`0007`000020000b0080LP0D04U0000300000P0080X000030000040000W00006000004000000000
i^H00000000U000030000040000Z000060000<<000030@00c`0000l1000Z000060000<<0001;0@00
c`0005L1000U0000300000L0080U000030000000080X00003000004000160000500000P00017A4U3
0`0000`0000@00000000000000160000:00001`00017A4U30P0005L0003W00004`8001<100000000
9@0000`0000800209`0001P0000100000000066?o@0000009@0000`000010000>`0000P0000K0000
40000102003l0000F00002P00000000000000?oooooooooo0`000102l@0:0^P00`;X03H0000@0000
I@000>P0001H0000=000000000000000ooooooooool60000GP3X05P0l@1H0?`0F0070Eh0405U0101
=P00010000030P00404005P0000X000000000000003oooooooooo`<0000:0Q0140870A02o00m0000
200003`000080000?P0001P0000k000040000?<1000h00009@0000`0000700209@0000`000000020
:00000`0000100009@0000`0000800209`0001P0000100000000082UoP0000009@0000`000010000
>`0000P0000K0000400000<2003X0000F00004`00000000000000?oooooooooo30000?`1j03f0O40
mP7l0?H11`7l0A010`8@0@X2404@0PL140;l0102l@0:0^P00`;X03d000080000?00000P0000n0000
60000=T1000@0000l`4003P0000U0000300000L0080U000030000000080X000030000040001O0000
>0000040000h0000000003P00000000000810040000000000000000000000000000002D0000<0000
0@0002D0000<00001@00P3/0000800006`000100000@0P00o00005P0000X000000000000003ooooo
ooooo`<0000@0_402P;X00<2j00f0000400006D0003X0000F00003@00000000000000?oooooooooo
1P0005h0j01H0?40F03l05P01`5N0101I@0@0CH0000@00000`800101001H0000:000000000000000
ooooooooool300002P8@0A021`4@0_`0?@0000P0000l000020000400000H0000>@0000h0003e0@00
>P0003/0000800006`00010000030P00j00005P0000d000000000000003oooooooooo`H0003l0NP0
mP7a0?H1o03f0@L1o04@0@<2404l000020000400000H0000e`4000h0003X0@00>P0002D0000<0000
1`00P2P0000<00000@0002D0000<00000000P4H0000D0000200004M4BD<30000600000`000000002
6@0000`0003oool26`00010000000000000001P0000<000000000QT0000<0000oooo0Q/0000@0000
00000000000F0000300001P0000B000030000040001D0000H0000?T0000D00009`40030000010000
003j@@00nT4F0@000`4000<0001<00000000000000000000oooooooooomD0000DP1_06@0000A0000
3`0000l0000F000030000000000B000030000080000B000030000080000<00004000000000000000
AP0002P0000L0000AdA9@`80001G0000M`4005X0002J0@00000005l0000h00000@0003P000000000
>000000000000P400@0000000000000000000000000000009@0000`0000100009@0000`000050020
E`0002@0000i0000WP0003d0003200000P0005P0N05H09P19@0000`000070020:00000`000010000
9@0000`000000020AP0001@000080000AdA9@`<0000<00004000000000000000AP0002P0000L0000
AdA9@`80001G0000P@400<80002@0@00000005l0000h00000@0003P000000000>000000000000P40
0@0000000000000000000000000000009@0000`0000100009@0000`000050020E`0002@0000i0000
[P0009`0002b00000P0005P0R06g08P19@0000`000080020:00000`0000100009`0001P000010000
00000000000000009@0000`000010000EP0002P0002H0000Z`000:<0002f00000`000;D0SP7008P1
]@230BD0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000200004M4BD<30000
3000010000000000000002D0000<00001@00P2D0000<00002000P2/0000H0000X0000:P100030@00
bP4002D0000<00000000P2D0000<00001`00P1P0000<000000000QT0000<0000oooo0Q/0000@0000
00000000000H000030000000008I000030000?ooo`8K000040000000000000005P0000`0000H0000
4P0000`000010000E00005P0002=0000d@000:L0003]00000@000000nT400?Y1ZP000<0100020000
C00000000000000000000?ooooooooooD00007P0?@0=00003P0001H0000<000000000180000<0000
0P0001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000F0000300001P0000B0000
30000040001D0000K0000:P0003A0000g0000>d000010000003j@@00nT750000`04000D0001<0000
0000000000000000oooooooooomH0000K01306l0J@1/00001`000140000?00001`0000L0000F0000
30000000000B000030000080000B000030000080000<00004000000000000000AP0002P0000L0000
AdA9@`80001@0000f0000=00000T0@00000004H0000X0000700004M4BD<20000D0000=P0001i0000
9P400000000U0000300000P0080W00006000004000000000i^H00000000U000030000040000k0000
200001/0000@0000M00001D1001H0000C000000000000000ooooooooool<0000L@0I0F`0705X01`1
GP0L0ED03P5E0?h0E@3^05h0h01X0>00K03P0740h`1d0>L0=P000100001g0000h@0005P0001<0000
00000000003oooooooooo``0001c0=/0KP3H06P0f01K0=P0D03Y0500oP1@01<1F`0T0FP0905^02@1
L`0Q0GL06`4m0000200003`000080000?P0001P0000c0000000005X0001<00009@0000`000070020
9@0000`000000020:00000`000010000AP0001@000080000AdA9@`<000160000:00001`00017A4U3
0P000600003H0000R@0002H1000000009@0000`0000800209`0001P00001000000000>KV00000000
9@0000`000010000>`0000P0000K0000400008@0000E0@00F00004`00000000000000?oooooooooo
300008406@5l01`1N00L0Fh0705U00h1I@3n06D0kP1^0>00N03P07`0h0210><0Q03W03H0000@0000
Q`000>40001H0000C000000000000000ooooooooool<0000P`3K07h0f01h0=P0J`3H0600j@1P0?h0
H00C0F/0905h02@1OP0T0H<08@6701/1?@0000P0000l0000200003h0000H0000@`000000001Z0000
C00002D0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80001`0000f00009T0000V0@00000002D0000<00002000P2L0000H0000
0@000000003ViP00000002D0000<00000@0003/0000800006`000100002D00005@4005P0001<0000
00000000003oooooooooo``0002A01T1S00L0HP0705n01`1M@0>0GD0oP1e0>h0OP3P08P0h02<0>00
T@3S09@0i`0f0000400009L0003Q0000F00004`00000000000000?oooooooooo300009<0f`2>0=P0
R03H07/0f01`0>T0L03n07004`5k02@1R00T0Hh0906C0241U`0K0Cd000080000?00000P0000n0000
600005<000000000NP0004`0000U0000300000L0080U000030000000080X00003000004000160000
500000P00017A4U30`0004H0000X0000700004M4BD<20000P0000=P0002Y00009P400000000U0000
300000P0080W00006000004000000000i^H00000000U000030000040000k0000200001/0000@0000
Y00001D1001H0000C000000000000000ooooooooool<0000X@0I0I`0706H01`1SP0L0HD03P650?h0
Q@3^08h0h02H0>00W03P0:40h`2T0>L0=P000100002W0000h@0005P0001<000000000000003ooooo
ooooo``0002S0=/0WP3H09P0f02;0=P0P03Y0800oP2001<1R`0T0IP0906N02@1X`0Q0JL06`4m0000
200003`000080000?P0001P0001S0000000008X0001<00009@0000`0000700209@0000`000000020
:00000`000010000AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000900003H0000
^@0002H1000000009@0000`0000800209`0001P00001000000000>KV000000009@0000`000010000
>`0000P0000K000040000;@0000E0@00F00004`00000000000000?oooooooooo30000;406@6/01`1
Z00L0Ih0706E00h1U@3n09D0kP2N0>00Z03P0:`0h02a0><0]03W03H0000@0000]`000>40001H0000
C000000000000000ooooooooool<0000/`3K0:h0f02X0=P0V`3H0900j@2@0?h0T00C0I/0906X02@1
[P0T0K<08@6g01/1?@0000P0000l0000200003h0000H0000L`000000002J0000C00002D0000<0000
1`00P2D0000<00000000P2P0000<00000@0004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80002P0000f0000<T0000V0@00000002D0000<00002000P2L0000H00000@000000003ViP00
000002D0000<00000@0003/0000800006`000100003400005@4005P0001<000000000000003ooooo
ooooo``0003101T1_00L0KP0706^01`1Y@0>0JD0oP2U0>h0[P3P0;P0h02l0>00`@3S0<@0i`0f0000
40000<L0003Q0000F00004`00000000000000?oooooooooo30000<<0f`2n0=P0^03H0:/0f02P0>T0
X03n0:004`6[02@1^00T0Kh090730241a`0K0Cd000080000?00000P0000n0000600008<000000000
ZP0004`0000U0000300000L0080U000030000000080X00003000004000160000500000P00017A4U3
0`0000`0000@00000000000000160000:00001`00017A4U30P000500003H0000N@0002H100000000
9@0000`0000800209`0001P00001000000000>KV000000009@0000`000010000>`0000P0000K0000
400007@0000E0@00F00004`00000000000000?oooooooooo300007406@5/01`1J00L0Eh0705E00h1
E@3n05D0kP1N0>00J03P06`0h01a0><0M03W03H0000@0000M`000>40001H0000C000000000000000
ooooooooool<0000L`3K06h0f01X0=P0F`3H0500j@1@0?h0D00C0E/0905X02@1KP0T0G<08@5g01/1
?@0000P0000l0000200003h0000H0000<`000000001J0000C00002D0000<00001`00P2D0000<0000
0000P2P0000<00000@0004H0000D0000200004M4BD<300003000010000000000000004H0000X0000
700004M4BD<20000H0000=P0002900009P400000000U0000300000P0080W00006000004000000000
i^H00000000U000030000040000k0000200001/0000@0000Q00001D1001H0000C000000000000000
ooooooooool<0000P@0I0G`0705h01`1KP0L0FD03P5U0?h0I@3^06h0h01h0>00O03P0840h`240>L0
=P00010000270000h@0005P0001<000000000000003oooooooooo``000230=/0OP3H07P0f01[0=P0
H03Y0600oP1P01<1J`0T0GP0905n02@1P`0Q0HL06`4m0000200003`000080000?P0001P000130000
000006X0001<00009@0000`0000700209@0000`000000020:00000`000010000AP0001@000080000
AdA9@`<0000<00004000000000000000AP0002P0000L0000AdA9@`80001`0000f00009T0000V0@00
000002D0000<00002000P2L0000H00000@000000003ViP00000002D0000<00000@0003/000080000
6`000100002D00005@4005P0001<000000000000003oooooooooo``0002A01T1S00L0HP0705n01`1
M@0>0GD0oP1e0>h0OP3P08P0h02<0>00T@3S09@0i`0f0000400009L0003Q0000F00004`000000000
00000?oooooooooo300009<0f`2>0=P0R03H07/0f01`0>T0L03n07004`5k02@1R00T0Hh0906C0241
U`0K0Cd000080000?00000P0000n0000600005<000000000NP0004`0000U0000300000L0080U0000
30000000080X00003000004000160000500000P00017A4U30`0000`0000@00000000000000160000
:00001`00017A4U30P000800003H0000Z@0002H1000000009@0000`0000800209`0001P000010000
00000>KV000000009@0000`000010000>`0000P0000K000040000:@0000E0@00F00004`000000000
00000?oooooooooo30000:406@6L01`1V00L0Hh0706500h1Q@3n08D0kP2>0>00V03P09`0h02Q0><0
Y03W03H0000@0000Y`000>40001H0000C000000000000000ooooooooool<0000X`3K09h0f02H0=P0
R`3H0800j@200?h0P00C0H/0906H02@1WP0T0J<08@6W01/1?@0000P0000l0000200003h0000H0000
H`000000002:0000C00002D0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000
200004M4BD<300003000010000000000000004H0000X0000700004M4BD<20000T0000=P0002i0000
9P400000000U0000300000P0080W00006000004000000000i^H00000000U000030000040000k0000
200001/0000@0000]00001D1001H0000C000000000000000ooooooooool<0000/@0I0J`0706X01`1
WP0L0ID03P6E0?h0U@3^09h0h02X0>00[03P0;40h`2d0>L0=P000100002g0000h@0005P0001<0000
00000000003oooooooooo``0002c0=/0[P3H0:P0f02K0=P0T03Y0900oP2@01<1V`0T0JP0906^02@1
/`0Q0KL06`4m0000200003`000080000?P0001P0001c0000000009X0001<00009@0000`000070020
9@0000`000000020:00000`000010000AP0001@000080000AdA9@`<0000<00004000000000000000
AP0002P0000L0000AdA9@`80002P0000f0000<T0000V0@00000002D0000<00002000P2L0000H0000
0@000000003ViP00000002D0000<00000@0003/0000800006`000100003400005@4005P0001<0000
00000000003oooooooooo``0003101T1_00L0KP0706^01`1Y@0>0JD0oP2U0>h0[P3P0;P0h02l0>00
`@3S0<@0i`0f000040000<L0003Q0000F00004`00000000000000?oooooooooo30000<<0f`2n0=P0
^03H0:/0f02P0>T0X03n0:004`6[02@1^00T0Kh090730241a`0K0Cd000080000?00000P0000n0000
600008<000000000ZP0004`0000U0000300000L0080U000030000000080X00003000004000160000
500000P00017A4U30`0000`0000@00000000000000160000:00001`00017A4U30P0004d0000=0@00
I00005`100000000G`0003P000010000>0000000000h0000000000020@06000000000>KV00000000
00000000000U000030000040000U0000300000D0081G0000900003L0000l0000?`0007`000020000
F00H0EP0D04U0000300000P0080X000030000040000W00006000004000000000i^H00000000U0000
30000040000Z0000600005<0000C0@00G`0001l1000Z0000600005<0001;0@00G`0005L1000U0000
300000L0080U000030000000080X00003000004000160000500000P00017A4U30`0000`0000@0000
0000000000160000:00001`00017A4U30P0001`0000O0@00F@0004/1000000008@0000P0000F0000
30000000000H000030000000000I000030000?ooo`0A0000300000P0000;0000400003/0000Z0000
3000010000000000B00000X0000@0000000000000009000040000<0200000P009@0000`000000020
9@0000`000070020600000`0000000004P0000`0000100006@0000`0003oool05P0000`0000H0000
2P00010000000000000000T0000@0000`0800002001B0000L04000400020o_oo0000000000000000
T040000000040P0@E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0000000000000000000000000
000000000000000000000000502`8a@0o=PB06`Ck7MX9>Mgooooo`40001?OOAg`1dD00P0000XXaD0
e=HB0<0M50341oEg`5OgM`0000010000I7H02000001^01l0T>HB09;_S30j0000000008cG4P1LfQ80
?000006m03010@00`=DB0000001LfQ80000001PfR7OoooooV=HB09BBigL001<02@0002RS5@2`eQ80
A03a0l06mGL10000j`DQiP`2002_2?Egj`DQiP0000000P002@000<]`m7O[1B7V`080004000000000
308004@0l@<10000?=LB0:RHm7O[1B7V`0800002001TMP08000002D0000<00000@0005@0001D0000
:P0004T0000c0000J`000040000HWBM0010T@?H1001P0@000@0004`00000000000000000003ooooo
oooooe00000Y0000M`0005@0001D0000500004T0000M0000J`000040000HWBM0010T@?@0001P0@00
0@0004`00000000000000000003ooooooooooe00000X0000M`000580001`0@000`00083nool00000
00000000002@0@000@0000@2011D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP00000000000000
00000000000000000000000000000000000QiP0000000P002@000<]`m7O[1B7V`080004000000000
308004@0l@<10000?=LB0:RHm7O[1B7V`0800002001TMP08000006h07`2@iQ80T^n<<3X000000000
S=LB05cJ4P0l00000Kd0<0410030eA80000005cJ4P00000063J8MooooonHeQ80U9;WM`004`090000
::<E0;3F4P140?43`0KeM`40003[1B7V30800:l8mGO[1B7V0000000200090000bg3dMn/58NK00P00
0@000000000U0000::<E0>3F4P3K1@00U`ceM`40000000000@0006Af00P000009@0000`000030000
:00000`000010000E00005@0000O0000B00002P0001[00000@0001RM9d0042A0LP40060100010000
C00000000000000000000?ooooooooooD00007@0001[0000E00005@000040000B0000100001[0000
0@0001RM9d0042A0AP00060100010000C00000000000000000000?ooooooooooD00004T0001g0000
DP00070100010000400000L00000000000000;`20000000010824U@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^00000000000000000000000000000000000000000000000001@0`1dD000200090000
bg3dMn/58NK00P000@000000000U0000::<E0>3F4P3K1@00U`ceM`40000000000@0006Af00P00000
KP0O093V4P2Bkh``000C00@00000ea80G=XB03`00001_@0`0@400<3E4P000000R=HB0000R7LH=XQg
oooooiSF4P2DT^Mg000C000000307A@0f`D:]/0M5030EoMg0@000>/58NH<0P00[`SeMfCF4P000000
o=PB06`Ck7MX9>Mgooooo`40001?OOAg`1dD00P0000XXaD0e=HB0<0M50341oEg`5OgM`0000010000
I7H02000000U000030000040000X0000300000<0000U0000300000L0080U000030000000080`0000
300000l0080U000030000080001;00004000000000050000:00000`0000100009@0000`000000020
9@0000`0000700208P0000`0003oooooAP0001@000080000AdA9@`<0000<00004000000000000000
AP0002P0000L0000AdA9@`80001g0000A`400<H0001c0@0000000240000800005P0000`000000000
600000`0000000006@0000`0003oool04@0000`0000800002`000100001=0000:P0000`0000@0000
F`000700000:000040000000000000002@000100002P0`00008002D0000<00000000P2D0000<0000
1`00P1P0000<000000000180000<00000@0001T0000<0000oooo01H0000<0000600000X0000@0000
000000000009000040000:0300000P00DP00070100010000P?koo`00000000000000090100000000
108045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^000000000000000000000000000000000000
00000000000001@0/2<D0?cH4P1/4nagJ2CWMoooool10000CggdMl0M50080000::<E0=CF4P307A@0
a0OeMl1GmgL000000@0006Af00P00000KP0O093V4P2Bkh``>P000000002<ea80G=XB03`00001_@0`
0@400<3E4P000000G=XB0000000H=XQgoooooiSF4P2DT^Mg000C00T0000XXaD0/=HB04@0lP?01_Eg
0@000>/58NH<0P00[`SeMn/58NH00000008000T0003;L?Agj`DQiZ0300010000000000`200140?83
0@0003cG4P2XV?Agj`DQiZ0300000P00I7H02000000U000030000040001D0000F00008h0001a0000
X@0009<000010000`_8U@00@941R0P00H0400080001<00000000000000000000oooooooooom@0000
:@0Y07T0001h0000E00005@0001h0000L@000840002C00000@000<;b9D0042A0H040060100010000
C00000000000000000000?ooooooooooD00002P0001i0000DP00070100030000P?koo`0000000000
0000090100010000108045@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^00000000000000000000
0000000000000000000000000000027V0000000200090000bg3dMn/58NJP0`000@000000000<0P00
A03b0`40000lea80Z9SdMn/58NJP0`00008006Af00P00000KP0O093V4P2Bkh``>P000000002<ea80
G=XB03`00001_@0`0@400<3E4P000000G=XB0000000H=XQgoooooiSF4P2DT^Mg000C00T0000XXaD0
/=HB04@0lP?01_Eg0@000>/58NH<0P00[`SeMn/58NH00000008000T0003;L?Agj`DQiZ0300010000
000002D0000XXaD0h=HB0=/5002G3?Eg0@00000000010000I7H02000000U0000300000<0000X0000
30000040001D0000E00008<0001`0000S00009<000010000`_8U@00@943N0@00H0400040001<0000
0000000000000000oooooooooom@0000M00006`0001D0000E00005d0001`0000M00009<000010000
`_8U@00@940F0000H0400040001<00000000000000000000oooooooooom@0000E@0000T1001B0000
L0400040000@00001`00000000000000_080000000040P8BE01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h000000000000000000000000000000000000000000000000050307A@0008000T0003;L?Ag
j`DQiZ0300010000000002D0000XXaD0h=HB0=/5002G3?Eg0@00000000010000I7H02000001^01l0
T>HB09;_S30001<01000003G4P1LfQ80?000006m03010@00`=DB00000028eQ800028MaPfR7Oooooo
V=HB09BBigL001<000000<0M503K1@Zh`1dD0<1GmgL10000j`DQiP`2002_2?EgI=HB0000003lf180
K1?/MfPTigOooooo0@0004mmm7O07A@0200002RS5@3DeQ80`1dD0<@7mGO0EoMg00000040001TMP08
000002D0000<00000@0002P0000<00000`0002D0000<00001`00P2D0000<00000000P300000<0000
3`00P2D0000<00000P0004/0000@0000000000D0000X000030000040000U000030000000080U0000
300000L0080R000030000?oooom60000500000P00017A4U30`0000`0000@00000000000000160000
:00001`00017A4U30P0004T0000T0@00J00005D100000000G`0003P000010000>0000000000h0000
000000020@06000000000>KV0000000000000000000U000030000040000U0000300000D0081G0000
900003L0001_0000?`0007`000020000F01;0EP0D04U0000300000P0080X000030000040000W0000
6000004000000000i^H00000000U000030000040001F0000:0000300001@0000A`0007H000030000
I01>0EP0:05=04h19@0000`0000700209@0000`000000020:00000`000010000AP0001@000080000
AdA9@`<0000<000040000000000000009@0000`0000500209@0000`000080020:`0001P0000j0000
Z04007H0003:0@009@0000`0000000209@0000`000070020600000`0000000026@0000`0003oool2
6`00010000000000000001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000F0000
300001P0000B000030000040001D0000H00002H0003A0000C@000>d000010000003j@@00nT530000
`04000<0001<00000000000000000000oooooooooomD0000N00m0300000=00003P0000d0000F0000
30000000000B000030000080000B000030000080000<00004000000000000000AP0002P0000L0000
AdA9@`80002o0000M`400<80002J0@00000005l0000h00000@0003P000000000>000000000000P40
0@0000000000000000000000000000009@0000`0000100009@0000`000050020E`0002@0002Q0000
WP000:D0003200000P000<00N07009P19@0000`000070020:00000`0000100009@0000`000000020
AP0001@000080000AdA9@`<0000<000040000000000000009@0000`0000800209@0000`000050020
9@0000`0000=0020:00000`0000200003P0001@000000000400001@0
\>"], "Graphics",
  InitializationCell->True,
  ImageSize->{325, 154.938},
  ImageMargins->{{27, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Magnetic field strength H", "Subsection",
  InitializationCell->True],

Cell[TextData[{
  "The following equation is designated as the ",
  StyleBox["second magnetostrictive equation",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  " of the linear model. The classical relationship between magnetic field \
strength and flux density (B=\[Mu] H) is extended by strain"
}], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(H[x_, t_] := 1\/\[Mu]R*B[t] - \[Theta]\ \[Epsilon][x, t]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "With:",
  StyleBox["\nH:\tMagnetic field strength (SI unit ",
    FontSlant->"Plain"],
  Cell[BoxData[
      \(TraditionalForm\`Ampere\/Meter\)]],
  "). The magnetic field strength"
}], "Text",
  InitializationCell->True,
  FontSlant->"Italic"],

Cell[TextData[StyleBox["Verification:",
  FontSlant->"Italic"]], "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(H[x, t]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(-\(\(\[ImaginaryI]\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ \
Ud\)\/\(A\ N\ w\ \[Mu]R\)\)\) - \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ \
\[Theta]\ \((\(a2\ w\ Cos[\(w\ x\)\/cR]\)\/cR - \(a1\ w\ Sin[\(w\ \
x\)\/cR]\)\/cR)\)\)], "Output"]
}, Open  ]],

Cell["\<\
Contrary to the flux density, the field strength varies in between the rod. \
Therefore H has to be integrated over the length of the coil. In the \
following consideration the solenoid is placed at the free end of the rod, \
with a yet unknown length lCoil1:\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(Hq[t_] := \[Integral]\_x1\%\(x1 + lCoil1\)\(H[x, 
                t]\/lCoil1\) \[DifferentialD]x\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "With:",
  StyleBox["\nHq:\tAverage magnetic flux density in the solenoid\n",
    FontSlant->"Plain"],
  "lCoil1",
  StyleBox[":\tLength of the solenoid\nx1:\tLocation of the coil",
    FontSlant->"Plain"]
}], "Text",
  InitializationCell->True,
  FontSlant->"Italic"],

Cell["Verification:", "Text",
  InitializationCell->True,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Hq[t]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(1\/lCoil1\)\((\(-\(\(\[ImaginaryI]\ \
\[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ lCoil1\ Ud\)\/\(A\ N\ w\ \[Mu]R\)\)\
\) + a1\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ \[Theta]\ Cos[\(w\ \
x1\)\/cR] - 
        a1\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ \[Theta]\ Cos[\(w\ \
\((lCoil1 + x1)\)\)\/cR] + 
        a2\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ \[Theta]\ Sin[\(w\ x1\)\
\/cR] - a2\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ \[Theta]\ Sin[\(w\ \
\((lCoil1 + x1)\)\)\/cR])\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Current i", "Subsection",
  InitializationCell->True],

Cell["\<\
The current i is proportional to the (average) magnetic field strength, \
assuming an ideal solenoid:\
\>", "SmallText",
  InitializationCell->True],

Cell[BoxData[
    \(i[t_] := \(\(Hq[t]*lCoil1\)\/N\)/K1\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "With:",
  StyleBox["\ni:\tCurrent through solenoid\nK1:\tA combined factor of \
geometry factor and field factor of the coil. For K=1 it becomes an equation \
for an ideal solenoid. ",
    FontSlant->"Plain"]
}], "Text",
  InitializationCell->True,
  FontSlant->"Italic"],

Cell["Verification:", "Text",
  InitializationCell->True,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[BoxData[
    \(i[t]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(1\/\(K1\ N\)\)\((\(-\(\(\[ImaginaryI]\ \[ExponentialE]\^\(\
\[ImaginaryI]\ t\ w\)\ lCoil1\ Ud\)\/\(A\ N\ w\ \[Mu]R\)\)\) + 
        a1\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ \[Theta]\ Cos[\(w\ x1\)\
\/cR] - a1\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ \[Theta]\ Cos[\(w\ \
\((lCoil1 + x1)\)\)\/cR] + 
        a2\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ \[Theta]\ Sin[\(w\ x1\)\
\/cR] - a2\ \[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ \[Theta]\ Sin[\(w\ \
\((lCoil1 + x1)\)\)\/cR])\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
This shows that the current is approximately proportional to the amplitude \
coefficient a1 (a2 is small near the resonance frequencies)!\
\>", "Text",
  InitializationCell->True,
  FontWeight->"Bold"],

Cell["\<\
Including the displacement coefficients which where derived by using the \
boundary conditions:\
\>", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ia[t_] = FullSimplify[i[t] /. Flatten[{rulea1, rulea2}]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(-\(\((\[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ Ud\ \((cR\ ER\ lCoil1\
\ w\ ZC\ Cos[\(lRod\ w\)\/cR] + \[ImaginaryI]\ \((A\ cR\ ER\ \[Theta]\^2\ \
\[Mu]R\ Cos[\(w\ \((lRod - x1)\)\)\/cR] - 
                      A\ cR\ ER\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ x1\)\/cR] + 
                      A\ cR\ ER\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ \((lCoil1 + \
x1)\)\)\/cR] - 
                      A\ cR\ ER\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ \((lCoil1 - \
lRod + x1)\)\)\/cR] + 
                      A\ ER\^2\ lCoil1\ w\ Sin[\(lRod\ w\)\/cR] + \
\[ImaginaryI]\ cR\^2\ ZC\ \[Theta]\^2\ \[Mu]R\ Sin[\(w\ \((lRod - \
x1)\)\)\/cR] + \[ImaginaryI]\ cR\^2\ ZC\ \[Theta]\^2\ \[Mu]R\ Sin[\(w\ \
\((lCoil1 - lRod + x1)\)\)\/cR])\))\))\)/\((A\ ER\ K1\ N\^2\ w\^2\ \[Mu]R\ \
\((\(-\[ImaginaryI]\)\ cR\ ZC\ Cos[\(lRod\ w\)\/cR] + 
                A\ ER\ Sin[\(lRod\ w\)\/cR])\))\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["With:",
    FontSlant->"Italic"],
  "\nia:\tCurrent through solenoid"
}], "Text",
  InitializationCell->True],

Cell[TextData[StyleBox["Verification:",
  FontSlant->"Italic"]], "Text",
  InitializationCell->True],

Cell[BoxData[
    \( (*FullSimplify[ia[t] /. {ZC \[Rule] 0, lCoil1 -> lRod}]*) \)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \( (*FullSimplify[ia[t] /. {ZC \[Rule] 0}]*) \)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Electric Impedance Z", "Subsection",
  InitializationCell->True],

Cell[BoxData[
    \(Z := Simplify[U[t]/ia[t]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["With:",
    FontSlant->"Italic"],
  "\nZ:\tElectric impedance of coil"
}], "Text",
  InitializationCell->True],

Cell[TextData[StyleBox["Verification:",
  FontSlant->"Italic"]], "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[Z /. {ZC \[Rule] 0, lCoil1 -> lRod}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[ImaginaryI]\ A\ ER\ K1\ N\^2\ w\^2\ \[Mu]R\ Sin[\(lRod\ \
w\)\/cR]\)\/\(\(-4\)\ cR\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ x1\)\/cR]\ Sin[\(lRod\
\ w\)\/\(2\ cR\)]\^2 + ER\ lRod\ w\ Sin[\(lRod\ w\)\/cR]\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Magnetostrictive power", "Subsection",
  InitializationCell->True],

Cell["\<\
Electric power which goes into the solenoid (complex - real part is active \
power, complex part is reactive power):\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(P[t_] = U[t]*ia[t];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "This is the ",
  StyleBox["effective",
    FontWeight->"Bold"],
  " (time independent) apparent power:"
}], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(Pa = 
        1/2*Simplify[Abs[U[t]]]*Simplify[Abs[ia[t]], cond1];\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model verification", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Unit Verification", "Subsection",
  InitializationCell->True],

Cell["\<\
The following rule sets all variables with Units (but fictive values). For a \
description of the variables see chapter below:\
\>", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(values1u = {\[IndentingNewLine]\[Mu]0 -> 
          VacuumPermeability, \[IndentingNewLine]N -> 
          100, \[IndentingNewLine]r \[Rule] 
          2\ Milli\ Meter, \[IndentingNewLine]ER \[Rule] 
          200*10^9\ Pascal, \[IndentingNewLine]cR \[Rule] 
          4000\ Meter/
              Second, \[IndentingNewLine]\[Theta] \[Rule] \(-20\)*10^6\ \
Pascal/Tesla, \[IndentingNewLine]lRod \[Rule] 
          40/1000\ Meter, \[IndentingNewLine]x1 \[Rule] 10/1000\ Meter, \ 
        lCoil1 \[Rule] \ 20/1000\ Meter, \[IndentingNewLine]w \[Rule] \ 
          2\ \[Pi]\ 75000\ Hertz, \[IndentingNewLine]K1 -> 
          3/4\[IndentingNewLine]}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({\[Mu]0 \[Rule] \(\[Pi]\ Second\ Volt\)\/\(2500000\ Ampere\ Meter\), 
      N \[Rule] 100, r \[Rule] 2\ Meter\ Milli, 
      ER \[Rule] 200000000000\ Pascal, 
      cR \[Rule] \(4000\ Meter\)\/Second, \[Theta] \[Rule] \(-\(\(20000000\ \
Pascal\)\/Tesla\)\), lRod \[Rule] Meter\/25, x1 \[Rule] Meter\/100, 
      lCoil1 \[Rule] Meter\/50, w \[Rule] 150000\ Hertz\ \[Pi], 
      K1 \[Rule] 3\/4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(values2u = {\[IndentingNewLine]\[Mu]R \[Rule] \[Mu]0*60, \
\[IndentingNewLine]A \[Rule] \[Pi]\ r\^2} /. values1u\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({\[Mu]R \[Rule] \(3\ \[Pi]\ Second\ Volt\)\/\(125000\ Ampere\ Meter\), 
      A \[Rule] 4\ Meter\^2\ Milli\^2\ \[Pi]}\)], "Output"]
}, Open  ]],

Cell["\<\
The command \"Convert\" is successful. This proves the units to be all right:\
\
\>", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Convert[
        Z /. Flatten[{values1u, \ values2u, \ 
              ZC \[Rule] \((5 + 3  \[ImaginaryI])\) Kilo\ Gram/Second}], 
        Ohm] // N\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\((\(\(0.08183149307170048`\)\(\[InvisibleSpace]\)\) + 
          143.49330187223208`\ \[ImaginaryI])\)\ Ohm\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(H[ .005\ Meter, 1\ Second] /. 
      Flatten[{values1u, \ values2u, Ud \[Rule] 8.125\ Volt, 
          a1 \[Rule] 1*10^\(-8\)\ Meter, 
          a2 \[Rule] 1*10^\(-8\)\ Meter}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(-\(\(0.00018197480365954576`\ \[ImaginaryI]\ Ampere\ \
\[ExponentialE]\^\(150000\ \[ImaginaryI]\ Hertz\ \[Pi]\ Second\)\)\/\(Hertz\ \
Meter\ Milli\^2\ Second\)\)\) + \(20000000\ \[ExponentialE]\^\(150000\ \
\[ImaginaryI]\ Hertz\ \[Pi]\ Second\)\ Pascal\ \((\(3\ Hertz\ \[Pi]\ Second\ \
Cos[0.5890486225480862`\ Hertz\ Second]\)\/8000000 - \(3\ Hertz\ \[Pi]\ \
Second\ Sin[0.5890486225480862`\ Hertz\ Second]\)\/8000000)\)\)\/Tesla\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Convert[%, Ampere/Meter]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\((\(\(6.500725973139584`\)\(\[InvisibleSpace]\)\) - \
181.97480365954576`\ \[ImaginaryI])\)\ Ampere\)\/Meter\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numeric calculations", "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Values", "Subsubsection",
  InitializationCell->True],

Cell[TextData[StyleBox["All values are given in standard SI units!",
  FontWeight->"Bold"]], "Text",
  InitializationCell->True],

Cell["Permeability of Vacuum (w/o units):", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(val0 = {\[IndentingNewLine]\[Mu]0 -> 
          VacuumPermeability/\((Volt\ Second/\((Ampere\ Meter)\))\)}\)], \
"Input",
  InitializationCell->True],

Cell[BoxData[
    \({\[Mu]0 \[Rule] \[Pi]\/2500000}\)], "Output"]
}, Open  ]],

Cell["\<\
Properties of the rod and the solenoid (radius of coil = radius of solenoid).\
\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(val1 = {\[IndentingNewLine]N -> 
            100, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\  (*Number\ of\ turns\ on\ excitation\ coil*) \[IndentingNewLine]x1 \[Rule] 
            0, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \  (*Position\ of\ excitation\ coil\ in\ meter*) \[IndentingNewLine]r \
\[Rule] 2/
              1000, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*radius\ of\ rod\ and\ solenoid\ in\ meter\ *) \[IndentingNewLine]K1 \[Rule] 
            2/3, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*Geometry\ factor\ for\ excitation\ coil*) \[IndentingNewLine]lRod \[Rule] 
            40/1000, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*Length\ of\ rod\ in\ \
meter*) \[IndentingNewLine]ER \[Rule] 
            200*10^9, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*E - 
              modulus\ rod\ in\ Pa*) \[IndentingNewLine]cR \[Rule] 
            4700, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*sound\ velocity\ in\ meter/
                second*) \[IndentingNewLine]\[Theta] \[Rule] \(-10\)*10^6, \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*Magnetostrictive\ constant\ in\ \
xxxxxxxxxx*) \[IndentingNewLine]\[Mu]rR \[Rule] 
            60}\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \  (*relative\ permeability\ rod*) ;\)\)], "Input",
  InitializationCell->True],

Cell["Properties of the function generator:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(val2 = {\[IndentingNewLine]U0d \[Rule] 
            10, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*Amplitude\ in\ Volt\ \((NOT\ peak - \(peak!\))\)*) \[IndentingNewLine]Ri \
\[Rule] \ 
            50}\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  \
(*Internal\ resistance\ in\ Ohm*) ;\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(val3 = {\[IndentingNewLine]A \[Rule] \[Pi]\ r\^2, \[IndentingNewLine]\
\[Mu]R \[Rule] \[Mu]0*\[Mu]rR} /. Flatten[{val0, val1}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({A \[Rule] \[Pi]\/250000, \[Mu]R \[Rule] \(3\ \[Pi]\)\/125000}\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(values = Flatten[{val1, val2, val3}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({N \[Rule] 100, x1 \[Rule] 0, r \[Rule] 1\/500, K1 \[Rule] 2\/3, 
      lRod \[Rule] 1\/25, ER \[Rule] 200000000000, 
      cR \[Rule] 4700, \[Theta] \[Rule] \(-10000000\), \[Mu]rR \[Rule] 60, 
      U0d \[Rule] 10, Ri \[Rule] 50, 
      A \[Rule] \[Pi]\/250000, \[Mu]R \[Rule] \(3\ \[Pi]\)\/125000}\)], \
"Output"]
}, Open  ]],

Cell["\<\
Now the values are applied onto the coefficients a1 and a2, generating new \
rules:\
\>", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(valuerulea1 = rulea1 /. values\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({a1 \[Rule] \(-\(\(1175\ Ud\ \((\(-800000\)\ \[Pi] + 
                    800000\ \[Pi]\ Cos[w\/117500] + 
                    4700\ \[ImaginaryI]\ ZC\ Sin[
                        w\/117500])\)\)\/\(2\ \[Pi]\ w\^2\ \((4700\ ZC\ Cos[
                        w\/117500] + 
                    800000\ \[ImaginaryI]\ \[Pi]\ Sin[
                        w\/117500])\)\)\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(valuerulea2 = rulea2 /. values\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({a2 \[Rule] \(1175\ \[ImaginaryI]\ Ud\)\/\(2\ \[Pi]\ w\^2\)}\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(valuerulea = Flatten[{valuerulea1, valuerulea2}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({a1 \[Rule] \(-\(\(1175\ Ud\ \((\(-800000\)\ \[Pi] + 
                    800000\ \[Pi]\ Cos[w\/117500] + 
                    4700\ \[ImaginaryI]\ ZC\ Sin[
                        w\/117500])\)\)\/\(2\ \[Pi]\ w\^2\ \((4700\ ZC\ Cos[
                        w\/117500] + 
                    800000\ \[ImaginaryI]\ \[Pi]\ Sin[w\/117500])\)\)\)\), 
      a2 \[Rule] \(1175\ \[ImaginaryI]\ Ud\)\/\(2\ \[Pi]\ w\^2\)}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["Verification:",
  FontSlant->"Italic"]], "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(a1 /. valuerulea\) /. {ZC \[Rule] \((5 + 32  \[ImaginaryI])\), 
          w \[Rule] 2\ \[Pi]\ 78000} // N\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\((\(-1.3995648660798281`*^-11\) + 
          1.2838759988541273`*^-9\ \[ImaginaryI])\)\ Ud\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a2 /. valuerulea // N\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\((\(\(0.`\)\(\[InvisibleSpace]\)\) + 187.00705813297702`\ \
\[ImaginaryI])\)\ Ud\)\/w\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculating natural resonance frequencies for rod ", "Subsubsection",
  InitializationCell->True],

Cell["free-free", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(f1 = cR/\((2*lRod)\) /. values\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(58750\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f2 = 2*cR/\((2*lRod)\) /. values\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(117500\)], "Output"]
}, Open  ]],

Cell["free-fixed", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(f1f = cR/\((4*lRod)\) /. values\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(29375\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f2f = cR/\((4/3*lRod)\) /. values\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(88125\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plotting", "Section"],

Cell[CellGroupData[{

Cell["Amplitude at Constant Voltage (Artificial Case!)", "Subsection"],

Cell[BoxData[
    \(\(test1i = \(Abs[a1] /. valuerulea\) /. {w \[Rule] 2\ \[Pi]\ f, 
              ZC \[Rule] 0, Ud -> 10} // N;\)\)], "Input"],

Cell[BoxData[
    \(\(test2i = \(Abs[a1] /. valuerulea\) /. {w \[Rule] 2\ \[Pi]\ f, 
              ZC \[Rule] ZCexample1, Ud -> 10} // N;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{test1i, test2i}, {f, 50000, 70000}, PlotPoints \[Rule] 150, 
      PlotRange \[Rule] \ {0, 2/1000000}, 
      PlotStyle \[Rule] {{Thickness[ .004], 
            RGBColor[1, 0, 0]}, {Thickness[ .002], RGBColor[0, 1, 0]}}, 
      GridLines \[Rule] {{58750, 117.5}, None}, 
      Axes \[Rule] {True, True}]\)], "Input"],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(test2i\) is not a machine-size real number at \!\(f\) = \
\!\(50000.00013422819`\)."\)], "Message"],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(test2i\) is not a machine-size real number at \!\(f\) = \
\!\(50130.685610436245`\)."\)], "Message"],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(test2i\) is not a machine-size real number at \!\(f\) = \
\!\(50273.20955659396`\)."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Plot :: \"plnr\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.35714 4.7619e-005 0 309017 [
[.2619 -0.0125 -15 -9 ]
[.2619 -0.0125 15 0 ]
[.5 -0.0125 -15 -9 ]
[.5 -0.0125 15 0 ]
[.7381 -0.0125 -15 -9 ]
[.7381 -0.0125 15 0 ]
[.97619 -0.0125 -15 -9 ]
[.97619 -0.0125 15 0 ]
[.01131 .07725 -45 -6.25 ]
[.01131 .07725 0 6.25 ]
[.01131 .15451 -33 -6.25 ]
[.01131 .15451 0 6.25 ]
[.01131 .23176 -45 -6.25 ]
[.01131 .23176 0 6.25 ]
[.01131 .30902 -33 -6.25 ]
[.01131 .30902 0 6.25 ]
[.01131 .38627 -51 -6.25 ]
[.01131 .38627 0 6.25 ]
[.01131 .46353 -45 -6.25 ]
[.01131 .46353 0 6.25 ]
[.01131 .54078 -51 -6.25 ]
[.01131 .54078 0 6.25 ]
[.01131 .61803 -33 -6.25 ]
[.01131 .61803 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.44048 0 m
.44048 .61803 L
s
0 g
.2619 0 m
.2619 .00625 L
s
[(55000)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(60000)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(65000)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(70000)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
gsave
.01131 .07725 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .15451 m
.03006 .15451 L
s
gsave
.01131 .15451 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .23176 m
.03006 .23176 L
s
gsave
.01131 .23176 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .30902 m
.03006 .30902 L
s
gsave
.01131 .30902 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .38627 m
.03006 .38627 L
s
gsave
.01131 .38627 -51 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.25) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .46353 m
.03006 .46353 L
s
gsave
.01131 .46353 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .54078 m
.03006 .54078 L
s
gsave
.01131 .54078 -51 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.75) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .61803 m
.03006 .61803 L
s
gsave
.01131 .61803 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.004 w
.02381 .02457 m
.03003 .02483 L
.03682 .02512 L
.04319 .0254 L
.04932 .02568 L
.05585 .02599 L
.06213 .02629 L
.0688 .02663 L
.07524 .02697 L
.08142 .02731 L
.08801 .02769 L
.09434 .02806 L
.10044 .02843 L
.10693 .02885 L
.11317 .02926 L
.11981 .02972 L
.12621 .03019 L
.13236 .03065 L
.13891 .03116 L
.14521 .03168 L
.15191 .03226 L
.15836 .03284 L
.16457 .03342 L
.17118 .03408 L
.17754 .03474 L
.18365 .03541 L
.19016 .03616 L
.19643 .03692 L
.20309 .03777 L
.20951 .03864 L
.21569 .03952 L
.22225 .04051 L
.22858 .04153 L
.23466 .04257 L
.24114 .04374 L
.24737 .04495 L
.25399 .04633 L
.26038 .04775 L
.26651 .04921 L
.27305 .05089 L
.27934 .05263 L
.28602 .05465 L
.29246 .05676 L
.29866 .05897 L
.30525 .06156 L
.3116 .06429 L
.3177 .06719 L
.3242 .07061 L
.33045 .07429 L
.3371 .07869 L
Mistroke
.3435 .0835 L
.34966 .08877 L
.35622 .09523 L
.36253 .10247 L
.36924 .11158 L
.3757 .12214 L
.38192 .13451 L
.38853 .15091 L
.3949 .17121 L
.40102 .19692 L
.40443 .21504 L
.40754 .23481 L
.41382 .28878 L
.4169 .32578 L
.42024 .37876 L
.42343 .44866 L
.42505 .49492 L
.42682 .55855 L
Mfstroke
.42682 .55855 m
.42811 .61803 L
s
.45262 .61803 m
.45283 .60597 L
.45439 .53757 L
.45604 .47992 L
.45901 .40221 L
.46215 .34319 L
.46509 .30149 L
.46835 .26568 L
.47133 .2395 L
.47771 .19752 L
.48385 .16882 L
.49039 .14603 L
.49668 .1291 L
.50337 .11482 L
.50981 .10368 L
.51601 .09475 L
.52261 .08673 L
.52896 .08015 L
.53506 .07465 L
.54156 .06952 L
.54782 .06518 L
.55447 .06109 L
.56088 .05757 L
.56704 .05453 L
.5736 .0516 L
.57992 .04905 L
.58663 .04657 L
.59309 .0444 L
.59931 .04247 L
.60593 .04058 L
.6123 .0389 L
.61843 .0374 L
.62495 .03591 L
.63123 .03457 L
.6379 .03324 L
.64433 .03205 L
.65052 .03097 L
.6571 .02989 L
.66344 .02891 L
.66953 .02802 L
.67602 .02712 L
.68226 .0263 L
.6889 .02548 L
.69529 .02473 L
.70144 .02404 L
.70799 .02334 L
.71429 .02271 L
.72098 .02206 L
.72743 .02146 L
.73364 .02092 L
Mistroke
.74024 .02036 L
.7466 .01985 L
.75272 .01938 L
.75923 .01889 L
.76549 .01845 L
.77215 .01799 L
.77857 .01757 L
.78474 .01718 L
.79131 .01678 L
.79763 .01641 L
.80371 .01606 L
.81018 .01571 L
.81641 .01538 L
.82304 .01504 L
.82942 .01473 L
.83555 .01444 L
.84208 .01414 L
.84837 .01386 L
.85505 .01357 L
.86149 .0133 L
.86768 .01305 L
.87427 .01279 L
.88062 .01255 L
.88672 .01233 L
.89322 .01209 L
.89947 .01187 L
.90611 .01165 L
.91252 .01144 L
.91867 .01124 L
.92523 .01104 L
.93154 .01085 L
.93824 .01065 L
.9447 .01047 L
.95092 .01029 L
.95753 .01011 L
.96389 .00994 L
.97002 .00979 L
.97619 .00963 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{90.625, 320}, {356.75, 215.438}} -> {34655.8, \
3.52054*^-06, 91.8033, 1.41467*^-08}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Impedance Plots", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Plotting the electrical Impedance, once with long coil and once with short \
coil\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(test1 = 
      Abs[\(\(Z /. lCoil1 \[Rule] lRod\) /. values\) /. {ZC \[Rule] 0, 
              w \[Rule] 2\ \[Pi]\ f}] // N\)], "Input"],

Cell[BoxData[
    \(1.2534566288805127`*^14\ f\^2\ Abs[
        Sin[0.00005347391750791138`\ f]\/\(\(-1.7812662023086073`*^20\) + \
1.7812662023086073`*^20\ Cos[0.00005347391750791138`\ f] + \
1.2633093633394378`*^17\ f\ Sin[0.00005347391750791138`\ f]\)]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(test2 = 
        Abs[\(\(Z /. lCoil1 \[Rule] lRod/2\) /. values\) /. {ZC \[Rule] 0, 
                w \[Rule] 2\ \[Pi]\ f}] // N;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogLinearPlot[{test1, test2}, {f, 10000, 200000}, 
      PlotRange \[Rule] Automatic, 
      PlotStyle \[Rule] {{Thickness[ .004], 
            RGBColor[1, 0, 0]}, {Thickness[ .002], 
            RGBColor[0, 1, 0]}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.90427 0.732021 0.0147151 0.000783688 [
[.02381 -0.0125 -17 -12.5625 ]
[.02381 -0.0125 17 0 ]
[.15271 -0.0125 -17 -12.5625 ]
[.15271 -0.0125 17 0 ]
[.24417 -0.0125 -17 -12.5625 ]
[.24417 -0.0125 17 0 ]
[.37307 -0.0125 -17 -12.5625 ]
[.37307 -0.0125 17 0 ]
[.53547 -0.0125 -17 -12.5625 ]
[.53547 -0.0125 17 0 ]
[.64244 -0.0125 -17 -12.5625 ]
[.64244 -0.0125 17 0 ]
[.75583 -0.0125 -23 -12.5625 ]
[.75583 -0.0125 23 0 ]
[.88473 -0.0125 -23 -12.5625 ]
[.88473 -0.0125 23 0 ]
[.97619 -0.0125 -23 -12.5625 ]
[.97619 -0.0125 23 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09308 -18 -4.5 ]
[-0.0125 .09308 0 4.5 ]
[-0.0125 .17145 -18 -4.5 ]
[-0.0125 .17145 0 4.5 ]
[-0.0125 .24982 -18 -4.5 ]
[-0.0125 .24982 0 4.5 ]
[-0.0125 .32819 -18 -4.5 ]
[-0.0125 .32819 0 4.5 ]
[-0.0125 .40656 -18 -4.5 ]
[-0.0125 .40656 0 4.5 ]
[-0.0125 .48493 -18 -4.5 ]
[-0.0125 .48493 0 4.5 ]
[-0.0125 .5633 -18 -4.5 ]
[-0.0125 .5633 0 4.5 ]
[ 0 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.15271 0 m
.15271 .00625 L
s
gsave
.15271 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.24417 0 m
.24417 .00625 L
s
gsave
.24417 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.37307 0 m
.37307 .00625 L
s
gsave
.37307 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.53547 0 m
.53547 .00625 L
s
gsave
.53547 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.64244 0 m
.64244 .00625 L
s
gsave
.64244 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.75583 0 m
.75583 .00625 L
s
gsave
.75583 -0.0125 -84 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100000.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.88473 0 m
.88473 .00625 L
s
gsave
.88473 -0.0125 -84 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150000.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -84 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200000.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.05411 0 m
.05411 .00375 L
s
.08177 0 m
.08177 .00375 L
s
.10722 0 m
.10722 .00375 L
s
.13078 0 m
.13078 .00375 L
s
.17323 0 m
.17323 .00375 L
s
.1925 0 m
.1925 .00375 L
s
.21067 0 m
.21067 .00375 L
s
.22786 0 m
.22786 .00375 L
s
.46453 0 m
.46453 .00375 L
s
.59343 0 m
.59343 .00375 L
s
.68489 0 m
.68489 .00375 L
s
.72233 0 m
.72233 .00375 L
s
.78613 0 m
.78613 .00375 L
s
.81379 0 m
.81379 .00375 L
s
.83924 0 m
.83924 .00375 L
s
.8628 0 m
.8628 .00375 L
s
.90525 0 m
.90525 .00375 L
s
.92452 0 m
.92452 .00375 L
s
.9427 0 m
.9427 .00375 L
s
.95988 0 m
.95988 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09308 m
.00625 .09308 L
s
[(100)] -0.0125 .09308 1 0 Mshowa
0 .17145 m
.00625 .17145 L
s
[(200)] -0.0125 .17145 1 0 Mshowa
0 .24982 m
.00625 .24982 L
s
[(300)] -0.0125 .24982 1 0 Mshowa
0 .32819 m
.00625 .32819 L
s
[(400)] -0.0125 .32819 1 0 Mshowa
0 .40656 m
.00625 .40656 L
s
[(500)] -0.0125 .40656 1 0 Mshowa
0 .48493 m
.00625 .48493 L
s
[(600)] -0.0125 .48493 1 0 Mshowa
0 .5633 m
.00625 .5633 L
s
[(700)] -0.0125 .5633 1 0 Mshowa
.125 Mabswid
0 .03039 m
.00375 .03039 L
s
0 .04606 m
.00375 .04606 L
s
0 .06174 m
.00375 .06174 L
s
0 .07741 m
.00375 .07741 L
s
0 .10876 m
.00375 .10876 L
s
0 .12443 m
.00375 .12443 L
s
0 .14011 m
.00375 .14011 L
s
0 .15578 m
.00375 .15578 L
s
0 .18713 m
.00375 .18713 L
s
0 .2028 m
.00375 .2028 L
s
0 .21847 m
.00375 .21847 L
s
0 .23415 m
.00375 .23415 L
s
0 .2655 m
.00375 .2655 L
s
0 .28117 m
.00375 .28117 L
s
0 .29684 m
.00375 .29684 L
s
0 .31252 m
.00375 .31252 L
s
0 .34386 m
.00375 .34386 L
s
0 .35954 m
.00375 .35954 L
s
0 .37521 m
.00375 .37521 L
s
0 .39089 m
.00375 .39089 L
s
0 .42223 m
.00375 .42223 L
s
0 .43791 m
.00375 .43791 L
s
0 .45358 m
.00375 .45358 L
s
0 .46925 m
.00375 .46925 L
s
0 .5006 m
.00375 .5006 L
s
0 .51628 m
.00375 .51628 L
s
0 .53195 m
.00375 .53195 L
s
0 .54762 m
.00375 .54762 L
s
0 .57897 m
.00375 .57897 L
s
0 .59464 m
.00375 .59464 L
s
0 .61032 m
.00375 .61032 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.004 w
.02381 .0228 m
.1251 .02585 L
.20547 .02907 L
.32897 .03598 L
.4101 .04239 L
.4477 .04609 L
.47843 .04962 L
.5078 .05369 L
.5327 .05819 L
.54438 .06111 L
.55011 .06295 L
.5563 .06552 L
.55949 .06723 L
.56239 .06915 L
.56569 .07203 L
.5672 .07371 L
.5688 .07587 L
.57029 .07836 L
.57164 .0812 L
.57298 .08484 L
.57424 .08939 L
.57572 .09699 L
.57706 .108 L
.57776 .11664 L
.57853 .13035 L
.57934 .15378 L
.58008 .19554 L
s
.58008 .19554 m
.58101 .61803 L
s
.58198 .61803 m
.58217 .54302 L
.58294 .16523 L
.58429 .05984 L
.58555 .02932 L
.58627 .01954 L
.58703 .01731 L
.58838 .02638 L
.58913 .03001 L
.58983 .0328 L
.5914 .03767 L
.59277 .04083 L
.59406 .0432 L
.59645 .0466 L
.59901 .04929 L
.60176 .05154 L
.60655 .05449 L
.61155 .05682 L
.62032 .05996 L
.63878 .06496 L
.65514 .06872 L
.68726 .07577 L
.71819 .08275 L
.74538 .08928 L
.76951 .09549 L
.79332 .10206 L
.81467 .10837 L
.83589 .11508 L
.85508 .12158 L
.87251 .12792 L
.89006 .13483 L
.90609 .14194 L
.91386 .14597 L
.92077 .15044 L
.92259 .15191 L
.92454 .15376 L
.92623 .15571 L
.92807 .1585 L
.92907 .1605 L
.93001 .1629 L
.931 .16634 L
.93155 .16893 L
.93206 .17197 L
.9325 .17538 L
.93297 .18033 L
.93341 .18702 L
.93382 .19628 L
.9343 .21525 L
.93454 .2322 L
.93481 .26514 L
Mistroke
.93527 .53873 L
.9357 .18947 L
.93616 .04533 L
.93659 .08645 L
.93698 .10343 L
.9374 .11426 L
.93786 .12176 L
.93809 .12458 L
.93835 .12719 L
.9388 .13089 L
.93922 .13354 L
.94003 .13738 L
.94089 .14036 L
.94166 .14238 L
.94246 .14411 L
.94426 .14709 L
.94592 .14918 L
.94968 .15275 L
.95664 .15768 L
.96285 .16139 L
.97579 .16854 L
.97619 .16876 L
Mfstroke
0 1 0 r
.002 w
.02381 .03089 m
.1251 .03698 L
.20547 .04342 L
.32897 .05725 L
.4101 .07006 L
.4477 .07746 L
.47843 .08453 L
.5078 .09266 L
.5327 .10167 L
.54438 .1075 L
.55011 .11119 L
.5563 .11632 L
.55949 .11975 L
.56239 .12359 L
.56569 .12934 L
.5672 .1327 L
.5688 .13702 L
.57029 .14201 L
.57164 .14768 L
.57298 .15497 L
.57424 .16407 L
.57572 .17926 L
.57706 .20129 L
.57776 .21856 L
.57853 .24598 L
.57934 .29285 L
.58008 .37637 L
s
.58008 .37637 m
.58035 .61803 L
s
.58263 .61803 m
.58294 .31575 L
.58429 .10496 L
.58555 .04392 L
.58627 .02436 L
.58703 .0199 L
.58838 .03804 L
.58913 .04531 L
.58983 .05088 L
.5914 .06063 L
.59277 .06695 L
.59406 .07169 L
.59645 .07848 L
.59901 .08387 L
.60176 .08836 L
.60655 .09426 L
.61155 .09892 L
.62032 .10521 L
.63878 .1152 L
.65514 .12273 L
.68726 .13683 L
.71819 .15078 L
.74538 .16385 L
.76951 .17627 L
.79332 .1894 L
.81467 .20202 L
.83589 .21544 L
.85508 .22845 L
.87251 .24112 L
.89006 .25495 L
.90609 .26916 L
.91386 .27723 L
.92077 .28616 L
.92259 .2891 L
.92454 .29281 L
.92623 .2967 L
.92807 .30228 L
.92907 .30629 L
.93001 .31109 L
.931 .31796 L
.93155 .32315 L
.93206 .32923 L
.9325 .33604 L
.93297 .34595 L
.93341 .35932 L
.93382 .37785 L
.9343 .41578 L
.93454 .44969 L
.93481 .51556 L
s
.93481 .51556 m
.93489 .61803 L
s
.93554 .61803 m
.9357 .36423 L
.93616 .07595 L
.93659 .15818 L
.93698 .19215 L
.9374 .21381 L
.93786 .22881 L
.93809 .23445 L
.93835 .23966 L
.9388 .24707 L
.93922 .25237 L
.94003 .26005 L
.94089 .26601 L
.94166 .27005 L
.94246 .27351 L
.94426 .27946 L
.94592 .28365 L
.94968 .29079 L
.95664 .30065 L
.96285 .30807 L
.97579 .32237 L
.97619 .3228 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plotting the electrical Impedance, once without and once with load ZC:\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(test3 = 
        Abs[\(\(Z /. lCoil1 \[Rule] lRod\) /. values\) /. {ZC \[Rule] 0, 
                w \[Rule] 2\ \[Pi]\ f}] // N;\)\)], "Input"],

Cell[BoxData[
    \(\(test4 = 
        Abs[\(\(Z /. lCoil1 \[Rule] lRod\) /. 
                values\) /. {ZC \[Rule] 50 - \[ImaginaryI]\ 300, 
                w \[Rule] 2\ \[Pi]\ f}] // N;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{test3, test4}, {f, 0, 200000}, PlotPoints \[Rule] 150, 
      PlotRange \[Rule] {0, 450}, AxesLabel \[Rule] {"\<\>", "\<\>"}, 
      TextStyle \[Rule] {FontSize \[Rule] 20}, 
      PlotStyle \[Rule] {{Thickness[ .004], 
            RGBColor[1, 0, 0]}, {Thickness[ .004], 
            RGBColor[0, 1, 0]}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.7619e-006 0 0.00137341 [
[.2619 -0.0125 -32 -23.5 ]
[.2619 -0.0125 32 0 ]
[.5 -0.0125 -38 -23.5 ]
[.5 -0.0125 38 0 ]
[.7381 -0.0125 -38 -23.5 ]
[.7381 -0.0125 38 0 ]
[.97619 -0.0125 -38 -23.5 ]
[.97619 -0.0125 38 0 ]
[.01131 .13734 -40 -11.75 ]
[.01131 .13734 0 11.75 ]
[.01131 .27468 -40 -11.75 ]
[.01131 .27468 0 11.75 ]
[.01131 .41202 -40 -11.75 ]
[.01131 .41202 0 11.75 ]
[.01131 .54936 -40 -11.75 ]
[.01131 .54936 0 11.75 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -93 -27.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.5 translate 1 -1 scale
63.000 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50000) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -99 -27.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.5 translate 1 -1 scale
63.000 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100000) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -99 -27.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.5 translate 1 -1 scale
63.000 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150000) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -99 -27.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.5 translate 1 -1 scale
63.000 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200000) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .13734 m
.03006 .13734 L
s
gsave
.01131 .13734 -101 -15.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.5 translate 1 -1 scale
63.000 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.02381 .27468 m
.03006 .27468 L
s
gsave
.01131 .27468 -101 -15.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.5 translate 1 -1 scale
63.000 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.02381 .41202 m
.03006 .41202 L
s
gsave
.01131 .41202 -101 -15.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.5 translate 1 -1 scale
63.000 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.02381 .54936 m
.03006 .54936 L
s
gsave
.01131 .54936 -101 -15.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.5 translate 1 -1 scale
63.000 21.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .02747 m
.02756 .02747 L
s
.02381 .05494 m
.02756 .05494 L
s
.02381 .0824 m
.02756 .0824 L
s
.02381 .10987 m
.02756 .10987 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .19228 m
.02756 .19228 L
s
.02381 .21975 m
.02756 .21975 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .30215 m
.02756 .30215 L
s
.02381 .32962 m
.02756 .32962 L
s
.02381 .35709 m
.02756 .35709 L
s
.02381 .38455 m
.02756 .38455 L
s
.02381 .43949 m
.02756 .43949 L
s
.02381 .46696 m
.02756 .46696 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .5219 m
.02756 .5219 L
s
.02381 .57683 m
.02756 .57683 L
s
.02381 .6043 m
.02756 .6043 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.004 w
.02381 0 m
.03003 .00185 L
.03682 .00387 L
.04319 .00577 L
.04932 .00759 L
.05585 .00953 L
.06213 .0114 L
.0688 .01339 L
.07524 .01531 L
.08142 .01716 L
.08801 .01912 L
.09434 .02102 L
.10044 .02285 L
.10693 .02479 L
.11317 .02667 L
.11981 .02867 L
.12621 .0306 L
.13236 .03247 L
.13891 .03445 L
.14521 .03637 L
.15191 .03842 L
.15836 .0404 L
.16457 .04232 L
.17118 .04437 L
.17754 .04636 L
.18365 .04828 L
.19016 .05035 L
.19643 .05237 L
.20309 .05453 L
.20951 .05665 L
.21569 .05873 L
.22225 .06099 L
.22858 .06323 L
.23466 .06545 L
.24114 .06793 L
.24737 .07046 L
.25399 .07336 L
.26038 .07647 L
.26651 .07993 L
.27305 .08447 L
.27934 .09049 L
.28278 .09514 L
.28435 .09783 L
.28602 .10127 L
.28756 .10517 L
.28925 .11069 L
.29078 .11746 L
.29222 .1263 L
.29302 .13293 L
.29389 .14235 L
Mistroke
.29472 .15451 L
.29511 .16201 L
.29549 .17048 L
.29585 .1806 L
.29624 .19428 L
.2966 .21023 L
.29693 .22925 L
.29729 .25717 L
.29749 .27809 L
.29768 .30252 L
.29788 .33575 L
.29806 .37588 L
.29827 .44113 L
.29847 .53605 L
Mfstroke
.29847 .53605 m
.29857 .61803 L
s
.29973 .61803 m
.29983 .50234 L
.30003 .35556 L
.30014 .30231 L
.30024 .26363 L
.30035 .2299 L
.30048 .19974 L
.30068 .16035 L
.3009 .1292 L
.30109 .10718 L
.3013 .08818 L
.30168 .06211 L
.30207 .04295 L
.30248 .02717 L
.30285 .01624 L
.30324 .00679 L
.3034 .00324 L
.30359 .00027 L
.30379 .00382 L
.30397 .00688 L
.30465 .01628 L
.30545 .02472 L
.30619 .03089 L
.30707 .03677 L
.30788 .04111 L
.30952 .048 L
.31127 .05343 L
.31436 .06021 L
.3161 .06308 L
.31771 .06534 L
.32405 .07198 L
.33015 .07651 L
.33664 .08034 L
.34289 .08348 L
.34953 .08646 L
.35593 .08909 L
.36209 .09148 L
.36864 .0939 L
.37494 .09614 L
.38164 .09846 L
.3881 .10064 L
.39431 .10269 L
.40092 .10485 L
.40729 .1069 L
.4134 .10884 L
.41992 .1109 L
.42619 .11286 L
.43285 .11493 L
.43928 .11691 L
.44545 .11881 L
Mistroke
.45203 .12082 L
.45835 .12275 L
.46444 .1246 L
.47092 .12656 L
.47715 .12844 L
.48378 .13044 L
.49017 .13236 L
.49631 .1342 L
.50284 .13616 L
.50914 .13804 L
.51582 .14004 L
.52227 .14196 L
.52847 .14381 L
.53506 .14577 L
.54141 .14766 L
.54752 .14948 L
.55402 .15141 L
.56027 .15327 L
.56693 .15524 L
.57333 .15715 L
.5795 .15898 L
.58606 .16093 L
.59237 .1628 L
.59908 .16479 L
.60554 .16671 L
.61177 .16856 L
.61838 .17053 L
.62475 .17243 L
.63088 .17425 L
.6374 .17619 L
.64368 .17807 L
.65036 .18006 L
.65679 .18198 L
.66297 .18383 L
.66955 .18581 L
.67589 .18771 L
.68198 .18954 L
.68847 .1915 L
.69471 .19339 L
.70135 .1954 L
.70774 .19735 L
.71389 .19922 L
.72044 .20123 L
.72674 .20317 L
.73344 .20525 L
.73989 .20726 L
.74609 .20922 L
.7527 .21131 L
.75906 .21335 L
.76517 .21533 L
Mistroke
.77168 .21748 L
.77794 .21958 L
.7846 .22187 L
.79102 .22413 L
.79719 .22638 L
.80376 .22889 L
.81008 .23145 L
.81616 .2341 L
.82263 .23722 L
.82886 .2407 L
.83549 .24526 L
.83879 .24811 L
.84187 .25133 L
.84484 .25524 L
.84801 .26088 L
.84965 .2648 L
.85144 .27031 L
.85226 .27347 L
.85313 .27743 L
.85394 .28189 L
.85469 .28684 L
.85541 .29275 L
.85621 .30094 L
.85704 .31254 L
.85746 .32002 L
.85784 .32817 L
.8582 .33745 L
.85858 .34987 L
.85899 .36682 L
.85937 .38821 L
.85973 .41599 L
.85991 .43426 L
.86011 .45916 L
.86028 .48608 L
.86046 .5233 L
.86063 .5704 L
Mfstroke
.86063 .5704 m
.86076 .61803 L
s
.86209 .61803 m
.8622 .40575 L
.86239 .23571 L
.86258 .13518 L
.86276 .0728 L
.86293 .03214 L
.8631 .00146 L
.8633 .02982 L
.8635 .05332 L
.86387 .08454 L
.86426 .10851 L
.86469 .12725 L
.86509 .14069 L
.86546 .15049 L
.86589 .15982 L
.86636 .16807 L
.86721 .17954 L
.86799 .18738 L
.86872 .19322 L
.86959 .1988 L
.87039 .20299 L
.87202 .20964 L
.87377 .21495 L
.87682 .22152 L
.87854 .22433 L
.88015 .22656 L
.88643 .23309 L
.88986 .23577 L
.89311 .23796 L
.8993 .24155 L
.90588 .24481 L
.91222 .24762 L
.91832 .25012 L
.92481 .25262 L
.93105 .25492 L
.93769 .25728 L
.94409 .25948 L
.95025 .26156 L
.95679 .26372 L
.9631 .26577 L
.9698 .26792 L
.97619 .26996 L
s
0 1 0 r
.02381 0 m
.03003 .00185 L
.03682 .00387 L
.04319 .00577 L
.04932 .0076 L
.05585 .00957 L
.06213 .01148 L
.0688 .01345 L
.07524 .01516 L
.08142 .01697 L
.08801 .01893 L
.09434 .02081 L
.10044 .02262 L
.10693 .02455 L
.11317 .02641 L
.11981 .02838 L
.12621 .03028 L
.13236 .03211 L
.13891 .03406 L
.14521 .03594 L
.15191 .03794 L
.15836 .03987 L
.16457 .04173 L
.17118 .04371 L
.17754 .04562 L
.18365 .04746 L
.19016 .04943 L
.19643 .05133 L
.20309 .05335 L
.20951 .05531 L
.21569 .05721 L
.22225 .05923 L
.22858 .0612 L
.23466 .0631 L
.24114 .06514 L
.24737 .06713 L
.25399 .06927 L
.26038 .07136 L
.26651 .0734 L
.27305 .07563 L
.27934 .07783 L
.28602 .08026 L
.29246 .0827 L
.29866 .0852 L
.30525 .08808 L
.3116 .09116 L
.3177 .09459 L
.3242 .09907 L
.33045 .10477 L
.33363 .10844 L
Mistroke
.3371 .11298 L
.33871 .11499 L
.33959 .1159 L
.34002 .11625 L
.34021 .11638 L
.34042 .1165 L
.3406 .11659 L
.3408 .11667 L
.34101 .11672 L
.3412 .11674 L
.34131 .11673 L
.34142 .11672 L
.34154 .1167 L
.34164 .11667 L
.34183 .11659 L
.34204 .11646 L
.34221 .11632 L
.3424 .11613 L
.34273 .11568 L
.34314 .11495 L
.3435 .11409 L
.34427 .11163 L
.34509 .10798 L
.34656 .09925 L
.34829 .0879 L
.34906 .08359 L
.34989 .07972 L
.3507 .07696 L
.35114 .07584 L
.35155 .07501 L
.35178 .07463 L
.352 .07432 L
.35241 .07388 L
.35264 .07371 L
.35285 .07358 L
.35297 .07353 L
.35309 .07349 L
.35322 .07345 L
.35334 .07343 L
.35353 .07341 L
.35373 .07342 L
.35384 .07343 L
.35395 .07345 L
.35415 .0735 L
.35435 .07356 L
.35454 .07365 L
.3549 .07383 L
.35571 .0744 L
.35659 .07516 L
.36317 .0819 L
Mistroke
.36951 .08722 L
.37561 .09123 L
.3821 .09478 L
.38835 .09776 L
.39499 .10061 L
.40139 .10316 L
.40755 .10548 L
.4141 .10784 L
.4204 .11004 L
.42711 .11232 L
.43356 .11446 L
.43978 .11649 L
.44638 .11862 L
.45275 .12064 L
.45887 .12257 L
.46538 .1246 L
.47165 .12655 L
.47832 .1286 L
.48474 .13057 L
.49092 .13245 L
.49749 .13445 L
.50382 .13636 L
.5099 .1382 L
.51638 .14015 L
.52261 .14202 L
.52924 .14401 L
.53563 .14592 L
.54177 .14775 L
.54831 .1497 L
.5546 .15158 L
.56129 .15357 L
.56773 .15548 L
.57393 .15732 L
.58052 .15928 L
.58687 .16117 L
.59298 .16298 L
.59948 .16491 L
.60574 .16678 L
.61239 .16877 L
.6188 .1707 L
.62496 .17258 L
.63152 .17438 L
.63783 .17616 L
.64454 .17814 L
.65101 .18006 L
.65723 .18191 L
.66384 .18387 L
.67022 .18576 L
.67634 .18758 L
.68287 .18952 L
Mistroke
.68915 .19139 L
.69582 .19337 L
.70225 .19528 L
.70843 .19713 L
.71501 .19909 L
.72135 .20098 L
.72744 .2028 L
.73393 .20475 L
.74017 .20662 L
.74681 .20862 L
.75321 .21055 L
.75936 .21242 L
.7659 .21441 L
.7722 .21633 L
.7789 .21839 L
.78535 .22038 L
.79156 .22231 L
.79816 .22437 L
.80452 .22638 L
.81063 .22833 L
.81714 .23044 L
.82341 .23249 L
.83007 .23472 L
.83648 .23692 L
.84265 .23909 L
.84922 .2415 L
.85554 .24392 L
.86162 .2464 L
.8681 .24926 L
.87433 .25235 L
.88095 .25619 L
.88733 .26081 L
.89347 .2667 L
.89689 .27075 L
.89851 .27271 L
.9 .27433 L
.90075 .27497 L
.90113 .27521 L
.90135 .27532 L
.90155 .2754 L
.90165 .27544 L
.90177 .27546 L
.90197 .2755 L
.90208 .2755 L
.9022 .2755 L
.90232 .27548 L
.90242 .27546 L
.90262 .27539 L
.90273 .27534 L
.90284 .27528 L
Mistroke
.90303 .27514 L
.90323 .27495 L
.9036 .2745 L
.90399 .27382 L
.90435 .27299 L
.90469 .27206 L
.90551 .26899 L
.90629 .26507 L
.90923 .24541 L
.91003 .24075 L
.91045 .23869 L
.9109 .23684 L
.91129 .23549 L
.91172 .23429 L
.91211 .23344 L
.91247 .23283 L
.91267 .23256 L
.91288 .23233 L
.91307 .23216 L
.91328 .23202 L
.91346 .23193 L
.91366 .23187 L
.91384 .23184 L
.91401 .23183 L
.91411 .23184 L
.91422 .23185 L
.91442 .23189 L
.91462 .23196 L
.9148 .23204 L
.91522 .23227 L
.91566 .2326 L
.91726 .23419 L
.91904 .23628 L
.92551 .24336 L
.93173 .24849 L
.93835 .25273 L
.94473 .25611 L
.95086 .25897 L
.95739 .26173 L
.96367 .26421 L
.97035 .2667 L
.97619 .26879 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{466.75, 288.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{90.625, 463}, {352.5, 122.75}} -> {-82784.4, 216.991, \
522.951, 1.81318}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Further electric relations (part 3)", "Section",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Amplitude at HP Function Generator", "Subsubsection",
  InitializationCell->True],

Cell["\<\
The Voltage drop at the solenoid depends on the internal resistence and on \
the current:\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(Kirchhoff1 = U0[t] \[Equal] i[t]\ \((Ri + Z)\);\)\)], "Input",
  InitializationCell->True],

Cell["\<\
The internal voltage-source of the generator and the voltage at the solenoid \
have the same phase angle (because of the true ohmic internal resistance ri) \
ans the sam timefunction:\
\>", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(U0[t_] = U0d*T[t]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ U0d\)], "Output"]
}, Open  ]],

Cell["Solve for the voltage amplitude at the solenoid:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(Kirchhoff1 = 
        Simplify[Kirchhoff1 /. Flatten[{rulea1, rulea2}]];\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ruleUd = Flatten[Simplify[Solve[Kirchhoff1, Ud]]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({Ud \[Rule] \((A\ ER\ K1\ N\^2\ U0d\ w\^2\ \[Mu]R\ \
\((\(-\[ImaginaryI]\)\ cR\ ZC\ Cos[\(lRod\ w\)\/cR] + 
                  A\ ER\ Sin[\(lRod\ w\)\/cR])\))\)/\((\(-cR\)\ ER\ w\ ZC\ \
\((lCoil1\ Ri + \[ImaginaryI]\ A\ K1\ N\^2\ w\ \[Mu]R)\)\ Cos[\(lRod\ \
w\)\/cR] - \[ImaginaryI]\ A\ cR\ ER\ Ri\ \[Theta]\^2\ \[Mu]R\ Cos[\(w\ \
\((lRod - x1)\)\)\/cR] + \[ImaginaryI]\ A\ cR\ ER\ Ri\ \[Theta]\^2\ \[Mu]R\ \
Cos[\(w\ x1\)\/cR] - \[ImaginaryI]\ A\ cR\ ER\ Ri\ \[Theta]\^2\ \[Mu]R\ \
Cos[\(w\ \((lCoil1 + x1)\)\)\/cR] + \[ImaginaryI]\ A\ cR\ ER\ Ri\ \[Theta]\^2\
\ \[Mu]R\ Cos[\(w\ \((lCoil1 - lRod + x1)\)\)\/cR] - \[ImaginaryI]\ A\ ER\^2\ \
lCoil1\ Ri\ w\ Sin[\(lRod\ w\)\/cR] + 
              A\^2\ ER\^2\ K1\ N\^2\ w\^2\ \[Mu]R\ Sin[\(lRod\ w\)\/cR] + 
              cR\^2\ Ri\ ZC\ \[Theta]\^2\ \[Mu]R\ Sin[\(w\ \((lRod - \
x1)\)\)\/cR] + 
              cR\^2\ Ri\ ZC\ \[Theta]\^2\ \[Mu]R\ Sin[\(w\ \((lCoil1 - lRod + \
x1)\)\)\/cR])\)}\)], "Output"]
}, Open  ]],

Cell["Ud in case of constant lCoil:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(ruleUdlc = \(\(ruleUd /. values\) /. {lCoil1 \[Rule] lRod}\) /. 
          values;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(ruleUdlc2 = \(\(ruleUd /. values\) /. {lCoil1 \[Rule] lRod/2}\) /. 
          values;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
The following rule sets a1 and a2 for the HP function generator. Open is: \
lCoil1, Zp, w\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(valueruleaHP = \(valuerulea /. ruleUd\) /. values;\)\)], "Input",
  InitializationCell->True],

Cell["In case of lcoil=lRod:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(valueruleaHPlc = 
        Simplify[\(\(valuerulea /. ruleUd\) /. lCoil1 \[Rule] lRod\) /. 
            values];\)\)], "Input",
  InitializationCell->True],

Cell["In case of lcoil=lRod / 3:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(valueruleaHPlc3 = 
        Simplify[\(\(valuerulea /. ruleUd\) /. lCoil1 \[Rule] lRod/3\) /. 
            values];\)\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plotting (part 2)", "Section"],

Cell[CellGroupData[{

Cell["Amplitude and Phase", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(test3 = 
      Abs[\(\(\(a1 /. rulea1\) /. values\) /. ZC \[Rule] 0\) /. 
            w \[Rule] 2\ \[Pi]\ f] // N\)], "Input"],

Cell[BoxData[
    \(\(\(1\/f\^2\)\((1.8847701795709524`*^-6\ Abs[
          Ud\ \((\(-2.5132741228718343`*^6\) + 
                2.5132741228718343`*^6\ Cos[
                    0.00005347391750791138`\ f])\)\ Csc[
              0.00005347391750791138`\ f]])\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(test1 = 
        Abs[\(\(a1 /. valueruleaHPlc\) /. ZC \[Rule] 0\) /. 
              w \[Rule] 2\ \[Pi]\ f] // N;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(test1b = 
        Abs[\(\(a1 /. valueruleaHPlc\) /. ZC \[Rule] ZCexample1\) /. 
              w \[Rule] 2\ \[Pi]\ f] // N;\)\)], "Input"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(test1b\)\" is similar \
to existing symbols \!\({test1, test1i}\)."\)], "Message"]
}, Open  ]],

Cell[BoxData[
    \(\(test2 = 
        Arg[\(\(a1 /. valueruleaHPlc\) /. ZC \[Rule] 0\) /. 
              w \[Rule] 2\ \[Pi]\ f] // N;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl1a = 
      Plot[{test1 /. f \[Rule] fk*1000, test1b /. f \[Rule] fk*1000, 
          test1i /. f \[Rule] fk*1000, test2i /. f \[Rule] fk*1000}, {fk, 55, 
          65}, PlotPoints \[Rule] 150, PlotRange \[Rule] \ {0, 0.000002}, 
        PlotStyle \[Rule] {{Thickness[ .003], 
              RGBColor[1, 0, 0]}, {Thickness[ .002], 
              RGBColor[0, 1, 0]}, {Thickness[ .002], 
              RGBColor[0, 0, 1]}, {Thickness[ .002], 
              RGBColor[1, 0, 1]}, {Thickness[ .002], 
              RGBColor[0.2, 0.8, 0]}, {Thickness[ .002], 
              RGBColor[0, 1, 0]}, {Thickness[ .002], RGBColor[0, 0.6, 0.4]}}, 
        TextStyle \[Rule] {FontFamily \[Rule] "\<Helvetica\>", 
            FontSize \[Rule] 10}, GridLines \[Rule] {{58.75, 117.5}, None}, 
        Axes \[Rule] {True, True}]\)], "Input"],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(test1b /. \[InvisibleSpace] \(\(f \[Rule] \(\(fk\\ 1000\)\)\)\)\) \
is not a machine-size real number at \!\(fk\) = \
\!\(55.000000067114094`\)."\)], "Message"],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(test1b /. \[InvisibleSpace] \(\(f \[Rule] \(\(fk\\ 1000\)\)\)\)\) \
is not a machine-size real number at \!\(fk\) = \
\!\(55.065342805218116`\)."\)], "Message"],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(test1b /. \[InvisibleSpace] \(\(f \[Rule] \(\(fk\\ 1000\)\)\)\)\) \
is not a machine-size real number at \!\(fk\) = \
\!\(55.13660477829698`\)."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Plot :: \"plnr\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-5.21429 0.0952381 0 309017 [
[.30952 -0.0125 -7.5 -13 ]
[.30952 -0.0125 7.5 0 ]
[.5 -0.0125 -7.5 -13 ]
[.5 -0.0125 7.5 0 ]
[.69048 -0.0125 -7.5 -13 ]
[.69048 -0.0125 7.5 0 ]
[.88095 -0.0125 -7.5 -13 ]
[.88095 -0.0125 7.5 0 ]
[.10655 .07725 -46.5 -6.8125 ]
[.10655 .07725 0 6.8125 ]
[.10655 .15451 -38.25 -6.8125 ]
[.10655 .15451 0 6.8125 ]
[.10655 .23176 -46.5 -6.8125 ]
[.10655 .23176 0 6.8125 ]
[.10655 .30902 -38.25 -6.8125 ]
[.10655 .30902 0 6.8125 ]
[.10655 .38627 -52 -6.8125 ]
[.10655 .38627 0 6.8125 ]
[.10655 .46353 -46.5 -6.8125 ]
[.10655 .46353 0 6.8125 ]
[.10655 .54078 -52 -6.8125 ]
[.10655 .54078 0 6.8125 ]
[.10655 .61803 -38.25 -6.8125 ]
[.10655 .61803 0 6.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.38095 0 m
.38095 .61803 L
s
0 g
.30952 0 m
.30952 .00625 L
s
gsave
.30952 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(58) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.69048 0 m
.69048 .00625 L
s
gsave
.69048 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(62) show
1.000 setlinewidth
grestore
.88095 0 m
.88095 .00625 L
s
gsave
.88095 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(64) show
1.000 setlinewidth
grestore
.125 Mabswid
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.07143 0 m
.07143 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.11905 .07725 m
.1253 .07725 L
s
gsave
.10655 .07725 -107.5 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.500 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
78.250 14.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
86.125 14.500 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
97.125 9.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
101.688 9.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.11905 .15451 m
.1253 .15451 L
s
gsave
.10655 .15451 -99.25 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.500 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
70.000 14.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
77.875 14.500 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
88.875 9.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
93.438 9.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.11905 .23176 m
.1253 .23176 L
s
gsave
.10655 .23176 -107.5 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.500 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
78.250 14.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
86.125 14.500 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
97.125 9.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
101.688 9.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.11905 .30902 m
.1253 .30902 L
s
gsave
.10655 .30902 -99.25 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.500 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
70.000 14.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
77.875 14.500 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
88.875 9.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
93.438 9.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.11905 .38627 m
.1253 .38627 L
s
gsave
.10655 .38627 -113 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.500 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
83.750 14.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
91.625 14.500 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
102.625 9.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
107.188 9.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.11905 .46353 m
.1253 .46353 L
s
gsave
.10655 .46353 -107.5 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.500 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
78.250 14.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
86.125 14.500 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
97.125 9.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
101.688 9.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.11905 .54078 m
.1253 .54078 L
s
gsave
.10655 .54078 -113 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.500 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
83.750 14.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
91.625 14.500 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
102.625 9.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
107.188 9.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.11905 .61803 m
.1253 .61803 L
s
gsave
.10655 .61803 -99.25 -10.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.500 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
70.000 14.500 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
77.875 14.500 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
88.875 9.875 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
93.438 9.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.11905 .01545 m
.1228 .01545 L
s
.11905 .0309 m
.1228 .0309 L
s
.11905 .04635 m
.1228 .04635 L
s
.11905 .0618 m
.1228 .0618 L
s
.11905 .09271 m
.1228 .09271 L
s
.11905 .10816 m
.1228 .10816 L
s
.11905 .12361 m
.1228 .12361 L
s
.11905 .13906 m
.1228 .13906 L
s
.11905 .16996 m
.1228 .16996 L
s
.11905 .18541 m
.1228 .18541 L
s
.11905 .20086 m
.1228 .20086 L
s
.11905 .21631 m
.1228 .21631 L
s
.11905 .24721 m
.1228 .24721 L
s
.11905 .26266 m
.1228 .26266 L
s
.11905 .27812 m
.1228 .27812 L
s
.11905 .29357 m
.1228 .29357 L
s
.11905 .32447 m
.1228 .32447 L
s
.11905 .33992 m
.1228 .33992 L
s
.11905 .35537 m
.1228 .35537 L
s
.11905 .37082 m
.1228 .37082 L
s
.11905 .40172 m
.1228 .40172 L
s
.11905 .41717 m
.1228 .41717 L
s
.11905 .43262 m
.1228 .43262 L
s
.11905 .44807 m
.1228 .44807 L
s
.11905 .47898 m
.1228 .47898 L
s
.11905 .49443 m
.1228 .49443 L
s
.11905 .50988 m
.1228 .50988 L
s
.11905 .52533 m
.1228 .52533 L
s
.11905 .55623 m
.1228 .55623 L
s
.11905 .57168 m
.1228 .57168 L
s
.11905 .58713 m
.1228 .58713 L
s
.11905 .60258 m
.1228 .60258 L
s
.25 Mabswid
.11905 0 m
.11905 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.003 w
.02381 .03973 m
.03003 .04043 L
.03682 .04122 L
.04319 .042 L
.04932 .04278 L
.05585 .04365 L
.06213 .04452 L
.0688 .04549 L
.07524 .04646 L
.08142 .04745 L
.08801 .04854 L
.09434 .04965 L
.10044 .05076 L
.10693 .05201 L
.11317 .05327 L
.11981 .05469 L
.12621 .05613 L
.13236 .0576 L
.13891 .05925 L
.14521 .06093 L
.15191 .06283 L
.15836 .06478 L
.16457 .06678 L
.17118 .06905 L
.17754 .07139 L
.18365 .07379 L
.19016 .07654 L
.19643 .07939 L
.20309 .08266 L
.20951 .08608 L
.21569 .08964 L
.22225 .09376 L
.22858 .09809 L
.23466 .10263 L
.24114 .10793 L
.24737 .11354 L
.25399 .12012 L
.26038 .12716 L
.26651 .13465 L
.27305 .1435 L
.27934 .15298 L
.28602 .16419 L
.29246 .17618 L
.29866 .18884 L
.30525 .20343 L
.3116 .21828 L
.3177 .23278 L
.3242 .24752 L
.33045 .25968 L
.33386 .26493 L
Mistroke
.33543 .26693 L
.3371 .26872 L
.33878 .27017 L
.34029 .27115 L
.34103 .27151 L
.34182 .27181 L
.34219 .27192 L
.34257 .27202 L
.3429 .27208 L
.34326 .27213 L
.34347 .27215 L
.34366 .27217 L
.34377 .27217 L
.34388 .27218 L
.34399 .27218 L
.3441 .27218 L
.34431 .27217 L
.34449 .27216 L
.34469 .27215 L
.34491 .27213 L
.34528 .27207 L
.34562 .272 L
.34641 .27178 L
.34726 .27143 L
.34804 .27103 L
.34978 .26981 L
.35139 .26832 L
.35287 .26665 L
.35623 .26191 L
.36258 .24993 L
.36869 .236 L
.3752 .22009 L
.38146 .20479 L
.38812 .18929 L
.39453 .17547 L
.4007 .16333 L
.40726 .15166 L
.41358 .14156 L
.41966 .13281 L
.42613 .12443 L
.43235 .11716 L
.43898 .1102 L
.44535 .10415 L
.45149 .09886 L
.45801 .09374 L
.4643 .08924 L
.47098 .08486 L
.47741 .081 L
.4836 .07758 L
.49019 .07422 L
Mistroke
.49653 .07123 L
.50263 .06856 L
.50912 .06591 L
.51537 .06353 L
.52201 .06117 L
.52841 .05905 L
.53457 .05713 L
.54112 .05521 L
.54742 .05347 L
.55412 .05173 L
.56058 .05015 L
.56679 .04872 L
.5734 .04727 L
.57976 .04595 L
.58588 .04474 L
.5924 .04352 L
.59867 .0424 L
.60533 .04126 L
.61176 .04022 L
.61793 .03927 L
.6245 .03829 L
.63083 .0374 L
.63692 .03657 L
.6434 .03573 L
.64963 .03495 L
.65626 .03415 L
.66265 .03342 L
.66879 .03274 L
.67532 .03204 L
.68162 .0314 L
.6883 .03074 L
.69475 .03012 L
.70095 .02955 L
.70754 .02897 L
.71389 .02842 L
.72 .02792 L
.7265 .0274 L
.73275 .02691 L
.7394 .02641 L
.74581 .02595 L
.75198 .02551 L
.75853 .02507 L
.76485 .02465 L
.77156 .02422 L
.77802 .02381 L
.78424 .02344 L
.79086 .02305 L
.79723 .02269 L
.80336 .02234 L
.80988 .02199 L
Mistroke
.81616 .02166 L
.82284 .02132 L
.82927 .021 L
.83545 .0207 L
.84203 .02039 L
.84837 .0201 L
.85446 .01982 L
.86095 .01954 L
.86719 .01927 L
.87383 .01899 L
.88022 .01873 L
.88637 .01849 L
.89292 .01823 L
.89922 .018 L
.90591 .01775 L
.91237 .01751 L
.91857 .01729 L
.92518 .01706 L
.93154 .01685 L
.93765 .01665 L
.94416 .01643 L
.95042 .01624 L
.95708 .01603 L
.9635 .01583 L
.96967 .01565 L
.97619 .01546 L
Mfstroke
0 0 1 r
.002 w
.02381 .0481 m
.03003 .04884 L
.03682 .04968 L
.04319 .05051 L
.04932 .05132 L
.05585 .05223 L
.06213 .05314 L
.0688 .05414 L
.07524 .05515 L
.08142 .05617 L
.08801 .05729 L
.09434 .05843 L
.10044 .05956 L
.10693 .06083 L
.11317 .06211 L
.11981 .06354 L
.12621 .06498 L
.13236 .06644 L
.13891 .06808 L
.14521 .06974 L
.15191 .07161 L
.15836 .07351 L
.16457 .07545 L
.17118 .07764 L
.17754 .07989 L
.18365 .08218 L
.19016 .08479 L
.19643 .08747 L
.20309 .09053 L
.20951 .0937 L
.21569 .09699 L
.22225 .10076 L
.22858 .10471 L
.23466 .10882 L
.24114 .1136 L
.24737 .11863 L
.25399 .12452 L
.26038 .13082 L
.26651 .13753 L
.27305 .14551 L
.27934 .15417 L
.28602 .16463 L
.29246 .17621 L
.29866 .18905 L
.30525 .20503 L
.3116 .22328 L
.3177 .24429 L
.3242 .27162 L
.33045 .30457 L
.3371 .34991 L
Mistroke
.3435 .40881 L
.34966 .48822 L
.35284 .54274 L
.35622 .61617 L
Mfstroke
.35622 .61617 m
.35628 .61803 L
s
.40529 .61803 m
.4072 .57024 L
.41034 .50865 L
.41371 .45578 L
.42038 .37782 L
.4268 .32416 L
.43297 .28504 L
.43955 .25247 L
.44587 .22735 L
.45196 .20742 L
.45844 .18964 L
.46467 .17513 L
.4713 .16189 L
.47769 .15086 L
.48383 .14155 L
.49037 .13278 L
.49666 .12528 L
.50335 .11815 L
.50979 .11199 L
.51599 .10661 L
.52258 .10141 L
.52893 .09684 L
.53504 .0928 L
.54154 .08883 L
.5478 .08531 L
.55445 .08185 L
.56086 .07875 L
.56702 .07598 L
.57358 .07322 L
.57989 .07074 L
.5866 .06827 L
.59307 .06603 L
.59929 .06401 L
.6059 .06198 L
.61228 .06014 L
.6184 .05846 L
.62493 .05676 L
.63121 .05522 L
.63788 .05365 L
.64431 .05222 L
.65049 .05091 L
.65707 .04959 L
.66341 .04836 L
.6695 .04724 L
.67599 .0461 L
.68223 .04504 L
.68887 .04397 L
.69527 .04297 L
.70142 .04206 L
.70796 .04112 L
Mistroke
.71426 .04025 L
.72096 .03937 L
.72741 .03854 L
.73362 .03778 L
.74022 .037 L
.74658 .03628 L
.75269 .0356 L
.7592 .03491 L
.76547 .03426 L
.77213 .0336 L
.77854 .03298 L
.78471 .03241 L
.79128 .03182 L
.7976 .03126 L
.80368 .03075 L
.81016 .03021 L
.81639 .02972 L
.82301 .0292 L
.82939 .02872 L
.83553 .02827 L
.84206 .02781 L
.84835 .02737 L
.85503 .02692 L
.86147 .0265 L
.86766 .02611 L
.87425 .0257 L
.88059 .02531 L
.88669 .02495 L
.89319 .02458 L
.89944 .02423 L
.90609 .02387 L
.91249 .02353 L
.91865 .02321 L
.9252 .02287 L
.93151 .02256 L
.93822 .02224 L
.94468 .02193 L
.95089 .02164 L
.9575 .02135 L
.96387 .02107 L
.96999 .0208 L
.97619 .02054 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{90.625, 320}, {407.5, 266.188}} -> {48.6275, \
4.11954*^-06, 0.0422158, 1.30108*^-08}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl1b = 
      Plot[{test1i /. f \[Rule] fk*1000, test2i /. f \[Rule] fk*1000}, {fk, 
          55, 65}, PlotPoints \[Rule] 350, PlotRange \[Rule] \ {0, 0.000003}, 
        PlotStyle \[Rule] {{Thickness[ .003], 
              RGBColor[1, 0, 0]}, {Thickness[ .002], 
              RGBColor[0, 1, 0]}, {Thickness[ .002], 
              RGBColor[0, 0, 1]}, {Thickness[ .002], 
              RGBColor[1, 0, 1]}, {Thickness[ .002], 
              RGBColor[0.2, 0.8, 0]}, {Thickness[ .002], 
              RGBColor[0, 1, 0]}, {Thickness[ .002], RGBColor[0, 0.6, 0.4]}}, 
        TextStyle \[Rule] {FontFamily \[Rule] "\<Helvetica\>", 
            FontSize \[Rule] 10}, GridLines \[Rule] {{58.75, 117.5}, None}, 
        Axes \[Rule] {True, True}, \ 
        Ticks \[Rule] {{55, 57.5, 58.75, 62.5, 65}, None}, 
        AxesOrigin \[Rule] {54.75, 0}]\)], "Input"],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(test2i /. \[InvisibleSpace] \(\(f \[Rule] \(\(fk\\ 1000\)\)\)\)\) \
is not a machine-size real number at \!\(fk\) = \!\(55.0000000286533`\)."\)], \
"Message"],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(test2i /. \[InvisibleSpace] \(\(f \[Rule] \(\(fk\\ 1000\)\)\)\)\) \
is not a machine-size real number at \!\(fk\) = \
\!\(55.027897071568766`\)."\)], "Message"],

Cell[BoxData[
    \(Plot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(test2i /. \[InvisibleSpace] \(\(f \[Rule] \(\(fk\\ 1000\)\)\)\)\) \
is not a machine-size real number at \!\(fk\) = \
\!\(55.05832123772564`\)."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Plot :: \"plnr\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-5.21429 0.0952381 0 206011 [
[.02381 -0.0125 -7.5 -13 ]
[.02381 -0.0125 7.5 0 ]
[.2619 -0.0125 -11.625 -13 ]
[.2619 -0.0125 11.625 0 ]
[.38095 -0.0125 -14.375 -13 ]
[.38095 -0.0125 14.375 0 ]
[.7381 -0.0125 -11.625 -13 ]
[.7381 -0.0125 11.625 0 ]
[.97619 -0.0125 -7.5 -13 ]
[.97619 -0.0125 7.5 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.38095 0 m
.38095 .61803 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(55) show
1.000 setlinewidth
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57.5) show
1.000 setlinewidth
grestore
.38095 0 m
.38095 .00625 L
s
gsave
.38095 -0.0125 -75.375 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(58.75) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -72.625 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(62.5) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(65) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.003 w
.02381 .03207 m
.02647 .03228 L
.02936 .03251 L
.03209 .03273 L
.0347 .03295 L
.03749 .03318 L
.04017 .03341 L
.04302 .03365 L
.04577 .0339 L
.04841 .03413 L
.05122 .03439 L
.05392 .03464 L
.05653 .03488 L
.0593 .03515 L
.06196 .03541 L
.0648 .03569 L
.06753 .03597 L
.07015 .03624 L
.07295 .03653 L
.07564 .03681 L
.0785 .03712 L
.08125 .03743 L
.08391 .03772 L
.08673 .03805 L
.08944 .03836 L
.09205 .03867 L
.09483 .03901 L
.09751 .03934 L
.10035 .0397 L
.10309 .04005 L
.10573 .0404 L
.10853 .04077 L
.11123 .04114 L
.11383 .0415 L
.11659 .04189 L
.11925 .04228 L
.12208 .04269 L
.12481 .04311 L
.12743 .04351 L
.13022 .04395 L
.1329 .04438 L
.13576 .04485 L
.13851 .04532 L
.14115 .04577 L
.14397 .04627 L
.14668 .04676 L
.14928 .04724 L
.15205 .04777 L
.15472 .04828 L
.15756 .04885 L
Mistroke
.1603 .0494 L
.16293 .04995 L
.16573 .05055 L
.16842 .05114 L
.17128 .05179 L
.17404 .05242 L
.1767 .05305 L
.17952 .05374 L
.18224 .05443 L
.18485 .0551 L
.18764 .05584 L
.19032 .05657 L
.19316 .05737 L
.19591 .05816 L
.19855 .05894 L
.20136 .05981 L
.20406 .06066 L
.20666 .06151 L
.20943 .06244 L
.21209 .06336 L
.21492 .06438 L
.21765 .06539 L
.22028 .0664 L
.22307 .0675 L
.22576 .0686 L
.22862 .06982 L
.23137 .07103 L
.23402 .07225 L
.23684 .07358 L
.23955 .07492 L
.24216 .07626 L
.24494 .07774 L
.24761 .07922 L
.25045 .08087 L
.25319 .08252 L
.25582 .08417 L
.25862 .08602 L
.26132 .08787 L
.26392 .08973 L
.26668 .09181 L
.26934 .09391 L
.27216 .09625 L
.27489 .09863 L
.27751 .10103 L
.28029 .10372 L
.28298 .10646 L
.28583 .10954 L
.28857 .11268 L
.29122 .11589 L
.29403 .11952 L
Mistroke
.29674 .12324 L
.29934 .12706 L
.30211 .13139 L
.30478 .13586 L
.30761 .14098 L
.31035 .14629 L
.31297 .1518 L
.31577 .15815 L
.31846 .16481 L
.32132 .17254 L
.32408 .18072 L
.32673 .18939 L
.32955 .19958 L
.33227 .21051 L
.33488 .22224 L
.33767 .23629 L
.34034 .25162 L
.34319 .27031 L
.34593 .29118 L
.34857 .31459 L
.35137 .34409 L
.35407 .37831 L
.35667 .41839 L
.35944 .47171 L
.3621 .5378 L
Mfstroke
.3621 .5378 m
.36451 .61803 L
s
.39718 .61803 m
.39756 .60298 L
.40039 .51445 L
.40313 .45059 L
.40576 .40245 L
.40855 .36129 L
.41125 .32885 L
.41411 .30016 L
.41687 .27684 L
.41952 .25754 L
.42234 .23974 L
.42506 .22475 L
.42768 .21198 L
.43046 .19986 L
.43314 .18942 L
.43598 .17944 L
.43873 .17076 L
.44137 .16314 L
.44417 .15574 L
.44688 .14921 L
.44947 .14342 L
.45224 .13772 L
.45491 .13263 L
.45774 .12761 L
.46046 .12311 L
.46309 .11907 L
.46588 .11504 L
.46857 .11141 L
.47142 .10778 L
.47418 .10449 L
.47682 .10151 L
.47964 .09852 L
.48235 .09579 L
.48496 .0933 L
.48774 .09078 L
.49041 .08848 L
.49325 .08616 L
.49599 .08402 L
.49862 .08207 L
.50142 .08008 L
.50412 .07825 L
.50671 .07657 L
.50948 .07485 L
.51213 .07326 L
.51496 .07164 L
.51768 .07015 L
.5203 .06877 L
.52308 .06735 L
.52577 .06604 L
.52862 .0647 L
Mistroke
.53136 .06346 L
.53401 .0623 L
.53682 .06112 L
.53952 .06002 L
.54213 .059 L
.5449 .05794 L
.54756 .05696 L
.5504 .05595 L
.55313 .05501 L
.55576 .05413 L
.55855 .05323 L
.56124 .05238 L
.5641 .05151 L
.56686 .0507 L
.56951 .04994 L
.57233 .04915 L
.57505 .04842 L
.57766 .04773 L
.58044 .04702 L
.58312 .04635 L
.58596 .04566 L
.5887 .04502 L
.59134 .04441 L
.59414 .04378 L
.59684 .04319 L
.59944 .04264 L
.60221 .04207 L
.60487 .04153 L
.6077 .04097 L
.61042 .04044 L
.61304 .03995 L
.61583 .03943 L
.61852 .03895 L
.62137 .03845 L
.62412 .03798 L
.62677 .03753 L
.62958 .03707 L
.63229 .03664 L
.6349 .03623 L
.63767 .0358 L
.64034 .0354 L
.64318 .03498 L
.64592 .03459 L
.64855 .03421 L
.65135 .03383 L
.65404 .03346 L
.65691 .03308 L
.65966 .03272 L
.66232 .03238 L
.66514 .03203 L
Mistroke
.66786 .03169 L
.67048 .03138 L
.67326 .03105 L
.67594 .03074 L
.67879 .03041 L
.68154 .0301 L
.68418 .02981 L
.68698 .02951 L
.68969 .02922 L
.69229 .02895 L
.69506 .02867 L
.69772 .0284 L
.70055 .02812 L
.70328 .02786 L
.70591 .02761 L
.7087 .02734 L
.71139 .0271 L
.71425 .02684 L
.717 .02659 L
.71965 .02636 L
.72247 .02611 L
.72518 .02588 L
.72779 .02566 L
.73057 .02544 L
.73325 .02522 L
.73609 .02499 L
.73883 .02478 L
.74146 .02457 L
.74426 .02436 L
.74696 .02416 L
.74956 .02396 L
.75232 .02376 L
.75498 .02357 L
.75781 .02337 L
.76053 .02318 L
.76315 .023 L
.76594 .02281 L
.76862 .02263 L
.77147 .02244 L
.77422 .02226 L
.77686 .0221 L
.77967 .02192 L
.78238 .02175 L
.78499 .02159 L
.78776 .02142 L
.79043 .02126 L
.79326 .02109 L
.796 .02093 L
.79862 .02078 L
.80142 .02062 L
Mistroke
.80411 .02047 L
.80698 .02032 L
.80973 .02016 L
.81239 .02002 L
.81521 .01987 L
.81792 .01973 L
.82054 .01959 L
.82332 .01945 L
.826 .01932 L
.82884 .01917 L
.83159 .01904 L
.83422 .01891 L
.83703 .01878 L
.83973 .01865 L
.84233 .01852 L
.8451 .0184 L
.84776 .01827 L
.85059 .01815 L
.85332 .01802 L
.85594 .01791 L
.85873 .01779 L
.86142 .01767 L
.86427 .01755 L
.86702 .01743 L
.86967 .01732 L
.87249 .0172 L
.8752 .01709 L
.87781 .01699 L
.88058 .01688 L
.88325 .01677 L
.88609 .01666 L
.88883 .01655 L
.89146 .01645 L
.89426 .01635 L
.89696 .01625 L
.89982 .01614 L
.90258 .01604 L
.90524 .01594 L
.90807 .01584 L
.91079 .01574 L
.9134 .01565 L
.91619 .01556 L
.91887 .01546 L
.92172 .01537 L
.92447 .01527 L
.92711 .01519 L
.92992 .01509 L
.93262 .015 L
.93522 .01492 L
.93799 .01483 L
Mistroke
.94066 .01475 L
.94349 .01466 L
.94623 .01457 L
.94885 .01449 L
.95165 .01441 L
.95434 .01433 L
.9572 .01424 L
.95995 .01416 L
.9626 .01408 L
.96542 .014 L
.96814 .01392 L
.97075 .01385 L
.97353 .01377 L
.97619 .01369 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{90.625, 320}, {420.188, 278.875}} -> {49.6168, \
6.21617*^-06, 0.0404584, 1.87037*^-08}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl2 = 
      Plot[{test2/\((2\ \[Pi])\)*360}, {f, 10000, 200000}, 
        PlotPoints \[Rule] 150, PlotRange \[Rule] \ Automatic, 
        AspectRatio \[Rule] 1/3]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.7619e-006 0.16668 0.000886028 [
[.2619 .15418 -15 -9 ]
[.2619 .15418 15 0 ]
[.5 .15418 -18 -9 ]
[.5 .15418 18 0 ]
[.7381 .15418 -18 -9 ]
[.7381 .15418 18 0 ]
[.97619 .15418 -18 -9 ]
[.97619 .15418 18 0 ]
[.01131 .03378 -24 -4.5 ]
[.01131 .03378 0 4.5 ]
[.01131 .07808 -24 -4.5 ]
[.01131 .07808 0 4.5 ]
[.01131 .12238 -18 -4.5 ]
[.01131 .12238 0 4.5 ]
[.01131 .21098 -12 -4.5 ]
[.01131 .21098 0 4.5 ]
[.01131 .25528 -18 -4.5 ]
[.01131 .25528 0 4.5 ]
[.01131 .29958 -18 -4.5 ]
[.01131 .29958 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .16668 m
.2619 .17293 L
s
[(50000)] .2619 .15418 0 1 Mshowa
.5 .16668 m
.5 .17293 L
s
[(100000)] .5 .15418 0 1 Mshowa
.7381 .16668 m
.7381 .17293 L
s
[(150000)] .7381 .15418 0 1 Mshowa
.97619 .16668 m
.97619 .17293 L
s
[(200000)] .97619 .15418 0 1 Mshowa
.125 Mabswid
.07143 .16668 m
.07143 .17043 L
s
.11905 .16668 m
.11905 .17043 L
s
.16667 .16668 m
.16667 .17043 L
s
.21429 .16668 m
.21429 .17043 L
s
.30952 .16668 m
.30952 .17043 L
s
.35714 .16668 m
.35714 .17043 L
s
.40476 .16668 m
.40476 .17043 L
s
.45238 .16668 m
.45238 .17043 L
s
.54762 .16668 m
.54762 .17043 L
s
.59524 .16668 m
.59524 .17043 L
s
.64286 .16668 m
.64286 .17043 L
s
.69048 .16668 m
.69048 .17043 L
s
.78571 .16668 m
.78571 .17043 L
s
.83333 .16668 m
.83333 .17043 L
s
.88095 .16668 m
.88095 .17043 L
s
.92857 .16668 m
.92857 .17043 L
s
.25 Mabswid
0 .16668 m
1 .16668 L
s
.02381 .03378 m
.03006 .03378 L
s
[(-150)] .01131 .03378 1 0 Mshowa
.02381 .07808 m
.03006 .07808 L
s
[(-100)] .01131 .07808 1 0 Mshowa
.02381 .12238 m
.03006 .12238 L
s
[(-50)] .01131 .12238 1 0 Mshowa
.02381 .21098 m
.03006 .21098 L
s
[(50)] .01131 .21098 1 0 Mshowa
.02381 .25528 m
.03006 .25528 L
s
[(100)] .01131 .25528 1 0 Mshowa
.02381 .29958 m
.03006 .29958 L
s
[(150)] .01131 .29958 1 0 Mshowa
.125 Mabswid
.02381 .04264 m
.02756 .04264 L
s
.02381 .0515 m
.02756 .0515 L
s
.02381 .06036 m
.02756 .06036 L
s
.02381 .06922 m
.02756 .06922 L
s
.02381 .08694 m
.02756 .08694 L
s
.02381 .0958 m
.02756 .0958 L
s
.02381 .10466 m
.02756 .10466 L
s
.02381 .11352 m
.02756 .11352 L
s
.02381 .13124 m
.02756 .13124 L
s
.02381 .1401 m
.02756 .1401 L
s
.02381 .14896 m
.02756 .14896 L
s
.02381 .15782 m
.02756 .15782 L
s
.02381 .17554 m
.02756 .17554 L
s
.02381 .1844 m
.02756 .1844 L
s
.02381 .19326 m
.02756 .19326 L
s
.02381 .20212 m
.02756 .20212 L
s
.02381 .21984 m
.02756 .21984 L
s
.02381 .2287 m
.02756 .2287 L
s
.02381 .23756 m
.02756 .23756 L
s
.02381 .24642 m
.02756 .24642 L
s
.02381 .26414 m
.02756 .26414 L
s
.02381 .273 m
.02756 .273 L
s
.02381 .28186 m
.02756 .28186 L
s
.02381 .29072 m
.02756 .29072 L
s
.02381 .02492 m
.02756 .02492 L
s
.02381 .01605 m
.02756 .01605 L
s
.02381 .00719 m
.02756 .00719 L
s
.02381 .30844 m
.02756 .30844 L
s
.02381 .3173 m
.02756 .3173 L
s
.02381 .32616 m
.02756 .32616 L
s
.25 Mabswid
.02381 0 m
.02381 .33333 L
s
0 0 m
1 0 L
1 .33333 L
0 .33333 L
closepath
clip
newpath
.5 Mabswid
.07143 .15635 m
.07734 .1551 L
.08379 .15376 L
.08984 .15251 L
.09567 .15133 L
.10187 .15009 L
.10783 .14891 L
.11417 .14768 L
.12028 .14651 L
.12616 .14541 L
.13242 .14425 L
.13844 .14316 L
.14423 .14212 L
.15039 .14105 L
.15632 .14003 L
.16263 .13896 L
.16871 .13796 L
.17455 .13701 L
.18077 .13602 L
.18676 .13509 L
.19312 .13411 L
.19925 .13318 L
.20515 .1323 L
.21143 .13138 L
.21747 .1305 L
.22328 .12966 L
.22947 .12877 L
.23542 .12792 L
.24175 .12699 L
.24785 .12608 L
.25371 .12518 L
.25995 .12416 L
.26596 .12308 L
.27174 .12189 L
.27789 .12033 L
.28072 .11944 L
.28381 .11825 L
.28688 .11671 L
.28855 .11564 L
.2901 .11442 L
.29171 .11281 L
.29323 .11083 L
.2946 .10842 L
.29537 .10667 L
.29608 .10471 L
.29679 .10225 L
.29756 .09888 L
.29829 .09468 L
.29895 .08958 L
.29972 .08137 L
Mistroke
.30016 .07526 L
.30057 .06846 L
.30211 .03459 L
.30289 .01823 L
.3031 .01444 L
.30333 .01078 L
.30352 .00794 L
.30363 .3254 L
.30373 .32406 L
.30453 .31544 L
.30525 .30986 L
.30596 .30581 L
.30663 .30284 L
.3081 .29819 L
.30881 .29657 L
.30958 .29508 L
.31116 .29275 L
.31261 .29113 L
.31398 .28992 L
.31707 .28789 L
.3199 .28655 L
.32281 .28549 L
.32598 .28455 L
.33219 .28313 L
.33817 .28207 L
.34453 .28114 L
.35066 .28036 L
.35655 .27969 L
.36282 .27904 L
.36886 .27846 L
.37466 .27793 L
.38084 .27741 L
.38679 .27692 L
.39312 .27643 L
.39921 .27598 L
.40507 .27556 L
.41131 .27514 L
.41731 .27474 L
.42308 .27437 L
.42923 .27398 L
.43514 .27363 L
.44143 .27326 L
.44749 .27291 L
.45332 .27259 L
.45952 .27225 L
.46549 .27194 L
.47183 .27161 L
.47795 .27131 L
.48383 .27102 L
.49009 .27072 L
Mistroke
.49611 .27044 L
.5019 .27018 L
.50807 .2699 L
.51401 .26965 L
.52032 .26938 L
.5264 .26912 L
.53224 .26888 L
.53847 .26864 L
.54446 .2684 L
.55082 .26816 L
.55696 .26793 L
.56286 .26771 L
.56914 .26749 L
.57518 .26727 L
.57822 .26717 L
.581 .26707 L
.58173 .26704 L
.58253 .26702 L
.5829 .267 L
.5831 .267 L
.58329 .26699 L
.58344 .1075 L
.58362 .1075 L
.58398 .10748 L
.58718 .10737 L
.59348 .10716 L
.59955 .10697 L
.60538 .10678 L
.61159 .10658 L
.61757 .1064 L
.62392 .1062 L
.63005 .10602 L
.63593 .10585 L
.6422 .10566 L
.64823 .10549 L
.65403 .10533 L
.66021 .10516 L
.66615 .105 L
.67247 .10483 L
.67856 .10467 L
.68441 .10452 L
.69064 .10436 L
.69664 .10421 L
.70302 .10405 L
.70916 .1039 L
.71507 .10376 L
.72135 .10361 L
.72741 .10347 L
.73323 .10333 L
.73943 .10319 L
Mistroke
.74539 .10305 L
.75173 .10291 L
.75784 .10277 L
.76372 .10264 L
.76997 .1025 L
.77599 .10237 L
.78177 .10224 L
.78794 .1021 L
.79387 .10197 L
.80017 .10182 L
.80625 .10167 L
.81209 .10153 L
.81831 .10136 L
.82429 .10119 L
.83066 .10098 L
.83678 .10074 L
.84268 .10043 L
.84573 .10021 L
.84729 .10007 L
.84895 .0999 L
.85052 .0997 L
.85196 .09948 L
.8534 .0992 L
.85476 .09884 L
.85624 .09831 L
.85698 .09795 L
.85781 .09743 L
.85851 .09685 L
.85887 .09646 L
.85926 .09598 L
.8596 .09546 L
.85997 .09477 L
.86031 .09398 L
.86063 .09304 L
.86082 .09233 L
.86103 .09143 L
.8614 .08925 L
.8616 .08756 L
.8618 .0855 L
.86201 .08242 L
.86213 .08011 L
.86223 .07749 L
.86243 .07095 L
.86261 .06139 L
.8628 .04426 L
.86291 .03102 L
.86301 .01772 L
.8632 .31447 L
.8634 .29838 L
.86358 .28917 L
Mistroke
.86375 .2837 L
.86392 .28002 L
.8641 .27714 L
.86426 .27509 L
.86441 .27361 L
.86459 .2722 L
.86479 .27098 L
.86514 .26929 L
.86551 .26802 L
.8659 .26701 L
.86623 .26634 L
.8666 .26574 L
.86735 .26482 L
.86815 .26414 L
.86882 .2637 L
.86956 .26332 L
.87036 .26299 L
.87122 .26271 L
.87276 .26232 L
.87433 .26203 L
.87603 .26178 L
.87911 .26145 L
.88216 .26121 L
.88538 .26102 L
.89118 .26076 L
.89736 .26054 L
.90331 .26037 L
.90963 .26021 L
.91572 .26008 L
.92158 .25996 L
.92781 .25984 L
.93382 .25973 L
.93959 .25963 L
.94573 .25953 L
.95164 .25943 L
.95793 .25934 L
.96399 .25924 L
.96981 .25916 L
.97601 .25907 L
.97619 .25907 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 95.9375},
  ImageMargins->{{45, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000Gb000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooo`<0oooo000K0?ooo`030000003oool0oooo0?l0oooo0`3oool001/0
oooo0P0000150?ooo`030000003oool0oooo0;/0oooo000K0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0^`3oool001/0oooo0P0000150?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0;@3oool001/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo02d0oooo00070?ooo`D000000P3oool2000000@0oooo0P0000050?oo
o`800000A@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02d0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@`3oool2000008d0oooo00<000000?ooo`3oool0;@3oool0
00T0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0080oooo0P0000140?ooo`800000S@3oool00`000000oooo0?ooo`0]0?ooo`0000<0oooo0000
000000000P0000040?ooo`030000003oool0oooo0080oooo0P0000030?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0@`3oool2000008d0oooo00<000000?ooo`3oool0;@3oool0
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0@`3oool2000008d0oooo00<000000?ooo`3oool0;@3oool0
00P0oooo0P0000040?ooo`<000000`3oool2000000D0oooo0P0000140?ooo`800000S@3oool00`00
0000oooo0?ooo`0]0?ooo`006`3oool00`000000oooo0?ooo`130?ooo`800000S@3oool00`000000
oooo0?ooo`0]0?ooo`006`3oool2000004@0oooo0P00002=0?ooo`030000003oool0oooo02d0oooo
000K0?ooo`030000003oool0oooo04<0oooo0P00002=0?ooo`030000003oool0oooo02d0oooo000K
0?ooo`800000A03oool2000008d0oooo00<000000?ooo`3oool0;@3oool001/0oooo00<000000?oo
o`3oool0@`3oool2000008d0oooo00<000000?ooo`3oool0;@3oool001/0oooo0P0000140?ooo`80
0000S@3oool00`000000oooo0?ooo`0]0?ooo`001`3oool500000080oooo0P0000040?ooo`800000
1@3oool00`000000oooo0?ooo`130?ooo`800000S@3oool00`000000oooo0?ooo`0]0?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo04<0oooo0P00002=0?ooo`030000003oool0oooo02d0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo0080oooo0P0000140?ooo`800000S@3oool00`000000oooo0?ooo`0]0?oo
o`0000<0oooo0000000000000P0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@`3oool2
000008`0oooo0P00000_0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000A03oool2000008`0oooo0P00
000_0?ooo`00203oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`13
0?ooo`800000S03oool2000002l0oooo000K0?ooo`800000@`3oool00`000000oooo0000002;0?oo
o`<00000;`3oool001/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0000001o0?ooo`d0
000000<0oooo0000003oool0;P3oool001/0oooo0P0000130?ooo`030000003oool0000005H0oooo
:@00000>0?ooo`030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo0440oooo0P00
00000`3oool000000?ooo`150?oooa000000=`3oool00`000000oooo0?ooo`0]0?ooo`006`3oool0
0`000000oooo0?ooo`110?ooo`040000003oool0oooo000004H0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0]0?ooo`003P3oool2000000@0oooo0P0000050?ooo`800000@03oool2
000000<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo02d0oooo000=0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0m0?ooo`<00000103oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0;@3oool00100oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`020?ooo`800000;@3oool2000000@0oooo0P0000030?ooo`H0000000<0
oooo000000000000103oool2000001l0oooo1@0000020?ooo`800000103oool2000000@0oooo0P00
00040?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool04`3oool500000080oooo0P00
00040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000403oool00`000000oooo0?oo
o`090?ooo`@000000`3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00
00030?ooo`001`3oool4000000<0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool0:`3oool01@000000oooo0?ooo`000000oooo00P000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo0080000000<0oooo0000003oool07`3oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`003P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo0P00000[0?ooo`H0000000D0oooo0000003oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`00
0000oooo01l0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo000>0?ooo`<000000`3oool20000
00D0oooo00<000000?ooo`3oool08P3oool800000080oooo0P0000030?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`800000
00<0oooo0000003oool07`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000003`3o
ool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`4000000@3oool10?ooo`006`3oool2000001l0oooo1000000:
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo0P0000000`3oool000000?ooo`0O0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000003`3oool00`000000oooo
0?ooo`090?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`006`3oool00`000000oooo0?ooo`0H0?ooo`H00000
3P3oool3000000<0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000P0?ooo`800000
103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000
003oool0oooo01@0oooo0P0000040?ooo`<000000`3oool2000000@0oooo0P0000040?ooo`800000
103oool200000100oooo00<000000?ooo`3oool02P3oool2000000@0oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000040?ooo`8000000`3oool001/0oooo00<000000?ooo`3oool04`3o
ool5000002`0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo02d0oooo000K0?ooo`8000003P3oool600000340oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo
00T0oooo1000000g0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0]0?ooo`006`3oool2000004D0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02d0oooo
000E0?ooool00000303oool001/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00P0oooo0P00000;0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0@0?ooo`006`3oool2000003X0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0403o
ool001/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0;@3oool001/0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0;@3oool001/0
oooo0P0000150?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0]0?ooo`006`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0]0?ooo`006`3oool2000004D0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02d0oooo000K
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo02d0oooo000>0?ooo`800000103oool2000000D0oooo0P0000150?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0]0?oo
o`003@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0;@3oool00100oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`800000A@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0;@3oool000h0oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0;@3oool000h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo02d0oooo000>0?ooo`<000000`3oool2000000D0oooo0P0000150?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0]0?oo
o`006`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0]0?ooo`006`3oool2000004D0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02d0oooo000K0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo02d0oooo000K0?ooo`800000A@3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool0;@3oool001/0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0;@3oool001/0
oooo0P0000150?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0]0?ooo`001`3oool500000080oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0]0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02d0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0080oooo0P0000150?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0I0?ooo`8000004P3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0000000I
000001@0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo0P0000150?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0A03oool2000002h0oooo00080?ooo`800000103oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0:`3ooolJ000004H0oooo00<00000
0?ooo`3oool0;@3oool001/0oooo0P0000150?ooo`030000003oool0oooo01T0oooo4P00001P0?oo
o`030000003oool0oooo02d0oooo000K0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool03@3oool<00000780oooo00<000000?ooo`3oool0;@3oool001/0oooo0P0000150?ooo`030000
003oool0oooo00D0oooo2000001n0?ooo`030000003oool0oooo02d0oooo000K0?ooo`030000003o
ool0oooo04@0oooo00@000000?ooo`3oool0oooo100000260?ooo`030000003oool0oooo02d0oooo
000K0?ooo`030000003oool0oooo04@0oooo00@000000?ooo`0000000000RP3oool00`000000oooo
0?ooo`0]0?ooo`001`3oool500000080oooo0P0000040?ooo`8000001@3oool2000004D0oooo00<0
00000?ooo`000000R`3oool00`000000oooo0?ooo`0]0?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo04@0oooo0P00002<0?ooo`030000003oool0oooo02d0oooo00090?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`800000
A@3oool2000008`0oooo00<000000?ooo`3oool0;@3oool000T0oooo00<000000?ooo`3oool00P3o
ool2000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo08/0oooo00<000000?ooo`3oool0;@3oool000T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P0000150?ooo`030000
003oool0oooo08/0oooo00<000000?ooo`3oool0;@3oool000P0oooo0P0000040?ooo`<000000`3o
ool2000000D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo02d0oooo000K0?ooo`800000A@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo02d0oooo000K0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0^`3oool001/0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`2k0?ooo`006`3oool200000?l0oooo
103oool001/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{92.25, 321.625}, {560.188, 484.438}} -> {-117977, 2484, \
828, 4.45003}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Amplitude over Length-coordinate (Function X[x])", "Subsection"],

Cell["\<\
Plotting the imaginary part of the function X at a certain frequency (once \
without ZC, once with ZC\[NotEqual]0),over its coordinate x:\
\>", "Text"],

Cell[BoxData[
    \(\(test1 = 
        Im[\(\(\(\(\(X[x] /. Flatten[{rulea1, rulea2}]\) /. ruleUdlc\) /. 
                    values\) /. ZC \[Rule] 0\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  /. 
                w \[Rule] 2\ \[Pi]\ f\) /. f \[Rule] 149000] // 
          N;\)\)], "Input"],

Cell[BoxData[
    \(\(test2 = 
        Im[\(\(\(\(\(X[x] /. Flatten[{rulea1, rulea2}]\) /. ruleUdlc\) /. 
                    values\) /. ZC \[Rule] 0 + 250\ \[ImaginaryI]\) /. 
                w \[Rule] 2\ \[Pi]\ f\) /. f \[Rule] 149000] // 
          N;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{test1, test2}, {x, 0, 
        lRod /. values}, \[IndentingNewLine]PlotStyle \[Rule] {{Thickness[ \
.001], RGBColor[1, 0, 0]}, {Thickness[ .001], RGBColor[0, 1, 0]}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 23.8095 0.309016 7.84849e+007 [
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.5 .29652 -12 -9 ]
[.5 .29652 12 0 ]
[.7381 .29652 -12 -9 ]
[.7381 .29652 12 0 ]
[.97619 .29652 -12 -9 ]
[.97619 .29652 12 0 ]
[.01131 .07356 -39 -6.25 ]
[.01131 .07356 0 6.25 ]
[.01131 .15205 -39 -6.25 ]
[.01131 .15205 0 6.25 ]
[.01131 .23053 -39 -6.25 ]
[.01131 .23053 0 6.25 ]
[.01131 .3875 -33 -6.25 ]
[.01131 .3875 0 6.25 ]
[.01131 .46599 -33 -6.25 ]
[.01131 .46599 0 6.25 ]
[.01131 .54447 -33 -6.25 ]
[.01131 .54447 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
[(0.01)] .2619 .29652 0 1 Mshowa
.5 .30902 m
.5 .31527 L
s
[(0.02)] .5 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.03)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(0.04)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .07356 m
.03006 .07356 L
s
gsave
.01131 .07356 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .15205 m
.03006 .15205 L
s
gsave
.01131 .15205 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .23053 m
.03006 .23053 L
s
gsave
.01131 .23053 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .3875 m
.03006 .3875 L
s
gsave
.01131 .3875 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .46599 m
.03006 .46599 L
s
gsave
.01131 .46599 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .54447 m
.03006 .54447 L
s
gsave
.01131 .54447 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.125 Mabswid
.02381 .08926 m
.02756 .08926 L
s
.02381 .10496 m
.02756 .10496 L
s
.02381 .12065 m
.02756 .12065 L
s
.02381 .13635 m
.02756 .13635 L
s
.02381 .16774 m
.02756 .16774 L
s
.02381 .18344 m
.02756 .18344 L
s
.02381 .19914 m
.02756 .19914 L
s
.02381 .21483 m
.02756 .21483 L
s
.02381 .24623 m
.02756 .24623 L
s
.02381 .26192 m
.02756 .26192 L
s
.02381 .27762 m
.02756 .27762 L
s
.02381 .29332 m
.02756 .29332 L
s
.02381 .32471 m
.02756 .32471 L
s
.02381 .34041 m
.02756 .34041 L
s
.02381 .35611 m
.02756 .35611 L
s
.02381 .3718 m
.02756 .3718 L
s
.02381 .4032 m
.02756 .4032 L
s
.02381 .41889 m
.02756 .41889 L
s
.02381 .43459 m
.02756 .43459 L
s
.02381 .45029 m
.02756 .45029 L
s
.02381 .48168 m
.02756 .48168 L
s
.02381 .49738 m
.02756 .49738 L
s
.02381 .51308 m
.02756 .51308 L
s
.02381 .52877 m
.02756 .52877 L
s
.02381 .05786 m
.02756 .05786 L
s
.02381 .04217 m
.02756 .04217 L
s
.02381 .02647 m
.02756 .02647 L
s
.02381 .01077 m
.02756 .01077 L
s
.02381 .56017 m
.02756 .56017 L
s
.02381 .57586 m
.02756 .57586 L
s
.02381 .59156 m
.02756 .59156 L
s
.02381 .60726 m
.02756 .60726 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.001 w
.02381 .14025 m
.06244 .19683 L
.10458 .27153 L
.14415 .34607 L
.18221 .41405 L
.20342 .44776 L
.22272 .47467 L
.24299 .49829 L
.26171 .51529 L
.271 .52188 L
.28086 .52745 L
.29075 .53155 L
.29637 .53321 L
.2991 .53384 L
.30164 .53431 L
.30404 .53467 L
.3066 .53495 L
.30807 .53506 L
.30878 .53511 L
.30944 .53514 L
.31068 .53518 L
.31133 .5352 L
.31202 .5352 L
.31319 .53519 L
.31445 .53516 L
.31564 .53511 L
.31672 .53504 L
.31799 .53494 L
.31937 .5348 L
.32189 .53447 L
.3241 .53409 L
.32655 .53358 L
.33151 .53227 L
.34041 .52895 L
.3505 .52371 L
.35976 .51756 L
.38061 .4992 L
.39954 .47751 L
.42024 .44899 L
.4608 .38187 L
.49984 .30931 L
.54134 .23233 L
.58132 .16673 L
.59964 .14156 L
.61979 .11842 L
.63967 .10089 L
.65054 .09371 L
.66071 .0886 L
.66569 .08667 L
.67112 .08502 L
Mistroke
.6736 .08441 L
.67624 .08388 L
.67872 .08348 L
.681 .08319 L
.68217 .08308 L
.68341 .08298 L
.68465 .08291 L
.68535 .08288 L
.68601 .08285 L
.6872 .08283 L
.68829 .08283 L
.68954 .08285 L
.69072 .0829 L
.69179 .08296 L
.69292 .08304 L
.69495 .08324 L
.69713 .08352 L
.69953 .08393 L
.70447 .08504 L
.70965 .08661 L
.71892 .09047 L
.72889 .09609 L
.73979 .10392 L
.75944 .12229 L
.7804 .14743 L
.82195 .21101 L
.86199 .28346 L
.9005 .35595 L
.94148 .42759 L
.97619 .47778 L
Mfstroke
0 1 0 r
.02381 .05622 m
.06244 .11717 L
.10458 .20602 L
.14415 .30122 L
.18221 .39371 L
.22272 .48259 L
.26171 .5496 L
.27193 .56319 L
.28302 .57584 L
.2926 .58493 L
.30316 .59289 L
.30809 .59585 L
.3134 .59849 L
.31841 .60046 L
.32299 .60182 L
.32567 .60241 L
.32815 .60282 L
.32958 .60301 L
.33087 .60314 L
.33159 .60319 L
.33237 .60324 L
.3331 .60328 L
.33377 .6033 L
.335 .60332 L
.33615 .60331 L
.33741 .60326 L
.33811 .60322 L
.33876 .60318 L
.34005 .60306 L
.34146 .6029 L
.34402 .6025 L
.34635 .60201 L
.34887 .60136 L
.35342 .59986 L
.35883 .59753 L
.3638 .59487 L
.37403 .58783 L
.3848 .57822 L
.40455 .555 L
.42291 .52737 L
.46196 .45251 L
.50346 .35653 L
.54344 .25855 L
.5819 .16943 L
.60139 .12923 L
.62282 .09056 L
.64341 .05999 L
.66223 .03848 L
.6722 .02977 L
.68167 .02329 L
Mistroke
.68651 .02067 L
.69167 .01839 L
.69464 .01733 L
.69732 .01653 L
.69982 .01591 L
.70257 .01538 L
.70379 .01519 L
.7051 .01502 L
.70633 .0149 L
.70746 .01481 L
.70873 .01475 L
.70944 .01473 L
.71011 .01472 L
.71132 .01472 L
.71262 .01475 L
.71371 .01481 L
.71488 .0149 L
.71599 .01501 L
.71701 .01514 L
.71937 .0155 L
.72185 .01602 L
.72701 .01748 L
.73181 .01933 L
.74268 .02525 L
.75323 .03324 L
.76318 .04273 L
.78178 .06538 L
.8203 .1302 L
.86127 .21916 L
.90073 .31485 L
.93867 .40639 L
.97619 .4874 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{448.25, 277.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007000015B000`400?l00000o`00003oo`3oooo1
0?ooo`00o`3oooo10?ooo`00o`3oooo10?ooo`00o`3oooo10?ooo`00o`3oooo10?ooo`00o`3oooo1
0?ooo`00o`3oooo10?ooo`00o`3oooo10?ooo`00o`3oooo10?ooo`00o`3oooo10?ooo`00o`3oooo1
0?ooo`00o`3oooo10?ooo`00;03oool00`000000oooo0?ooo`3o0?oooi80oooo000/0?ooo`030000
003oool0oooo0?l0ooooTP3oool002`0oooo00<000000?ooo`3oool0o`3ooonB0?ooo`00;03oool0
0`000000oooo0?ooo`3o0?oooi80oooo000/0?ooo`800000o`3ooonC0?ooo`00;03oool00`000000
oooo0?ooo`3o0?oooi80oooo000/0?ooo`030000003oool0oooo0?l0oooo4P3oool<003o07@0oooo
000/0?ooo`030000003oool0oooo0?l0oooo3`3oool3003o00`0oooo0P00o`1b0?ooo`00;03oool0
0`000000oooo0?ooo`3o0?ooo`d0oooo0P00o`0A0?ooo`800?l0L03oool002`0oooo00<000000?oo
o`3oool0o`3oool<0?ooo`03003o003oool0oooo01<0oooo0P00o`1^0?ooo`00;03oool200000?l0
oooo2`3oool2003o01P0oooo0P00o`1/0?ooo`00;03oool00`000000oooo0?ooo`3o0?ooo`T0oooo
00<00?l00?ooo`3oool06P3oool2003o06X0oooo000/0?ooo`030000003oool0oooo0?l0oooo203o
ool00`00o`00oooo0?ooo`0M0?ooo`03003o003oool0oooo06L0oooo000/0?ooo`030000003oool0
oooo0?l0oooo1P3oool2003o0240oooo00<00?l00?ooo`3oool0IP3oool002`0oooo00<000000?oo
o`3oool0o`3oool50?ooo`03003o003oool0oooo0280oooo00<00?l00?ooo`3oool0I@3oool002`0
oooo00<000000?ooo`3oool0o`3oool40?ooo`03003o003oool0oooo02@0oooo00<00?l00?ooo`3o
ool0I03oool002`0oooo00<000000?ooo`3oool0o`3oool30?ooo`03003o003oool0oooo02H0oooo
00<00?l00?ooo`3oool0H`3oool002`0oooo0P00003o0?ooo`<0oooo00<00?l00?ooo`3oool0:03o
ool00`00o`00oooo0?ooo`1R0?ooo`00;03oool00`000000oooo0?ooo`3o0?ooo`40oooo00<00?l0
0?ooo`3oool0:P3oool00`00o`00oooo0?ooo`1Q0?ooo`00;03oool00`000000oooo0?ooo`3o0?oo
o`03003o003oool0oooo02`0oooo00<00?l00?ooo`3oool0H03oool002`0oooo00<000000?ooo`3o
ool0o`3oool00`00o`00oooo0?ooo`0]0?ooo`03003o003oool0oooo05l0oooo000/0?ooo`030000
003oool0oooo0?h0oooo00<00?l00?ooo`3oool0;`3oool00`00o`00oooo0?ooo`1N0?ooo`00;03o
ool00`000000oooo0?ooo`3m0?ooo`03003o003oool0oooo0300oooo00<00?l00?ooo`3oool0GP3o
ool002`0oooo00<00?l00000003oool0o03oool00`00o`00oooo0?ooo`0b0?ooo`03003o003oool0
oooo05d0oooo000/0?ooo`0300000000o`00oooo0?/0oooo00<00?l00?ooo`3oool0=03oool00`00
o`00oooo0?ooo`1L0?ooo`00;03oool00`0000000?l00?ooo`3j0?ooo`03003o003oool0oooo03H0
oooo00<00?l00?ooo`3oool0F`3oool002`0oooo00<000000?ooo`00o`00nP3oool00`00o`00oooo
0?ooo`0g0?ooo`03003o003oool0oooo05X0oooo00080?ooo`8000000`3oool01P000000oooo0?oo
o`3oool000000?ooo`D000000P3oool200000100oooo00@000000?ooo`3oool00?l0n03oool00`00
o`00oooo0?ooo`0i0?ooo`03003o003oool0oooo05T0oooo00070?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool03@3oool010000000oooo0?ooo`00o`3h0?ooo`03003o003oool0oooo03T0oooo00<0
0?l00?ooo`3oool0F@3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0=0?ooo`050000003o
ool0oooo0?ooo`00o`00mP3oool00`00o`00oooo0?ooo`0k0?ooo`03003o003oool0oooo05P0oooo
00000`3oool0000000000002000000D0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00d0oooo0`0000000`3o
ool00?l00?ooo`3d0?ooo`03003o003oool0oooo03`0oooo00<00?l00?ooo`3oool0F03oool000L0
oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3o
ool00`00o`00oooo0?ooo`3b0?ooo`03003o003oool0oooo03d0oooo00<00?l00?ooo`3oool0E`3o
ool000P0oooo0P00000:0?ooo`800000103oool2000000P0oooo0`0000050?ooo`030000003oool0
oooo00<0oooo00<00?l00?ooo`3oool0l03oool00`00o`00oooo0?ooo`0o0?ooo`03003o003oool0
oooo05H0oooo000V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
o`00oooo0?ooo`3_0?ooo`03003o003oool0oooo0400oooo00<00?l00?ooo`3oool0EP3oool001l0
oooo0`0000020?ooo`<000001@3oool00`000000oooo0?ooo`040?ooo`03003o003oool0oooo0>h0
oooo00<00?l00?ooo`3oool03@3ooolA0?l002<0oooo00<00?l00?ooo`3oool0E@3oool002@0oooo
00<000000?ooo`0000001@3oool00`000000oooo0?ooo`050?ooo`03003o003oool0oooo0>`0oooo
00<00?l00?ooo`3oool0303oool20?l00140oooo0P3o000Q0?ooo`03003o003oool0oooo05D0oooo
000T0?ooo`<000001@3oool2000000H0oooo00<00?l00?ooo`3oool0k03oool00`00o`00oooo0?oo
o`0:0?ooo`80o`005@3oool20?l00200oooo00<00?l00?ooo`3oool0E03oool002`0oooo00<00000
0?ooo`3oool01P3oool00`00o`00oooo0?ooo`3Z0?ooo`03003o003oool0oooo00T0oooo0P3o000I
0?ooo`80o`007`3oool00`00o`00oooo0?ooo`1C0?ooo`00;03oool00`000000oooo0?ooo`070?oo
o`03003o003oool0oooo0>P0oooo00<00?l00?ooo`3oool02@3oool00`3o0000oooo0?ooo`0K0?oo
o`80o`007@3oool00`00o`00oooo0?ooo`1C0?ooo`00;03oool00`000000oooo0?ooo`070?ooo`03
003o003oool0oooo0>P0oooo00<00?l00?ooo`3oool01`3oool20?l00200oooo00<0o`000?ooo`3o
ool06`3oool00`00o`00oooo0?ooo`1B0?ooo`00;03oool00`000000oooo0?ooo`080?ooo`03003o
003oool0oooo0>H0oooo00<00?l00?ooo`3oool01`3oool00`3o0000oooo0?ooo`0Q0?ooo`80o`00
6`3oool00`00o`00oooo0?ooo`1B0?ooo`00;03oool00`000000oooo0?ooo`090?ooo`03003o003o
ool0oooo0>D0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`0T0?ooo`80o`006P3o
ool00`00o`00oooo0?ooo`1A0?ooo`00;03oool00`000000oooo0?ooo`090?ooo`03003o003oool0
oooo0>@0oooo00<00?l00?ooo`3oool01P3oool00`3o0000oooo0?ooo`0W0?ooo`030?l0003oool0
oooo01L0oooo00<00?l00?ooo`3oool0D@3oool002`0oooo0P00000;0?ooo`03003o003oool0oooo
0><0oooo00<00?l00?ooo`3oool0103oool20?l002/0oooo00<0o`000?ooo`3oool05`3oool00`00
o`00oooo0?ooo`1@0?ooo`00;03oool00`000000oooo0?ooo`0:0?ooo`03003o003oool0oooo0>80
oooo00<00?l00?ooo`3oool0103oool00`3o0000oooo0?ooo`0/0?ooo`030?l0003oool0oooo01L0
oooo00<00?l00?ooo`3oool0C`3oool002`0oooo00<000000?ooo`3oool02`3oool00`00o`00oooo
0?ooo`3Q0?ooo`03003o003oool0oooo00<0oooo00<0o`000?ooo`3oool0;P3oool00`3o0000oooo
0?ooo`0F0?ooo`03003o003oool0oooo04l0oooo000/0?ooo`030000003oool0oooo00`0oooo00<0
0?l00?ooo`3oool0g`3oool00`00o`00oooo0?ooo`020?ooo`80o`00<P3oool00`3o0000oooo0?oo
o`0F0?ooo`03003o003oool0oooo04h0oooo000/0?ooo`030000003oool0oooo00`0oooo00<00?l0
0?ooo`3oool0gP3oool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo03<0oooo00<0o`00
0?ooo`3oool05@3oool00`00o`00oooo0?ooo`1>0?ooo`00;03oool00`000000oooo0?ooo`0=0?oo
o`03003o003oool0oooo0=d0oooo00D00?l00?ooo`3oool0oooo0?l0000g0?ooo`030?l0003oool0
oooo01D0oooo00<00?l00?ooo`3oool0C@3oool002`0oooo0P00000>0?ooo`03003o003oool0oooo
0=`0oooo00D00?l00?ooo`3oool0oooo0?l0000i0?ooo`030?l0003oool0oooo01D0oooo00<00?l0
0?ooo`3oool0C03oool002`0oooo00<000000?ooo`3oool03P3oool00`00o`00oooo0?ooo`3K0?oo
o`04003o003oool0oooo0?l003/0oooo00<0o`000?ooo`3oool0503oool00`00o`00oooo0?ooo`1<
0?ooo`00;03oool00`000000oooo0?ooo`0>0?ooo`03003o003oool0oooo0=X0oooo00D00?l00?oo
o`3oool0oooo0?l0000l0?ooo`030?l0003oool0oooo01@0oooo00<00?l00?ooo`3oool0B`3oool0
02`0oooo00<000000?ooo`3oool03`3oool00`00o`00oooo0?ooo`3I0?ooo`04003o003oool0oooo
0?l003h0oooo00<0o`000?ooo`3oool04`3oool00`00o`00oooo0?ooo`1;0?ooo`00;03oool00`00
0000oooo0?ooo`0?0?ooo`03003o003oool0oooo0=P0oooo00@00?l00?ooo`3oool0o`00?`3oool0
0`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo04X0oooo000/0?ooo`030000003oool0oooo
0100oooo00<00?l00?ooo`3oool0e`3oool00`00o`00oooo0?l000110?ooo`030?l0003oool0oooo
01<0oooo00<00?l00?ooo`3oool0BP3oool002`0oooo00<000000?ooo`3oool0403oool00`00o`00
oooo0?ooo`3F0?ooo`03003o003oool0o`0004<0oooo00<0o`000?ooo`3oool04`3oool00`00o`00
oooo0?ooo`190?ooo`00;03oool200000180oooo00<00?l00?ooo`3oool0e@3oool00`00o`00oooo
0?l000140?ooo`030?l0003oool0oooo0180oooo00<00?l00?ooo`3oool0B@3oool002`0oooo00<0
o`000?ooo`3oool04@3oool00`00o`00oooo0?ooo`3D0?ooo`03003o003oool0o`0004H0oooo00<0
o`000?ooo`3oool04P3oool00`00o`00oooo0?ooo`180?ooo`00;03oool00`000000o`000?ooo`0B
0?ooo`03003o003oool0oooo0=<0oooo00<00?l00?l0003oool0AP3oool00`3o0000oooo0?ooo`0B
0?ooo`03003o003oool0oooo04P0oooo00070?ooo`@000000P3oool01P000000oooo0?ooo`3oool0
00000?ooo`D000000P3oool200000100oooo00<000000?l0003oool04P3oool00`00o`00oooo0?oo
o`3B0?ooo`03003o003o0000oooo04P0oooo00<0o`000?ooo`3oool04P3oool00`00o`00oooo0?oo
o`170?ooo`001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o00004`3o
ool00`00o`00oooo0?ooo`3A0?ooo`03003o003o0000oooo04T0oooo00<0o`000?ooo`3oool04@3o
ool00`00o`00oooo0?ooo`170?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00d0oooo00@0
00000?ooo`3oool0o`004P3oool00`00o`00oooo0?ooo`3@0?ooo`03003o003o0000oooo04/0oooo
00<0o`000?ooo`3oool04@3oool00`00o`00oooo0?ooo`160?ooo`0000<0oooo0000000000000P00
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool03@3oool3000000030?l0003oool0oooo0140oooo
00<00?l00?ooo`3oool0c`3oool00`00o`00oooo0?ooo`1;0?ooo`030?l0003oool0oooo0140oooo
00<00?l00?ooo`3oool0AP3oool000L0oooo00@000000?ooo`3oool000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00d0oooo00D000000?ooo`3oool0oooo0?l0000B0?ooo`03003o003oool0oooo0<h0oooo00<00?l0
0?l0003oool0C@3oool00`3o0000oooo0?ooo`0A0?ooo`03003o003oool0oooo04D0oooo00080?oo
o`8000002P3oool2000000@0oooo0P0000080?ooo`<000001@3oool00`000000oooo0?ooo`020?oo
o`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool0c@3oool00`00o`00oooo0?ooo`1>0?oo
o`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool0A@3oool002H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3o
ool0c03oool00`00o`00oooo0?ooo`1?0?ooo`030?l0003oool0oooo0140oooo00<00?l00?ooo`3o
ool0A03oool001l0oooo0`0000020?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030?l0
003oool0oooo0100oooo00<00?l00?ooo`3oool0bP3oool00`3o00000?l00?ooo`1A0?ooo`030?l0
003oool0oooo0100oooo00<00?l00?ooo`3oool0A03oool002@0oooo00<000000?ooo`0000001@3o
ool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3oool0bP3o
ool00`00o`00oooo0?ooo`1B0?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3oool0A03o
ool002@0oooo0`0000050?ooo`8000001P3oool00`3o0000oooo0?ooo`0>0?ooo`03003o003oool0
oooo0<T0oooo00<0o`00003o003oool0D`3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0
oooo04<0oooo000/0?ooo`030000003oool0oooo00D0oooo00<0o`000?ooo`3oool03`3oool00`00
o`00oooo0?ooo`370?ooo`030?l00000o`00oooo05D0oooo00<0o`000?ooo`3oool03`3oool00`00
o`00oooo0?ooo`130?ooo`00;03oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo00h0
oooo00<00?l00?ooo`3oool0a`3oool00`3o00000?l00?ooo`1F0?ooo`030?l0003oool0oooo00l0
oooo00<00?l00?ooo`3oool0@P3oool002`0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo
0?ooo`0>0?ooo`03003o003oool0oooo0<D0oooo00<0o`00003o003oool0E`3oool00`3o0000oooo
0?ooo`0?0?ooo`03003o003oool0oooo0480oooo000/0?ooo`030000003oool0oooo00L0oooo00<0
o`000?ooo`3oool03P3oool00`00o`00oooo0?ooo`340?ooo`030?l0003oool00?l005T0oooo00<0
o`000?ooo`3oool03`3oool00`00o`00oooo0?ooo`110?ooo`00;03oool00`000000oooo0?ooo`08
0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool0``3oool00`3o00000?l00?ooo`1J
0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool0@@3oool002`0oooo00<000000?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo0<80oooo00<0o`000?oo
o`00o`00F`3oool00`3o0000oooo0?ooo`0?0?ooo`03003o003oool0oooo0400oooo000/0?ooo`80
00002`3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo0<40oooo00<0o`00003o003o
ool0G03oool00`3o0000oooo0?ooo`0>0?ooo`03003o003oool0oooo0400oooo000/0?ooo`030000
003oool0oooo00X0oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`300?ooo`030?l0
003oool00?l005d0oooo00<0o`000?ooo`3oool03`3oool00`00o`00oooo0?ooo`0o0?ooo`00;03o
ool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo00<00?l00?ooo`3oool0_P3o
ool0103o0000oooo0?ooo`00o`1N0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool0
?`3oool002`0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03003o003o
ool0oooo0;h0oooo00<0o`000?ooo`00o`00H03oool00`3o0000oooo0?ooo`0=0?ooo`03003o003o
ool0oooo03l0oooo000/0?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool0
0`00o`00oooo0?ooo`2l0?ooo`040?l0003oool0oooo003o0600oooo00<0o`000?ooo`3oool03P3o
ool00`00o`00oooo0?ooo`0n0?ooo`00;03oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00`0oooo00<00?l00?ooo`3oool0^`3oool0103o0000oooo0?ooo`00o`1R0?ooo`030?l0003o
ool0oooo00d0oooo00<00?l00?ooo`3oool0?P3oool002`0oooo0P00000?0?ooo`030?l0003oool0
oooo00`0oooo00<00?l00?ooo`3oool0^P3oool0103o0000oooo0?ooo`00o`1S0?ooo`030?l0003o
ool0oooo00d0oooo00<00?l00?ooo`3oool0?@3oool002`0oooo00<000000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo0;T0oooo00@0o`000?ooo`3oool00?l0I03o
ool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo03d0oooo000/0?ooo`030000003oool0
oooo00l0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`2h0?ooo`040?l0003oool0
oooo003o06D0oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?ooo`0l0?ooo`00;03oool0
0`000000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0]`3oool0
1@3o0000oooo0?ooo`3oool00?l006H0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?oo
o`0l0?ooo`00;03oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00/0oooo00<00?l0
0?ooo`3oool0]P3oool01@3o0000oooo0?ooo`3oool00?l006L0oooo00<0o`000?ooo`3oool03@3o
ool00`00o`00oooo0?ooo`0k0?ooo`00;03oool00`000000oooo0?ooo`0@0?ooo`030?l0003oool0
oooo00`0oooo00<00?l00?ooo`3oool0]@3oool01@3o0000oooo0?ooo`3oool00?l006P0oooo00<0
o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`0k0?ooo`00;03oool00`000000oooo0?ooo`0A
0?ooo`030?l0003oool0oooo00/0oooo00<00?l00?ooo`3oool0]03oool01@3o0000oooo0?ooo`3o
ool00?l006X0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`0j0?ooo`00;03oool2
00000180oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`2b0?ooo`030?l0003oool0
oooo0080oooo00<00?l00?ooo`3oool0J03oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0
oooo03X0oooo000/0?ooo`030000003oool0oooo0180oooo00<0o`000?ooo`3oool02`3oool00`00
o`00oooo0?ooo`2b0?ooo`050?l0003oool0oooo0?ooo`00o`00K03oool00`3o0000oooo0?ooo`0<
0?ooo`03003o003oool0oooo03T0oooo000/0?ooo`030000003oool0oooo0180oooo00<0o`000?oo
o`3oool02`3oool00`00o`00oooo0?ooo`2a0?ooo`030?l0003oool0oooo0080oooo00<00?l00?oo
o`3oool0JP3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo03T0oooo00070?ooo`D0
000000<0oooo0000003oool00P3oool00`000000oooo0000000400000080oooo0P00000@0?ooo`03
0000003oool0oooo01<0oooo00<0o`000?ooo`3oool02`3oool00`00o`00oooo0?ooo`2`0?ooo`05
0?l0003oool0oooo0?ooo`00o`00KP3oool00`3o0000oooo0?ooo`0;0?ooo`03003o003oool0oooo
03T0oooo00090?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?oo
o`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool0[`3oool00`3o0000oooo0?ooo`020?oo
o`03003o003oool0oooo06`0oooo00<0o`000?ooo`3oool0303oool00`00o`00oooo0?ooo`0h0?oo
o`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0503oool00`3o
0000oooo0?ooo`0;0?ooo`03003o003oool0oooo0:d0oooo00<0o`000?ooo`3oool00`3oool00`00
o`00oooo0?ooo`1]0?ooo`030?l0003oool0oooo00/0oooo00<00?l00?ooo`3oool0>03oool00003
0?ooo`000000000000800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00d0oooo0`00000E0?oo
o`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool0[@3oool00`3o0000oooo0?ooo`020?oo
o`03003o003oool0oooo06l0oooo00<0o`000?ooo`3oool02`3oool00`00o`00oooo0?ooo`0g0?oo
o`002@3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0;0?ooo`03003o003oool0oooo0:/0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?oo
o`1_0?ooo`030?l0003oool0oooo00/0oooo00<00?l00?ooo`3oool0=`3oool000P0oooo0P00000:
0?ooo`800000103oool2000000P0oooo0`0000050?ooo`030000003oool0oooo01H0oooo00<0o`00
0?ooo`3oool02P3oool00`00o`00oooo0?ooo`2Z0?ooo`030?l0003oool0oooo00<0oooo00<00?l0
0?ooo`3oool0L@3oool00`3o0000oooo0?ooo`0:0?ooo`03003o003oool0oooo03L0oooo000V0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0:0?oo
o`03003o003oool0oooo0:X0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`1a0?oo
o`030?l0003oool0oooo00/0oooo00<00?l00?ooo`3oool0=P3oool001l0oooo0`0000020?ooo`<0
00001@3oool00`000000oooo0?ooo`0G0?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3o
ool0Z03oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo07<0oooo00<0o`000?ooo`3o
ool02P3oool00`00o`00oooo0?ooo`0f0?ooo`00903oool00`000000oooo000000050?ooo`030000
003oool0oooo01L0oooo00<0o`000?ooo`3oool02P3oool00`00o`00oooo0?ooo`2X0?ooo`030?l0
003oool0oooo00<0oooo00<00?l00?ooo`3oool0L`3oool00`3o0000oooo0?ooo`0;0?ooo`03003o
003oool0oooo03D0oooo000T0?ooo`<000001@3oool00`000000oooo0?ooo`0H0?ooo`030?l0003o
ool0oooo00X0oooo00<00?l00?ooo`3oool0YP3oool00`3o0000oooo0?ooo`040?ooo`03003o003o
ool0oooo07@0oooo00<0o`000?ooo`3oool02P3oool00`00o`00oooo0?ooo`0e0?ooo`00;03oool2
000001X0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo0?ooo`2V0?ooo`030?l0003oool0
oooo00<0oooo00<00?l00?ooo`3oool0MP3oool00`3o0000oooo0?ooo`0:0?ooo`03003o003oool0
oooo03@0oooo000/0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool02@3oool00`00
o`00oooo0?ooo`2U0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool0MP3oool00`3o
0000oooo0?ooo`0:0?ooo`03003o003oool0oooo03@0oooo000/0?ooo`030000003oool0oooo01X0
oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo0?ooo`2T0?ooo`030?l0003oool0oooo00<0
oooo00<00?l00?ooo`3oool0N03oool00`3o0000oooo0?ooo`090?ooo`03003o003oool0oooo03@0
oooo000/0?ooo`030000003oool0oooo01X0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo
0?ooo`2S0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool0N03oool00`3o0000oooo
0?ooo`0:0?ooo`03003o003oool0oooo03<0oooo000/0?ooo`030000003oool0oooo01/0oooo00<0
o`000?ooo`3oool02@3oool00`00o`00oooo0?ooo`2R0?ooo`030?l0003oool0oooo00<0oooo00<0
0?l00?ooo`3oool0NP3oool00`3o0000oooo0?ooo`090?ooo`03003o003oool0oooo03<0oooo000/
0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo0?ooo`2Q
0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool0NP3oool00`3o0000oooo0?ooo`0:
0?ooo`03003o003oool0oooo0380oooo000/0?ooo`8000007@3oool00`3o0000oooo0?ooo`080?oo
o`03003o003oool0oooo0:40oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`1k0?oo
o`030?l0003oool0oooo00T0oooo00<00?l00?ooo`3oool0<P3oool002`0oooo00<000000?ooo`3o
ool0703oool00`3o0000oooo0?ooo`090?ooo`03003o003oool0oooo09l0oooo00<0o`000?ooo`3o
ool0103oool00`00o`00oooo0?ooo`1l0?ooo`030?l0003oool0oooo00T0oooo00<00?l00?ooo`3o
ool0<P3oool002`0oooo00<000000?ooo`3oool07@3oool00`3o0000oooo0?ooo`080?ooo`03003o
003oool0oooo09l0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`1m0?ooo`030?l0
003oool0oooo00T0oooo00<00?l00?ooo`3oool0<@3oool002`0oooo00<000000?ooo`3oool07@3o
ool00`3o0000oooo0?ooo`090?ooo`03003o003oool0oooo09d0oooo00<0o`000?ooo`3oool0103o
ool00`00o`00oooo0?ooo`1o0?ooo`030?l0003oool0oooo00P0oooo00<00?l00?ooo`3oool0<@3o
ool002`0oooo00<000000?ooo`3oool07P3oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0
oooo09d0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`1o0?ooo`030?l0003oool0
oooo00T0oooo00<00?l00?ooo`3oool0<03oool002`0oooo00<000000?ooo`3oool07`3oool00`3o
0000oooo0?ooo`070?ooo`03003o003oool0oooo09`0oooo00<0o`000?ooo`3oool01@3oool00`00
o`00oooo0?ooo`200?ooo`030?l0003oool0oooo00P0oooo00<00?l00?ooo`3oool0<03oool002`0
oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo02L0
oooo0P0000040?ooo`800000103oool2000000<0oooo1@00001<0?ooo`800000103oool2000000@0
oooo0P0000030?ooo`040?l0000000000000000000@0oooo00<00?l00?ooo`3oool0AP3oool20000
00@0oooo0P0000040?ooo`800000103oool2000002L0oooo00<0o`000?ooo`3oool0203oool00`00
o`00oooo0?ooo`0I0?ooo`800000103oool2000000@0oooo0P0000050?ooo`<000000@3oool002`0
oooo0P00000Q0?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool09P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0B`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00<0o`000?ooo`3oool0
1@3oool00`00o`00oooo0?ooo`150?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`00000W0?ooo`030?l0003oool0oooo00P0oooo00<00?l0
0?ooo`3oool05`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo
0@0000010?ooo`40oooo000/0?ooo`030000003oool0oooo0200oooo00<0o`000?ooo`3oool0203o
ool00`00o`00oooo0?ooo`0U0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1;0?ooo`040000003oool0oooo000000P0oooo00P000000?oo
o`3oool000000?ooo`3o0000oooo000000D0oooo00<00?l00?ooo`3oool0AP3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool09P3oool00`3o
0000oooo0?ooo`080?ooo`03003o003oool0oooo01L0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`D000000@3oool002`0oooo00<000000?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo02D0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo04/0oooo00@000000?ooo`3oool0
0000203oool01P000000oooo0?ooo`000000oooo0?l00080oooo00<000000?ooo`3oool00P3oool0
0`00o`00oooo0?ooo`160?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`0V0?ooo`030?l0003oool0oooo00P0oooo00<00?l00?ooo`3oool0
5P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool002`0oooo00<000000?ooo`3oool08@3oool00`3o0000oooo0?ooo`080?oo
o`03003o003oool0oooo02@0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo04/0oooo00@000000?ooo`3oool00000203oool01`000000oooo
0?ooo`000000o`000?ooo`0000000P3oool01@000000oooo0?ooo`3oool00?l004P0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002T0
oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0F0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000020?ooo`00;03oool00`00
0000oooo0?ooo`0R0?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool09@3oool20000
00X0oooo0P0000040?ooo`800000CP3oool2000000X0oooo0P000000103oool0o`000?ooo`3oool2
000000<0oooo00<00?l00?ooo`3oool0B03oool2000000X0oooo0P0000040?ooo`800000:P3oool0
0`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo01L0oooo0P00000:0?ooo`8000001@3oool2
00000080oooo000/0?ooo`030000003oool0oooo0280oooo00<0o`000?ooo`3oool01`3oool00`00
o`00oooo0?ooo`2E0?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool0Q`3oool00`3o
0000oooo0?ooo`070?ooo`03003o003oool0oooo02d0oooo000/0?ooo`800000903oool00`3o0000
oooo0?ooo`070?ooo`03003o003oool0oooo09@0oooo00<0o`000?ooo`3oool01@3oool00`00o`00
oooo0?ooo`280?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool0;@3oool002`0oooo
00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo09<0oooo
00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`290?ooo`030?l0003oool0oooo00L0oooo
00<00?l00?ooo`3oool0;03oool002`0oooo00<000000?ooo`3oool0903oool00`3o0000oooo0?oo
o`070?ooo`03003o003oool0oooo0980oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?oo
o`290?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool0;03oool002`0oooo00<00000
0?ooo`3oool0903oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo0940oooo00<0o`00
0?ooo`3oool01P3oool00`00o`00oooo0?ooo`2;0?ooo`030?l0003oool0oooo00L0oooo00<00?l0
0?ooo`3oool0:`3oool002`0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?ooo`060?oo
o`03003o003oool0oooo0940oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`2;0?oo
o`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool0:`3oool002`0oooo00<000000?ooo`3o
ool09@3oool00`3o0000oooo0?ooo`070?ooo`03003o003oool0oooo08l0oooo00<0o`000?ooo`3o
ool01P3oool00`00o`00oooo0?ooo`2=0?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3o
ool0:`3oool00280oooo<`0000000`3o000000000000000600000003003o00000000000008l00000
00<0o`000000000000001P0000000`00o`0000000000002=000000030?l000000000000000L00000
00<00?l0000000000000:00000020?ooo`00;03oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3o00002@3oool00`00o`00oooo0?ooo`040?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0100oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`070?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00l0oooo00<0o`000?ooo`0000001P3oool00`00o`00oooo0?ooo`090?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool02P3oool002`0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0?l000P0oooo00<00?l00?ooo`3oool0103o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0?0?ooo`030?l000000000oooo00L0oooo00<00?l00?ooo`3oool0203o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0000000L0oooo00<00?l00?ooo`3oool0203o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000/0?ooo`030000003oool0
oooo02L0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`0Z0?ooo`030000003oool0
oooo05h0oooo00<0o`000000003oool01`3oool00`00o`00oooo0?ooo`1F0?ooo`030000003oool0
oooo03L0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`0L0?ooo`030000003oool0
oooo00X0oooo000/0?ooo`030000003oool0oooo02P0oooo00<0o`000?ooo`3oool01P3oool00`00
o`00oooo0?ooo`2:0?ooo`030?l0003oool0oooo00L0oooo00<00?l00?ooo`3oool0T@3oool00`3o
0000oooo0?ooo`060?ooo`03003o003oool0oooo02T0oooo000/0?ooo`030000003oool0oooo02P0
oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo0?ooo`2:0?ooo`030?l0003oool0oooo00L0
oooo00<00?l00?ooo`3oool0TP3oool00`3o0000oooo0?ooo`060?ooo`03003o003oool0oooo02P0
oooo000/0?ooo`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool01P3oool00`00o`00oooo
0?ooo`280?ooo`030?l0003oool0oooo00P0oooo00<00?l00?ooo`3oool0T`3oool00`3o0000oooo
0?ooo`050?ooo`03003o003oool0oooo02P0oooo000/0?ooo`800000:P3oool00`3o0000oooo0?oo
o`060?ooo`03003o003oool0oooo08P0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?oo
o`2D0?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool09`3oool002`0oooo00<00000
0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`060?ooo`03003o003oool0oooo08H0oooo00<0o`00
0?ooo`3oool0203oool00`00o`00oooo0?ooo`2E0?ooo`030?l0003oool0oooo00D0oooo00<00?l0
0?ooo`3oool09`3oool002`0oooo00<000000?ooo`3oool0:P3oool00`3o0000oooo0?ooo`060?oo
o`03003o003oool0oooo08H0oooo00<0o`000?ooo`3oool01`3oool00`00o`00oooo0?ooo`2F0?oo
o`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool09`3oool002`0oooo00<000000?ooo`3o
ool0:`3oool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo08D0oooo00<0o`000?ooo`3o
ool0203oool00`00o`00oooo0?ooo`2G0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3o
ool09P3oool002`0oooo00<000000?ooo`3oool0:`3oool00`3o0000oooo0?ooo`060?ooo`03003o
003oool0oooo08<0oooo00<0o`000?ooo`3oool02@3oool00`00o`00oooo0?ooo`2G0?ooo`030?l0
003oool0oooo00D0oooo00<00?l00?ooo`3oool09P3oool002`0oooo00<000000?ooo`3oool0;03o
ool00`3o0000oooo0?ooo`050?ooo`03003o003oool0oooo08<0oooo00<0o`000?ooo`3oool0203o
ool00`00o`00oooo0?ooo`2I0?ooo`030?l0003oool0oooo00D0oooo00<00?l00?ooo`3oool09@3o
ool002`0oooo0P00000]0?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool0P@3oool0
0`3o0000oooo0?ooo`090?ooo`03003o003oool0oooo09T0oooo00<0o`000?ooo`3oool01@3oool0
0`00o`00oooo0?ooo`0U0?ooo`00;03oool00`000000oooo0?ooo`0]0?ooo`030?l0003oool0oooo
00D0oooo00<00?l00?ooo`3oool0P@3oool00`3o0000oooo0?ooo`080?ooo`03003o003oool0oooo
09/0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0U0?ooo`00;03oool00`000000
oooo0?ooo`0]0?ooo`030?l0003oool0oooo00H0oooo00<00?l00?ooo`3oool0O`3oool00`3o0000
oooo0?ooo`090?ooo`03003o003oool0oooo09/0oooo00<0o`000?ooo`3oool01@3oool00`00o`00
oooo0?ooo`0T0?ooo`00;03oool00`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo00D0oooo
00<00?l00?ooo`3oool0O`3oool00`3o0000oooo0?ooo`090?ooo`03003o003oool0oooo09`0oooo
00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0T0?ooo`00;03oool00`000000oooo0?oo
o`0_0?ooo`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool0OP3oool00`3o0000oooo0?oo
o`090?ooo`03003o003oool0oooo09d0oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?oo
o`0S0?ooo`00;03oool00`000000oooo0?ooo`0_0?ooo`030?l0003oool0oooo00D0oooo00<00?l0
0?ooo`3oool0O@3oool00`3o0000oooo0?ooo`090?ooo`03003o003oool0oooo09h0oooo00<0o`00
0?ooo`3oool0103oool00`00o`00oooo0?ooo`0S0?ooo`00;03oool00`000000oooo0?ooo`0`0?oo
o`030?l0003oool0oooo00@0oooo00<00?l00?ooo`3oool0O03oool00`3o0000oooo0?ooo`090?oo
o`03003o003oool0oooo09l0oooo00<0o`000?ooo`3oool0103oool00`00o`00oooo0?ooo`0S0?oo
o`00;03oool200000340oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`1k0?ooo`03
0?l0003oool0oooo00T0oooo00<00?l00?ooo`3oool0X03oool00`3o0000oooo0?ooo`040?ooo`03
003o003oool0oooo0280oooo000/0?ooo`030000003oool0oooo0340oooo00<0o`000?ooo`3oool0
103oool00`00o`00oooo0?ooo`1j0?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool0
X@3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0280oooo000/0?ooo`030000003o
ool0oooo0340oooo00<0o`000?ooo`3oool01@3oool00`00o`00oooo0?ooo`1h0?ooo`030?l0003o
ool0oooo00X0oooo00<00?l00?ooo`3oool0XP3oool00`3o0000oooo0?ooo`040?ooo`03003o003o
ool0oooo0240oooo000/0?ooo`030000003oool0oooo0380oooo00<0o`000?ooo`3oool0103oool0
0`00o`00oooo0?ooo`1h0?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool0X`3oool0
0`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo0240oooo000/0?ooo`030000003oool0oooo
03<0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`1g0?ooo`030?l0003oool0oooo
00X0oooo00<00?l00?ooo`3oool0Y03oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo
0200oooo000/0?ooo`030000003oool0oooo03<0oooo00<0o`000?ooo`3oool0103oool00`00o`00
oooo0?ooo`1f0?ooo`030?l0003oool0oooo00X0oooo00<00?l00?ooo`3oool0Y@3oool00`3o0000
oooo0?ooo`030?ooo`03003o003oool0oooo0200oooo000/0?ooo`800000=@3oool00`3o0000oooo
0?ooo`030?ooo`03003o003oool0oooo07D0oooo00<0o`000?ooo`3oool02P3oool00`00o`00oooo
0?ooo`2V0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool0803oool002`0oooo00<0
00000?ooo`3oool0=03oool00`3o0000oooo0?ooo`040?ooo`03003o003oool0oooo07@0oooo00<0
o`000?ooo`3oool02P3oool00`00o`00oooo0?ooo`2W0?ooo`030?l0003oool0oooo00<0oooo00<0
0?l00?ooo`3oool07`3oool002`0oooo00<000000?ooo`3oool0=@3oool00`3o0000oooo0?ooo`03
0?ooo`03003o003oool0oooo07<0oooo00<0o`000?ooo`3oool02`3oool00`00o`00oooo0?ooo`2W
0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?ooo`3oool07`3oool000L0oooo1@0000000`3o
ool000000?ooo`020?ooo`030000003oool0000000@000000P3oool200000100oooo00<000000?oo
o`3oool0=@3oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0oooo07<0oooo00<0o`000?oo
o`3oool02P3oool00`00o`00oooo0?ooo`2Y0?ooo`030?l0003oool0oooo00<0oooo00<00?l00?oo
o`3oool07P3oool000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
03H0oooo00<0o`000?ooo`3oool00`3oool00`00o`00oooo0?ooo`1a0?ooo`030?l0003oool0oooo
00/0oooo00<00?l00?ooo`3oool0ZP3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo
01h0oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0g0?oo
o`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool0L03oool00`3o0000oooo0?ooo`0;0?oo
o`03003o003oool0oooo0:/0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`0N0?oo
o`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=`3oool00`3o
0000oooo0?ooo`030?ooo`03003o003oool0oooo06l0oooo00<0o`000?ooo`3oool02`3oool00`00
o`00oooo0?ooo`2/0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3oool07@3oool000T0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`00000?0?ooo`<00000>03oool00`3o0000oooo0?ooo`020?ooo`03003o003o
ool0oooo06h0oooo00<0o`000?ooo`3oool02`3oool00`00o`00oooo0?ooo`2]0?ooo`030?l0003o
ool0oooo0080oooo00<00?l00?ooo`3oool07@3oool000P0oooo0P00000:0?ooo`800000103oool2
00000100oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?ooo`030?ooo`03003o003oool0
oooo06d0oooo00<0o`000?ooo`3oool02`3oool00`00o`00oooo0?ooo`2^0?ooo`030?l0003oool0
oooo0080oooo00<00?l00?ooo`3oool0703oool002@0oooo0`0000050?ooo`030000003oool0oooo
03T0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`1/0?ooo`030?l0003oool0oooo
00/0oooo00<00?l00?ooo`3oool0[`3oool00`3o0000oooo0?ooo`020?ooo`03003o003oool0oooo
01`0oooo000V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>@3oool00`3o0000
oooo0?ooo`020?ooo`03003o003oool0oooo06/0oooo00<0o`000?ooo`3oool0303oool00`00o`00
oooo0?ooo`2`0?ooo`050?l0003oool0oooo0?ooo`00o`007P3oool001l0oooo0`0000020?ooo`<0
00001@3oool00`000000oooo0?ooo`0j0?ooo`030?l0003oool0oooo0080oooo00<00?l00?ooo`3o
ool0JP3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo0;00oooo00<0o`000?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`0K0?ooo`00903oool00`000000oooo000000050?ooo`030000
003oool0oooo03/0oooo00D0o`000?ooo`3oool0oooo003o001[0?ooo`030?l0003oool0oooo00`0
oooo00<00?l00?ooo`3oool0/P3oool01@3o0000oooo0?ooo`3oool00?l001d0oooo000T0?ooo`<0
00001@3oool2000003`0oooo00<0o`000?ooo`3oool00P3oool00`00o`00oooo0?ooo`1X0?ooo`03
0?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0/P3oool00`3o0000oooo0?ooo`020?ooo`03
003o003oool0oooo01X0oooo000/0?ooo`030000003oool0oooo03`0oooo00D0o`000?ooo`3oool0
oooo003o001Y0?ooo`030?l0003oool0oooo00`0oooo00<00?l00?ooo`3oool0]03oool01@3o0000
oooo0?ooo`3oool00?l001`0oooo000/0?ooo`030000003oool0oooo03`0oooo00<0o`000?ooo`3o
ool00P3oool00`00o`00oooo0?ooo`1U0?ooo`030?l0003oool0oooo00d0oooo00<00?l00?ooo`3o
ool0]@3oool0103o0000oooo0?ooo`00o`0L0?ooo`00;03oool00`000000oooo0?ooo`0m0?ooo`05
0?l0003oool0oooo0?ooo`00o`00I`3oool00`3o0000oooo0?ooo`0<0?ooo`03003o003oool0oooo
0;H0oooo00D0o`000?ooo`3oool0oooo003o000K0?ooo`00;03oool00`000000oooo0?ooo`0m0?oo
o`050?l0003oool0oooo0?ooo`00o`00IP3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0
oooo0;L0oooo00@0o`000?ooo`3oool00?l06`3oool002`0oooo00<000000?ooo`3oool0?P3oool0
1@3o0000oooo0?ooo`3oool00?l006D0oooo00<0o`000?ooo`3oool03@3oool00`00o`00oooo0?oo
o`2g0?ooo`050?l0003oool0oooo0?ooo`00o`006P3oool002`0oooo00<000000?ooo`3oool0?`3o
ool0103o0000oooo0?ooo`00o`1T0?ooo`030?l0003oool0oooo00d0oooo00<00?l00?ooo`3oool0
^@3oool0103o0000oooo0?ooo`00o`0J0?ooo`00;03oool200000400oooo00D0o`000?ooo`3oool0
oooo003o001R0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool0^@3oool01@3o0000
oooo0?ooo`3oool00?l001T0oooo000/0?ooo`030000003oool0oooo0400oooo00@0o`000?ooo`3o
ool00?l0HP3oool00`3o0000oooo0?ooo`0=0?ooo`03003o003oool0oooo0;/0oooo00@0o`000?oo
o`3oool00?l06@3oool002`0oooo00<000000?ooo`3oool0@03oool01@3o0000oooo0?ooo`3oool0
0?l00600oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo0?ooo`2k0?ooo`050?l0003oool0
oooo0?ooo`00o`00603oool002`0oooo00<000000?ooo`3oool0@@3oool0103o0000oooo0?ooo`00
o`1O0?ooo`030?l0003oool0oooo00h0oooo00<00?l00?ooo`3oool0_@3oool0103o0000oooo0?oo
o`00o`0H0?ooo`00;03oool00`000000oooo0?ooo`120?ooo`030?l0003oool00?l005l0oooo00<0
o`000?ooo`3oool03P3oool00`00o`00oooo0?ooo`2n0?ooo`040?l0003oool0oooo003o01L0oooo
000/0?ooo`030000003oool0oooo0480oooo00@0o`000?ooo`3oool00?l0G@3oool00`3o0000oooo
0?ooo`0>0?ooo`03003o003oool0oooo0;l0oooo00@0o`000?ooo`3oool00?l05`3oool002`0oooo
0P0000140?ooo`030?l0003oool00?l005d0oooo00<0o`000?ooo`3oool03P3oool00`00o`00oooo
0?ooo`300?ooo`040?l0003oool0oooo003o01H0oooo000/0?ooo`030000003oool0oooo04@0oooo
00<0o`000?ooo`00o`00F`3oool00`3o0000oooo0?ooo`0?0?ooo`03003o003oool0oooo0<40oooo
00<0o`000?ooo`00o`005P3oool002`0oooo00<000000?ooo`3oool0A03oool00`3o0000oooo003o
001J0?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3oool0``3oool00`3o0000oooo003o
000E0?ooo`00;03oool00`000000oooo0?ooo`150?ooo`030?l0003oool00?l005T0oooo00<0o`00
0?ooo`3oool03`3oool00`00o`00oooo0?ooo`330?ooo`030?l0003oool00?l001D0oooo000/0?oo
o`030000003oool0oooo04D0oooo00<0o`000?ooo`00o`00F03oool00`3o0000oooo0?ooo`0?0?oo
o`03003o003oool0oooo0<D0oooo00<0o`000?ooo`00o`00503oool002`0oooo00<000000?ooo`3o
ool0AP3oool00`3o0000oooo003o001G0?ooo`030?l0003oool0oooo00l0oooo00<00?l00?ooo`3o
ool0aP3oool00`3o00000?l00?ooo`0C0?ooo`00;03oool2000004P0oooo00<0o`00003o003oool0
E@3oool00`3o0000oooo0?ooo`0?0?ooo`03003o003oool0oooo0<L0oooo00<0o`00003o003oool0
4`3oool002`0oooo00<000000?ooo`3oool0A`3oool00`3o00000?l00?ooo`1D0?ooo`030?l0003o
ool0oooo0100oooo00<00?l00?ooo`3oool0b03oool00`3o00000?l00?ooo`0B0?ooo`00;03oool0
0`000000oooo0?ooo`180?ooo`030?l00000o`00oooo05<0oooo00<0o`000?ooo`3oool03`3oool0
0`00o`00oooo0?ooo`3:0?ooo`03003o003oool0oooo0140oooo000/0?ooo`030000003oool0oooo
04T0oooo00<00?l00?ooo`3oool0D@3oool00`3o0000oooo0?ooo`0@0?ooo`03003o003oool0oooo
0</0oooo00<00?l00?ooo`3oool0403oool000L0oooo100000020?ooo`060000003oool0oooo0?oo
o`000000oooo1@0000020?ooo`800000403oool00`000000oooo0?ooo`1:0?ooo`03003o003oool0
oooo04l0oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`3<0?ooo`03003o003oool0
oooo0100oooo00070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1:
0?ooo`03003o003oool0oooo04l0oooo00<0o`000?ooo`3oool0403oool00`00o`00oooo0?ooo`3=
0?ooo`03003o003oool0oooo00l0oooo00080?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`1;0?ooo`03003o003oool0oooo04d0oooo00<0o`000?ooo`3oool0403oool0
0`00o`00oooo0?ooo`3>0?ooo`03003o003o0000oooo00l0oooo00090?ooo`030000003oool0oooo
0080oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool03@3oool3000004/0oooo00<00?l00?l0003oool0C03oool00`3o0000oooo0?ooo`0A
0?ooo`03003o003oool0oooo0<l0oooo00<00?l00?ooo`3oool03P3oool000L0oooo00@000000?oo
o`3oool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0B`3oool00`00o`00oooo
0?l0001<0?ooo`030?l0003oool0oooo0100oooo00<00?l00?ooo`3oool0d03oool00`00o`00o`00
0?ooo`0>0?ooo`00203oool2000000X0oooo0P0000040?ooo`800000203oool3000000D0oooo00<0
00000?ooo`3oool0C03oool00`00o`00o`000?ooo`1:0?ooo`030?l0003oool0oooo0140oooo00<0
0?l00?ooo`3oool0d@3oool00`00o`00o`000?ooo`0=0?ooo`009P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo04`0oooo00<00?l00?ooo`3o0000B@3oool00`3o0000oooo0?ooo`0A
0?ooo`03003o003oool0oooo0=80oooo00<00?l00?ooo`3o00003@3oool001l0oooo0`0000020?oo
o`<000001@3oool00`000000oooo0?ooo`1=0?ooo`03003o003oool0o`0004P0oooo00<0o`000?oo
o`3oool04@3oool00`00o`00oooo0?ooo`3C0?ooo`03003o003o0000oooo00`0oooo000T0?ooo`03
0000003oool0000000D0oooo00<000000?ooo`3oool0C@3oool01000o`00oooo0?ooo`3o00160?oo
o`030?l0003oool0oooo0140oooo00<00?l00?ooo`3oool0e03oool00`00o`00oooo0?l0000<0?oo
o`00903oool3000000D0oooo0P00001?0?ooo`04003o003oool0oooo0?l004@0oooo00<0o`000?oo
o`3oool04P3oool00`00o`00oooo0?ooo`3E0?ooo`03003o003oool0oooo00/0oooo000/0?ooo`03
0000003oool0oooo04h0oooo00D00?l00?ooo`3oool0oooo0?l000120?ooo`030?l0003oool0oooo
0180oooo00<00?l00?ooo`3oool0eP3oool00`00o`00oooo0?ooo`0;0?ooo`00;03oool00`000000
oooo0?ooo`1?0?ooo`05003o003oool0oooo0?ooo`3o0000@03oool00`3o0000oooo0?ooo`0C0?oo
o`03003o003oool0oooo0=L0oooo00<00?l00?ooo`3oool02P3oool002`0oooo00<000000?ooo`3o
ool0C`3oool01@00o`00oooo0?ooo`3oool0o`0003l0oooo00<0o`000?ooo`3oool04`3oool00`00
o`00oooo0?ooo`3H0?ooo`03003o003oool0oooo00X0oooo000/0?ooo`030000003oool0oooo0500
oooo00D00?l00?ooo`3oool0oooo0?l0000n0?ooo`030?l0003oool0oooo01<0oooo00<00?l00?oo
o`3oool0i@3oool002`0oooo00<000000?ooo`3oool0D03oool00`00o`00oooo0?ooo`020?ooo`03
0?l0003oool0oooo03X0oooo00<0o`000?ooo`3oool04`3oool00`00o`00oooo0?ooo`3V0?ooo`00
;03oool00`000000oooo0?ooo`1A0?ooo`03003o003oool0oooo0080oooo00<0o`000?ooo`3oool0
>03oool00`3o0000oooo0?ooo`0D0?ooo`03003o003oool0oooo0>H0oooo000/0?ooo`800000D`3o
ool00`00o`00oooo0?ooo`020?ooo`030?l0003oool0oooo03H0oooo00<0o`000?ooo`3oool0503o
ool00`00o`00oooo0?ooo`3W0?ooo`00;03oool00`000000oooo0?ooo`1B0?ooo`03003o003oool0
oooo00<0oooo00<0o`000?ooo`3oool0=03oool00`3o0000oooo0?ooo`0E0?ooo`03003o003oool0
oooo0>L0oooo000/0?ooo`030000003oool0oooo05<0oooo00<00?l00?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0b0?ooo`030?l0003oool0oooo01D0oooo00<00?l00?ooo`3oool0j03oool002`0
oooo00<000000?ooo`3oool0D`3oool00`00o`00oooo0?ooo`040?ooo`030?l0003oool0oooo0300
oooo00<0o`000?ooo`3oool05P3oool00`00o`00oooo0?ooo`3X0?ooo`00;03oool00`000000oooo
0?ooo`1D0?ooo`03003o003oool0oooo00@0oooo00<0o`000?ooo`3oool0;@3oool20?l001P0oooo
00<00?l00?ooo`3oool0j@3oool002`0oooo00<000000?ooo`3oool0E@3oool00`00o`00oooo0?oo
o`040?ooo`030?l0003oool0oooo02/0oooo00<0o`000?ooo`3oool0603oool00`00o`00oooo0?oo
o`3Y0?ooo`00;03oool2000005H0oooo00<00?l00?ooo`3oool01@3oool00`3o0000oooo0?ooo`0Y
0?ooo`030?l0003oool0oooo01P0oooo00<00?l00?ooo`3oool0jP3oool002`0oooo00<000000?oo
o`3oool0EP3oool00`00o`00oooo0?ooo`050?ooo`030?l0003oool0oooo02L0oooo00<0o`000?oo
o`3oool06@3oool00`00o`00oooo0?ooo`3Z0?ooo`00;03oool00`000000oooo0?ooo`1F0?ooo`03
003o003oool0oooo00H0oooo0P3o000V0?ooo`030?l0003oool0oooo01T0oooo00<00?l00?ooo`3o
ool0j`3oool002`0oooo00<000000?ooo`3oool0E`3oool00`00o`00oooo0?ooo`070?ooo`030?l0
003oool0oooo0240oooo0P3o000L0?ooo`03003o003oool0oooo0>/0oooo000/0?ooo`030000003o
ool0oooo05L0oooo00<00?l00?ooo`3oool0203oool20?l00200oooo00<0o`000?ooo`3oool06`3o
ool00`00o`00oooo0?ooo`3/0?ooo`00;03oool00`000000oooo0?ooo`1H0?ooo`03003o003oool0
oooo00T0oooo0P3o000L0?ooo`80o`007P3oool00`00o`00oooo0?ooo`3/0?ooo`00;03oool00`00
0000oooo0?ooo`1I0?ooo`03003o003oool0oooo00X0oooo0P3o000H0?ooo`80o`007`3oool00`00
o`00oooo0?ooo`3]0?ooo`00;03oool2000005X0oooo00<00?l00?ooo`3oool0303oool20?l001<0
oooo0`3o000P0?ooo`03003o003oool0oooo0>h0oooo000/0?ooo`030000003oool0oooo05X0oooo
00<00?l00?ooo`3oool03@3oool20?l000h0oooo0`3o000S0?ooo`03003o003oool0oooo0>h0oooo
000/0?ooo`030000003oool0oooo05X0oooo00<00?l00?ooo`3oool03`3oool>0?l002D0oooo00<0
0?l00?ooo`3oool0k`3oool000P0oooo0P0000030?ooo`060000003oool0oooo0?ooo`000000oooo
1@0000020?ooo`800000403oool00`000000oooo0?ooo`1K0?ooo`03003o003oool0oooo0400oooo
00<00?l00?ooo`3oool0l03oool000L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo05`0oooo00<00?l00?ooo`3oool0?P3oool00`00o`00oooo0?ooo`3a0?ooo`00
2@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0G03oool00`00o`00
oooo0?ooo`0n0?ooo`03003o003oool0oooo0?40oooo000:0?ooo`070000003oool0oooo0?ooo`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0=
0?ooo`<00000G@3oool00`00o`00oooo0?ooo`0l0?ooo`03003o003oool0oooo0?80oooo00070?oo
o`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05d0oooo
00<00?l00?ooo`3oool0>`3oool00`00o`00oooo0?ooo`3c0?ooo`00203oool2000000X0oooo0P00
00040?ooo`800000203oool3000000D0oooo00<000000?ooo`3oool0GP3oool00`00o`00oooo0?oo
o`0i0?ooo`03003o003oool0oooo0?@0oooo000V0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0G`3oool00`00o`00oooo0?ooo`0h0?ooo`03003o003oool0oooo0?@0oooo000O0?oo
o`<000000P3oool3000000D0oooo00<000000?ooo`3oool0H03oool00`00o`00oooo0?ooo`0f0?oo
o`03003o003oool0oooo0?D0oooo000T0?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool0H@3oool00`00o`00oooo0?ooo`0d0?ooo`03003o003oool0oooo0?H0oooo000T0?ooo`<00000
1@3oool00`000000oooo0?ooo`1Q0?ooo`03003o003oool0oooo03<0oooo00<00?l00?ooo`3oool0
m`3oool002`0oooo0P00001S0?ooo`03003o003oool0oooo0380oooo00<00?l00?ooo`3oool0m`3o
ool002`0oooo00<000000?ooo`3oool0H`3oool00`00o`00oooo0?ooo`0`0?ooo`03003o003oool0
oooo0?P0oooo000/0?ooo`030000003oool0oooo06@0oooo00<00?l00?ooo`3oool0;P3oool00`00
o`00oooo0?ooo`3i0?ooo`00;03oool00`000000oooo0?ooo`1U0?ooo`03003o003oool0oooo02`0
oooo00<00?l00?ooo`3oool0nP3oool002`0oooo00<000000?ooo`3oool0I@3oool00`00o`00oooo
0?ooo`0[0?ooo`03003o003oool0oooo0?/0oooo000/0?ooo`030000003oool0oooo06H0oooo00<0
0?l00?ooo`3oool0:P3oool00`00o`00oooo0?ooo`3k0?ooo`00;03oool2000006P0oooo00<00?l0
0?ooo`3oool0:03oool00`00o`00oooo0?ooo`3l0?ooo`00;03oool00`000000oooo0?ooo`1X0?oo
o`03003o003oool0oooo02H0oooo00<00?l00?ooo`3oool0o@3oool002`0oooo00<000000?ooo`3o
ool0J@3oool00`00o`00oooo0?ooo`0T0?ooo`03003o003oool0oooo0?h0oooo000/0?ooo`030000
003oool0oooo06X0oooo00<00?l00?ooo`3oool08@3oool2003o0?l0oooo0P3oool002`0oooo00<0
00000?ooo`3oool0J`3oool00`00o`00oooo0?ooo`0O0?ooo`03003o003oool0oooo0?l0oooo0P3o
ool002`0oooo00<000000?ooo`3oool0K03oool2003o01h0oooo00<00?l00?ooo`3oool0o`3oool3
0?ooo`00;03oool2000006l0oooo00<00?l00?ooo`3oool06@3oool2003o0?l0oooo1P3oool002`0
oooo00<000000?ooo`3oool0K`3oool2003o01P0oooo00<00?l00?ooo`3oool0o`3oool60?ooo`00
;03oool00`000000oooo0?ooo`1a0?ooo`800?l0503oool2003o0?l0oooo2@3oool002`0oooo00<0
00000?ooo`3oool0L`3oool3003o00l0oooo0P00o`3o0?ooo`/0oooo000/0?ooo`030000003oool0
oooo07H0oooo0P00o`0;0?ooo`800?l0o`3oool=0?ooo`00;03oool00`000000oooo0?ooo`1h0?oo
o`/00?l0o`3oool?0?ooo`00;03oool00`000000oooo0?ooo`3o0?oooi80oooo000/0?ooo`800000
o`3ooonC0?ooo`00;03oool00`000000oooo0?ooo`3o0?oooi80oooo000/0?ooo`030000003oool0
oooo0?l0ooooTP3oool002`0oooo00<000000?ooo`3oool0o`3ooonB0?ooo`00;03oool00`000000
oooo0?ooo`3o0?oooi80oooo003o0?oool40oooo003o0?oool40oooo003o0?oool40oooo003o0?oo
ol40oooo003o0?oool40oooo003o0?oool40oooo003o0?oool40oooo003o0?oool40oooo003o0?oo
ol40oooo003o0?oool40oooo003o0?oool40oooo0000\
\>"],
  ImageRangeCache->{{{90.625, 448.188}, {390.938, 170.313}} -> {-0.016111, \
2.32866*^-09, 0.000102349, 3.1049*^-11}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Now plotting X over frequency:", "Text"],

Cell[BoxData[
    \(\(test4 = Im[Xv /. w \[Rule] 2\ \[Pi]\ f];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[test4, {x, 0, lRod /. values}, {f, 10000, 210000}, 
      PlotPoints \[Rule] 50]\)], "Input"],

Cell[BoxData[
    \(Plot3D::"plnc" \(\(:\)\(\ \)\) 
      "\!\(test4\) is neither a machine-size real number at \!\({x, \
f}\)=\!\({0.`, 10000.`}\) nor a list of a real number and a valid color \
directive."\)], "Message"],

Cell[BoxData[
    \(Plot3D::"plnc" \(\(:\)\(\ \)\) 
      "\!\(test4\) is neither a machine-size real number at \!\({x, \
f}\)=\!\({0.0008163265306122449`, 10000.`}\) nor a list of a real number and \
a valid color directive."\)], "Message"],

Cell[BoxData[
    \(Plot3D::"plnc" \(\(:\)\(\ \)\) 
      "\!\(test4\) is neither a machine-size real number at \!\({x, \
f}\)=\!\({0.0016326530612244899`, 10000.`}\) nor a list of a real number and \
a valid color directive."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Plot3D :: \"plnc\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    \(Plot3D::"gval" \(\(:\)\(\ \)\) 
      "Function value \!\(Im[Xv]\) at grid point xi = \!\(1\), yi = \!\(1\) \
is not a real number."\)], "Message"],

Cell[BoxData[
    \(Plot3D::"gval" \(\(:\)\(\ \)\) 
      "Function value \!\(Im[Xv]\) at grid point xi = \!\(1\), yi = \!\(2\) \
is not a real number."\)], "Message"],

Cell[BoxData[
    \(Plot3D::"gval" \(\(:\)\(\ \)\) 
      "Function value \!\(Im[Xv]\) at grid point xi = \!\(1\), yi = \!\(3\) \
is not a real number."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Plot3D :: \"gval\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -22.3468 -9 ]
[.3345 .12542 1.65319 0 ]
[.50253 .05935 -21.0959 -9 ]
[.50253 .05935 2.90415 0 ]
[.68156 -0.01098 -19.8449 -9 ]
[.68156 -0.01098 4.1551 0 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 30 2.83813 ]
[.84246 .21189 0 -6.05159 ]
[.84246 .21189 36 2.94841 ]
[.90976 .31495 0 -5.95504 ]
[.90976 .31495 36 3.04496 ]
[.97048 .40794 0 -5.8698 ]
[.97048 .40794 36 3.1302 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(0.01)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0.02)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.03)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.04)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75514 .10158 m
.74899 .10385 L
s
[(50000)] .76745 .09703 -1 .3693 Mshowa
.83006 .21617 m
.82385 .21831 L
s
[(100000)] .84246 .21189 -1 .3448 Mshowa
.89727 .31899 m
.89103 .32101 L
s
[(150000)] .90976 .31495 -1 .32334 Mshowa
.95792 .41176 m
.95165 .41367 L
s
[(200000)] .97048 .40794 -1 .3044 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.9099 .3383 m
.90615 .3395 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.73912 .07706 m
.73543 .07845 L
s
.72272 .05198 m
.71904 .05338 L
s
.70593 .0263 m
.70226 .02771 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(0.01)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0.02)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.03)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(0.04)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{513.813, 416.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000810001X2000`400?l00000o`00003oo`3ooooo
0?ooo`<0oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo
003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo003o0?ooool0
oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo003o0?ooool0oooo0`3oool0
0?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo003o0?ooodD0oooo0P0000040?ooo`800000
103oool2000000D0oooo0`00002W0?ooo`00o`3ooom40?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`2V0?ooo`00o`3ooom40?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool500000:L0oooo003o0?oood@0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000:P0oooo003o0?oood@0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000030?ooo`030000003oool000000:P0oooo003o0?ooodD0oooo0P00000:0?ooo`8000001@3o
ool200000:P0oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0
oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo003o0?oo
ool0oooo0`3oool00?l0ooooF@3oool200000:L0oooo003o0?oooeL0oooo0P0000000`3oool00000
0000002V0?ooo`00o`3ooomD0?ooo`<000000`3oool300000:D0oooo003o0?oooe80oooo0P000006
0?ooo`030000003oool000000:D0oooo003o0?ooodl0oooo0`0000080?ooo`040000003oool0oooo
00000:@0oooo003o0?oood`0oooo0`00000;0?ooo`040000003oool0oooo00000:@0oooo003o0?oo
odT0oooo0`00000>0?ooo`050000003oool0oooo0?ooo`000000X`3oool00?l0ooooA`3oool40000
00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2P0?ooo`00o`3ooom50?ooo`80
00000`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0X03oool00?l0oooo@P3oool3000001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`2O0?ooo`00o`3ooom00?ooo`8000006@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo09h0oooo003o0?ooocd0oooo0`00000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0WP3oool00?l0oooo>`3oool2000001h0oooo00<000000?ooo`3oool00`3oool20000
09l0oooo003o0?ooocP0oooo0`00000P0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000WP3oool00?l0oooo=P3oool2000000030?ooo`000000oooo0200oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`2L0?ooo`00o`3ooolc0?ooo`<000000`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0V`3oool00?l0oooo<03o
ool3000002P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2K0?ooo`00o`3oool^
0?ooo`800000:`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo09X0oooo003o0?oo
ob/0oooo0`00000]0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0V@3oool00>l0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000U0?ooo`800000<03oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo09T0oooo003^0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000Q0?ooo`<00000<P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo09P0oooo003^0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0N0?ooo`8000000`3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0U`3o
ool00>h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
U`3oool00>h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000001X0oooo0P00000j0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0UP3oool00>l0oooo0P00000:0?ooo`800000103oool2000001P0oooo0`00000l0?ooo`03
0000003oool0oooo00/0oooo0P00002G0?ooo`00o`3ooolJ0?ooo`800000@03oool00`000000oooo
0?ooo`090?ooo`030000003oool0000009L0oooo003o0?oooaL0oooo0`0000120?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0U03oool00?l0oooo503oool3000000030?ooo`000000
oooo0480oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2C0?ooo`00o`3ooolB0?oo
o`800000B03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo09<0oooo003o0?ooo`l0
oooo0`00001:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0TP3oool00?l0oooo
3@3oool2000004d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2A0?ooo`00o`3o
ool:0?ooo`<00000C`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0940oooo003o
0?ooo`L0oooo0`00001B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0T03oool0
0?l0oooo1@3oool4000005<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2?0?oo
o`00o`3oool30?ooo`8000000`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0S`3oool00?l0oooo0`0000060?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2>0?ooo`00o@3oool2000005`0oooo00<0
00000?ooo`3oool04@3oool3000008l0oooo003j0?ooo`<00000GP3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo08d0oooo003g0?ooo`<00000H@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo08`0oooo003e0?ooo`800000I03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo08/0oooo003b0?ooo`<000000P3oool00`000000oooo0?ooo`1Q0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0R`3oool00?00oooo0P00001Z0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool02@3oool2000000@0oooo0P0000040?ooo`800000103o
ool2000000@0oooo0P00001W0?ooo`00k@3oool3000006`0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool00000IP3oool00>/0oooo0P00001_0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool02P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo06@0
oooo003X0?ooo`<00000L@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo
0P0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000006H0oooo003V0?ooo`800000M03oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00001V0?ooo`00h`3oool300000080oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo0`0000030?ooo`80
0000103oool2000000@0oooo0P0000040?ooo`800000I`3oool00>40oooo0P00001i0?ooo`030000
003oool0oooo01P0oooo0P0000280?ooo`00gP3oool3000007/0oooo00<000000?ooo`3oool05P3o
ool2000000030?ooo`000000oooo08L0oooo003K0?ooo`<00000OP3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo08D0oooo002P0?ooo`800000103oool2000000@0oooo0P0000030?oo
o`@00000903oool200000840oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`240?oo
o`00W`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool08P3oool3000008<0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`24
0?ooo`00W`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool07`3oool200000080oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo08<0oooo002O0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0K0?ooo`<00000R03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo0880oooo002O0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000J0?ooo`800000R`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo0880oooo002P0?ooo`8000002P3oool2000000@0
oooo0P00000H0?ooo`<00000S@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0840
oooo003:0?ooo`800000T03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0800oooo
00370?ooo`<00000T`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0800oooo0035
0?ooo`8000000P3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0O`3oool00<80oooo0`00002H0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`000000P03oool00;l0oooo0`00002K0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0OP3oool00;d0oooo0P00002N0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
O@3oool00;X0oooo0`00002P0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0O03o
ool00;P0oooo0P00002S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0O03oool0
0;D0oooo0`0000000`3oool000000?ooo`2R0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0N`3oool00;<0oooo0P0000050?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`1j0?ooo`00/03oool300000:X0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`1j0?ooo`00[P3oool200000:d0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`1i0?ooo`00Z`3oool300000:l0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`1h0?ooo`00Z@3oool200000;80oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`1h0?ooo`00YP3oool3000000030?ooo`000000oooo0;40oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0000001i0?ooo`00X`3oool300000;L0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`1f0?ooo`00X@3oool200000;X0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`1f0?ooo`00WP3oool300000;`0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`1e0?ooo`00W03oool200000<00oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`1e0?ooo`00V@3oool300000<80oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`1d0?ooo`00U`3oool2000000<0oooo00<000000?ooo`3oool0_`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo07<0oooo002D0?ooo`<00000a`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo07<0oooo002B0?ooo`800000bP3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0780oooo001E0?ooo`800000103oool2000000@0oooo0P0000030?oo
o`D00000903oool300000<`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1a0?oo
o`00E03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool08@3oool300000<l0oooo00<000000?ooo`3oool0:`3oool2000007<0oooo001D0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`0O0?ooo`@00000d03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0700oooo001D
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`0L0?ooo`<000000`3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0K`3oool005@0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo01X0oooo0P00003G0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0K`3oool005D0oooo0P00000:0?ooo`800000103oool2000001T0oooo
0`00003I0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0KP3oool00800oooo0P00
003L0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0K@3oool007d0oooo0`00003N
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0K@3oool007/0oooo0P0000000`3o
ool000000?ooo`3N0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0K03oool007P0
oooo0`00003S0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0J`3oool007H0oooo
0P00003V0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0J`3oool007<0oooo0`00
003Y0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0JP3oool00740oooo0P00003/
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`000000J`3oool006h0oooo0`00003^0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0J@3oool006/0oooo0`0000020?ooo`03
0000003oool0oooo0>`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1X0?ooo`00
J@3oool2000000H0oooo00<000000?ooo`3oool0j`3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00P0oooo1@0000020?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000
103oool2000003h0oooo001V0?ooo`<00000mP3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo00X0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0>`3oool006@0oooo0P00003i0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0k0?ooo`00H@3oool30000
0?/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
03/0oooo001O0?ooo`80000000<0oooo0000003oool0n`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0>`3oool005`0oooo0`00003o0?ooo`40oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`060?ooo`800000103oool2000000@0oooo
0P0000040?ooo`800000103oool2000000@0oooo0P00000n0?ooo`00FP3oool200000?l0oooo103o
ool00`000000oooo0?ooo`0h0?ooo`800000I@3oool005L0oooo0`00003o0?ooo`H0oooo00<00000
0?ooo`3oool0=P3oool2000000030?ooo`000000oooo06@0oooo001E0?ooo`800000o`3oool90?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0HP3oool00580oooo0`00003o0?ooo`/0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1R0?ooo`00C`3oool300000080oooo
00<000000?ooo`3oool0o`3oool90?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
H@3oool004d0oooo0P00003o0?oooa40oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`1P0?ooo`00BP3oool300000?l0oooo503oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo0600oooo000Q0?ooo`8000009@3oool200000?l0oooo5`3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo05l0oooo000P0?ooo`040000003oool0oooo00000240oooo0`00003o0?oo
oaT0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1N0?ooo`00803oool010000000
oooo0?ooo`00000O0?ooo`80000000<0oooo0000003oool0o`3ooolI0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool0GP3oool00200oooo00@000000?ooo`3oool00000703oool30000
0?l0oooo7P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo05d0oooo000P0?ooo`04
0000003oool0oooo000001X0oooo0P00003o0?ooob40oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0000001N0?ooo`008@3oool2000001P0oooo0`00003o0?ooob<0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`1L0?ooo`00=`3oool010000000oooo00000000003o0?ooobH0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1K0?ooo`00=P3oool300000?l0oooo
9`3oool2000004<0oooo00<000000?ooo`3oool0FP3oool003<0oooo0`0000030?ooo`030000003o
ool0oooo0?l0oooo8@3oool300000080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`1J0?ooo`00<@3oool200000?l0oooo9`3oool3000000D0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`1I0?ooo`00;P3oool300000?l0oooo9P3oool3000000T0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`1H0?ooo`00;03oool200000?l0oooo9`3oool2000000d0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1H0?ooo`00:P3oool200000?l0oooo
9P3oool300000100oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1G0?ooo`00:P3o
ool300000?l0oooo8P3oool3000001<0oooo00<000000?ooo`3oool0@03oool2000005P0oooo000Y
0?ooo`80000000<0oooo0000003oool0o`3ooolN0?ooo`<000005`3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0000005P0oooo000Z0?ooo`040000003oool0oooo00000?l0oooo6`3oool3
000001/0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1E0?ooo`00:@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo5@3oool3000001l0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`1D0?ooo`00803oool2000000L0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?oooa40oooo0`00000R0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0E03oool001l0oooo00@000000?ooo`3oool000001P3oool2000000D0
oooo00<000000?ooo`3oool0o`3oool=0?ooo`<000009P3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo05<0oooo000O0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool01@3oool200000?l0oooo2`3oool2000002X0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`1B0?ooo`007`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3oool50?ooo`<00000;03oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo0580oooo000O0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`3o0?ooo`40oooo0`00000`0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0D@3oool00200oooo0P0000060?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0o03oool3000003@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`1A0?ooo`00:03oool3000000/0oooo00<000000?ooo`3oool0n03oool3000003P0oooo00<0
00000?ooo`3oool0?@3oool300000580oooo000X0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0m03oool3000003/0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1?
0?ooo`00:03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?00oooo0`00000o0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0C`3oool002P0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`3/0?ooo`<00000@`3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo04h0oooo000X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
j@3oool2000004L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1=0?ooo`009`3o
ool300000140oooo00<000000?ooo`3oool0i@3oool3000004T0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`1=0?ooo`009`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo0>40oooo0`00001=0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0C03oool0
02L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3M0?ooo`<00000D@3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo04/0oooo000W0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0f@3oool3000005@0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`1;0?ooo`009`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0=D0oooo
0`00001H0?ooo`030000003oool0oooo03h0oooo0P00001<0?ooo`009`3oool2000001L0oooo00<0
00000?ooo`3oool0d@3oool3000005`0oooo00<000000?ooo`3oool0?03oool010000000oooo0?oo
o`00001;0?ooo`009P3oool00`000000oooo0?ooo`0H0?ooo`800000cP3oool300000600oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`190?ooo`009P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0<P0oooo0`00001S0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0B03oool002H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`350?oo
o`800000I`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00L0oooo1@0000020?oo
o`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000001l0oooo000V0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0`@3oool3000006X0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01`0oooo000V0?ooo`<00000
7@3oool00`000000oooo0?ooo`2m0?ooo`<00000KP3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo01`0oooo000U0?ooo`800000803oool00`000000oooo0?ooo`2i
0?ooo`<00000L@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000007P3oool002D0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2e0?ooo`<00000M@3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000001h0oooo000:0?ooo`800000103o
ool2000000<0oooo100000030?ooo`8000001`3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0;40oooo0`00001i0?ooo`030000003oool0oooo03d0oooo0P0000070?ooo`800000103o
ool3000000<0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000O0?ooo`002@3oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0:d0oooo0`00001l0?ooo`030000
003oool0oooo03/0oooo0P0000020?ooo`030000003oool0oooo04<0oooo00090?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`800000
903oool00`000000oooo0?ooo`2Y0?ooo`<00000P03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo04<0oooo00090?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
0P3oool2000000L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2V0?ooo`800000
Q03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0480oooo00090?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0XP3oool3000008L0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`110?ooo`002P3oool2000000X0oooo0P0000040?ooo`<00000
1@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo09h0oooo0`00002:0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool0@@3oool002@0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`2J0?ooo`<00000SP3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo0400oooo000T0?ooo`<00000:@3oool2000009L0oooo0`00002B0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0?`3oool002@0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`2A0?ooo`<00000UP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
03l0oooo000T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0S@3oool3000009T0
oooo00<000000?ooo`3oool0?@3oool200000400oooo000T0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0R@3oool3000009d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
000000100?ooo`008`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo08H0oooo0P00
002Q0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?@3oool002<0oooo0`00000`
0?ooo`030000003oool0oooo0880oooo0`00002S0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool0?03oool002<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1n0?oo
o`<00000Y`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo000S0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0NP3oool300000:/0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0k0?ooo`008`3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo07H0oooo0`00002_0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
>P3oool002<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1b0?ooo`<00000/P3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03X0oooo000R0?ooo`<00000=P3oool0
0`000000oooo0?ooo`1^0?ooo`<00000]P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo03T0oooo000R0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0JP3oool30000
0;X0oooo00<000000?ooo`3oool0?03oool2000003X0oooo000R0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0I`3oool200000;d0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0000000j0?ooo`008P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo06<0oooo
0`0000300?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=`3oool00280oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`1O0?ooo`<00000a03oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo03H0oooo000R0?ooo`<00000>`3oool2000005`0oooo0`000038
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=P3oool00240oooo0P00000o0?oo
o`030000003oool0oooo05H0oooo0`00003;0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0=@3oool00240oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1B0?ooo`<0
0000c`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03@0oooo000Q0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0CP3oool300000=<0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0d0?ooo`00303oool2000000@0oooo0P0000040?ooo`8000001`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04X0oooo0`00003G0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool0<`3oool000/0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
A`3oool200000=X0oooo00<000000?ooo`3oool0>`3oool3000003@0oooo000;0?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool0103oool2000004@0oooo00<000000?ooo`3oool0
@`3oool300000=d0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0b0?ooo`002`3o
ool010000000oooo0?ooo`0000090?ooo`8000001P3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo03l0oooo0`00003Q0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
<@3oool000/0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0>`3oool300000>@0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0`0?ooo`00303oool2000000X0oooo0`0000050?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0=`3oool300000>P0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0`0?ooo`00803oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo03<0oooo0`00003/0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0;`3oool0
0200oooo0`0000190?ooo`030000003oool0oooo02l0oooo0`00003`0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0;P3oool00200oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0[0?ooo`<00000l`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02h0
oooo000O0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0:03oool200000?L0oooo
00<000000?ooo`3oool0>`3oool2000002l0oooo000O0?ooo`030000003oool0oooo04d0oooo0P00
000U0?ooo`<00000nP3oool00`000000oooo0?ooo`0i0?ooo`040000003oool0oooo000002h0oooo
000O0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool07`3oool300000?h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0/0?ooo`007`3oool300000500oooo00<00000
0?ooo`3oool06`3oool300000?l0oooo0P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo00L0oooo100000030?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2
000000<0oooo000O0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool05`3oool30000
0?l0oooo1P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo000O0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04`3oool300000?l0
oooo2P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool300000?l0oooo
3@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo0@0000010?ooo`40oooo
000N0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool02`3oool300000?l0oooo4@3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0203oool200000?l0oooo5@3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`800000103o
ool2000000@0oooo0P0000040?ooo`800000103oool2000000<0oooo000N0?ooo`<00000E`3oool0
0`000000oooo0?ooo`040?ooo`<00000o`3ooolH0?ooo`030000003oool0oooo03P0oooo1000000Y
0?ooo`007P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo00<00000o`3ooolK0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool09`3oool001h0oooo00<000000?ooo`3o
ool0F03oool300000?l0oooo7`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02H0
oooo000M0?ooo`030000003oool0oooo05H0oooo0`0000020?ooo`030000003oool0oooo0?l0oooo
7P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo02D0oooo000M0?ooo`030000003o
ool0oooo05<0oooo0`0000060?ooo`030000003oool0oooo0?l0oooo7P3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo02D0oooo000M0?ooo`040000003oool00000000004l0oooo0`00
000:0?ooo`030000003oool0oooo0?l0oooo7@3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo02@0oooo000M0?ooo`800000CP3oool3000000h0oooo00<000000?ooo`3oool0o`3ooolM
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool08`3oool001d0oooo00<000000?oo
o`3oool0BP3oool300000180oooo0P00003o0?oooah0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0S0?ooo`000P3oool2000000@0oooo0P0000050?ooo`030000003oool0oooo0080
oooo0P0000070?ooo`030000003oool0oooo04P0oooo0P00000G0?ooo`030000003oool0oooo0?l0
oooo6`3oool00`000000oooo0?ooo`0j0?ooo`800000903oool000050?ooo`000000oooo0?ooo`00
00002P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`160?ooo`<000006P3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?oo
o`3oool0=P3oool3000000030?ooo`000000oooo02<0oooo00001@3oool000000?ooo`3oool00000
00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`<00000@`3oool30000
01h0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo0340oooo100000040?oo
o`030000003oool0oooo0280oooo00001@3oool000000?ooo`3oool0000000/0oooo00@000000?oo
o`3oool0oooo0P0000060?ooo`030000003oool0oooo0400oooo0`00000R0?ooo`030000003oool0
oooo0?l0oooo6`3oool00`000000oooo0?ooo`0]0?ooo`<00000203oool00`000000oooo0?ooo`0R
0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0m0?ooo`<000009P3oool00`000000oooo0?oo
o`3o0?oooaX0oooo00<000000?ooo`3oool0:P3oool3000000`0oooo00<000000?ooo`3oool08@3o
ool00080oooo0P0000090?ooo`@000000`3oool3000000D0oooo00<000000?ooo`3oool0>P3oool3
000002X0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`030000003oool0oooo02D0oooo1000000?
0?ooo`030000003oool0oooo0240oooo000L0?ooo`030000003oool0oooo03L0oooo0`00000^0?oo
o`030000003oool0oooo0?l0oooo6P3oool00`000000oooo0?ooo`0Q0?ooo`<000004`3oool00`00
0000oooo0?ooo`0Q0?ooo`006`3oool00`000000oooo0?ooo`0e0?ooo`<00000<P3oool00`000000
oooo0?ooo`3o0?oooaX0oooo00<000000?ooo`3oool07@3oool3000001H0oooo00<000000?ooo`3o
ool08@3oool001/0oooo0`00000c0?ooo`800000=P3oool00`000000oooo0?ooo`3o0?oooaT0oooo
00<000000?ooo`3oool06@3oool4000001T0oooo00<000000?ooo`3oool08@3oool001/0oooo00<0
00000?ooo`3oool0<03oool3000003T0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`030000003o
ool0oooo01D0oooo0`00000M0?ooo`030000003oool0oooo0240oooo000K0?ooo`030000003oool0
oooo02d0oooo0`00000m0?ooo`030000003oool0oooo0?l0oooo6@3oool00`000000oooo0?ooo`0A
0?ooo`<00000803oool00`000000oooo0?ooo`0Q0?ooo`006`3oool00`000000oooo0?ooo`0Z0?oo
o`<00000@@3oool00`000000oooo0?ooo`3o0?oooaP0oooo00<000000?ooo`3oool03@3oool40000
02<0oooo00<000000?ooo`3oool08@3oool001/0oooo00<000000?ooo`3oool09`3oool3000004D0
oooo00<000000?ooo`3oool0o`3ooolH0?ooo`030000003oool0oooo00T0oooo0`00000X0?ooo`03
0000003oool0oooo0200oooo000J0?ooo`030000003oool0000002D0oooo0`0000190?ooo`030000
003oool0oooo0?l0oooo603oool00`000000oooo0?ooo`050?ooo`<00000:`3oool00`000000oooo
0?ooo`0P0?ooo`006P3oool2000002<0oooo0`00001=0?ooo`800000o`3ooolI0?ooo`030000003o
ool0oooo00@00000;P3oool00`000000oooo0?ooo`0P0?ooo`006P3oool00`000000oooo0?ooo`0O
0?ooo`<00000DP3oool00`000000oooo0?ooo`3o0?oooaH0oooo0`00000b0?ooo`030000003oool0
oooo0200oooo000J0?ooo`030000003oool0oooo01d0oooo0P00001F0?ooo`030000003oool0oooo
0?l0oooo4P3oool3000000030?ooo`000000oooo0380oooo00<000000?ooo`3oool0803oool001X0
oooo00<000000?ooo`3oool06P3oool3000005T0oooo00<000000?ooo`3oool0o`3oool=0?ooo`@0
00001@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0200oooo000J0?ooo`030000
003oool0oooo01L0oooo0`00001M0?ooo`030000003oool0oooo0?l0oooo2@3oool3000000X0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0P0?ooo`006@3oool4000001@0oooo0`00
001Q0?ooo`030000003oool0oooo0?l0oooo1@3oool3000000d0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0O0?ooo`006@3oool00`000000oooo0?ooo`0B0?ooo`<00000I@3oool0
0`000000oooo0?ooo`3o0?ooo`@000004@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo01l0oooo000I0?ooo`030000003oool0oooo00l0oooo0`00001Y0?ooo`030000003oool0oooo
0?/0oooo0`00000F0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool07`3oool001T0
oooo00<000000?ooo`3oool0303oool3000006d0oooo00<000000?ooo`3oool0m`3oool3000001T0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0O0?ooo`006@3oool00`000000oooo
0?ooo`090?ooo`<00000L@3oool00`000000oooo0?ooo`3b0?ooo`@000007@3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo01l0oooo000I0?ooo`040000003oool00000000000H0oooo
0P00001e0?ooo`030000003oool0oooo0>h0oooo0`00000R0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool07`3oool001P0oooo0`0000050?ooo`<00000N03oool00`000000oooo0?oo
o`3Z0?ooo`<000009P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01l0oooo000H
0?ooo`030000003oool0oooo0080oooo0`00001l0?ooo`030000003oool0oooo0>D0oooo1000000Y
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool07P3oool000h0oooo1@0000050?oo
o`030000003oool0000000800000P03oool00`000000oooo0?ooo`3Q0?ooo`<00000;P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01h0oooo000@0?ooo`030000003oool0oooo00D0
oooo0P0000240?ooo`800000gP3oool300000380oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`0N0?ooo`00403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08@0oooo
00<000000?ooo`3oool0e`3oool4000003H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0N0?ooo`00403oool00`000000oooo0?ooo`070?ooo`800000Q@3oool00`000000oooo0?oo
o`3C0?ooo`<00000>P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo000@
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`3?
0?ooo`<00000?P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01h0oooo000?0?oo
o`800000303oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0<X0oooo100000120?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool07P3oool001h0oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`360?ooo`<00000AP3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo01h0oooo000O0?ooo`800000Q03oool00`000000oooo0?ooo`320?ooo`<00000
BP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01d0oooo000Q0?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0_@3oool4000004h0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0M0?ooo`008P3oool00`000000oooo0?ooo`220?ooo`030000003oool0
oooo0;T0oooo0`00001C0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07@3oool0
02<0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`2e0?ooo`<00000EP3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01d0oooo000T0?ooo`800000P`3oool00`000000
oooo0?ooo`2`0?ooo`@00000FP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01d0
oooo000V0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0[03oool3000005l0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0M0?ooo`009`3oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo0:P0oooo0`00001S0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool07@3oool002P0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2S
0?ooo`@00000IP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01`0oooo000Y0?oo
o`800000PP3oool00`000000oooo0?ooo`2O0?ooo`<00000J`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo01`0oooo000[0?ooo`030000003oool0oooo0800oooo0P00002L0?ooo`<0
0000K`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01`0oooo000/0?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool0U@3oool400000780oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0L0?ooo`00;@3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo0940oooo0`00001g0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0703o
ool002h0oooo0P0000220?ooo`030000003oool0oooo08d0oooo0`00001k0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0703oool00300oooo00<000000?ooo`3oool0P03oool00`00
0000oooo0?ooo`280?ooo`@00000O`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01`0oooo000a0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0Q03oool3000008<0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0L0?ooo`00<P3oool00`000000oooo
0?ooo`200?ooo`030000003oool0oooo0800oooo0`0000270?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool06`3oool003<0oooo0P0000210?ooo`030000003oool0oooo07/0oooo1000
002;0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool003D0oooo00<00000
0?ooo`3oool0O`3oool00`000000oooo0?ooo`1g0?ooo`<00000T03oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01/0oooo000f0?ooo`030000003oool0oooo07l0oooo00<000000?oo
o`3oool0L`3oool3000009<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0K0?oo
o`00=`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo06h0oooo1000002G0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool06`3oool003P0oooo0P0000200?ooo`030000
003oool0oooo06X0oooo0`00002L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
6`3oool003X0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1V0?ooo`<00000W`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo000k0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0H@3oool400000:<0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0J0?ooo`00?03oool00`000000oooo0?ooo`1n0?ooo`800000GP3oool30000
0:P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`00?@3oool200000800
oooo00<000000?ooo`3oool0F03oool300000:`0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0J0?ooo`00?`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo05<0oooo
1000002_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06P3oool00400oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`1?0?ooo`<00000]03oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo01X0oooo00110?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0B`3oool300000;P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0J
0?ooo`00@P3oool2000007l0oooo00<000000?ooo`3oool0AP3oool400000;/0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0J0?ooo`00A03oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0480oooo0`0000300?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool06P3oool004D0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0n0?ooo`<00000
a03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01T0oooo00160?ooo`030000003o
ool0oooo07d0oooo00<000000?ooo`3oool0>@3oool400000<P0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0I0?ooo`00A`3oool2000007h0oooo00<000000?ooo`3oool0=@3oool3
00000<`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0I0?ooo`00B@3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0340oooo0`00003@0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool06@3oool004X0oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`0/0?ooo`@00000e03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0
oooo001;0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0:03oool300000=T0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`00C03oool2000007d0oooo00<0
00000?ooo`3oool0903oool300000=`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0I0?ooo`00CP3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo01l0oooo1000003P
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0603oool004l0oooo00<000000?oo
o`3oool0N`3oool2000001`0oooo0`00003U0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0603oool00500oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0F0?ooo`<0
0000j03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo001A0?ooo`800000
O@3oool00`000000oooo0?ooo`0A0?ooo`@00000k03oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01P0oooo001C0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool03@3o
ool300000?40oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`00E03oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo00T0oooo0`00003e0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0603oool005D0oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`040?ooo`@00000n03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
01P0oooo001F0?ooo`800000O03oool00`000000oooo0?ooo`0300000?d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0G0?ooo`00F03oool00`000000oooo0?ooo`1j0?ooo`800000
o`3oool20?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05`3oool005T0oooo00<0
00000?ooo`3oool0N@3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0G0?ooo`00FP3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0?l0oooo0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo001K0?oo
o`800000N03oool00`000000oooo0?ooo`3o0?ooo`<0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0G0?ooo`00G@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0?l0
oooo103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo001N0?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool0o`3oool40?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool05`3oool005l0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`00H03oool2
000007<0oooo00<000000?ooo`3oool0o`3oool60?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool05P3oool00680oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`3o0?oo
o`L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`00H`3oool00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01H0oooo001T0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0
o`3oool80?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05P3oool006D0oooo0P00
001^0?ooo`030000003oool0oooo0?l0oooo2@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01H0oooo001W0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0o`3oool:
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool006P0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`3o0?ooo`X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0F0?ooo`00J@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0?l0
oooo2`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo001Z0?ooo`800000
J@3oool00`000000oooo0?ooo`3o0?ooo``0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0E0?ooo`00K03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0?l0oooo303o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo001]0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool0o`3oool>0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool05@3oool006h0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`3o0?oo
o`l0oooo00D000000?ooo`3oool0oooo0000000G0?ooo`00K`3oool2000006<0oooo00<000000?oo
o`3oool0o`3oool@0?ooo`040000003oool0oooo000001L0oooo001a0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0o`3oool@0?ooo`040000003oool0oooo000001L0oooo001b0?oo
o`030000003oool0oooo05l0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`030000003oool00000
01L0oooo001c0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`03
0000003oool0000001H0oooo001d0?ooo`800000GP3oool00`000000oooo0?ooo`3o0?oooa<0oooo
0P00000F0?ooo`00MP3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0?l0oooo4`3o
ool2000001H0oooo001g0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0o`3ooolC
0?ooo`8000005P3oool007P0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`3o0?oo
o`l0oooo1000000H0?ooo`00N@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0?l0
oooo2`3oool4000001`0oooo001j0?ooo`800000F03oool00`000000oooo0?ooo`3o0?ooo`L0oooo
1000000P0?ooo`00O03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0?l0oooo0`3o
ool4000002@0oooo001m0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0oP3oool4
000002P0oooo001n0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0n`3oool30000
02`0oooo001o0?ooo`800000D`3oool00`000000oooo0?ooo`3g0?ooo`@00000;`3oool00840oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3c0?ooo`@00000<`3oool00880oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`3_0?ooo`@00000=`3oool008<0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`3[0?ooo`@00000>`3oool008@0oooo0P00001>0?oo
o`030000003oool0oooo0>L0oooo1000000o0?ooo`00QP3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo0>@0oooo0`0000130?ooo`00Q`3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo0>00oooo100000160?ooo`00R03oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0=`0oooo1000001:0?ooo`00R@3oool2000004T0oooo00<000000?ooo`3oool0f03oool4
000004h0oooo002;0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0e03oool40000
0580oooo002<0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0d03oool4000005H0
oooo002=0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0c@3oool3000005X0oooo
002>0?ooo`800000A03oool00`000000oooo0?ooo`390?ooo`@00000G@3oool00900oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`350?ooo`@00000H@3oool00940oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`310?ooo`@00000I@3oool00980oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`2m0?ooo`@00000J@3oool009<0oooo0P00000o0?ooo`030000
003oool0oooo0;T0oooo1000001]0?ooo`00U@3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo0;H0oooo0`00001a0?ooo`00UP3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo0;<0oooo1000001d0?ooo`00U`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0:l0oooo1000001h0?ooo`00V03oool2000003T0oooo00<000000?ooo`3oool0Z`3oool4000007`0
oooo002J0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0Y`3oool400000800oooo
002K0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0X`3oool4000008@0oooo002L
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0X03oool3000008P0oooo002M0?oo
o`800000=03oool00`000000oooo0?ooo`2L0?ooo`@00000R`3oool009l0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`2H0?ooo`@00000S`3oool00:00oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`2D0?ooo`@00000T`3oool00:40oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`2@0?ooo`@00000U`3oool00:80oooo0P00000_0?ooo`030000003oool0
oooo08`0oooo1000002K0?ooo`00Y03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
08P0oooo1000002O0?ooo`00Y@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo08D0
oooo0`00002S0?ooo`00YP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0840oooo
1000002V0?ooo`00Y`3oool2000002X0oooo00<000000?ooo`3oool0O@3oool400000:X0oooo002Y
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0N@3oool400000:h0oooo002Z0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0M@3oool400000;80oooo002[0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0L@3oool400000;H0oooo002/0?ooo`800000
9@3oool00`000000oooo0?ooo`1^0?ooo`<00000^P3oool00:h0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`1Z0?ooo`@00000_@3oool00:l0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`1V0?ooo`@00000`@3oool00;00oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`1R0?ooo`@00000a@3oool00;40oooo0P00000P0?ooo`030000003oool0oooo05h0
oooo100000390?ooo`00/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05X0oooo
1000003=0?ooo`00]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo0`00
003A0?ooo`00]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05<0oooo1000003D
0?ooo`00]P3oool2000001/0oooo00<000000?ooo`3oool0C`3oool400000=P0oooo002h0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0B`3oool400000=`0oooo002i0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0A`3oool400000>00oooo002j0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0@`3oool400000>@0oooo002k0?ooo`8000005P3oool0
0`000000oooo0?ooo`100?ooo`<00000j03oool00;d0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0l0?ooo`@00000j`3oool00;h0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0i0?ooo`@00000k`3oool00;l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0e0?ooo`@00000l`3oool00<00oooo0P00000@0?ooo`030000003oool0oooo0340oooo1000
003g0?ooo`00`P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02d0oooo1000003k
0?ooo`00``3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02X0oooo0`00003o0?oo
o`00a03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02H0oooo1000003o0?ooo`<0
oooo00350?ooo`8000002`3oool00`000000oooo0?ooo`0R0?ooo`@00000o`3oool70?ooo`00a`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo1000003o0?ooo`/0oooo0038
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000?l0oooo3`3oool0
0<T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`@00000o`3ooolC0?oo
o`00bP3oool2000000H0oooo00<000000?ooo`3oool04`3oool300000?l0oooo5`3oool00<`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`@00000o`3ooolJ0?ooo`00c@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo1000003o0?oooah0oooo003>
0?ooo`050000003oool0oooo0?ooo`0000002@3oool400000?l0oooo8P3oool00<l0oooo0P000000
0`3oool000000?ooo`040?ooo`@00000o`3ooolV0?ooo`00d@3oool2000000030?ooo`0000000000
00800000o`3ooolZ0?ooo`00dP3oool200000?l0oooo;P3oool00?l0ooooo`3oool30?ooo`00o`3o
oooo0?ooo`<0oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0
oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo003o0?oo
ool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo003o0?ooool0oooo0`3o
ool00001\
\>"],
  ImageRangeCache->{{{56.25, 466.25}, {609.5, 277.063}} -> {-0.195084, \
0.720316, 0.00204743, 0.00204743}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Amplitude components (sin and cos)", "Subsection"],

Cell["ZC<>0", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vas = a1 /. valueruleaHPlc\)], "Input"],

Cell[BoxData[
    \(\((5875\ \[ImaginaryI]\ \[Pi]\ \((\(-8000\)\ \[Pi] + 
              8000\ \[Pi]\ Cos[w\/117500] + 
              47\ \[ImaginaryI]\ ZC\ Sin[
                  w\/117500])\))\)/\((\(-47\)\ \[ImaginaryI]\ \((\(-3125000\)\
\ \[ImaginaryI]\ w\ ZC + \[Pi]\^2\ \((1500000000000 + w\^2\ ZC)\))\)\ Cos[
              w\/117500] + 
          2000\ \[Pi]\ \((35250000000\ \[ImaginaryI]\ \[Pi] + \
\((\(-12500000\)\ \[ImaginaryI]\ w + 4\ \[Pi]\^2\ w\^2 + 
                      103546875\ ZC)\)\ Sin[w\/117500])\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(vas2 = a2 /. valueruleaHPlc\)], "Input"],

Cell[BoxData[
    \(\((5875\ \[Pi]\ \((47\ ZC\ Cos[w\/117500] + 
              8000\ \[ImaginaryI]\ \[Pi]\ Sin[
                  w\/117500])\))\)/\((\(-47\)\ \[ImaginaryI]\ \((\(-3125000\)\
\ \[ImaginaryI]\ w\ ZC + \[Pi]\^2\ \((1500000000000 + w\^2\ ZC)\))\)\ Cos[
              w\/117500] + 
          2000\ \[Pi]\ \((35250000000\ \[ImaginaryI]\ \[Pi] + \
\((\(-12500000\)\ \[ImaginaryI]\ w + 4\ \[Pi]\^2\ w\^2 + 
                      103546875\ ZC)\)\ Sin[w\/117500])\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{Abs[\(vas2 /. ZC \[Rule] 0\) /. w \[Rule] 2\ \[Pi]\ f], 
        Abs[\(vas /. ZC \[Rule] 0\) /. w \[Rule] 2\ \[Pi]\ f]}, {f, 40000, 
        130000}, PlotPoints \[Rule] 150, PlotRange \[Rule] \ Automatic, 
      PlotStyle \[Rule] {{Thickness[ .004], 
            RGBColor[1, 0, 0]}, {Thickness[ .002], 
            RGBColor[0, 1, 0]}}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.399471 1.0582e-005 0.0147151 8.94646e+006 [
[.23545 .00222 -15 -9 ]
[.23545 .00222 15 0 ]
[.44709 .00222 -15 -9 ]
[.44709 .00222 15 0 ]
[.65873 .00222 -18 -9 ]
[.65873 .00222 18 0 ]
[.87037 .00222 -18 -9 ]
[.87037 .00222 18 0 ]
[.01131 .10418 -33 -6.25 ]
[.01131 .10418 0 6.25 ]
[.01131 .19364 -33 -6.25 ]
[.01131 .19364 0 6.25 ]
[.01131 .28311 -33 -6.25 ]
[.01131 .28311 0 6.25 ]
[.01131 .37257 -33 -6.25 ]
[.01131 .37257 0 6.25 ]
[.01131 .46204 -33 -6.25 ]
[.01131 .46204 0 6.25 ]
[.01131 .5515 -33 -6.25 ]
[.01131 .5515 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23545 .01472 m
.23545 .02097 L
s
[(60000)] .23545 .00222 0 1 Mshowa
.44709 .01472 m
.44709 .02097 L
s
[(80000)] .44709 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(100000)] .65873 .00222 0 1 Mshowa
.87037 .01472 m
.87037 .02097 L
s
[(120000)] .87037 .00222 0 1 Mshowa
.125 Mabswid
.07672 .01472 m
.07672 .01847 L
s
.12963 .01472 m
.12963 .01847 L
s
.18254 .01472 m
.18254 .01847 L
s
.28836 .01472 m
.28836 .01847 L
s
.34127 .01472 m
.34127 .01847 L
s
.39418 .01472 m
.39418 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.55291 .01472 m
.55291 .01847 L
s
.60582 .01472 m
.60582 .01847 L
s
.71164 .01472 m
.71164 .01847 L
s
.76455 .01472 m
.76455 .01847 L
s
.81746 .01472 m
.81746 .01847 L
s
.92328 .01472 m
.92328 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10418 m
.03006 .10418 L
s
gsave
.01131 .10418 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .19364 m
.03006 .19364 L
s
gsave
.01131 .19364 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .28311 m
.03006 .28311 L
s
gsave
.01131 .28311 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .37257 m
.03006 .37257 L
s
gsave
.01131 .37257 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .46204 m
.03006 .46204 L
s
gsave
.01131 .46204 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .5515 m
.03006 .5515 L
s
gsave
.01131 .5515 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.125 Mabswid
.02381 .03261 m
.02756 .03261 L
s
.02381 .0505 m
.02756 .0505 L
s
.02381 .06839 m
.02756 .06839 L
s
.02381 .08629 m
.02756 .08629 L
s
.02381 .12207 m
.02756 .12207 L
s
.02381 .13997 m
.02756 .13997 L
s
.02381 .15786 m
.02756 .15786 L
s
.02381 .17575 m
.02756 .17575 L
s
.02381 .21154 m
.02756 .21154 L
s
.02381 .22943 m
.02756 .22943 L
s
.02381 .24732 m
.02756 .24732 L
s
.02381 .26522 m
.02756 .26522 L
s
.02381 .301 m
.02756 .301 L
s
.02381 .31889 m
.02756 .31889 L
s
.02381 .33679 m
.02756 .33679 L
s
.02381 .35468 m
.02756 .35468 L
s
.02381 .39047 m
.02756 .39047 L
s
.02381 .40836 m
.02756 .40836 L
s
.02381 .42625 m
.02756 .42625 L
s
.02381 .44415 m
.02756 .44415 L
s
.02381 .47993 m
.02756 .47993 L
s
.02381 .49782 m
.02756 .49782 L
s
.02381 .51572 m
.02756 .51572 L
s
.02381 .53361 m
.02756 .53361 L
s
.02381 .5694 m
.02756 .5694 L
s
.02381 .58729 m
.02756 .58729 L
s
.02381 .60518 m
.02756 .60518 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.004 w
.02381 .18606 m
.03003 .1827 L
.03682 .17915 L
.04319 .17592 L
.04932 .17292 L
.05585 .16982 L
.06213 .16694 L
.0688 .16397 L
.07524 .16121 L
.08142 .15864 L
.08801 .15599 L
.09434 .15354 L
.10044 .15125 L
.10693 .14891 L
.11317 .14674 L
.11981 .14452 L
.12621 .14248 L
.13236 .14061 L
.13891 .13872 L
.14521 .13702 L
.15191 .13534 L
.15836 .13387 L
.16457 .13262 L
.17118 .13152 L
.17447 .13108 L
.17754 .13075 L
.17905 .13062 L
.18049 .13052 L
.18128 .13047 L
.18214 .13043 L
.18293 .1304 L
.18365 .13038 L
.18404 .13038 L
.18423 .13037 L
.1844 .13037 L
.18459 .13037 L
.18479 .13037 L
.18499 .13037 L
.1851 .13037 L
.1852 .13037 L
.18539 .13037 L
.18556 .13037 L
.18575 .13037 L
.18595 .13037 L
.18629 .13038 L
.18666 .13039 L
.18709 .1304 L
.18749 .13041 L
.18837 .13046 L
.1892 .13051 L
Mistroke
.18998 .13058 L
.19153 .13075 L
.19317 .131 L
.19473 .13131 L
.19614 .13166 L
.19924 .13271 L
.20099 .13351 L
.2026 .1344 L
.20564 .13654 L
.20897 .13951 L
.20974 .1402 L
.21059 .14087 L
.21097 .14112 L
.21118 .14123 L
.21138 .14133 L
.21157 .1414 L
.21173 .14145 L
.21192 .14148 L
.21212 .14149 L
.21222 .14149 L
.21233 .14147 L
.21253 .14142 L
.21265 .14136 L
.21276 .1413 L
.21298 .14114 L
.2132 .14091 L
.21341 .14064 L
.21364 .14025 L
.21388 .13974 L
.21428 .13863 L
.21465 .13724 L
.21505 .13523 L
.21549 .13242 L
.2159 .12904 L
.21634 .12458 L
.21713 .11409 L
.21797 .09931 L
.21891 .07987 L
.2206 .04346 L
.22134 .02934 L
.22173 .02256 L
.22194 .01905 L
.22215 .01587 L
.22234 .01652 L
.22245 .01813 L
.22256 .01959 L
.22293 .02462 L
.22366 .03333 L
.22526 .04802 L
.22603 .05349 L
Mistroke
.22689 .05856 L
.22862 .06649 L
.23025 .07196 L
.23175 .07578 L
.23347 .07919 L
.23511 .08172 L
.23665 .08362 L
.2383 .08526 L
.24126 .08746 L
.24292 .08839 L
.24472 .08921 L
.24627 .08978 L
.24797 .0903 L
.25118 .09103 L
.25293 .09131 L
.25457 .09151 L
.25626 .09168 L
.25785 .09179 L
.25929 .09186 L
.2601 .09189 L
.26049 .0919 L
.26084 .09191 L
.2612 .09191 L
.26159 .09192 L
.26198 .09193 L
.2622 .09193 L
.2624 .09193 L
.26259 .09193 L
.26276 .09193 L
.26293 .09193 L
.2631 .09193 L
.26329 .09193 L
.26349 .09193 L
.26366 .09193 L
.26385 .09193 L
.26407 .09193 L
.26428 .09193 L
.26468 .09192 L
.2651 .09192 L
.26557 .09191 L
.26717 .09187 L
.26803 .09184 L
.26884 .09181 L
.27035 .09174 L
.27373 .09154 L
.27995 .09104 L
.28657 .0904 L
.29294 .08969 L
.29907 .08895 L
.30559 .08813 L
Mistroke
.31187 .08731 L
.31854 .08642 L
.32497 .08556 L
.33116 .08472 L
.33774 .08383 L
.34407 .08297 L
.35017 .08216 L
.35665 .08129 L
.3629 .08046 L
.36954 .07959 L
.37593 .07877 L
.38208 .07798 L
.38862 .07715 L
.39493 .07637 L
.40162 .07555 L
.40807 .07477 L
.41428 .07403 L
.42088 .07325 L
.42724 .07252 L
.43336 .07183 L
.43986 .0711 L
.44613 .07041 L
.45279 .06969 L
.45921 .069 L
.46538 .06836 L
.47194 .06768 L
.47827 .06704 L
.48435 .06643 L
.49082 .0658 L
.49705 .06519 L
.50367 .06456 L
.51005 .06397 L
.51619 .0634 L
.52272 .06281 L
.52901 .06226 L
.53569 .06167 L
.54213 .06112 L
.54832 .06059 L
.55491 .06005 L
.56126 .05953 L
.56736 .05903 L
.57385 .05852 L
.58011 .05803 L
.58675 .05752 L
.59315 .05704 L
.59931 .05658 L
.60587 .0561 L
.61218 .05565 L
.61888 .05517 L
.62534 .05472 L
Mistroke
.63156 .0543 L
.63817 .05385 L
.64453 .05343 L
.65066 .05303 L
.65717 .0526 L
.66345 .05221 L
.67012 .05179 L
.67654 .05139 L
.68272 .05102 L
.6893 .05063 L
.69563 .05026 L
.70171 .0499 L
.7082 .04953 L
.71443 .04918 L
.72107 .04882 L
.72746 .04847 L
.7336 .04814 L
.74014 .04779 L
.74644 .04746 L
.75313 .04712 L
.75957 .04679 L
.76578 .04648 L
.77237 .04616 L
.77873 .04585 L
.78484 .04556 L
.79134 .04525 L
.7976 .04496 L
.80425 .04465 L
.81067 .04436 L
.81683 .04409 L
.82339 .0438 L
.82971 .04353 L
.83578 .04327 L
.84225 .043 L
.84848 .04274 L
.8551 .04246 L
.86147 .04221 L
.8676 .04196 L
.87413 .0417 L
.88041 .04146 L
.88709 .04121 L
.89352 .04096 L
.89971 .04073 L
.90629 .04049 L
.91263 .04026 L
.91873 .04004 L
.92522 .03981 L
.93147 .03959 L
.93811 .03936 L
.9445 .03915 L
Mistroke
.95066 .03894 L
.95721 .03872 L
.96351 .03851 L
.97021 .0383 L
.97619 .03811 L
Mfstroke
0 1 0 r
.002 w
.02381 .32738 m
.03003 .33302 L
.03682 .33967 L
.04319 .34645 L
.04932 .35352 L
.05585 .3617 L
.06213 .37029 L
.0688 .38028 L
.07524 .39087 L
.08142 .40207 L
.08801 .41523 L
.09434 .42931 L
.10044 .44436 L
.10693 .46227 L
.11317 .48169 L
.11981 .50514 L
.12621 .53103 L
.13236 .55965 L
.13891 .59509 L
s
.13891 .59509 m
.1425 .61803 L
s
.27242 .61803 m
.27253 .61648 L
.27916 .5421 L
.28555 .4843 L
.2917 .43822 L
.29824 .39698 L
.30454 .36323 L
.31123 .33243 L
.31768 .30672 L
.32388 .28499 L
.33048 .26456 L
.33684 .24708 L
.34295 .23199 L
.34945 .21751 L
.35572 .20491 L
.36237 .19275 L
.36879 .18208 L
.37495 .17268 L
.38152 .16349 L
.38784 .15534 L
.39391 .14808 L
.40038 .14091 L
.40661 .1345 L
.41323 .12816 L
.41961 .12247 L
.42574 .11735 L
.43227 .11224 L
.43855 .10762 L
.44523 .10302 L
.45167 .09885 L
.45786 .09507 L
.46444 .09127 L
.47079 .08782 L
.47688 .08467 L
.48338 .0815 L
.48962 .0786 L
.49627 .07567 L
.50267 .07299 L
.50882 .07054 L
.51537 .06805 L
.52168 .06577 L
.52838 .06345 L
.53484 .06133 L
.54105 .05937 L
.54766 .05738 L
.55402 .05555 L
.56014 .05386 L
.56665 .05213 L
.57292 .05054 L
.57959 .04891 L
Mistroke
.58601 .04741 L
.59219 .04602 L
.59876 .0446 L
.60509 .04328 L
.61117 .04205 L
.61765 .0408 L
.62389 .03963 L
.63052 .03844 L
.6369 .03733 L
.64304 .0363 L
.64958 .03524 L
.65587 .03425 L
.66256 .03323 L
.669 .03229 L
.6752 .03141 L
.6818 .0305 L
.68815 .02966 L
.69425 .02887 L
.70075 .02805 L
.70701 .02729 L
.71366 .0265 L
.72007 .02577 L
.72623 .02508 L
.73279 .02437 L
.7391 .0237 L
.74581 .02301 L
.75228 .02236 L
.7585 .02176 L
.76512 .02113 L
.77149 .02054 L
.77762 .01999 L
.78414 .01941 L
.79042 .01887 L
.79709 .01831 L
.80352 .01778 L
.80971 .01729 L
.81629 .01677 L
.82262 .01628 L
.82872 .01582 L
.8352 .01534 L
.83819 .01513 L
.84145 .01489 L
.8423 .01483 L
.84277 .0148 L
.84321 .01477 L
.84362 .01474 L
.84374 .01473 L
.84386 .01472 L
.84396 .01472 L
.84407 .01473 L
Mistroke
.84485 .01478 L
.84809 .01501 L
.85459 .01546 L
.86086 .01589 L
.86752 .01634 L
.87394 .01677 L
.88011 .01717 L
.88667 .01759 L
.893 .01799 L
.89908 .01837 L
.90555 .01877 L
.91178 .01914 L
.9184 .01954 L
.92478 .01992 L
.93092 .02028 L
.93745 .02066 L
.94374 .02102 L
.95042 .0214 L
.95686 .02176 L
.96305 .02211 L
.96964 .02248 L
.97599 .02283 L
.97619 .02284 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{380, 234.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005l0000jR000`400?l00000o`00003oo`3ooomm
0?ooo`00o`3ooomm0?ooo`00o`3ooomm0?ooo`00o`3ooomm0?ooo`00o`3ooomm0?ooo`00H@3oool3
000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000`0?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000103oool2000002`0oooo1@0000020?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000103oool2000002T0oooo1@0000000`3oool0000000000002
000000<0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000O0?ooo`00H@3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002h0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000]0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
02P0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
01h0oooo001Q0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000;P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000002d0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000007P3oool00640oooo0`0000030?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000002l0oooo0P0000030?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
02d0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0L0?ooo`00HP3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000002h0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000]0?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02P0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0703oool00680oooo0`0000030?ooo`800000103oool2000000@0oooo0P000004
0?ooo`800000<03oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000]
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000Z
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000O
0?ooo`00o`3ooomm0?ooo`00o`3ooomm0?ooo`009@3oool00`000000oooo0?ooo`3o0?oooeD0oooo
000U0?ooo`030000003oool0oooo0?l0ooooE@3oool002D0oooo00<000000?ooo`3oool0o`3ooomE
0?ooo`009@3oool00`000000oooo0?ooo`3o0?oooeD0oooo000U0?ooo`030000003oool0oooo0?l0
ooooE@3oool001d0ooooC@0000000`3o000000000000003<000001L00?l0;000000002D0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00`3oool;003o0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0@003o00030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool002D0oooo00<00000
0?ooo`3oool0@P3oool20?l000<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo01d0oooo2`00o`0O0?ooo`030000003oool0oooo0100oooo4P00o`0:
0?ooo`009@3oool00`000000oooo0?ooo`120?ooo`80o`00[P3oool9003o04l0oooo00<00?l00?oo
o`3oool01`3oool002D0oooo00<000000?ooo`3oool0@P3oool20?l00:D0oooo2@00o`1R0?ooo`00
9@3oool00`000000oooo0?ooo`120?ooo`80o`00WP3oool7003o06/0oooo000U0?ooo`800000@`3o
ool20?l009L0oooo1`00o`1b0?ooo`009@3oool00`000000oooo0?ooo`120?ooo`80o`00T@3oool6
003o07T0oooo000U0?ooo`030000003oool0oooo0480oooo0P3o002:0?ooo`L00?l0I@3ooolA0?l0
00T0oooo000U0?ooo`030000003oool0oooo0480oooo0P3o00250?ooo`D00?l0D@3ooolK0?l001X0
oooo000U0?ooo`030000003oool0oooo0480oooo0P3o00210?ooo`@00?l0?`3ooolG0?l003D0oooo
000U0?ooo`030000003oool0oooo0480oooo0P3o001m0?ooo`@00?l0;`3ooolD0?l004`0oooo000U
0?ooo`800000@`3oool00`3o0000oooo0?l0001g0?ooo`D00?l08@3ooolB0?l00600oooo000U0?oo
o`030000003oool0oooo0480oooo00<0o`000?ooo`3o0000L`3oool4003o01L0oooo3`3o001b0?oo
o`009@3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0o`000700oooo0`00o`0=0?ooo`h0
o`00P@3oool002D0oooo00<000000?ooo`3oool0@P3oool00`3o0000oooo0?l0001/0?ooo`@00?l0
0`3oool=0?l008l0oooo000U0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3o0000J03o
ool20?l000800?l01`3o002L0?ooo`009@3oool00`000000oooo0?ooo`110?ooo`050?l0003oool0
oooo0?ooo`3o0000F`3oool;0?l000<00?l0Y@3oool002D0oooo00<000000?ooo`3oool0@@3oool0
1@3o0000oooo0?ooo`3oool0o`0005<0oooo203o00070?ooo`@00?l0Z03oool002D0oooo0P000012
0?ooo`050?l0003oool0oooo0?ooo`3o0000A`3oool<0?l000d0oooo0P00o`2/0?ooo`009@3oool0
0`000000oooo0?ooo`110?ooo`050?l0003oool0oooo0?ooo`3o0000@@3oool60?l001H0oooo0`00
o`2^0?ooo`009@3oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0=@3oool90?l001X0oooo0P00o`2a0?ooo`009@3oool00`000000oooo0?ooo`110?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0;03oool90?l00240oooo0P00o`2c0?oo
o`009@3oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0903oool70?l002P0oooo0P00o`2e0?ooo`009@3oool00`000000oooo0?ooo`110?ooo`030?l0
003oool0oooo00<0oooo0P3o000N0?ooo`L0o`00;03oool3003o0;L0oooo000U0?ooo`800000@P3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0180oooo2@3o000b0?ooo`03003o003o
ool0oooo0;P0oooo000U0?ooo`030000003oool0oooo0440oooo00<0o`000?ooo`3oool01P3oool3
0?l000<0oooo00<0o`000?ooo`3oool00`3oool80?l003X0oooo00<00?l00?ooo`3oool0^@3oool0
02D0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`090?ooo`T0o`00@03oool2003o
0;`0oooo00000`3oool0000000000003000000030?ooo`000000oooo0080oooo00<000000?ooo`00
0000100000020?ooo`8000003`3oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo0500
oooo0P00o`2n0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0@@3oool00`3o0000oooo0?ooo`1?0?ooo`03003o003oool0oooo0;h0oooo00030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo04d0
oooo0P00o`310?ooo`000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo0`0000110?ooo`03
0?l0003oool0oooo04/0oooo0P00o`330?ooo`000`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000h0oooo00<00000
0?ooo`3oool0@@3oool00`3o0000oooo0?ooo`1:0?ooo`03003o003oool0oooo0<<0oooo00020?oo
o`8000002P3oool2000000@0oooo0P0000080?ooo`<00000103oool00`000000oooo0?ooo`110?oo
o`030?l0003oool0oooo04T0oooo00<00?l00?ooo`3oool0a03oool001h0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`110?ooo`030?l0003oool0oooo04P0oooo00<00?l00?ooo`3o
ool0a@3oool001T0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
@@3oool00`3o0000oooo0?ooo`170?ooo`03003o003oool0oooo0<H0oooo000N0?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool0@@3oool00`3o0000oooo0?ooo`150?ooo`800?l0b@3o
ool001h0oooo0`0000040?ooo`800000@@3oool00`3o0000oooo0?ooo`140?ooo`800?l0b`3oool0
02D0oooo00<000000?ooo`3oool0@03oool00`3o0000oooo0?ooo`130?ooo`03003o003oool0oooo
0</0oooo000U0?ooo`030000003oool0oooo03D0oooo00<0o`000?ooo`3oool0203oool00`3o0000
oooo0?ooo`120?ooo`03003o003oool0oooo0<`0oooo000U0?ooo`030000003oool0oooo0340oooo
203o00070?ooo`030?l0003oool0oooo0440oooo00<00?l00?ooo`3oool0c@3oool002D0oooo00<0
00000?ooo`3oool0:`3oool60?l000P0oooo0`3o00040?ooo`030?l0003oool0oooo0440oooo00<0
0?l00?ooo`3oool0c@3oool002D0oooo00<000000?ooo`3oool0:@3oool20?l00100oooo0`3o0002
0?ooo`030?l0003oool0oooo0400oooo00<00?l00?ooo`3oool0cP3oool002D0oooo00<000000?oo
o`3oool0903oool50?l001D0oooo0`3o00110?ooo`03003o003oool0oooo0<l0oooo000U0?ooo`80
00008@3oool40?l001X0oooo0P3o00110?ooo`03003o003oool0oooo0=00oooo000U0?ooo`030000
003oool0oooo01d0oooo0`3o001O0?ooo`800?l0d`3oool002D0oooo00<000000?ooo`3oool06`3o
ool20?l00640oooo00<00?l00?ooo`3oool0d`3oool002D0oooo00<000000?ooo`3oool06@3oool2
0?l00680oooo00<00?l00?ooo`3oool0e03oool002D0oooo00<000000?ooo`3oool05@3oool40?l0
06@0oooo00<00?l00?ooo`3oool0e03oool002D0oooo00<000000?ooo`3oool04P3oool30?l006L0
oooo00<00?l00?ooo`3oool0e@3oool002D0oooo0P00000A0?ooo`80o`00J@3oool00`00o`00oooo
0?ooo`3F0?ooo`009@3oool00`000000oooo0?ooo`0>0?ooo`80o`00J`3oool00`00o`00oooo0?oo
o`3F0?ooo`009@3oool00`000000oooo0?ooo`0<0?ooo`80o`00K03oool00`00o`00oooo0?ooo`3G
0?ooo`009@3oool00`000000oooo0?ooo`090?ooo`<0o`00K@3oool00`00o`00oooo0?ooo`3H0?oo
o`009@3oool00`000000oooo0?ooo`070?ooo`80o`00L03oool00`00o`00oooo0?ooo`3H0?ooo`00
9@3oool00`000000oooo0?ooo`050?ooo`80o`00L@3oool00`00o`00oooo0?ooo`3I0?ooo`009@3o
ool2000000@0oooo0P3o001b0?ooo`03003o003oool0oooo0=X0oooo000U0?ooo`040000003oool0
oooo0?ooo`80o`00M03oool00`00o`00oooo0?ooo`3J0?ooo`009@3oool010000000oooo0?ooo`3o
001e0?ooo`03003o003oool0oooo0=/0oooo00000`3oool000000000000200000080oooo00H00000
0?ooo`3oool0oooo0000003oool500000080oooo0P00000?0?ooo`030000003o0000o`0007D0oooo
00<00?l00?ooo`3oool0g03oool000030?ooo`000000oooo00D0oooo00<000000?ooo`000000103o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`3o0000oooo
0?ooo`1e0?ooo`03003o003oool0oooo0=`0oooo00020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`1d0?ooo`03003o003oool0oooo0=d0oooo00030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0303oool3000007<0oooo00<00?l00?ooo`3oool0gP3oool000050?ooo`00
0000oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0L`3oool00`00
o`00oooo0?ooo`3N0?ooo`000P3oool2000000X0oooo0P0000040?ooo`800000203oool3000000@0
oooo00<000000?ooo`3oool0LP3oool00`00o`00oooo0?ooo`3O0?ooo`007P3oool00`000000oooo
000000040?ooo`030000003oool0oooo0780oooo00<00?l00?ooo`3oool0g`3oool001T0oooo0`00
00030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L@3oool00`00o`00oooo0?oo
o`3P0?ooo`007P3oool00`000000oooo000000040?ooo`030000003oool0oooo0740oooo00<00?l0
0?ooo`3oool0h03oool001h0oooo0`0000040?ooo`030000003oool0oooo0700oooo00<00?l00?oo
o`3oool0h@3oool002D0oooo0P00001a0?ooo`03003o003oool0oooo0>40oooo000U0?ooo`030000
003oool0oooo06l0oooo00<00?l00?ooo`3oool0hP3oool002D0oooo00<000000?ooo`3oool0K`3o
ool00`00o`00oooo0?ooo`3R0?ooo`009@3oool00`000000oooo0?ooo`1_0?ooo`03003o003oool0
oooo0>80oooo000U0?ooo`030000003oool0oooo06h0oooo00<00?l00?ooo`3oool0h`3oool002D0
oooo00<000000?ooo`3oool0KP3oool00`00o`00oooo0?ooo`3S0?ooo`009@3oool2000006h0oooo
00<00?l00?ooo`3oool0i03oool002D0oooo00<000000?ooo`3oool0K@3oool00`00o`00oooo0?oo
o`3T0?ooo`009@3oool00`000000oooo0?ooo`1/0?ooo`03003o003oool0oooo0>D0oooo000U0?oo
o`030000003oool0oooo06`0oooo00<00?l00?ooo`3oool0i@3oool002D0oooo00<000000?ooo`3o
ool0J`3oool00`00o`00oooo0?ooo`3V0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`03003o
003oool0oooo0>H0oooo000U0?ooo`800000J`3oool00`00o`00oooo0?ooo`3W0?ooo`009@3oool0
0`000000oooo0?ooo`1Z0?ooo`03003o003oool0oooo0>L0oooo000U0?ooo`030000003oool0oooo
06T0oooo00<00?l00?ooo`3oool0j03oool002D0oooo00<000000?ooo`3oool0J@3oool00`00o`00
oooo0?ooo`3X0?ooo`009@3oool00`000000oooo0?ooo`1Y0?ooo`03003o003oool0oooo0>P0oooo
000U0?ooo`030000003oool0oooo06P0oooo00<00?l00?ooo`3oool0j@3oool002D0oooo0P00001Y
0?ooo`03003o003oool0oooo0>T0oooo000U0?ooo`030000003oool0oooo06P0oooo00<00?l00?oo
o`3oool0j@3oool002D0oooo00<000000?ooo`3oool0I`3oool00`00o`00oooo0?ooo`3Z0?ooo`00
0P3oool2000000<0oooo00H000000?ooo`3oool0oooo0000003oool500000080oooo0P00000?0?oo
o`030000003oool0oooo06L0oooo00<00?l00?ooo`3oool0jP3oool000050?ooo`000000oooo0?oo
o`0000000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06L0oooo00<00?l00?ooo`3oool0jP3oool0
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06L0oooo00<00?l0
0?ooo`3oool0jP3oool000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
IP3oool00`00o`00oooo0?ooo`3[0?ooo`0000D0oooo0000003oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0303oool3000006H0oooo00<00?l00?ooo`3oool0j`3oool00080oooo0P00000:0?ooo`80
0000103oool2000000l0oooo00<000000?ooo`3oool0IP3oool00`00o`00oooo0?ooo`3[0?ooo`00
7P3oool3000000@0oooo00<000000?ooo`3oool0IP3oool00`00o`00oooo0?ooo`3[0?ooo`007P3o
ool00`000000oooo000000040?ooo`030000003oool0oooo06D0oooo00<00?l00?ooo`3oool0k03o
ool001T0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0I@3oool0
0`00o`00oooo0?ooo`3/0?ooo`007P3oool00`000000oooo000000040?ooo`030000003oool0oooo
06D0oooo00<00?l00?ooo`3oool0k03oool001h0oooo0`0000040?ooo`800000IP3oool00`00o`00
oooo0?ooo`3/0?ooo`009@3oool00`000000oooo0?ooo`1T0?ooo`03003o003oool0oooo0>d0oooo
000U0?ooo`030000003oool0oooo06@0oooo00<00?l00?ooo`3oool0k@3oool002D0oooo00<00000
0?ooo`3oool0I03oool00`00o`00oooo0?ooo`3]0?ooo`009@3oool00`000000oooo0?ooo`1S0?oo
o`03003o003oool0oooo0>h0oooo000U0?ooo`030000003oool0oooo06<0oooo00<00?l00?ooo`3o
ool0kP3oool002D0oooo0P00001T0?ooo`03003o003oool0oooo0>h0oooo000U0?ooo`030000003o
ool0oooo0680oooo00<00?l00?ooo`3oool0k`3oool002D0oooo00<000000?ooo`3oool0HP3oool0
0`00o`00oooo0?ooo`3_0?ooo`009@3oool00`00o`00oooo0?ooo`1R0?ooo`03003o003oool0oooo
0>l0oooo000U0?ooo`0300000000o`00oooo0640oooo00<00?l00?ooo`3oool0l03oool002D0oooo
00<000000?ooo`00o`00H@3oool00`00o`00oooo0?ooo`3`0?ooo`009@3oool2000000030?ooo`00
o`00oooo05l0oooo00<00?l00?ooo`3oool0l03oool002D0oooo00D000000?ooo`3oool0oooo003o
001O0?ooo`03003o003oool0oooo0?00oooo000U0?ooo`030000003oool0oooo0080oooo00<00?l0
0?ooo`3oool0F`3oool00`00o`00oooo0?ooo`3a0?ooo`009@3oool00`000000oooo0?ooo`030?oo
o`03003o003oool0oooo05X0oooo00<00?l00?ooo`3oool0l@3oool002D0oooo00<000000?ooo`3o
ool0103oool00`00o`00oooo0?ooo`1I0?ooo`03003o003oool0oooo0?40oooo000U0?ooo`030000
003oool0oooo00D0oooo00<00?l00?ooo`3oool0F03oool00`00o`00oooo0?ooo`3a0?ooo`009@3o
ool00`000000oooo0?ooo`060?ooo`03003o003oool0oooo05L0oooo00<00?l00?ooo`3oool0l@3o
ool002D0oooo0P0000080?ooo`03003o003oool0oooo05H0oooo00<00?l00?ooo`3oool0l@3oool0
02D0oooo00<000000?ooo`3oool01`3oool00`00o`00oooo0?ooo`1E0?ooo`03003o003oool0oooo
0?80oooo000U0?ooo`030000003oool0oooo00P0oooo00<00?l00?ooo`3oool0E03oool00`00o`00
oooo0?ooo`3b0?ooo`000`3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`000000
100000020?ooo`8000003`3oool00`000000oooo0?ooo`090?ooo`03003o003oool0oooo05<0oooo
00<00?l00?ooo`3oool0lP3oool000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02@3oool00`00o`00oooo0?ooo`1C0?ooo`03003o003oool0oooo0?80oooo00000`3oool0
000000000003000000<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`03003o003oool0oooo
0580oooo00<00?l00?ooo`3oool0lP3oool000050?ooo`000000oooo0?ooo`0000000`3oool00`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<
0?ooo`<000002`3oool00`00o`00oooo0?ooo`1A0?ooo`03003o003oool0oooo0?80oooo00020?oo
o`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
0?l00?ooo`3oool0C`3oool00`00o`00oooo0?ooo`3c0?ooo`000`3oool2000000T0oooo0P000004
0?ooo`800000203oool3000000@0oooo00<000000?ooo`3oool0303oool00`00o`00oooo0?ooo`1?
0?ooo`03003o003oool0oooo0?<0oooo000N0?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool03@3oool00`00o`00oooo0?ooo`1>0?ooo`03003o003oool0oooo0?<0oooo000I0?ooo`<0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<00?l00?ooo`3o
ool0C@3oool00`00o`00oooo0?ooo`3c0?ooo`007P3oool00`000000oooo000000040?ooo`030000
003oool0oooo00h0oooo00<00?l00?ooo`3oool0C@3oool00`00o`00oooo0?ooo`3c0?ooo`007P3o
ool3000000@0oooo0P00000@0?ooo`03003o003oool0oooo04`0oooo00<00?l00?ooo`3oool0l`3o
ool002D0oooo00<000000?ooo`3oool0403oool00`00o`00oooo0?ooo`1:0?ooo`03003o003oool0
oooo0?@0oooo000U0?ooo`030000003oool0oooo0100oooo00<00?l00?ooo`3oool0BP3oool00`00
o`00oooo0?ooo`3d0?ooo`009@3oool00`000000oooo0?ooo`0A0?ooo`03003o003oool0oooo04T0
oooo00<00?l00?ooo`3oool0m03oool002D0oooo00<000000?ooo`3oool04@3oool00`00o`00oooo
0?ooo`190?ooo`03003o003oool0oooo0?@0oooo000U0?ooo`030000003oool0oooo0140oooo00<0
0?l00?ooo`3oool0B@3oool00`00o`00oooo0?ooo`3d0?ooo`009@3oool00`000000oooo0?ooo`0B
0?ooo`03003o003oool0oooo04P0oooo00<00?l00?ooo`3oool0m03oool002D0oooo0P00000C0?oo
o`03003o003oool0oooo04L0oooo00<00?l00?ooo`3oool0m@3oool002D0oooo00<000000?ooo`3o
ool04`3oool00`00o`00oooo0?ooo`160?ooo`03003o003oool0oooo0?D0oooo000U0?ooo`030000
003oool0oooo01<0oooo00<00?l00?ooo`3oool0AP3oool00`00o`00oooo0?ooo`3e0?ooo`009@3o
ool00`000000oooo0?ooo`0D0?ooo`03003o003oool0oooo04D0oooo00<00?l00?ooo`3oool0m@3o
ool002D0oooo00<000000?ooo`3oool0503oool00`00o`00oooo0?ooo`150?ooo`03003o003oool0
oooo0?D0oooo000U0?ooo`030000003oool0oooo01D0oooo00<00?l00?ooo`3oool0A03oool00`00
o`00oooo0?ooo`3e0?ooo`009@3oool2000001H0oooo00<00?l00?ooo`3oool0A03oool00`00o`00
oooo0?ooo`3e0?ooo`009@3oool00`000000oooo0?ooo`0F0?ooo`03003o003oool0oooo0480oooo
00<00?l00?ooo`3oool0mP3oool002D0oooo00<000000?ooo`3oool05P3oool00`00o`00oooo0?oo
o`120?ooo`03003o003oool0oooo0?H0oooo000U0?ooo`030000003oool0oooo01L0oooo00<00?l0
0?ooo`3oool0@@3oool00`00o`00oooo0?ooo`3f0?ooo`009@3oool00`000000oooo0?ooo`0G0?oo
o`03003o003oool0oooo0440oooo00<00?l00?ooo`3oool0mP3oool002D0oooo00<000000?ooo`3o
ool0603oool00`00o`00oooo0?ooo`100?ooo`03003o003oool0oooo0?H0oooo000U0?ooo`800000
6@3oool00`00o`00oooo0?ooo`100?ooo`03003o003oool0oooo0?H0oooo000U0?ooo`030000003o
ool0oooo01P0oooo00<00?l00?ooo`3oool0?`3oool00`00o`00oooo0?ooo`3g0?ooo`009@3oool0
0`000000oooo0?ooo`0I0?ooo`03003o003oool0oooo03h0oooo00<00?l00?ooo`3oool0m`3oool0
0080oooo0P0000030?ooo`060000003oool0oooo0?ooo`000000oooo1@0000020?ooo`8000003`3o
ool00`000000oooo0?ooo`0I0?ooo`03003o003oool0oooo03h0oooo00<00?l00?ooo`3oool0m`3o
ool000050?ooo`000000oooo0?ooo`0000000`3oool00`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01T0oooo
00<00?l00?ooo`3oool0?P3oool00`00o`00oooo0?ooo`3g0?ooo`00103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`00o`00oooo0?ooo`0m0?ooo`03003o
003oool0oooo0?L0oooo00020?ooo`800000103oool00`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`<000006P3oool00`00o`00oooo
0?ooo`0m0?ooo`03003o003oool0oooo0?L0oooo00020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<00?l00?ooo`3oool0?03oool00`00o`00
oooo0?ooo`3h0?ooo`000P3oool3000000T0oooo0P0000040?ooo`800000203oool3000000@0oooo
00<000000?ooo`3oool06`3oool00`00o`00oooo0?ooo`0k0?ooo`03003o003oool0oooo0?P0oooo
000N0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool06`3oool00`00o`00oooo0?oo
o`0k0?ooo`03003o003oool0oooo0?P0oooo000I0?ooo`<000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo01/0oooo00<00?l00?ooo`3oool0>`3oool00`00o`00oooo0?ooo`3h
0?ooo`007P3oool00`000000oooo000000040?ooo`030000003oool0oooo01/0oooo00<00?l00?oo
o`3oool0>`3oool00`00o`00oooo0?ooo`3h0?ooo`007P3oool3000000@0oooo00<000000?ooo`3o
ool0703oool00`00o`00oooo0?ooo`0i0?ooo`03003o003oool0oooo0?T0oooo000U0?ooo`800000
7@3oool00`00o`00oooo0?ooo`0i0?ooo`03003o003oool0oooo0?T0oooo000U0?ooo`030000003o
ool0oooo01`0oooo00<00?l00?ooo`3oool0>@3oool00`00o`00oooo0?ooo`3i0?ooo`009@3oool0
0`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo03P0oooo00<00?l00?ooo`3oool0n@3oool0
02D0oooo00<000000?ooo`3oool07@3oool00`00o`00oooo0?ooo`0h0?ooo`03003o003oool0oooo
0?T0oooo000U0?ooo`030000003oool0oooo01d0oooo00<00?l00?ooo`3oool0>03oool00`00o`00
oooo0?ooo`3i0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`03003o003oool0oooo03P0oooo
00<00?l00?ooo`3oool0n@3oool002D0oooo0P00000O0?ooo`03003o003oool0oooo03L0oooo00<0
0?l00?ooo`3oool0n@3oool002D0oooo00<000000?ooo`3oool07P3oool00`00o`00oooo0?ooo`0f
0?ooo`03003o003oool0oooo0?X0oooo000U0?ooo`030000003oool0oooo01h0oooo00<00?l00?oo
o`3oool0=P3oool00`00o`00oooo0?ooo`3j0?ooo`009@3oool00`000000oooo0?ooo`0N0?ooo`03
003o003oool0oooo03H0oooo00<00?l00?ooo`3oool0nP3oool002D0oooo00<000000?ooo`3oool0
7`3oool00`00o`00oooo0?ooo`0e0?ooo`03003o003oool0oooo0?X0oooo000U0?ooo`030000003o
ool0oooo01l0oooo00<00?l00?ooo`3oool0=@3oool00`00o`00oooo0?ooo`3j0?ooo`009@3oool2
00000200oooo00<00?l00?ooo`3oool0=@3oool00`00o`00oooo0?ooo`3j0?ooo`009@3oool00`00
0000oooo0?ooo`0P0?ooo`03003o003oool0oooo03@0oooo00<00?l00?ooo`3oool0nP3oool002D0
oooo00<000000?ooo`3oool0803oool00`00o`00oooo0?ooo`0d0?ooo`03003o003oool0oooo0?X0
oooo000U0?ooo`030000003oool0oooo0200oooo00<00?l00?ooo`3oool0=03oool00`00o`00oooo
0?ooo`3j0?ooo`009@3oool00`000000oooo0?ooo`0Q0?ooo`03003o003oool0oooo03<0oooo00<0
0?l00?ooo`3oool0nP3oool002D0oooo00<000000?ooo`3oool08@3oool00`00o`00oooo0?ooo`0b
0?ooo`03003o003oool0oooo0?/0oooo000U0?ooo`8000008P3oool00`00o`00oooo0?ooo`0b0?oo
o`03003o003oool0oooo0?/0oooo000U0?ooo`030000003oool0oooo0240oooo00<00?l00?ooo`3o
ool0<P3oool00`00o`00oooo0?ooo`3k0?ooo`009@3oool00`000000oooo0?ooo`0R0?ooo`03003o
003oool0oooo0340oooo00<00?l00?ooo`3oool0n`3oool000040?ooo`0000000000000000<0oooo
00H000000?ooo`3oool0oooo0000003oool500000080oooo0P00000?0?ooo`030000003oool0oooo
0280oooo00<00?l00?ooo`3oool0<@3oool00`00o`00oooo0?ooo`3k0?ooo`0000D0oooo0000003o
ool0oooo000000030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08P3oool00`00o`00oooo0?ooo`0a
0?ooo`03003o003oool0oooo0?/0oooo00001@3oool000000?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0R0?ooo`03003o003oool0oooo0340oooo00<00?l00?ooo`3oool0n`3o
ool000040?ooo`0000000000000000@0oooo00<000000?ooo`000000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0R0?ooo`03003o
003oool0oooo0340oooo00<00?l00?ooo`3oool0n`3oool00080oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00`0oooo0`00000S0?ooo`03003o003oool0oooo0300oooo00<00?l00?ooo`3o
ool0n`3oool00080oooo0`0000090?ooo`800000103oool2000000l0oooo00<000000?ooo`3oool0
8`3oool00`00o`00oooo0?ooo`0`0?ooo`03003o003oool0oooo0?/0oooo000N0?ooo`<00000103o
ool00`000000oooo0?ooo`0S0?ooo`03003o003oool0oooo0300oooo00<00?l00?ooo`3oool0n`3o
ool001h0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0S0?ooo`03003o003oool0
oooo02l0oooo00<00?l00?ooo`3oool0o03oool001T0oooo0`0000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool08`3oool00`00o`00oooo0?ooo`0_0?ooo`03003o003oool0oooo
0?`0oooo000N0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool08`3oool00`00o`00
oooo0?ooo`0_0?ooo`03003o003oool0oooo0?`0oooo000N0?ooo`<00000103oool2000002D0oooo
00<00?l00?ooo`3oool0;P3oool00`00o`00oooo0?ooo`3l0?ooo`009@3oool00`000000oooo0?oo
o`0T0?ooo`03003o003oool0oooo02h0oooo00<00?l00?ooo`3oool0o03oool002D0oooo00<00000
0?ooo`3oool0903oool00`00o`00oooo0?ooo`0^0?ooo`03003o003oool0oooo0?`0oooo000U0?oo
o`030000003oool0oooo02@0oooo00<00?l00?ooo`3oool0;P3oool00`00o`00oooo0?ooo`3l0?oo
o`009@3oool00`000000oooo0?ooo`0T0?ooo`03003o003oool0oooo02h0oooo00<00?l00?ooo`3o
ool0o03oool002D0oooo00<000000?ooo`3oool0903oool00`00o`00oooo0?ooo`0^0?ooo`03003o
003oool0oooo0?`0oooo000U0?ooo`8000009P3oool00`00o`00oooo0?ooo`0]0?ooo`03003o003o
ool0oooo0?`0oooo000U0?ooo`030000003oool0oooo02D0oooo00<00?l00?ooo`3oool0;@3oool0
0`00o`00oooo0?ooo`3l0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`03003o003oool0oooo
02d0oooo00<00?l00?ooo`3oool0o03oool002D0oooo00<000000?ooo`3oool09@3oool00`00o`00
oooo0?ooo`0]0?ooo`03003o003oool0oooo0?`0oooo000U0?ooo`030000003oool0oooo02D0oooo
00<00?l00?ooo`3oool0;03oool00`00o`00oooo0?ooo`3m0?ooo`009@3oool00`000000oooo0?oo
o`0U0?ooo`03003o003oool0oooo02`0oooo00<00?l00?ooo`3oool0o@3oool002D0oooo0P00000V
0?ooo`03003o003oool0oooo02`0oooo00<00?l00?ooo`3oool0o@3oool002D0oooo00<000000?oo
o`3oool09P3oool00`00o`00oooo0?ooo`0[0?ooo`03003o003oool0oooo0?d0oooo000U0?ooo`03
0000003oool0oooo02H0oooo00<00?l00?ooo`3oool0:`3oool00`00o`00oooo0?ooo`3m0?ooo`00
9@3oool00`000000oooo0?ooo`0V0?ooo`03003o003oool0oooo02/0oooo00<00?l00?ooo`3oool0
o@3oool002D0oooo00<000000?ooo`3oool09P3oool00`00o`00oooo0?ooo`0[0?ooo`03003o003o
ool0oooo0?d0oooo000U0?ooo`030000003oool0oooo02H0oooo00<00?l00?ooo`3oool0:`3oool0
0`00o`00oooo0?ooo`3m0?ooo`00o`3ooomm0?ooo`00o`3ooomm0?ooo`00o`3ooomm0?ooo`00o`3o
oomm0?ooo`00\
\>"],
  ImageRangeCache->{{{90.625, 393.625}, {482.25, 295.5}} -> {-711.295, \
1.12339*^-07, 270.231, 3.19633*^-10}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Amplitude does not go to infinity, even under resonance conditions! This is \
related with the internal losses of the HP power supply. Setting the internal \
resistance Ri to zero would cause a constant voltage condition, with infinite \
current. See below and see above.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Absolute Amplitude Plots", "Subsection"],

Cell[CellGroupData[{

Cell["Low mechanical impedance", "Subsubsection"],

Cell["Zero impedance (red):", "Text"],

Cell[BoxData[
    \(\(vat1 = \(\(amp[a1, a2] /. valueruleaHPlc\) /. 
              w \[Rule] 2\ \[Pi]\ f*1000\) /. ZC \[Rule] 0 // N;\)\)], "Input"],

Cell["Resistive impedance (green):", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(vat2 = \(\(amp[a1, a2] /. valueruleaHPlc\) /. 
              w \[Rule] 2\ \[Pi]\ f*1000\) /. ZC \[Rule] 15 // 
          N;\)\)], "Input"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(vat2\)\" is similar to \
existing symbols \!\({val2, vas2}\)."\)], "Message"]
}, Open  ]],

Cell["Resistive impedance + inertia term (blue):", "Text"],

Cell[BoxData[
    \(\(\(vat3 = \(\(amp[a1, a2] /. valueruleaHPlc\) /. 
              ZC \[Rule] 0 + \[ImaginaryI]\ w\ *5*10\^\(-4\)\) /. 
            w \[Rule] 2\ \[Pi]\ f*1000 // 
          N;\)\(\ \ \ \ \ \ \ \ \ \ \)\( (*\ \ \ \ ZC = 
        15 + \[ImaginaryI]\ 30\ \ \ \ *) \)\)\)], "Input"],

Cell["Resistive impedance + capacitive term (pink):", "Text"],

Cell[BoxData[
    \(\(\(vat4 = \(\(amp[a1, a2] /. valueruleaHPlc\) /. 
              ZC \[Rule] \(-\(\(\(\[ImaginaryI]\)\(\ \)\)\/\(\(2\)\(*\)\(10\^\
\(-8\)\) \(w\)\(\ \)\)\)\)\) /. w \[Rule] 2\ \[Pi]\ f*1000\  // 
          N;\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\( (*\ \ \ \ ZC = 
        15 - \[ImaginaryI]\ 30\ \ \ \ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl1 = 
      Plot[{10\^6\ vat1, 10\^6\ vat2, 10\^6\ vat3, 10\^6\ vat4}, {f, 40, 60}, 
        PlotPoints \[Rule] 350, PlotRange \[Rule] \ {0, 0.8}, 
        PlotStyle \[Rule] {{Thickness[ .003], 
              RGBColor[1, 0, 0]}, {Thickness[ .002], 
              RGBColor[0, 1, 0]}, {Thickness[ .002], 
              RGBColor[0, 0, 1]}, {Thickness[ .002], 
              RGBColor[1, 0, 1]}, {Thickness[ .002], 
              RGBColor[0.2, 0.8, 0]}, {Thickness[ .002], 
              RGBColor[0, 1, 0]}, {Thickness[ .002], RGBColor[0, 0.6, 0.4]}}, 
        TextStyle \[Rule] {FontFamily \[Rule] "\<Helvetica\>", 
            FontSize \[Rule] 10}, 
        GridLines \[Rule] {Automatic, None}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.88095 0.047619 0 0.772542 [
[.2619 -0.0125 -7.5 -13 ]
[.2619 -0.0125 7.5 0 ]
[.5 -0.0125 -7.5 -13 ]
[.5 -0.0125 7.5 0 ]
[.7381 -0.0125 -7.5 -13 ]
[.7381 -0.0125 7.5 0 ]
[.97619 -0.0125 -7.5 -13 ]
[.97619 -0.0125 7.5 0 ]
[.01131 .07725 -17.75 -6.5 ]
[.01131 .07725 0 6.5 ]
[.01131 .15451 -17.75 -6.5 ]
[.01131 .15451 0 6.5 ]
[.01131 .23176 -17.75 -6.5 ]
[.01131 .23176 0 6.5 ]
[.01131 .30902 -17.75 -6.5 ]
[.01131 .30902 0 6.5 ]
[.01131 .38627 -17.75 -6.5 ]
[.01131 .38627 0 6.5 ]
[.01131 .46353 -17.75 -6.5 ]
[.01131 .46353 0 6.5 ]
[.01131 .54078 -17.75 -6.5 ]
[.01131 .54078 0 6.5 ]
[.01131 .61803 -17.75 -6.5 ]
[.01131 .61803 0 6.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 g
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(55) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
gsave
.01131 .07725 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
1.000 setlinewidth
grestore
.02381 .15451 m
.03006 .15451 L
s
gsave
.01131 .15451 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .23176 m
.03006 .23176 L
s
gsave
.01131 .23176 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
1.000 setlinewidth
grestore
.02381 .30902 m
.03006 .30902 L
s
gsave
.01131 .30902 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .38627 m
.03006 .38627 L
s
gsave
.01131 .38627 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .46353 m
.03006 .46353 L
s
gsave
.01131 .46353 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .54078 m
.03006 .54078 L
s
gsave
.01131 .54078 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
.02381 .61803 m
.03006 .61803 L
s
gsave
.01131 .61803 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.003 w
.02381 .03079 m
.02647 .03081 L
.02936 .03084 L
.03209 .03087 L
.0347 .0309 L
.03749 .03092 L
.04017 .03095 L
.04302 .03098 L
.04577 .03101 L
.04841 .03104 L
.05122 .03107 L
.05392 .0311 L
.05653 .03113 L
.0593 .03116 L
.06196 .0312 L
.0648 .03123 L
.06753 .03126 L
.07015 .03129 L
.07295 .03133 L
.07564 .03136 L
.0785 .0314 L
.08125 .03143 L
.08391 .03147 L
.08673 .03151 L
.08944 .03154 L
.09205 .03158 L
.09483 .03162 L
.09751 .03165 L
.10035 .03169 L
.10309 .03173 L
.10573 .03177 L
.10853 .03181 L
.11123 .03185 L
.11383 .03189 L
.11659 .03193 L
.11925 .03197 L
.12208 .03202 L
.12481 .03206 L
.12743 .0321 L
.13022 .03215 L
.1329 .03219 L
.13576 .03224 L
.13851 .03229 L
.14115 .03233 L
.14397 .03238 L
.14668 .03243 L
.14928 .03247 L
.15205 .03252 L
.15472 .03257 L
.15756 .03262 L
Mistroke
.1603 .03267 L
.16293 .03272 L
.16573 .03278 L
.16842 .03283 L
.17128 .03288 L
.17404 .03294 L
.1767 .03299 L
.17952 .03305 L
.18224 .0331 L
.18485 .03316 L
.18764 .03322 L
.19032 .03327 L
.19316 .03333 L
.19591 .03339 L
.19855 .03345 L
.20136 .03351 L
.20406 .03357 L
.20666 .03363 L
.20943 .03369 L
.21209 .03376 L
.21492 .03382 L
.21765 .03389 L
.22028 .03395 L
.22307 .03402 L
.22576 .03408 L
.22862 .03416 L
.23137 .03422 L
.23402 .03429 L
.23684 .03436 L
.23955 .03443 L
.24216 .0345 L
.24494 .03458 L
.24761 .03465 L
.25045 .03473 L
.25319 .0348 L
.25582 .03487 L
.25862 .03495 L
.26132 .03503 L
.26392 .03511 L
.26668 .03519 L
.26934 .03526 L
.27216 .03535 L
.27489 .03543 L
.27751 .03551 L
.28029 .0356 L
.28298 .03568 L
.28583 .03577 L
.28857 .03586 L
.29122 .03594 L
.29403 .03604 L
Mistroke
.29674 .03612 L
.29934 .03621 L
.30211 .03631 L
.30478 .0364 L
.30761 .0365 L
.31035 .03659 L
.31297 .03668 L
.31577 .03678 L
.31846 .03688 L
.32132 .03699 L
.32408 .03709 L
.32673 .03719 L
.32955 .0373 L
.33227 .0374 L
.33488 .0375 L
.33767 .03761 L
.34034 .03772 L
.34319 .03783 L
.34593 .03795 L
.34857 .03806 L
.35137 .03817 L
.35407 .03829 L
.35667 .0384 L
.35944 .03852 L
.3621 .03864 L
.36493 .03876 L
.36766 .03888 L
.37028 .039 L
.37307 .03913 L
.37576 .03926 L
.37861 .03939 L
.38136 .03952 L
.38401 .03965 L
.38682 .03979 L
.38953 .03992 L
.39214 .04006 L
.39492 .0402 L
.39759 .04033 L
.40043 .04048 L
.40316 .04063 L
.40579 .04077 L
.40859 .04092 L
.41129 .04107 L
.41415 .04123 L
.41692 .04138 L
.41957 .04153 L
.4224 .0417 L
.42512 .04186 L
.42773 .04201 L
.43052 .04218 L
Mistroke
.4332 .04234 L
.43605 .04252 L
.43879 .04269 L
.44143 .04286 L
.44424 .04304 L
.44695 .04321 L
.44955 .04338 L
.45232 .04357 L
.45498 .04375 L
.45782 .04394 L
.46055 .04413 L
.46317 .04432 L
.46597 .04452 L
.46866 .04471 L
.47152 .04493 L
.47427 .04513 L
.47692 .04533 L
.47974 .04555 L
.48245 .04576 L
.48506 .04597 L
.48784 .04619 L
.49052 .04641 L
.49336 .04664 L
.4961 .04687 L
.49874 .04709 L
.50154 .04733 L
.50424 .04757 L
.50683 .0478 L
.5096 .04805 L
.51226 .04829 L
.51509 .04855 L
.51781 .04881 L
.52043 .04906 L
.52322 .04933 L
.5259 .0496 L
.52876 .04988 L
.5315 .05016 L
.53415 .05044 L
.53696 .05073 L
.53967 .05102 L
.54228 .0513 L
.54505 .05161 L
.54772 .05191 L
.55056 .05223 L
.55329 .05255 L
.55592 .05286 L
.55872 .05319 L
.56141 .05352 L
.56427 .05388 L
.56703 .05422 L
Mistroke
.56968 .05456 L
.57251 .05493 L
.57522 .05529 L
.57784 .05565 L
.58062 .05603 L
.5833 .0564 L
.58615 .05681 L
.58889 .05721 L
.59153 .0576 L
.59433 .05802 L
.59704 .05843 L
.59964 .05884 L
.6024 .05928 L
.60507 .05971 L
.6079 .06018 L
.61063 .06064 L
.61325 .06109 L
.61604 .06158 L
.61873 .06206 L
.62159 .06258 L
.62434 .06309 L
.62699 .0636 L
.6298 .06414 L
.63252 .06468 L
.63512 .06521 L
.6379 .06578 L
.64057 .06634 L
.64341 .06696 L
.64615 .06756 L
.64878 .06815 L
.65159 .0688 L
.65428 .06943 L
.65688 .07006 L
.65964 .07073 L
.66229 .0714 L
.66512 .07213 L
.66784 .07285 L
.67046 .07356 L
.67325 .07433 L
.67593 .07509 L
.67878 .07592 L
.68153 .07674 L
.68417 .07754 L
.68698 .07843 L
.68968 .0793 L
.69229 .08016 L
.69506 .0811 L
.69773 .08202 L
.70056 .08304 L
.70329 .08404 L
Mistroke
.70592 .08504 L
.70871 .08612 L
.71141 .0872 L
.71427 .08838 L
.71702 .08955 L
.71967 .09071 L
.72249 .09198 L
.72521 .09325 L
.72782 .0945 L
.7306 .09587 L
.73328 .09724 L
.73612 .09874 L
.73886 .10024 L
.7415 .10173 L
.7443 .10336 L
.74701 .105 L
.7496 .10662 L
.75237 .10841 L
.75503 .1102 L
.75786 .11217 L
.76058 .11415 L
.7632 .11612 L
.76599 .1183 L
.76868 .12049 L
.77153 .12291 L
.77428 .12535 L
.77693 .12779 L
.77974 .1305 L
.78245 .13323 L
.78506 .13597 L
.78783 .13902 L
.79051 .1421 L
.79334 .14554 L
.79608 .14902 L
.79871 .15253 L
.80151 .15647 L
.8042 .16046 L
.80707 .16495 L
.80983 .16952 L
.81248 .17417 L
.81531 .17942 L
.81803 .18478 L
.82064 .19026 L
.82342 .19646 L
.8261 .20283 L
.82895 .21007 L
.8317 .21755 L
.83434 .22525 L
.83715 .23407 L
.83985 .24321 L
Mistroke
.84245 .25268 L
.84522 .26357 L
.84788 .27493 L
.85072 .28806 L
.85345 .30185 L
.85607 .31629 L
.85886 .33308 L
.86155 .35077 L
.86441 .37138 L
.86716 .39318 L
.86981 .4161 L
.87263 .44266 L
.87535 .47039 L
.87796 .49893 L
.88073 .53096 L
.88341 .5627 L
.88625 .59615 L
Mfstroke
.88625 .59615 m
.88824 .61803 L
s
.9081 .61803 m
.91065 .58869 L
.91335 .55566 L
.91595 .52375 L
.91871 .49079 L
.92138 .46075 L
.92421 .43103 L
.92693 .40468 L
.92956 .38141 L
.93235 .35877 L
.93503 .3389 L
.93789 .31966 L
.94064 .30278 L
.94329 .28792 L
.9461 .27344 L
.94882 .26065 L
.95142 .24932 L
.9542 .23819 L
.95687 .22828 L
.95971 .21854 L
.96245 .20985 L
.96508 .20206 L
.96788 .19434 L
.97058 .1874 L
.97344 .18051 L
.97619 .17432 L
s
0 1 0 r
.002 w
.02381 .03076 m
.02647 .03078 L
.02936 .03081 L
.03209 .03084 L
.0347 .03087 L
.03749 .03089 L
.04017 .03092 L
.04302 .03095 L
.04577 .03098 L
.04841 .03101 L
.05122 .03104 L
.05392 .03107 L
.05653 .0311 L
.0593 .03113 L
.06196 .03116 L
.0648 .0312 L
.06753 .03123 L
.07015 .03126 L
.07295 .03129 L
.07564 .03133 L
.0785 .03136 L
.08125 .0314 L
.08391 .03143 L
.08673 .03147 L
.08944 .03151 L
.09205 .03154 L
.09483 .03158 L
.09751 .03162 L
.10035 .03166 L
.10309 .0317 L
.10573 .03173 L
.10853 .03177 L
.11123 .03181 L
.11383 .03185 L
.11659 .03189 L
.11925 .03193 L
.12208 .03198 L
.12481 .03202 L
.12743 .03206 L
.13022 .03211 L
.1329 .03215 L
.13576 .0322 L
.13851 .03224 L
.14115 .03229 L
.14397 .03234 L
.14668 .03238 L
.14928 .03243 L
.15205 .03248 L
.15472 .03253 L
.15756 .03258 L
Mistroke
.1603 .03263 L
.16293 .03268 L
.16573 .03273 L
.16842 .03278 L
.17128 .03284 L
.17404 .03289 L
.1767 .03294 L
.17952 .033 L
.18224 .03305 L
.18485 .03311 L
.18764 .03316 L
.19032 .03322 L
.19316 .03328 L
.19591 .03334 L
.19855 .0334 L
.20136 .03346 L
.20406 .03352 L
.20666 .03358 L
.20943 .03364 L
.21209 .0337 L
.21492 .03376 L
.21765 .03383 L
.22028 .03389 L
.22307 .03396 L
.22576 .03402 L
.22862 .03409 L
.23137 .03416 L
.23402 .03423 L
.23684 .0343 L
.23955 .03437 L
.24216 .03444 L
.24494 .03451 L
.24761 .03458 L
.25045 .03466 L
.25319 .03473 L
.25582 .03481 L
.25862 .03488 L
.26132 .03496 L
.26392 .03503 L
.26668 .03511 L
.26934 .03519 L
.27216 .03527 L
.27489 .03536 L
.27751 .03543 L
.28029 .03552 L
.28298 .0356 L
.28583 .03569 L
.28857 .03578 L
.29122 .03586 L
.29403 .03595 L
Mistroke
.29674 .03604 L
.29934 .03613 L
.30211 .03622 L
.30478 .03631 L
.30761 .03641 L
.31035 .0365 L
.31297 .03659 L
.31577 .03669 L
.31846 .03679 L
.32132 .03689 L
.32408 .03699 L
.32673 .03709 L
.32955 .0372 L
.33227 .0373 L
.33488 .0374 L
.33767 .03751 L
.34034 .03762 L
.34319 .03773 L
.34593 .03784 L
.34857 .03795 L
.35137 .03806 L
.35407 .03818 L
.35667 .03829 L
.35944 .03841 L
.3621 .03852 L
.36493 .03865 L
.36766 .03877 L
.37028 .03888 L
.37307 .03901 L
.37576 .03913 L
.37861 .03927 L
.38136 .0394 L
.38401 .03952 L
.38682 .03966 L
.38953 .03979 L
.39214 .03992 L
.39492 .04006 L
.39759 .0402 L
.40043 .04034 L
.40316 .04048 L
.40579 .04062 L
.40859 .04077 L
.41129 .04092 L
.41415 .04107 L
.41692 .04123 L
.41957 .04138 L
.4224 .04154 L
.42512 .04169 L
.42773 .04185 L
.43052 .04201 L
Mistroke
.4332 .04217 L
.43605 .04234 L
.43879 .04251 L
.44143 .04268 L
.44424 .04286 L
.44695 .04303 L
.44955 .0432 L
.45232 .04338 L
.45498 .04356 L
.45782 .04375 L
.46055 .04393 L
.46317 .04412 L
.46597 .04431 L
.46866 .0445 L
.47152 .04471 L
.47427 .04491 L
.47692 .04511 L
.47974 .04532 L
.48245 .04553 L
.48506 .04573 L
.48784 .04595 L
.49052 .04616 L
.49336 .04639 L
.4961 .04662 L
.49874 .04683 L
.50154 .04707 L
.50424 .0473 L
.50683 .04753 L
.5096 .04777 L
.51226 .04801 L
.51509 .04826 L
.51781 .04852 L
.52043 .04876 L
.52322 .04903 L
.5259 .04928 L
.52876 .04956 L
.5315 .04984 L
.53415 .0501 L
.53696 .05039 L
.53967 .05067 L
.54228 .05095 L
.54505 .05125 L
.54772 .05154 L
.55056 .05185 L
.55329 .05216 L
.55592 .05246 L
.55872 .05279 L
.56141 .05311 L
.56427 .05345 L
.56703 .05379 L
Mistroke
.56968 .05412 L
.57251 .05448 L
.57522 .05483 L
.57784 .05517 L
.58062 .05554 L
.5833 .0559 L
.58615 .0563 L
.58889 .05668 L
.59153 .05706 L
.59433 .05747 L
.59704 .05787 L
.59964 .05826 L
.6024 .05869 L
.60507 .0591 L
.6079 .05956 L
.61063 .06 L
.61325 .06043 L
.61604 .0609 L
.61873 .06137 L
.62159 .06187 L
.62434 .06236 L
.62699 .06284 L
.6298 .06337 L
.63252 .06388 L
.63512 .06439 L
.6379 .06494 L
.64057 .06547 L
.64341 .06606 L
.64615 .06663 L
.64878 .0672 L
.65159 .06781 L
.65428 .06842 L
.65688 .06901 L
.65964 .06966 L
.66229 .07029 L
.66512 .07098 L
.66784 .07166 L
.67046 .07233 L
.67325 .07306 L
.67593 .07378 L
.67878 .07456 L
.68153 .07533 L
.68417 .07609 L
.68698 .07692 L
.68968 .07773 L
.69229 .07854 L
.69506 .07941 L
.69773 .08028 L
.70056 .08122 L
.70329 .08216 L
Mistroke
.70592 .08308 L
.70871 .08409 L
.71141 .08508 L
.71427 .08617 L
.71702 .08724 L
.71967 .08831 L
.72249 .08947 L
.72521 .09063 L
.72782 .09177 L
.7306 .09302 L
.73328 .09426 L
.73612 .09561 L
.73886 .09696 L
.7415 .09829 L
.7443 .09976 L
.74701 .10121 L
.7496 .10266 L
.75237 .10424 L
.75503 .10581 L
.75786 .10754 L
.76058 .10927 L
.7632 .11098 L
.76599 .11286 L
.76868 .11474 L
.77153 .11681 L
.77428 .11887 L
.77693 .12093 L
.77974 .1232 L
.78245 .12547 L
.78506 .12773 L
.78783 .13023 L
.79051 .13273 L
.79334 .13549 L
.79608 .13825 L
.79871 .14102 L
.80151 .14408 L
.8042 .14715 L
.80707 .15055 L
.80983 .15396 L
.81248 .15738 L
.81531 .16117 L
.81803 .16498 L
.82064 .1688 L
.82342 .17303 L
.8261 .17728 L
.82895 .18198 L
.8317 .18671 L
.83434 .19145 L
.83715 .19669 L
.83985 .20194 L
Mistroke
.84245 .20718 L
.84522 .21296 L
.84788 .21872 L
.85072 .22503 L
.85345 .2313 L
.85607 .23748 L
.85886 .24419 L
.86155 .25076 L
.86441 .25779 L
.86716 .26458 L
.86981 .27104 L
.87263 .27777 L
.87535 .28403 L
.87796 .28973 L
.88073 .29536 L
.88341 .30024 L
.88625 .30472 L
.88899 .30824 L
.89162 .31078 L
.89298 .31174 L
.89368 .31214 L
.89443 .3125 L
.89512 .31276 L
.89543 .31285 L
.89576 .31294 L
.89606 .313 L
.89637 .31306 L
.89655 .31308 L
.89671 .3131 L
.89687 .31312 L
.89702 .31313 L
.8971 .31313 L
.89718 .31313 L
.89722 .31314 L
.89727 .31314 L
.89735 .31314 L
.89744 .31314 L
.89752 .31314 L
.89761 .31314 L
.89766 .31314 L
.89771 .31313 L
.89786 .31313 L
.89795 .31312 L
.89803 .31311 L
.89834 .31308 L
.89851 .31306 L
.89867 .31303 L
.89903 .31296 L
.89977 .31276 L
.90049 .31248 L
Mistroke
.90117 .31216 L
.90244 .31137 L
.90382 .31028 L
.90508 .30905 L
.90778 .30574 L
.91038 .30175 L
.91315 .29673 L
.91581 .29125 L
.91864 .28486 L
.92137 .27827 L
.92399 .27164 L
.92678 .26437 L
.92947 .25726 L
.93233 .24966 L
.93508 .24237 L
.93772 .23544 L
.94054 .2282 L
.94325 .22139 L
.94586 .21501 L
.94863 .20842 L
.95131 .20229 L
.95415 .19601 L
.95688 .19019 L
.95952 .1848 L
.96232 .1793 L
.96501 .17421 L
.96788 .16903 L
.97064 .16426 L
.97329 .15985 L
.97612 .15537 L
.97619 .15526 L
Mfstroke
0 0 1 r
.02381 .03918 m
.02647 .03927 L
.02936 .03936 L
.03209 .03946 L
.0347 .03954 L
.03749 .03964 L
.04017 .03973 L
.04302 .03983 L
.04577 .03993 L
.04841 .04003 L
.05122 .04013 L
.05392 .04023 L
.05653 .04033 L
.0593 .04043 L
.06196 .04053 L
.0648 .04064 L
.06753 .04075 L
.07015 .04086 L
.07295 .04097 L
.07564 .04108 L
.0785 .0412 L
.08125 .04131 L
.08391 .04143 L
.08673 .04155 L
.08944 .04167 L
.09205 .04178 L
.09483 .04191 L
.09751 .04203 L
.10035 .04216 L
.10309 .04228 L
.10573 .04241 L
.10853 .04254 L
.11123 .04267 L
.11383 .0428 L
.11659 .04294 L
.11925 .04307 L
.12208 .04321 L
.12481 .04335 L
.12743 .04349 L
.13022 .04364 L
.1329 .04378 L
.13576 .04394 L
.13851 .04409 L
.14115 .04424 L
.14397 .0444 L
.14668 .04455 L
.14928 .0447 L
.15205 .04486 L
.15472 .04502 L
.15756 .04519 L
Mistroke
.1603 .04536 L
.16293 .04553 L
.16573 .0457 L
.16842 .04587 L
.17128 .04606 L
.17404 .04624 L
.1767 .04642 L
.17952 .04661 L
.18224 .04679 L
.18485 .04697 L
.18764 .04717 L
.19032 .04736 L
.19316 .04757 L
.19591 .04777 L
.19855 .04796 L
.20136 .04817 L
.20406 .04838 L
.20666 .04858 L
.20943 .0488 L
.21209 .04901 L
.21492 .04924 L
.21765 .04947 L
.22028 .04969 L
.22307 .04992 L
.22576 .05016 L
.22862 .0504 L
.23137 .05065 L
.23402 .05089 L
.23684 .05114 L
.23955 .0514 L
.24216 .05164 L
.24494 .05191 L
.24761 .05217 L
.25045 .05245 L
.25319 .05272 L
.25582 .05299 L
.25862 .05328 L
.26132 .05356 L
.26392 .05384 L
.26668 .05414 L
.26934 .05443 L
.27216 .05475 L
.27489 .05506 L
.27751 .05536 L
.28029 .05569 L
.28298 .05601 L
.28583 .05636 L
.28857 .0567 L
.29122 .05703 L
.29403 .05739 L
Mistroke
.29674 .05775 L
.29934 .05809 L
.30211 .05847 L
.30478 .05883 L
.30761 .05923 L
.31035 .05962 L
.31297 .06 L
.31577 .06041 L
.31846 .06082 L
.32132 .06126 L
.32408 .06169 L
.32673 .06211 L
.32955 .06257 L
.33227 .06302 L
.33488 .06346 L
.33767 .06393 L
.34034 .0644 L
.34319 .06491 L
.34593 .06541 L
.34857 .0659 L
.35137 .06643 L
.35407 .06696 L
.35667 .06747 L
.35944 .06803 L
.3621 .06857 L
.36493 .06917 L
.36766 .06975 L
.37028 .07033 L
.37307 .07096 L
.37576 .07157 L
.37861 .07224 L
.38136 .0729 L
.38401 .07355 L
.38682 .07425 L
.38953 .07495 L
.39214 .07563 L
.39492 .07638 L
.39759 .07712 L
.40043 .07792 L
.40316 .07871 L
.40579 .07949 L
.40859 .08034 L
.41129 .08118 L
.41415 .08209 L
.41692 .083 L
.41957 .08389 L
.4224 .08487 L
.42512 .08583 L
.42773 .08679 L
.43052 .08783 L
Mistroke
.4332 .08886 L
.43605 .08999 L
.43879 .09111 L
.44143 .09222 L
.44424 .09343 L
.44695 .09464 L
.44955 .09583 L
.45232 .09714 L
.45498 .09843 L
.45782 .09986 L
.46055 .10128 L
.46317 .10268 L
.46597 .10423 L
.46866 .10577 L
.47152 .10746 L
.47427 .10915 L
.47692 .11083 L
.47974 .11269 L
.48245 .11454 L
.48506 .11639 L
.48784 .11843 L
.49052 .12047 L
.49336 .12272 L
.4961 .12498 L
.49874 .12725 L
.50154 .12976 L
.50424 .13227 L
.50683 .1348 L
.5096 .1376 L
.51226 .14042 L
.51509 .14356 L
.51781 .14673 L
.52043 .14992 L
.52322 .15348 L
.5259 .15708 L
.52876 .16111 L
.5315 .16521 L
.53415 .16936 L
.53696 .17402 L
.53967 .17877 L
.54228 .1836 L
.54505 .18904 L
.54772 .1946 L
.55056 .2009 L
.55329 .20737 L
.55592 .214 L
.55872 .22155 L
.56141 .22933 L
.56427 .23823 L
.56703 .24747 L
Mistroke
.56968 .25705 L
.57251 .26807 L
.57522 .27958 L
.57784 .29158 L
.58062 .30546 L
.5833 .32003 L
.58615 .33698 L
.58889 .35491 L
.59153 .3738 L
.59433 .39586 L
.59704 .4192 L
.59964 .44375 L
.6024 .47227 L
.60507 .50209 L
.6079 .53619 L
.61063 .57094 L
.61325 .60534 L
Mfstroke
.61325 .60534 m
.61423 .61803 L
s
.64062 .61803 m
.64089 .61448 L
.64354 .57833 L
.64636 .54051 L
.64908 .50581 L
.65169 .47458 L
.65447 .44387 L
.65715 .41681 L
.65999 .39061 L
.66273 .3677 L
.66537 .34762 L
.66817 .32818 L
.67087 .31112 L
.67347 .29611 L
.67624 .28146 L
.6789 .26852 L
.68173 .25588 L
.68445 .24467 L
.68707 .2347 L
.68986 .22487 L
.69255 .21609 L
.6954 .20742 L
.69815 .19965 L
.7008 .19266 L
.70361 .18571 L
.70632 .17944 L
.70893 .17377 L
.7117 .16808 L
.71437 .16292 L
.71721 .15775 L
.71995 .15305 L
.72258 .14877 L
.72538 .14445 L
.72807 .1405 L
.73094 .13652 L
.7337 .13288 L
.73635 .12954 L
.73917 .12616 L
.74189 .12305 L
.74451 .12019 L
.74729 .11728 L
.74997 .1146 L
.75282 .11187 L
.75557 .10936 L
.75821 .10703 L
.76101 .10466 L
.76372 .10246 L
.76632 .10042 L
.76909 .09834 L
.77175 .0964 L
Mistroke
.77459 .09442 L
.77731 .09259 L
.77994 .09088 L
.78273 .08912 L
.78542 .08749 L
.78828 .08582 L
.79103 .08426 L
.79368 .08281 L
.7965 .08131 L
.79921 .07992 L
.80182 .07862 L
.8046 .07727 L
.80728 .07602 L
.81012 .07473 L
.81286 .07352 L
.81549 .07239 L
.81829 .07122 L
.82099 .07013 L
.82359 .06911 L
.82635 .06805 L
.82901 .06706 L
.83184 .06603 L
.83456 .06507 L
.83718 .06417 L
.83997 .06323 L
.84265 .06236 L
.8455 .06145 L
.84825 .06059 L
.85089 .05979 L
.85371 .05896 L
.85641 .05818 L
.85902 .05744 L
.86179 .05668 L
.86446 .05596 L
.86729 .05522 L
.87003 .05451 L
.87266 .05385 L
.87545 .05317 L
.87814 .05252 L
.88101 .05185 L
.88376 .05121 L
.88642 .05062 L
.88924 .04999 L
.89196 .04941 L
.89457 .04886 L
.89735 .04828 L
.90003 .04774 L
.90287 .04717 L
.90562 .04664 L
.90825 .04614 L
Mistroke
.91106 .04561 L
.91376 .04511 L
.91636 .04465 L
.91913 .04416 L
.92179 .0437 L
.92462 .04321 L
.92735 .04276 L
.92997 .04233 L
.93276 .04188 L
.93545 .04146 L
.9383 .04101 L
.94105 .04059 L
.9437 .0402 L
.94652 .03978 L
.94923 .03939 L
.95184 .03902 L
.95461 .03863 L
.95728 .03826 L
.96012 .03788 L
.96286 .03752 L
.96549 .03717 L
.96829 .03681 L
.97099 .03647 L
.97385 .03612 L
.97619 .03583 L
Mfstroke
1 0 1 r
.02381 .02257 m
.02647 .02258 L
.02936 .02258 L
.03209 .02259 L
.0347 .0226 L
.03749 .0226 L
.04017 .02261 L
.04302 .02262 L
.04577 .02263 L
.04841 .02264 L
.05122 .02265 L
.05392 .02266 L
.05653 .02266 L
.0593 .02267 L
.06196 .02268 L
.0648 .02269 L
.06753 .0227 L
.07015 .02271 L
.07295 .02272 L
.07564 .02273 L
.0785 .02275 L
.08125 .02276 L
.08391 .02277 L
.08673 .02278 L
.08944 .02279 L
.09205 .0228 L
.09483 .02282 L
.09751 .02283 L
.10035 .02284 L
.10309 .02285 L
.10573 .02287 L
.10853 .02288 L
.11123 .02289 L
.11383 .02291 L
.11659 .02292 L
.11925 .02293 L
.12208 .02295 L
.12481 .02296 L
.12743 .02298 L
.13022 .02299 L
.1329 .02301 L
.13576 .02303 L
.13851 .02304 L
.14115 .02306 L
.14397 .02308 L
.14668 .02309 L
.14928 .02311 L
.15205 .02313 L
.15472 .02314 L
.15756 .02316 L
Mistroke
.1603 .02318 L
.16293 .0232 L
.16573 .02322 L
.16842 .02324 L
.17128 .02326 L
.17404 .02327 L
.1767 .02329 L
.17952 .02331 L
.18224 .02333 L
.18485 .02335 L
.18764 .02338 L
.19032 .0234 L
.19316 .02342 L
.19591 .02344 L
.19855 .02346 L
.20136 .02348 L
.20406 .02351 L
.20666 .02353 L
.20943 .02355 L
.21209 .02357 L
.21492 .0236 L
.21765 .02362 L
.22028 .02365 L
.22307 .02367 L
.22576 .0237 L
.22862 .02372 L
.23137 .02375 L
.23402 .02377 L
.23684 .0238 L
.23955 .02383 L
.24216 .02385 L
.24494 .02388 L
.24761 .02391 L
.25045 .02393 L
.25319 .02396 L
.25582 .02399 L
.25862 .02402 L
.26132 .02405 L
.26392 .02408 L
.26668 .02411 L
.26934 .02414 L
.27216 .02417 L
.27489 .0242 L
.27751 .02423 L
.28029 .02426 L
.28298 .02429 L
.28583 .02432 L
.28857 .02436 L
.29122 .02439 L
.29403 .02442 L
Mistroke
.29674 .02446 L
.29934 .02449 L
.30211 .02452 L
.30478 .02456 L
.30761 .02459 L
.31035 .02463 L
.31297 .02466 L
.31577 .0247 L
.31846 .02474 L
.32132 .02478 L
.32408 .02481 L
.32673 .02485 L
.32955 .02489 L
.33227 .02493 L
.33488 .02497 L
.33767 .02501 L
.34034 .02505 L
.34319 .02509 L
.34593 .02513 L
.34857 .02517 L
.35137 .02521 L
.35407 .02526 L
.35667 .0253 L
.35944 .02534 L
.3621 .02538 L
.36493 .02543 L
.36766 .02547 L
.37028 .02552 L
.37307 .02556 L
.37576 .02561 L
.37861 .02566 L
.38136 .0257 L
.38401 .02575 L
.38682 .0258 L
.38953 .02585 L
.39214 .0259 L
.39492 .02595 L
.39759 .026 L
.40043 .02605 L
.40316 .0261 L
.40579 .02615 L
.40859 .0262 L
.41129 .02626 L
.41415 .02631 L
.41692 .02637 L
.41957 .02642 L
.4224 .02648 L
.42512 .02653 L
.42773 .02659 L
.43052 .02664 L
Mistroke
.4332 .0267 L
.43605 .02676 L
.43879 .02682 L
.44143 .02688 L
.44424 .02694 L
.44695 .027 L
.44955 .02706 L
.45232 .02712 L
.45498 .02718 L
.45782 .02725 L
.46055 .02731 L
.46317 .02738 L
.46597 .02744 L
.46866 .02751 L
.47152 .02758 L
.47427 .02765 L
.47692 .02771 L
.47974 .02778 L
.48245 .02785 L
.48506 .02792 L
.48784 .02799 L
.49052 .02806 L
.49336 .02814 L
.4961 .02822 L
.49874 .02829 L
.50154 .02836 L
.50424 .02844 L
.50683 .02851 L
.5096 .02859 L
.51226 .02867 L
.51509 .02875 L
.51781 .02883 L
.52043 .02891 L
.52322 .02899 L
.5259 .02908 L
.52876 .02916 L
.5315 .02925 L
.53415 .02933 L
.53696 .02942 L
.53967 .02951 L
.54228 .0296 L
.54505 .02969 L
.54772 .02978 L
.55056 .02987 L
.55329 .02997 L
.55592 .03006 L
.55872 .03015 L
.56141 .03025 L
.56427 .03035 L
.56703 .03045 L
Mistroke
.56968 .03055 L
.57251 .03065 L
.57522 .03076 L
.57784 .03085 L
.58062 .03096 L
.5833 .03107 L
.58615 .03118 L
.58889 .03129 L
.59153 .03139 L
.59433 .03151 L
.59704 .03162 L
.59964 .03173 L
.6024 .03184 L
.60507 .03196 L
.6079 .03208 L
.61063 .0322 L
.61325 .03232 L
.61604 .03244 L
.61873 .03256 L
.62159 .03269 L
.62434 .03282 L
.62699 .03295 L
.6298 .03308 L
.63252 .03321 L
.63512 .03334 L
.6379 .03348 L
.64057 .03361 L
.64341 .03376 L
.64615 .0339 L
.64878 .03404 L
.65159 .03419 L
.65428 .03433 L
.65688 .03447 L
.65964 .03462 L
.66229 .03477 L
.66512 .03493 L
.66784 .03509 L
.67046 .03524 L
.67325 .0354 L
.67593 .03556 L
.67878 .03573 L
.68153 .0359 L
.68417 .03607 L
.68698 .03624 L
.68968 .03642 L
.69229 .03658 L
.69506 .03677 L
.69773 .03694 L
.70056 .03714 L
.70329 .03732 L
Mistroke
.70592 .03751 L
.70871 .0377 L
.71141 .03789 L
.71427 .0381 L
.71702 .03831 L
.71967 .0385 L
.72249 .03872 L
.72521 .03893 L
.72782 .03913 L
.7306 .03935 L
.73328 .03957 L
.73612 .0398 L
.73886 .04003 L
.7415 .04025 L
.7443 .04049 L
.74701 .04073 L
.7496 .04096 L
.75237 .04121 L
.75503 .04145 L
.75786 .04171 L
.76058 .04197 L
.7632 .04222 L
.76599 .04249 L
.76868 .04276 L
.77153 .04305 L
.77428 .04333 L
.77693 .0436 L
.77974 .0439 L
.78245 .04419 L
.78506 .04448 L
.78783 .04479 L
.79051 .04509 L
.79334 .04542 L
.79608 .04574 L
.79871 .04606 L
.80151 .0464 L
.8042 .04674 L
.80707 .0471 L
.80983 .04745 L
.81248 .0478 L
.81531 .04818 L
.81803 .04855 L
.82064 .04892 L
.82342 .04931 L
.8261 .0497 L
.82895 .05012 L
.8317 .05054 L
.83434 .05094 L
.83715 .05138 L
.83985 .05182 L
Mistroke
.84245 .05224 L
.84522 .0527 L
.84788 .05316 L
.85072 .05365 L
.85345 .05414 L
.85607 .05461 L
.85886 .05513 L
.86155 .05564 L
.86441 .0562 L
.86716 .05675 L
.86981 .05728 L
.87263 .05787 L
.87535 .05845 L
.87796 .05902 L
.88073 .05964 L
.88341 .06025 L
.88625 .06092 L
.88899 .06157 L
.89162 .06222 L
.89443 .06293 L
.89712 .06363 L
.89972 .06432 L
.90248 .06507 L
.90514 .06582 L
.90797 .06663 L
.91069 .06744 L
.91331 .06823 L
.9161 .0691 L
.91878 .06997 L
.92163 .07091 L
.92438 .07184 L
.92702 .07277 L
.92984 .07379 L
.93254 .0748 L
.93515 .0758 L
.93792 .0769 L
.94059 .07799 L
.94343 .07918 L
.94616 .08038 L
.94879 .08156 L
.95158 .08287 L
.95428 .08417 L
.95714 .0856 L
.95989 .08703 L
.96255 .08845 L
.96537 .09003 L
.96809 .0916 L
.9707 .09317 L
.97348 .09491 L
.97616 .09665 L
Mistroke
.97619 .09667 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{90.625, 320}, {479.5, 338.188}} -> {27.8114, 2.11196, \
0.0842639, 0.00519397}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["High mechanical impedance (limit values)", "Subsubsection"],

Cell["Zero impedance (red):", "Text"],

Cell[BoxData[
    \(\(vat21 = \(\(amp[a1, a2] /. valueruleaHPlc\) /. 
              w \[Rule] 2\ \[Pi]\ f*1000\) /. ZC \[Rule] 0 // N;\)\)], "Input"],

Cell["High resistive impedance (green):", "Text"],

Cell[BoxData[
    \(\(vat22 = \(\(amp[a1, a2] /. valueruleaHPlc\) /. 
              w \[Rule] 2\ \[Pi]\ f*1000\) /. ZC \[Rule] 1*10\^6 // 
          N;\)\)], "Input"],

Cell["Resistive impedance + inertia term (blue):", "Text"],

Cell[BoxData[
    \(\(vat23 = \(\(amp[a1, a2] /. valueruleaHPlc\) /. 
              w \[Rule] 2\ \[Pi]\ f*1000\) /. 
            ZC \[Rule] \[ImaginaryI]*1.5*10\^3 // N;\)\)], "Input"],

Cell["Resistive impedance + capacitive term (pink):", "Text"],

Cell[BoxData[
    \(\(vat24 = \(\(amp[a1, a2] /. valueruleaHPlc\) /. 
              w \[Rule] 2\ \[Pi]\ f*1000\) /. 
            ZC \[Rule] \(-\[ImaginaryI]\)*1.5*10\^3 // N;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl2 = 
      Plot[{10\^6\ vat21, 10\^6\ vat22, 10\^6\ vat23, 10\^6\ vat24}, {f, 27, 
          80}, PlotPoints \[Rule] 250, PlotRange \[Rule] \ {0, 1.5}, 
        AxesOrigin \[Rule] {27, 0}, 
        PlotStyle \[Rule] {{Thickness[ .003], 
              RGBColor[1, 0, 0]}, {Thickness[ .002], 
              RGBColor[0, 1, 0]}, {Thickness[ .002], 
              RGBColor[0, 0, 1]}, {Thickness[ .002], 
              RGBColor[1, 0, 1]}, {Thickness[ .002], 
              RGBColor[0.2, 0.8, 0]}, {Thickness[ .004], 
              RGBColor[0, 1, 0]}, {Thickness[ .002], RGBColor[0, 0.6, 0.4]}}, 
        TextStyle \[Rule] {FontFamily \[Rule] "\<Helvetica\>", 
            FontSize \[Rule] 10}, 
        GridLines \[Rule] {Automatic, None}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.461366 0.0179695 0 0.412023 [
[.07772 -0.0125 -7.5 -13 ]
[.07772 -0.0125 7.5 0 ]
[.25741 -0.0125 -7.5 -13 ]
[.25741 -0.0125 7.5 0 ]
[.43711 -0.0125 -7.5 -13 ]
[.43711 -0.0125 7.5 0 ]
[.6168 -0.0125 -7.5 -13 ]
[.6168 -0.0125 7.5 0 ]
[.7965 -0.0125 -7.5 -13 ]
[.7965 -0.0125 7.5 0 ]
[.97619 -0.0125 -7.5 -13 ]
[.97619 -0.0125 7.5 0 ]
[.01131 .0824 -17.75 -6.5 ]
[.01131 .0824 0 6.5 ]
[.01131 .16481 -17.75 -6.5 ]
[.01131 .16481 0 6.5 ]
[.01131 .24721 -17.75 -6.5 ]
[.01131 .24721 0 6.5 ]
[.01131 .32962 -17.75 -6.5 ]
[.01131 .32962 0 6.5 ]
[.01131 .41202 -9.5 -6.5 ]
[.01131 .41202 0 6.5 ]
[.01131 .49443 -17.75 -6.5 ]
[.01131 .49443 0 6.5 ]
[.01131 .57683 -17.75 -6.5 ]
[.01131 .57683 0 6.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.07772 0 m
.07772 .61803 L
s
.25741 0 m
.25741 .61803 L
s
.43711 0 m
.43711 .61803 L
s
.6168 0 m
.6168 .61803 L
s
.7965 0 m
.7965 .61803 L
s
.97619 0 m
.97619 .61803 L
s
0 g
.07772 0 m
.07772 .00625 L
s
gsave
.07772 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
.25741 0 m
.25741 .00625 L
s
gsave
.25741 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
.43711 0 m
.43711 .00625 L
s
gsave
.43711 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.6168 0 m
.6168 .00625 L
s
gsave
.6168 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.7965 0 m
.7965 .00625 L
s
gsave
.7965 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
.125 Mabswid
.11366 0 m
.11366 .00375 L
s
.1496 0 m
.1496 .00375 L
s
.18553 0 m
.18553 .00375 L
s
.22147 0 m
.22147 .00375 L
s
.29335 0 m
.29335 .00375 L
s
.32929 0 m
.32929 .00375 L
s
.36523 0 m
.36523 .00375 L
s
.40117 0 m
.40117 .00375 L
s
.47305 0 m
.47305 .00375 L
s
.50898 0 m
.50898 .00375 L
s
.54492 0 m
.54492 .00375 L
s
.58086 0 m
.58086 .00375 L
s
.65274 0 m
.65274 .00375 L
s
.68868 0 m
.68868 .00375 L
s
.72462 0 m
.72462 .00375 L
s
.76056 0 m
.76056 .00375 L
s
.83243 0 m
.83243 .00375 L
s
.86837 0 m
.86837 .00375 L
s
.90431 0 m
.90431 .00375 L
s
.94025 0 m
.94025 .00375 L
s
.04178 0 m
.04178 .00375 L
s
.00584 0 m
.00584 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .0824 m
.03006 .0824 L
s
gsave
.01131 .0824 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .16481 m
.03006 .16481 L
s
gsave
.01131 .16481 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .24721 m
.03006 .24721 L
s
gsave
.01131 .24721 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .32962 m
.03006 .32962 L
s
gsave
.01131 .32962 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .41202 m
.03006 .41202 L
s
gsave
.01131 .41202 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .49443 m
.03006 .49443 L
s
gsave
.01131 .49443 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .57683 m
.03006 .57683 L
s
gsave
.01131 .57683 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.003 w
.02381 .01747 m
.02753 .01739 L
.03159 .01731 L
.03541 .01723 L
.03908 .01716 L
.04298 .01709 L
.04674 .01702 L
.05073 .01695 L
.05458 .01689 L
.05829 .01683 L
.06222 .01677 L
.06602 .01671 L
.06966 .01666 L
.07355 .0166 L
.07728 .01655 L
.08126 .0165 L
.08509 .01645 L
.08877 .01641 L
.09268 .01636 L
.09646 .01632 L
.10046 .01628 L
.10433 .01624 L
.10804 .01621 L
.11199 .01617 L
.1158 .01614 L
.11946 .01611 L
.12336 .01609 L
.12711 .01606 L
.13109 .01603 L
.13493 .01601 L
.13863 .01599 L
.14256 .01597 L
.14634 .01596 L
.14998 .01594 L
.15386 .01593 L
.15759 .01592 L
.16155 .01591 L
.16353 .01591 L
.16537 .01591 L
.16726 .0159 L
.16904 .0159 L
.16999 .0159 L
.17101 .0159 L
.17194 .0159 L
.17281 .0159 L
.17328 .0159 L
.17372 .0159 L
.1742 .0159 L
.17447 .0159 L
.17472 .0159 L
Mistroke
.17497 .0159 L
.1751 .0159 L
.17523 .0159 L
.17534 .0159 L
.17547 .0159 L
.17558 .0159 L
.17569 .0159 L
.17582 .0159 L
.17594 .0159 L
.17601 .0159 L
.17607 .0159 L
.17621 .0159 L
.17649 .0159 L
.17675 .0159 L
.17719 .0159 L
.17768 .0159 L
.17867 .0159 L
.17959 .0159 L
.18045 .0159 L
.1824 .0159 L
.18418 .0159 L
.18801 .01591 L
.19169 .01592 L
.1956 .01593 L
.19937 .01594 L
.20337 .01595 L
.20723 .01597 L
.21095 .01599 L
.21489 .01601 L
.2187 .01604 L
.22235 .01606 L
.22625 .01609 L
.22999 .01612 L
.23398 .01616 L
.23781 .01619 L
.24151 .01623 L
.24543 .01627 L
.24922 .01632 L
.25285 .01636 L
.25672 .01641 L
.26045 .01646 L
.26441 .01652 L
.26823 .01658 L
.2719 .01664 L
.2758 .01671 L
.27956 .01677 L
.28356 .01685 L
.28741 .01693 L
.29112 .017 L
.29506 .01709 L
Mistroke
.29885 .01718 L
.3025 .01726 L
.30638 .01736 L
.31012 .01746 L
.3141 .01757 L
.31793 .01768 L
.32161 .01779 L
.32553 .01791 L
.3293 .01803 L
.33331 .01817 L
.33718 .0183 L
.3409 .01844 L
.34485 .0186 L
.34866 .01875 L
.35232 .0189 L
.35622 .01907 L
.35997 .01925 L
.36396 .01944 L
.3678 .01963 L
.3715 .01982 L
.37543 .02004 L
.37922 .02025 L
.38286 .02047 L
.38673 .02071 L
.39046 .02095 L
.39443 .02122 L
.39825 .0215 L
.40193 .02177 L
.40584 .02208 L
.40961 .02239 L
.41361 .02273 L
.41746 .02308 L
.42117 .02344 L
.42512 .02383 L
.42892 .02423 L
.43257 .02464 L
.43646 .0251 L
.44021 .02556 L
.44419 .02608 L
.44802 .02661 L
.45171 .02716 L
.45563 .02777 L
.45941 .02839 L
.46343 .0291 L
.4673 .02984 L
.47102 .03059 L
.47498 .03144 L
.47879 .03233 L
.48246 .03324 L
.48636 .03429 L
Mistroke
.49012 .03537 L
.49411 .03663 L
.49796 .03794 L
.50166 .03932 L
.5056 .04092 L
.50939 .04262 L
.51303 .04441 L
.51692 .04653 L
.52065 .04879 L
.52462 .05149 L
.52845 .05443 L
.53213 .05763 L
.53605 .06152 L
.53982 .06585 L
.54382 .07125 L
.54768 .07742 L
.5514 .08452 L
.55535 .09373 L
.55916 .10478 L
.56281 .11821 L
.56671 .1368 L
.57046 .1608 L
.57444 .19619 L
.57828 .24404 L
.58198 .30326 L
.58384 .33324 L
.58484 .34658 L
.58536 .35232 L
.58591 .35717 L
.58639 .36031 L
.58652 .36096 L
.58667 .36156 L
.58679 .36199 L
.58692 .36236 L
.58699 .36251 L
.58705 .36264 L
.58717 .36281 L
.58729 .3629 L
.58741 .36292 L
.58752 .36287 L
.58764 .36273 L
.58775 .36254 L
.58786 .3623 L
.58809 .36154 L
.58831 .36058 L
.5888 .35752 L
.58923 .35385 L
.58969 .34905 L
.59176 .31921 L
.5937 .28567 L
Mistroke
.59742 .22656 L
.60138 .17969 L
.60519 .14767 L
.60885 .12517 L
.61275 .1072 L
.6165 .09389 L
.62049 .08275 L
.62434 .07413 L
.62804 .06728 L
.63197 .06119 L
.63576 .05622 L
.6394 .0521 L
.64328 .04829 L
.64701 .04508 L
.65098 .04207 L
.65481 .0395 L
.65848 .03729 L
.6624 .03518 L
.66616 .03334 L
.67017 .03156 L
.67403 .03001 L
.67774 .02864 L
.68168 .0273 L
.68549 .02611 L
.68914 .02506 L
.69303 .02401 L
.69678 .02308 L
.70076 .02215 L
.7046 .02132 L
.70829 .02057 L
.71222 .01983 L
.716 .01915 L
.71963 .01854 L
.7235 .01792 L
.72723 .01736 L
.73119 .0168 L
.735 .01629 L
.73867 .01582 L
.74258 .01535 L
.74633 .01491 L
.75033 .01448 L
.75418 .01408 L
.75788 .01371 L
.76182 .01333 L
.76562 .01299 L
.76926 .01267 L
.77315 .01235 L
.77688 .01205 L
.78086 .01175 L
.78469 .01147 L
Mistroke
.78837 .01121 L
.79229 .01094 L
.79606 .0107 L
.80007 .01045 L
.80393 .01021 L
.80765 .01 L
.8116 .00978 L
.81541 .00957 L
.81907 .00938 L
.82296 .00919 L
.82672 .009 L
.8307 .00882 L
.83454 .00864 L
.83824 .00848 L
.84217 .00831 L
.84596 .00816 L
.8496 .00801 L
.85347 .00786 L
.8572 .00772 L
.86117 .00758 L
.86499 .00744 L
.86866 .00732 L
.87257 .00719 L
.87634 .00706 L
.88034 .00694 L
.88419 .00682 L
.8879 .00671 L
.89184 .0066 L
.89564 .00649 L
.89929 .00639 L
.90318 .00629 L
.90693 .00619 L
.91091 .00609 L
.91474 .00599 L
.91843 .0059 L
.92235 .00581 L
.92613 .00573 L
.93014 .00564 L
.93401 .00555 L
.93773 .00547 L
.94169 .00539 L
.9455 .00532 L
.94916 .00524 L
.95307 .00517 L
.95682 .0051 L
.96081 .00502 L
.96466 .00496 L
.96836 .00489 L
.9723 .00482 L
.97609 .00476 L
Mistroke
.97619 .00476 L
Mfstroke
0 1 0 r
.002 w
.02381 .11803 m
.02753 .12996 L
.03159 .14645 L
.03541 .1667 L
.03908 .19278 L
.04112 .21142 L
.04298 .23197 L
.04674 .28909 L
.04859 .3289 L
.05059 .38627 L
.0525 .46186 L
.05346 .51107 L
.05453 .57674 L
s
.05453 .57674 m
.05503 .61803 L
s
.06552 .61803 m
.06626 .55749 L
.06808 .45243 L
.06999 .37398 L
.07189 .31727 L
.07366 .27722 L
.07563 .24248 L
.07742 .21735 L
.08128 .1771 L
.08499 .14981 L
.08893 .12835 L
.09273 .11254 L
.09638 .10044 L
.10027 .08997 L
.10401 .08164 L
.10799 .07423 L
.11182 .06817 L
.11551 .06314 L
.11943 .05848 L
.12321 .05455 L
.12722 .05087 L
.13109 .04772 L
.13481 .045 L
.13876 .0424 L
.14257 .04014 L
.14624 .03815 L
.15014 .03623 L
.1539 .03453 L
.15789 .03287 L
.16173 .0314 L
.16543 .03009 L
.16937 .02879 L
.17316 .02764 L
.1768 .0266 L
.18068 .02557 L
.18442 .02464 L
.18839 .02371 L
.19221 .02288 L
.19589 .02212 L
.1998 .02136 L
.20357 .02067 L
.20758 .01998 L
.21144 .01935 L
.21515 .01877 L
.2191 .01819 L
.2229 .01766 L
.22656 .01718 L
.23045 .01669 L
.2342 .01624 L
.23818 .01578 L
Mistroke
.24202 .01536 L
.24571 .01497 L
.24964 .01458 L
.25342 .01422 L
.25705 .01389 L
.26093 .01355 L
.26465 .01324 L
.26861 .01292 L
.27243 .01262 L
.2761 .01235 L
.28001 .01207 L
.28377 .01181 L
.28776 .01155 L
.29161 .0113 L
.29532 .01108 L
.29926 .01084 L
.30305 .01063 L
.3067 .01043 L
.31059 .01022 L
.31433 .01003 L
.3183 .00983 L
.32213 .00965 L
.32581 .00948 L
.32973 .0093 L
.33351 .00914 L
.33752 .00897 L
.34138 .00882 L
.3451 .00867 L
.34905 .00852 L
.35286 .00838 L
.35652 .00825 L
.36042 .00812 L
.36417 .00799 L
.36816 .00786 L
.372 .00774 L
.3757 .00763 L
.37963 .00751 L
.38342 .0074 L
.38706 .0073 L
.39094 .00719 L
.39467 .00709 L
.39863 .00699 L
.40246 .00689 L
.40613 .00681 L
.41004 .00671 L
.41381 .00663 L
.41781 .00654 L
.42167 .00645 L
.42537 .00637 L
.42932 .00629 L
Mistroke
.43312 .00622 L
.43677 .00615 L
.44066 .00607 L
.44441 .006 L
.44839 .00593 L
.45222 .00586 L
.45591 .0058 L
.45984 .00573 L
.46361 .00567 L
.46763 .00561 L
.4715 .00555 L
.47522 .00549 L
.47918 .00544 L
.48299 .00538 L
.48666 .00533 L
.49056 .00528 L
.49432 .00523 L
.49831 .00518 L
.50216 .00513 L
.50586 .00508 L
.5098 .00504 L
.51359 .00499 L
.51724 .00495 L
.52112 .00491 L
.52485 .00487 L
.52883 .00483 L
.53265 .00479 L
.53633 .00475 L
.54025 .00472 L
.54402 .00468 L
.54803 .00464 L
.55189 .00461 L
.5556 .00458 L
.55955 .00455 L
.56336 .00451 L
.56702 .00449 L
.57091 .00446 L
.57466 .00443 L
.57865 .0044 L
.58249 .00437 L
.58618 .00435 L
.59011 .00432 L
.59389 .00429 L
.59753 .00427 L
.6014 .00425 L
.60513 .00423 L
.60909 .0042 L
.61291 .00418 L
.61658 .00416 L
.62049 .00414 L
Mistroke
.62426 .00412 L
.62825 .00411 L
.63211 .00409 L
.63581 .00407 L
.63976 .00405 L
.64355 .00404 L
.6472 .00402 L
.65109 .00401 L
.65483 .004 L
.65881 .00398 L
.66264 .00397 L
.66632 .00396 L
.67025 .00395 L
.67402 .00394 L
.67803 .00393 L
.6819 .00392 L
.68562 .00391 L
.68957 .0039 L
.69338 .00389 L
.69705 .00388 L
.70095 .00388 L
.7047 .00387 L
.70869 .00387 L
.71254 .00386 L
.71624 .00386 L
.72017 .00386 L
.72396 .00385 L
.7276 .00385 L
.72947 .00385 L
.73148 .00385 L
.73341 .00385 L
.73439 .00385 L
.73493 .00385 L
.73545 .00385 L
.73593 .00385 L
.73644 .00385 L
.73667 .00385 L
.73691 .00385 L
.73712 .00385 L
.73734 .00385 L
.73748 .00385 L
.73754 .00385 L
.73761 .00385 L
.73772 .00385 L
.73785 .00385 L
.73797 .00385 L
.73804 .00385 L
.73811 .00385 L
.73818 .00385 L
.73824 .00385 L
Mistroke
.73839 .00385 L
.7385 .00385 L
.73861 .00385 L
.73886 .00385 L
.7391 .00385 L
.73936 .00385 L
.73987 .00385 L
.74035 .00385 L
.74142 .00385 L
.74236 .00385 L
.74336 .00385 L
.74524 .00385 L
.74701 .00385 L
.75074 .00385 L
.75472 .00386 L
.75855 .00386 L
.76223 .00386 L
.76615 .00387 L
.76992 .00387 L
.77393 .00388 L
.77779 .00389 L
.78151 .00389 L
.78546 .0039 L
.78927 .00391 L
.79293 .00392 L
.79682 .00393 L
.80057 .00394 L
.80456 .00396 L
.8084 .00397 L
.8121 .00398 L
.81603 .004 L
.81981 .00401 L
.82345 .00403 L
.82733 .00405 L
.83106 .00407 L
.83503 .00409 L
.83885 .00411 L
.84252 .00413 L
.84643 .00415 L
.85019 .00418 L
.85419 .0042 L
.85805 .00423 L
.86176 .00426 L
.8657 .00429 L
.8695 .00432 L
.87315 .00435 L
.87704 .00439 L
.88078 .00442 L
.88476 .00446 L
.8886 .0045 L
Mistroke
.89228 .00454 L
.89621 .00458 L
.89998 .00463 L
.904 .00468 L
.90787 .00473 L
.91159 .00478 L
.91554 .00483 L
.91936 .00489 L
.92302 .00495 L
.92692 .00501 L
.93068 .00507 L
.93467 .00515 L
.93852 .00522 L
.94222 .00529 L
.94616 .00537 L
.94995 .00546 L
.95359 .00554 L
.95747 .00563 L
.96121 .00573 L
.96518 .00583 L
.969 .00594 L
.97268 .00605 L
.97619 .00616 L
Mfstroke
0 0 1 r
.02381 .03921 m
.02753 .0398 L
.03159 .04049 L
.03541 .04118 L
.03908 .04189 L
.04298 .04269 L
.04674 .04352 L
.05073 .04447 L
.05458 .04544 L
.05829 .04645 L
.06222 .04761 L
.06602 .04881 L
.06966 .05005 L
.07355 .05148 L
.07728 .05297 L
.08126 .0547 L
.08509 .05652 L
.08877 .05844 L
.09268 .06067 L
.09646 .06304 L
.10046 .06584 L
.10433 .06885 L
.10804 .07209 L
.11199 .07596 L
.1158 .0802 L
.11946 .08484 L
.12336 .09052 L
.12711 .09688 L
.13109 .10486 L
.13493 .11407 L
.13863 .12478 L
.14256 .13887 L
.14634 .15608 L
.14998 .17747 L
.15386 .20806 L
.15759 .24951 L
.15952 .27802 L
.16155 .31552 L
.16345 .35994 L
.16522 .41193 L
.16899 .5648 L
s
.16899 .5648 m
.17013 .61803 L
s
.1769 .61803 m
.18054 .44946 L
.18245 .3819 L
.18448 .326 L
.18812 .25469 L
.18999 .22808 L
.192 .2046 L
.19597 .16935 L
.19979 .1447 L
.20347 .12661 L
.20739 .11149 L
.21116 .09982 L
.21516 .08967 L
.21902 .08156 L
.22273 .07493 L
.22668 .06889 L
.23048 .06386 L
.23414 .05962 L
.23803 .05563 L
.24178 .05222 L
.24576 .04899 L
.2496 .0462 L
.25329 .04377 L
.25722 .04142 L
.261 .03936 L
.26464 .03754 L
.26851 .03577 L
.27223 .03419 L
.2762 .03264 L
.28001 .03126 L
.28368 .03003 L
.28759 .0288 L
.29135 .0277 L
.29535 .02661 L
.2992 .02562 L
.3029 .02473 L
.30684 .02384 L
.31064 .02304 L
.31429 .0223 L
.31817 .02156 L
.32191 .02089 L
.32589 .02021 L
.32971 .0196 L
.3334 .01903 L
.33732 .01846 L
.34109 .01794 L
.3451 .0174 L
.34896 .01692 L
.35268 .01647 L
.35664 .01602 L
Mistroke
.36044 .0156 L
.36411 .01521 L
.368 .01482 L
.37176 .01446 L
.37574 .01409 L
.37959 .01375 L
.38328 .01343 L
.38722 .01311 L
.391 .01281 L
.39464 .01253 L
.39852 .01225 L
.40225 .01198 L
.40622 .01171 L
.41004 .01146 L
.41371 .01123 L
.41763 .01099 L
.42139 .01077 L
.42539 .01054 L
.42925 .01033 L
.43296 .01013 L
.4369 .00992 L
.4407 .00973 L
.44436 .00956 L
.44825 .00937 L
.45199 .0092 L
.45597 .00903 L
.45981 .00887 L
.46349 .00871 L
.46742 .00855 L
.4712 .00841 L
.47521 .00825 L
.47908 .00811 L
.4828 .00798 L
.48676 .00784 L
.49058 .00771 L
.49424 .00759 L
.49815 .00747 L
.5019 .00735 L
.5059 .00723 L
.50974 .00712 L
.51345 .00701 L
.51738 .0069 L
.52118 .0068 L
.52482 .0067 L
.5287 .0066 L
.53244 .0065 L
.53641 .00641 L
.54024 .00632 L
.54392 .00623 L
.54783 .00614 L
Mistroke
.5516 .00606 L
.55561 .00597 L
.55947 .00589 L
.56319 .00581 L
.56714 .00573 L
.57094 .00566 L
.5746 .00559 L
.5785 .00551 L
.58224 .00544 L
.58623 .00537 L
.59007 .00531 L
.59376 .00524 L
.59769 .00518 L
.60148 .00512 L
.60511 .00506 L
.60899 .005 L
.61271 .00494 L
.61668 .00488 L
.6205 .00483 L
.62417 .00477 L
.62808 .00472 L
.63184 .00467 L
.63584 .00461 L
.63969 .00456 L
.6434 .00452 L
.64734 .00447 L
.65114 .00442 L
.65479 .00438 L
.65867 .00433 L
.66241 .00429 L
.66639 .00424 L
.67022 .0042 L
.67391 .00416 L
.67783 .00412 L
.6816 .00408 L
.68562 .00404 L
.68948 .004 L
.6932 .00397 L
.69716 .00393 L
.70097 .0039 L
.70463 .00386 L
.70853 .00383 L
.71229 .0038 L
.71628 .00376 L
.72012 .00373 L
.72382 .0037 L
.72775 .00367 L
.73154 .00364 L
.73518 .00361 L
.73906 .00359 L
Mistroke
.7428 .00356 L
.74677 .00353 L
.75059 .0035 L
.75427 .00348 L
.75818 .00345 L
.76195 .00343 L
.76595 .00341 L
.76981 .00338 L
.77352 .00336 L
.77747 .00334 L
.78127 .00332 L
.78492 .0033 L
.78882 .00327 L
.79256 .00326 L
.79654 .00324 L
.80038 .00322 L
.80407 .0032 L
.808 .00318 L
.81178 .00316 L
.81541 .00315 L
.81928 .00313 L
.82301 .00312 L
.82697 .0031 L
.83078 .00309 L
.83445 .00307 L
.83836 .00306 L
.84212 .00304 L
.84611 .00303 L
.84996 .00302 L
.85366 .00301 L
.8576 .003 L
.8614 .00299 L
.86504 .00298 L
.86893 .00297 L
.87267 .00296 L
.87664 .00295 L
.88047 .00294 L
.88415 .00293 L
.88807 .00293 L
.89184 .00292 L
.89585 .00291 L
.89971 .00291 L
.90343 .0029 L
.90738 .0029 L
.91119 .0029 L
.91485 .00289 L
.91875 .00289 L
.9225 .00289 L
.92454 .00289 L
.92648 .00289 L
Mistroke
.92742 .00289 L
.9284 .00289 L
.92933 .00289 L
.93018 .00289 L
.93108 .00289 L
.93156 .00289 L
.9318 .00289 L
.93206 .00289 L
.93229 .00289 L
.93249 .00288 L
.93259 .00288 L
.9327 .00288 L
.9328 .00288 L
.9329 .00288 L
.93301 .00288 L
.93311 .00288 L
.93322 .00288 L
.93335 .00288 L
.93347 .00288 L
.93359 .00288 L
.9337 .00288 L
.93382 .00289 L
.93407 .00289 L
.93433 .00289 L
.93482 .00289 L
.93529 .00289 L
.93572 .00289 L
.9367 .00289 L
.93774 .00289 L
.93964 .00289 L
.94141 .00289 L
.94516 .00289 L
.94916 .00289 L
.953 .00289 L
.9567 .0029 L
.96064 .0029 L
.96443 .00291 L
.96807 .00291 L
.97195 .00292 L
.97569 .00293 L
.97619 .00293 L
Mfstroke
1 0 1 r
.02381 .03869 m
.02753 .03663 L
.03159 .03461 L
.03541 .03289 L
.03908 .03138 L
.04298 .0299 L
.04674 .0286 L
.05073 .02732 L
.05458 .02619 L
.05829 .02517 L
.06222 .02417 L
.06602 .02328 L
.06966 .02247 L
.07355 .02167 L
.07728 .02095 L
.08126 .02023 L
.08509 .01958 L
.08877 .01899 L
.09268 .0184 L
.09646 .01786 L
.10046 .01732 L
.10433 .01683 L
.10804 .01638 L
.11199 .01593 L
.1158 .01552 L
.11946 .01514 L
.12336 .01476 L
.12711 .01441 L
.13109 .01406 L
.13493 .01373 L
.13863 .01343 L
.14256 .01313 L
.14634 .01285 L
.14998 .01259 L
.15386 .01233 L
.15759 .01209 L
.16155 .01184 L
.16537 .01161 L
.16904 .0114 L
.17295 .01119 L
.17672 .01099 L
.18072 .01079 L
.18457 .0106 L
.18828 .01042 L
.19222 .01024 L
.19602 .01008 L
.19967 .00992 L
.20356 .00977 L
.2073 .00962 L
.21128 .00947 L
Mistroke
.21511 .00933 L
.2188 .0092 L
.22272 .00907 L
.2265 .00894 L
.23051 .00882 L
.23438 .0087 L
.2381 .00859 L
.24205 .00847 L
.24587 .00837 L
.24953 .00827 L
.25343 .00817 L
.25719 .00807 L
.26118 .00797 L
.26502 .00788 L
.26872 .0078 L
.27266 .00771 L
.27645 .00763 L
.28009 .00755 L
.28397 .00747 L
.28771 .0074 L
.29168 .00732 L
.2955 .00725 L
.29918 .00718 L
.30309 .00711 L
.30686 .00705 L
.31087 .00698 L
.31473 .00692 L
.31844 .00686 L
.32239 .0068 L
.32619 .00674 L
.32985 .00669 L
.33374 .00664 L
.33749 .00659 L
.34147 .00653 L
.34531 .00649 L
.349 .00644 L
.35293 .00639 L
.35671 .00635 L
.36035 .00631 L
.36422 .00626 L
.36794 .00622 L
.3719 .00618 L
.37572 .00614 L
.37939 .00611 L
.3833 .00607 L
.38706 .00603 L
.39105 .006 L
.3949 .00596 L
.39861 .00593 L
.40255 .0059 L
Mistroke
.40634 .00587 L
.40999 .00584 L
.41388 .00581 L
.41762 .00578 L
.42159 .00576 L
.42542 .00573 L
.42911 .00571 L
.43303 .00568 L
.4368 .00566 L
.44081 .00563 L
.44467 .00561 L
.44839 .00559 L
.45234 .00557 L
.45615 .00555 L
.45981 .00553 L
.46371 .00551 L
.46746 .0055 L
.47145 .00548 L
.47529 .00546 L
.47899 .00545 L
.48292 .00543 L
.48671 .00542 L
.49035 .00541 L
.49423 .0054 L
.49796 .00538 L
.50193 .00537 L
.50575 .00536 L
.50942 .00535 L
.51333 .00534 L
.5171 .00534 L
.5211 .00533 L
.52496 .00532 L
.52867 .00531 L
.53261 .00531 L
.53641 .0053 L
.54007 .0053 L
.54396 .0053 L
.5477 .00529 L
.55168 .00529 L
.55367 .00529 L
.55551 .00529 L
.5573 .00529 L
.5592 .00529 L
.5602 .00529 L
.56072 .00529 L
.56127 .00529 L
.56176 .00529 L
.56201 .00529 L
.56229 .00529 L
.56254 .00529 L
Mistroke
.56277 .00529 L
.56288 .00529 L
.563 .00529 L
.56311 .00529 L
.56322 .00529 L
.56334 .00529 L
.56345 .00529 L
.56355 .00529 L
.56367 .00529 L
.56379 .00529 L
.56392 .00529 L
.56415 .00529 L
.56438 .00529 L
.56461 .00529 L
.56502 .00529 L
.56552 .00529 L
.56598 .00529 L
.56701 .00529 L
.56795 .00529 L
.56882 .00529 L
.57081 .00529 L
.57277 .00529 L
.57456 .00529 L
.5784 .00529 L
.5821 .0053 L
.58602 .0053 L
.58981 .0053 L
.59345 .00531 L
.59732 .00531 L
.60105 .00532 L
.60501 .00533 L
.60883 .00534 L
.6125 .00534 L
.61641 .00535 L
.62017 .00536 L
.62417 .00538 L
.62802 .00539 L
.63173 .0054 L
.63567 .00542 L
.63947 .00543 L
.64312 .00544 L
.64701 .00546 L
.65075 .00548 L
.65472 .0055 L
.65856 .00552 L
.66224 .00553 L
.66616 .00556 L
.66994 .00558 L
.67395 .0056 L
.67782 .00563 L
Mistroke
.68153 .00565 L
.68549 .00568 L
.6893 .00571 L
.69296 .00573 L
.69686 .00576 L
.70062 .0058 L
.70461 .00583 L
.70845 .00586 L
.71215 .0059 L
.71609 .00594 L
.71987 .00597 L
.72352 .00601 L
.7274 .00605 L
.73113 .0061 L
.7351 .00614 L
.73892 .00619 L
.7426 .00623 L
.74651 .00629 L
.75028 .00634 L
.75428 .00639 L
.75814 .00645 L
.76185 .00651 L
.7658 .00657 L
.7696 .00664 L
.77326 .0067 L
.77715 .00677 L
.78089 .00684 L
.78488 .00692 L
.78871 .007 L
.7924 .00708 L
.79633 .00716 L
.80011 .00725 L
.80374 .00734 L
.80761 .00744 L
.81134 .00753 L
.8153 .00764 L
.81912 .00775 L
.82278 .00786 L
.82669 .00799 L
.83045 .00811 L
.83444 .00825 L
.83829 .00839 L
.842 .00853 L
.84594 .00869 L
.84973 .00885 L
.85338 .00902 L
.85726 .0092 L
.861 .00938 L
.86497 .00959 L
.8688 .00981 L
Mistroke
.87248 .01002 L
.8764 .01027 L
.88017 .01052 L
.88418 .01081 L
.88805 .0111 L
.89176 .0114 L
.89571 .01175 L
.89952 .01211 L
.90318 .01247 L
.90708 .0129 L
.91083 .01334 L
.91482 .01385 L
.91866 .01438 L
.92235 .01495 L
.92629 .0156 L
.93007 .0163 L
.93371 .01704 L
.93759 .01792 L
.94132 .01886 L
.94528 .02 L
.9491 .02124 L
.95278 .02261 L
.95669 .02428 L
.96045 .02617 L
.96445 .02856 L
.9683 .03134 L
.97201 .03462 L
.97596 .03899 L
.97619 .03929 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pl3 = 
      Plot[{10\^6\ vat21, 10\^6\ vat22, 10\^6\ vat23, 10\^6\ vat24}, {f, 0, 
          160}, PlotPoints \[Rule] 250, PlotRange \[Rule] \ {0, 1.5}, 
        PlotStyle \[Rule] {{Thickness[ .003], 
              RGBColor[1, 0, 0]}, {Thickness[ .002], 
              RGBColor[0, 1, 0]}, {Thickness[ .002], 
              RGBColor[0, 0, 1]}, {Thickness[ .002], 
              RGBColor[1, 0, 1]}, {Thickness[ .002], 
              RGBColor[0.2, 0.8, 0]}, {Thickness[ .004], 
              RGBColor[0, 1, 0]}, {Thickness[ .002], RGBColor[0, 0.6, 0.4]}}, 
        TextStyle \[Rule] {FontFamily \[Rule] "\<Helvetica\>", 
            FontSize \[Rule] 10}, 
        GridLines \[Rule] {Automatic, None}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00595238 0 0.412023 [
[.17262 -0.0125 -7.5 -13 ]
[.17262 -0.0125 7.5 0 ]
[.32143 -0.0125 -7.5 -13 ]
[.32143 -0.0125 7.5 0 ]
[.47024 -0.0125 -7.5 -13 ]
[.47024 -0.0125 7.5 0 ]
[.61905 -0.0125 -10.25 -13 ]
[.61905 -0.0125 10.25 0 ]
[.76786 -0.0125 -10.25 -13 ]
[.76786 -0.0125 10.25 0 ]
[.91667 -0.0125 -10.25 -13 ]
[.91667 -0.0125 10.25 0 ]
[.01131 .0824 -17.75 -6.5 ]
[.01131 .0824 0 6.5 ]
[.01131 .16481 -17.75 -6.5 ]
[.01131 .16481 0 6.5 ]
[.01131 .24721 -17.75 -6.5 ]
[.01131 .24721 0 6.5 ]
[.01131 .32962 -17.75 -6.5 ]
[.01131 .32962 0 6.5 ]
[.01131 .41202 -9.5 -6.5 ]
[.01131 .41202 0 6.5 ]
[.01131 .49443 -17.75 -6.5 ]
[.01131 .49443 0 6.5 ]
[.01131 .57683 -17.75 -6.5 ]
[.01131 .57683 0 6.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .61803 L
s
.17262 0 m
.17262 .61803 L
s
.32143 0 m
.32143 .61803 L
s
.47024 0 m
.47024 .61803 L
s
.61905 0 m
.61905 .61803 L
s
.76786 0 m
.76786 .61803 L
s
.91667 0 m
.91667 .61803 L
s
0 g
.17262 0 m
.17262 .00625 L
s
gsave
.17262 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.32143 0 m
.32143 .00625 L
s
gsave
.32143 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.47024 0 m
.47024 .00625 L
s
gsave
.47024 -0.0125 -68.5 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
.61905 0 m
.61905 .00625 L
s
gsave
.61905 -0.0125 -71.25 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.76786 0 m
.76786 .00625 L
s
gsave
.76786 -0.0125 -71.25 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
.91667 0 m
.91667 .00625 L
s
gsave
.91667 -0.0125 -71.25 -17 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.125 Mabswid
.05357 0 m
.05357 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.1131 0 m
.1131 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.23214 0 m
.23214 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.35119 0 m
.35119 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.41071 0 m
.41071 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.5 0 m
.5 .00375 L
s
.52976 0 m
.52976 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.58929 0 m
.58929 .00375 L
s
.64881 0 m
.64881 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.82738 0 m
.82738 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.8869 0 m
.8869 .00375 L
s
.94643 0 m
.94643 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .0824 m
.03006 .0824 L
s
gsave
.01131 .0824 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .16481 m
.03006 .16481 L
s
gsave
.01131 .16481 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .24721 m
.03006 .24721 L
s
gsave
.01131 .24721 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .32962 m
.03006 .32962 L
s
gsave
.01131 .32962 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .41202 m
.03006 .41202 L
s
gsave
.01131 .41202 -70.5 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .49443 m
.03006 .49443 L
s
gsave
.01131 .49443 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .57683 m
.03006 .57683 L
s
gsave
.01131 .57683 -78.75 -10.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .0206 m
.02756 .0206 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .14421 m
.02756 .14421 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .22661 m
.02756 .22661 L
s
.02381 .26781 m
.02756 .26781 L
s
.02381 .28842 m
.02756 .28842 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .35022 m
.02756 .35022 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .39142 m
.02756 .39142 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .47383 m
.02756 .47383 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .53563 m
.02756 .53563 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .59743 m
.02756 .59743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.003 w
.0277 .61803 m
.02803 .56802 L
.02855 .50547 L
.02948 .42222 L
.03049 .35866 L
.03159 .30781 L
.03258 .2733 L
.03348 .24796 L
.03549 .20521 L
.03733 .17732 L
.03933 .1545 L
.04124 .13765 L
.04326 .12336 L
.0469 .10399 L
.05078 .08912 L
.0545 .07837 L
.05847 .06949 L
.06229 .06267 L
.06596 .05729 L
.06987 .05251 L
.07364 .04862 L
.07764 .0451 L
.08149 .04217 L
.0852 .03971 L
.08914 .0374 L
.09294 .03544 L
.09659 .03375 L
.10048 .03213 L
.10422 .03073 L
.1082 .02938 L
.11203 .02821 L
.11572 .02717 L
.11964 .02617 L
.12342 .02528 L
.12743 .02442 L
.1313 .02365 L
.13502 .02297 L
.13897 .02231 L
.14279 .02171 L
.14645 .02118 L
.15035 .02066 L
.15411 .02019 L
.1581 .01973 L
.16194 .01932 L
.16564 .01896 L
.16958 .0186 L
.17337 .01827 L
.17701 .01799 L
.18089 .01771 L
.18463 .01746 L
Mistroke
.1886 .01722 L
.19242 .01701 L
.1961 .01682 L
.20001 .01664 L
.20378 .01649 L
.20779 .01635 L
.21165 .01623 L
.21536 .01613 L
.21931 .01605 L
.22311 .01598 L
.22677 .01594 L
.22865 .01592 L
.23066 .01591 L
.23164 .0159 L
.23216 .0159 L
.23271 .0159 L
.23318 .0159 L
.23344 .0159 L
.23371 .0159 L
.23396 .0159 L
.23407 .0159 L
.23419 .0159 L
.2343 .0159 L
.23441 .0159 L
.23453 .0159 L
.23464 .0159 L
.23476 .0159 L
.23483 .0159 L
.23489 .0159 L
.23502 .0159 L
.23509 .0159 L
.23516 .0159 L
.23527 .0159 L
.2354 .0159 L
.23563 .0159 L
.2359 .0159 L
.23618 .0159 L
.2367 .0159 L
.23722 .0159 L
.23772 .0159 L
.23864 .01591 L
.23958 .01591 L
.24058 .01592 L
.24236 .01594 L
.24425 .01596 L
.24602 .01598 L
.24977 .01605 L
.25376 .01614 L
.2576 .01626 L
.2613 .0164 L
Mistroke
.26523 .01657 L
.26902 .01676 L
.27266 .01698 L
.27654 .01724 L
.28027 .01753 L
.28423 .01789 L
.28806 .01828 L
.29173 .0187 L
.29564 .01921 L
.29941 .01978 L
.30341 .02046 L
.30726 .02122 L
.31097 .02205 L
.31492 .02308 L
.31872 .02423 L
.32237 .02553 L
.32626 .02715 L
.33001 .02903 L
.33399 .03145 L
.33782 .03435 L
.34151 .03786 L
.34544 .04271 L
.34921 .049 L
.35128 .05345 L
.35323 .05855 L
.355 .06423 L
.35695 .07202 L
.35888 .082 L
.36091 .09625 L
.3628 .11489 L
.36385 .12885 L
.36481 .14475 L
.36577 .16474 L
.36666 .18812 L
.36763 .22095 L
.36866 .26552 L
.36957 .31088 L
.37007 .33467 L
.37031 .34475 L
.37054 .35252 L
.37076 .35801 L
.37088 .36024 L
.37098 .3617 L
.3711 .36266 L
.37117 .36289 L
.37123 .36291 L
.37134 .36245 L
.37146 .36127 L
.37156 .35976 L
.37167 .35761 L
Mistroke
.37187 .35248 L
.3721 .34451 L
.37231 .3358 L
.3743 .23662 L
.37518 .20146 L
.37615 .171 L
.37707 .14844 L
.37794 .13156 L
.37984 .1045 L
.38079 .09454 L
.38178 .08579 L
.38357 .07342 L
.38547 .06344 L
.38724 .05619 L
.391 .04498 L
.39306 .04045 L
.395 .03688 L
.39871 .03147 L
.40265 .0271 L
.40645 .02383 L
.4101 .02128 L
.41398 .01906 L
.41772 .01728 L
.4217 .01568 L
.42553 .01436 L
.42922 .01327 L
.43314 .01225 L
.43691 .01139 L
.44093 .01058 L
.44479 .00989 L
.44851 .0093 L
.45247 .00872 L
.45628 .00823 L
.45994 .00779 L
.46384 .00737 L
.4676 .007 L
.47159 .00664 L
.47543 .00632 L
.47913 .00603 L
.48306 .00575 L
.48685 .0055 L
.49049 .00528 L
.49437 .00505 L
.49811 .00485 L
.50207 .00466 L
.5059 .00448 L
.50957 .00432 L
.51349 .00415 L
.51726 .00401 L
.52126 .00386 L
Mistroke
.52512 .00373 L
.52883 .00361 L
.53278 .00349 L
.53658 .00338 L
.54023 .00328 L
.54412 .00318 L
.54787 .00308 L
.55185 .00299 L
.55569 .00291 L
.55938 .00283 L
.56331 .00275 L
.56709 .00268 L
.57072 .00261 L
.57459 .00254 L
.57832 .00248 L
.58228 .00242 L
.58609 .00236 L
.58976 .00231 L
.59367 .00225 L
.59743 .0022 L
.60142 .00215 L
.60527 .0021 L
.60897 .00206 L
.61291 .00202 L
.61671 .00197 L
.62035 .00194 L
.62424 .0019 L
.62798 .00186 L
.63195 .00183 L
.63578 .00179 L
.63946 .00176 L
.64338 .00173 L
.64715 .0017 L
.65116 .00167 L
.65502 .00164 L
.65874 .00162 L
.66269 .00159 L
.6665 .00157 L
.67016 .00154 L
.67406 .00152 L
.67781 .0015 L
.68179 .00148 L
.68563 .00146 L
.68933 .00144 L
.69326 .00142 L
.69705 .0014 L
.70069 .00139 L
.70456 .00137 L
.70829 .00135 L
.71226 .00134 L
Mistroke
.71608 .00132 L
.71975 .00131 L
.72366 .0013 L
.72743 .00129 L
.73143 .00127 L
.73528 .00126 L
.73899 .00125 L
.74293 .00124 L
.74673 .00123 L
.75039 .00122 L
.75427 .00121 L
.75802 .0012 L
.762 .00119 L
.76583 .00119 L
.76952 .00118 L
.77344 .00117 L
.77722 .00117 L
.78123 .00116 L
.7851 .00115 L
.78882 .00115 L
.79278 .00115 L
.79659 .00114 L
.80025 .00114 L
.80416 .00113 L
.80791 .00113 L
.81191 .00113 L
.81575 .00113 L
.81945 .00113 L
.82136 .00113 L
.82339 .00113 L
.82429 .00113 L
.82527 .00113 L
.82618 .00112 L
.82703 .00112 L
.8275 .00112 L
.82801 .00112 L
.82829 .00112 L
.82856 .00112 L
.82881 .00112 L
.82894 .00112 L
.82907 .00112 L
.82918 .00112 L
.8293 .00112 L
.82937 .00112 L
.82944 .00112 L
.82956 .00112 L
.82962 .00112 L
.82969 .00112 L
.82981 .00112 L
.82987 .00112 L
Mistroke
.82993 .00112 L
.83008 .00112 L
.83019 .00112 L
.83031 .00112 L
.83052 .00112 L
.83075 .00112 L
.831 .00112 L
.83151 .00112 L
.83199 .00112 L
.83289 .00112 L
.83386 .00113 L
.83491 .00113 L
.83682 .00113 L
.83885 .00113 L
.8425 .00113 L
.84639 .00113 L
.85013 .00113 L
.8541 .00113 L
.85793 .00114 L
.86162 .00114 L
.86554 .00115 L
.86931 .00115 L
.87332 .00116 L
.87719 .00116 L
.88091 .00117 L
.88486 .00118 L
.88867 .00119 L
.89233 .0012 L
.89623 .00121 L
.89998 .00122 L
.90397 .00123 L
.90782 .00124 L
.91151 .00126 L
.91545 .00127 L
.91923 .00129 L
.92287 .0013 L
.92675 .00132 L
.93048 .00134 L
.93445 .00136 L
.93827 .00138 L
.94195 .00141 L
.94586 .00143 L
.94963 .00146 L
.95363 .00149 L
.95749 .00153 L
.9612 .00156 L
.96514 .0016 L
.96894 .00164 L
.9726 .00168 L
.97619 .00173 L
Mistroke
Mfstroke
0 1 0 r
.002 w
.0277 .61803 m
.02803 .56833 L
.02855 .50583 L
.02948 .42265 L
.03049 .35916 L
.03159 .30839 L
.03258 .27395 L
.03348 .24868 L
.03549 .20608 L
.03733 .17834 L
.03933 .15567 L
.04124 .13896 L
.04326 .12483 L
.0469 .10574 L
.05078 .09119 L
.0545 .08074 L
.05847 .07219 L
.06229 .0657 L
.06596 .06064 L
.06987 .05623 L
.07364 .0527 L
.07764 .04958 L
.08149 .04706 L
.0852 .04501 L
.08914 .04317 L
.09294 .04167 L
.09659 .04047 L
.10048 .0394 L
.10422 .03856 L
.1082 .03786 L
.11019 .03759 L
.11203 .03737 L
.11393 .03718 L
.11572 .03704 L
.11667 .03698 L
.1177 .03693 L
.11863 .03689 L
.11949 .03686 L
.11995 .03685 L
.12043 .03684 L
.12067 .03684 L
.12089 .03684 L
.12109 .03684 L
.12131 .03683 L
.12144 .03683 L
.12155 .03683 L
.12168 .03683 L
.12175 .03683 L
.12181 .03683 L
.12194 .03683 L
Mistroke
.12201 .03683 L
.12207 .03683 L
.12214 .03683 L
.12221 .03683 L
.12235 .03683 L
.12247 .03683 L
.12258 .03684 L
.12284 .03684 L
.12307 .03684 L
.1233 .03684 L
.12378 .03685 L
.12422 .03686 L
.1252 .0369 L
.1261 .03693 L
.12696 .03698 L
.12888 .03712 L
.13065 .03728 L
.13443 .03777 L
.13807 .03844 L
.14194 .03938 L
.14567 .04056 L
.14963 .04215 L
.15345 .04409 L
.15712 .04644 L
.16102 .0496 L
.16478 .0535 L
.16878 .05895 L
.17263 .06608 L
.17633 .07562 L
.17825 .08211 L
.18028 .09068 L
.18216 .10083 L
.18392 .11306 L
.18588 .13127 L
.18766 .15474 L
.18861 .17138 L
.18949 .19063 L
.19046 .21777 L
.191 .23661 L
.19149 .25715 L
.19248 .31164 L
.19301 .35061 L
.19356 .40344 L
.19404 .46321 L
.19448 .53519 L
Mfstroke
.19448 .53519 m
.19488 .61803 L
s
.19833 .61803 m
.19856 .56266 L
.199 .4807 L
.19949 .4115 L
.19999 .35663 L
.20047 .31569 L
.20137 .25861 L
.20187 .23445 L
.20233 .21558 L
.20338 .18188 L
.2044 .15748 L
.20536 .13958 L
.20716 .11473 L
.2091 .09581 L
.21088 .08294 L
.2127 .07274 L
.21469 .06393 L
.21674 .05672 L
.2186 .05134 L
.22236 .04287 L
.2262 .03647 L
.2299 .03174 L
.23384 .02778 L
.23763 .02471 L
.24128 .02227 L
.24516 .0201 L
.2489 .01833 L
.25287 .01672 L
.2567 .0154 L
.26038 .01428 L
.26429 .01324 L
.26806 .01236 L
.27207 .01153 L
.27593 .01081 L
.27964 .0102 L
.2836 .00961 L
.2874 .0091 L
.29106 .00866 L
.29495 .00823 L
.2987 .00785 L
.30269 .00748 L
.30653 .00716 L
.31022 .00687 L
.31415 .0066 L
.31793 .00635 L
.32157 .00613 L
.32545 .00591 L
.32917 .00572 L
.33314 .00554 L
.33696 .00537 L
Mistroke
.34063 .00522 L
.34454 .00507 L
.3483 .00494 L
.3523 .00481 L
.35615 .0047 L
.35985 .0046 L
.3638 .0045 L
.36759 .00441 L
.37124 .00434 L
.37513 .00426 L
.37887 .0042 L
.38285 .00413 L
.38668 .00408 L
.39037 .00403 L
.39429 .00399 L
.39806 .00395 L
.40208 .00392 L
.40594 .00389 L
.40966 .00387 L
.41155 .00387 L
.41362 .00386 L
.41559 .00385 L
.41647 .00385 L
.41743 .00385 L
.41795 .00385 L
.41844 .00385 L
.41889 .00385 L
.41939 .00385 L
.41961 .00385 L
.41984 .00385 L
.42004 .00385 L
.42026 .00385 L
.42049 .00385 L
.42062 .00385 L
.42074 .00385 L
.42085 .00385 L
.42095 .00385 L
.42107 .00385 L
.42118 .00385 L
.42129 .00385 L
.42141 .00385 L
.42152 .00385 L
.42163 .00385 L
.42188 .00385 L
.42212 .00385 L
.42259 .00385 L
.42311 .00385 L
.42404 .00385 L
.42489 .00385 L
.42669 .00386 L
Mistroke
.42867 .00386 L
.43053 .00387 L
.43254 .00388 L
.4365 .0039 L
.44032 .00393 L
.44399 .00396 L
.44789 .00401 L
.45165 .00406 L
.45565 .00413 L
.4595 .0042 L
.4632 .00428 L
.46714 .00439 L
.47093 .0045 L
.47458 .00462 L
.47846 .00477 L
.4822 .00494 L
.48618 .00514 L
.49 .00537 L
.49369 .00562 L
.4976 .00594 L
.50138 .0063 L
.50539 .00676 L
.50925 .0073 L
.51296 .00794 L
.51692 .00878 L
.52072 .00984 L
.52439 .01119 L
.52642 .01213 L
.52828 .01317 L
.53203 .016 L
.53387 .01793 L
.53587 .02069 L
.53778 .02432 L
.53874 .02671 L
.53981 .02999 L
.54078 .03382 L
.54167 .03834 L
.54265 .04498 L
.54314 .04929 L
.54368 .05508 L
.54419 .06199 L
.54467 .07033 L
.5451 .08001 L
.54557 .09403 L
.54582 .10343 L
.54608 .11617 L
.54636 .13325 L
.54662 .15431 L
.54687 .1807 L
.54709 .21344 L
Mistroke
.54721 .23659 L
.54735 .26741 L
.54759 .34382 L
.54784 .45178 L
.54797 .50966 L
.54803 .53178 L
.54811 .5457 L
.54817 .5468 L
.54824 .53614 L
.54836 .49327 L
.54859 .38635 L
.54871 .33919 L
.54883 .29642 L
.54894 .26531 L
.54906 .23789 L
.54929 .19788 L
.54949 .17064 L
.54973 .14683 L
.54999 .12743 L
.55045 .10262 L
.55074 .09165 L
.55101 .08315 L
.55152 .07076 L
.552 .06191 L
.55244 .05557 L
.55291 .05003 L
.55342 .04515 L
.55433 .03842 L
.55519 .03366 L
.55611 .02972 L
.55711 .02632 L
.55818 .02347 L
.55914 .02134 L
.56102 .01813 L
.56304 .01559 L
.56488 .01381 L
.56688 .01226 L
.5708 .01003 L
.57459 .00851 L
.57822 .00742 L
.5821 .00651 L
.58582 .00582 L
.58979 .00522 L
.5936 .00475 L
.59727 .00437 L
.60118 .00402 L
.60494 .00373 L
.60894 .00346 L
.61279 .00324 L
.61649 .00305 L
Mistroke
.62044 .00287 L
.62423 .00272 L
.62788 .00259 L
.63177 .00246 L
.63551 .00235 L
.63948 .00224 L
.64331 .00215 L
.647 .00207 L
.65092 .00199 L
.65469 .00192 L
.6587 .00185 L
.66257 .00179 L
.66628 .00174 L
.67024 .00169 L
.67405 .00164 L
.67771 .0016 L
.68161 .00156 L
.68536 .00153 L
.68935 .00149 L
.69319 .00146 L
.69689 .00143 L
.70083 .00141 L
.70461 .00138 L
.70825 .00136 L
.71213 .00134 L
.71586 .00133 L
.71983 .00131 L
.72365 .0013 L
.72733 .00129 L
.73124 .00128 L
.73501 .00127 L
.73901 .00126 L
.74287 .00125 L
.74463 .00125 L
.74658 .00125 L
.74849 .00125 L
.74954 .00125 L
.75052 .00125 L
.751 .00125 L
.75153 .00125 L
.75199 .00125 L
.75224 .00125 L
.75248 .00125 L
.75271 .00125 L
.75297 .00125 L
.75308 .00125 L
.7532 .00125 L
.75331 .00125 L
.75341 .00125 L
.75351 .00125 L
Mistroke
.75362 .00125 L
.75372 .00125 L
.75382 .00125 L
.75393 .00125 L
.75403 .00125 L
.75415 .00125 L
.75427 .00125 L
.75438 .00125 L
.75451 .00125 L
.75474 .00125 L
.75517 .00125 L
.75568 .00125 L
.75615 .00125 L
.757 .00125 L
.75791 .00125 L
.75998 .00125 L
.76192 .00125 L
.76564 .00126 L
.76959 .00126 L
.77339 .00127 L
.77705 .00128 L
.78095 .00129 L
.7847 .00131 L
.78868 .00132 L
.79253 .00134 L
.79622 .00136 L
.80015 .00139 L
.80393 .00142 L
.80757 .00145 L
.81145 .00148 L
.81517 .00152 L
.81914 .00157 L
.82296 .00162 L
.82663 .00168 L
.83054 .00175 L
.8343 .00182 L
.8383 .00191 L
.84216 .00202 L
.84586 .00213 L
.84981 .00227 L
.8536 .00243 L
.85725 .00262 L
.86114 .00286 L
.86488 .00314 L
.86886 .00353 L
.87269 .00401 L
.87638 .00465 L
.87828 .00507 L
.8803 .00562 L
.88237 .00632 L
Mistroke
.88431 .00719 L
.88625 .00833 L
.88804 .00977 L
.88898 .01077 L
.88985 .0119 L
.89082 .01346 L
.89185 .01567 L
.89283 .01859 L
.89338 .02079 L
.8939 .02335 L
.89434 .02616 L
.89484 .03018 L
.89509 .03272 L
.89535 .03596 L
.89559 .03939 L
.89584 .04384 L
.89609 .04948 L
.89632 .05601 L
.89655 .06456 L
.89676 .07539 L
.89688 .0833 L
.89701 .09364 L
.89712 .10468 L
.89725 .12013 L
.89738 .14245 L
.89745 .15872 L
.89752 .17684 L
.89758 .19732 L
.89765 .22473 L
.89777 .2925 L
.89789 .37554 L
.89802 .42611 L
.89809 .40224 L
.89815 .3578 L
.89828 .26883 L
.89841 .20724 L
.89848 .18192 L
.89855 .16288 L
.89868 .13383 L
.89876 .12148 L
.89883 .11201 L
.89907 .08772 L
.89921 .07807 L
.89933 .07085 L
.89956 .06053 L
.89981 .0524 L
.90005 .04621 L
.90028 .04154 L
.90071 .0349 L
.90118 .02976 L
Mistroke
.90169 .02563 L
.90213 .02287 L
.90261 .02051 L
.90345 .01728 L
.90445 .0146 L
.90552 .01249 L
.90653 .01098 L
.90746 .00988 L
.90928 .00826 L
.91127 .007 L
.91315 .00611 L
.91517 .00537 L
.91708 .00482 L
.91916 .00433 L
.923 .00364 L
.92693 .00313 L
.93072 .00276 L
.93436 .00247 L
.93823 .00222 L
.94197 .00203 L
.94593 .00185 L
.94975 .00171 L
.95343 .00159 L
.95734 .00149 L
.9611 .0014 L
.9651 .00131 L
.96896 .00124 L
.97267 .00118 L
.97619 .00113 L
Mfstroke
0 0 1 r
.0277 .61803 m
.02803 .56832 L
.02855 .50582 L
.02948 .42264 L
.03049 .35915 L
.03159 .30837 L
.03258 .27393 L
.03348 .24865 L
.03549 .20604 L
.03733 .17828 L
.03933 .1556 L
.04124 .13887 L
.04326 .12471 L
.0469 .10558 L
.05078 .09097 L
.0545 .08046 L
.05847 .07183 L
.06229 .06526 L
.06596 .06011 L
.06987 .05559 L
.07364 .05195 L
.07764 .0487 L
.08149 .04603 L
.0852 .04383 L
.08914 .0418 L
.09294 .04012 L
.09659 .03871 L
.10048 .03739 L
.10422 .0363 L
.1082 .03529 L
.11203 .03446 L
.11572 .03377 L
.11964 .03316 L
.12342 .03266 L
.12743 .03225 L
.12944 .03208 L
.1313 .03194 L
.13322 .03183 L
.13502 .03174 L
.13684 .03167 L
.1378 .03164 L
.13883 .03162 L
.13981 .0316 L
.14037 .03159 L
.14063 .03159 L
.14088 .03159 L
.14111 .03159 L
.14133 .03159 L
.14156 .03159 L
.14169 .03159 L
Mistroke
.14176 .03159 L
.14182 .03159 L
.14194 .03159 L
.14201 .03159 L
.14207 .03159 L
.14218 .03159 L
.1423 .03159 L
.14236 .03159 L
.14243 .03159 L
.14257 .03159 L
.1427 .03159 L
.14282 .03159 L
.14307 .03159 L
.1433 .03159 L
.14383 .0316 L
.14429 .0316 L
.14478 .03161 L
.14563 .03163 L
.14657 .03165 L
.14843 .03171 L
.15044 .03181 L
.15237 .03193 L
.1544 .03208 L
.15807 .03243 L
.16198 .03293 L
.16574 .03354 L
.16973 .03434 L
.17358 .03529 L
.17729 .03639 L
.18123 .0378 L
.18503 .03945 L
.18867 .04136 L
.19256 .04383 L
.1963 .04676 L
.20027 .05066 L
.2041 .05547 L
.20779 .06149 L
.21171 .07015 L
.21548 .08198 L
.21754 .09074 L
.21949 .10123 L
.22143 .1148 L
.22321 .1314 L
.22502 .15468 L
.22605 .17224 L
.22701 .19281 L
.22802 .22054 L
.22898 .25526 L
.22983 .29681 L
.23077 .35878 L
Mistroke
.23264 .56796 L
Mfstroke
.23264 .56796 m
.23299 .61803 L
s
.2352 .61803 m
.23571 .54677 L
.23668 .42224 L
.23754 .3413 L
.23849 .27866 L
.23943 .23379 L
.24043 .19865 L
.24137 .17344 L
.24223 .15528 L
.24409 .12592 L
.24514 .11357 L
.2461 .10406 L
.24807 .08855 L
.24991 .07753 L
.25358 .06172 L
.25555 .05546 L
.25734 .05069 L
.26118 .04258 L
.26488 .03671 L
.26882 .03187 L
.27261 .02816 L
.27626 .02524 L
.28014 .02266 L
.28388 .02057 L
.28785 .01869 L
.29168 .01713 L
.29536 .01582 L
.29927 .0146 L
.30304 .01357 L
.30705 .0126 L
.31091 .01177 L
.31462 .01105 L
.31858 .01037 L
.32238 .00977 L
.32604 .00925 L
.32993 .00874 L
.33368 .0083 L
.33767 .00786 L
.34151 .00748 L
.3452 .00714 L
.34913 .00681 L
.35291 .00651 L
.35655 .00625 L
.36043 .00599 L
.36415 .00575 L
.36812 .00552 L
.37193 .00531 L
.37561 .00513 L
.37952 .00494 L
.38328 .00478 L
Mistroke
.38728 .00461 L
.39113 .00446 L
.39483 .00433 L
.39878 .0042 L
.40257 .00408 L
.40622 .00397 L
.41011 .00386 L
.41385 .00376 L
.41783 .00367 L
.42166 .00358 L
.42535 .0035 L
.42927 .00343 L
.43304 .00336 L
.43705 .00329 L
.44092 .00323 L
.44464 .00318 L
.4486 .00312 L
.45241 .00308 L
.45607 .00304 L
.45997 .003 L
.46372 .00297 L
.46771 .00294 L
.47156 .00292 L
.47526 .00291 L
.47713 .0029 L
.47919 .00289 L
.48013 .00289 L
.48115 .00289 L
.4821 .00289 L
.48298 .00289 L
.48346 .00289 L
.4839 .00289 L
.48439 .00289 L
.48466 .00289 L
.48491 .00289 L
.48516 .00289 L
.48529 .00289 L
.48536 .00289 L
.48542 .00289 L
.48554 .00288 L
.48567 .00288 L
.48578 .00288 L
.48589 .00288 L
.48602 .00289 L
.48608 .00289 L
.48615 .00289 L
.4864 .00289 L
.48653 .00289 L
.48668 .00289 L
.48695 .00289 L
Mistroke
.48743 .00289 L
.48787 .00289 L
.48888 .00289 L
.48986 .00289 L
.49091 .00289 L
.49296 .0029 L
.49491 .0029 L
.49861 .00292 L
.50255 .00295 L
.50634 .00298 L
.50999 .00302 L
.51387 .00308 L
.51761 .00314 L
.52159 .00323 L
.52541 .00332 L
.5291 .00344 L
.53301 .00358 L
.53679 .00374 L
.5408 .00396 L
.54466 .00421 L
.54837 .00451 L
.55233 .00491 L
.55613 .0054 L
.55979 .00602 L
.56369 .0069 L
.56744 .00811 L
.56949 .00901 L
.57143 .01008 L
.57335 .01147 L
.57512 .01317 L
.57692 .01556 L
.57795 .01737 L
.57891 .01953 L
.57986 .02228 L
.58086 .02619 L
.58171 .03084 L
.58219 .03431 L
.58264 .03834 L
.58313 .04396 L
.58338 .04764 L
.58365 .05228 L
.58389 .05717 L
.58415 .06372 L
.58439 .07124 L
.58461 .07985 L
.58484 .09141 L
.58506 .10596 L
.58529 .12734 L
.58542 .14371 L
.58554 .16311 L
Mistroke
.58565 .18682 L
.58576 .21624 L
.58585 .25152 L
.58596 .30449 L
.58607 .39255 L
.58619 .54901 L
Mfstroke
.58619 .54901 m
.58622 .61803 L
s
.58658 .61803 m
.58658 .60009 L
.58665 .48729 L
.58676 .36195 L
.58688 .28116 L
.58699 .233 L
.58711 .19633 L
.58722 .17076 L
.58732 .15249 L
.58756 .12141 L
.5877 .1088 L
.58782 .09921 L
.58805 .08539 L
.5883 .07432 L
.58853 .06632 L
.58878 .05939 L
.58923 .0499 L
.58967 .04317 L
.59007 .03839 L
.59052 .03414 L
.59101 .03051 L
.59188 .02558 L
.59292 .02144 L
.59387 .01867 L
.59483 .01652 L
.59571 .01492 L
.59771 .01223 L
.59951 .01051 L
.60149 .0091 L
.60336 .00807 L
.60537 .0072 L
.60726 .00653 L
.60933 .00592 L
.61315 .00506 L
.61705 .0044 L
.62081 .00392 L
.62481 .00351 L
.62866 .00319 L
.63237 .00294 L
.63631 .00272 L
.64011 .00254 L
.64375 .00239 L
.64764 .00225 L
.65138 .00214 L
.65536 .00203 L
.65919 .00194 L
.66287 .00186 L
.66679 .00179 L
.67056 .00173 L
.67458 .00167 L
Mistroke
.67844 .00162 L
.68216 .00157 L
.68611 .00153 L
.68992 .00149 L
.69358 .00146 L
.69748 .00143 L
.70124 .00141 L
.70523 .00138 L
.70907 .00136 L
.71277 .00134 L
.7167 .00132 L
.72049 .00131 L
.72413 .0013 L
.72801 .00128 L
.73174 .00127 L
.73571 .00127 L
.73953 .00126 L
.7432 .00125 L
.74711 .00125 L
.74892 .00125 L
.75088 .00124 L
.75195 .00124 L
.75294 .00124 L
.75394 .00124 L
.75488 .00124 L
.75576 .00124 L
.7562 .00124 L
.75669 .00124 L
.75697 .00124 L
.75723 .00124 L
.75749 .00124 L
.75773 .00124 L
.75785 .00124 L
.75797 .00124 L
.75809 .00124 L
.75819 .00124 L
.75831 .00124 L
.75843 .00124 L
.7585 .00124 L
.75856 .00124 L
.75868 .00124 L
.7588 .00124 L
.75887 .00124 L
.75893 .00124 L
.7592 .00124 L
.75942 .00124 L
.75967 .00124 L
.76023 .00124 L
.76074 .00124 L
.76173 .00124 L
Mistroke
.76268 .00124 L
.76459 .00124 L
.76636 .00124 L
.77013 .00125 L
.77414 .00125 L
.778 .00126 L
.78171 .00127 L
.78567 .00127 L
.78947 .00128 L
.79313 .0013 L
.79703 .00131 L
.80078 .00132 L
.80476 .00134 L
.8086 .00136 L
.8123 .00138 L
.81623 .0014 L
.82001 .00142 L
.82365 .00145 L
.82752 .00148 L
.83125 .00151 L
.83522 .00155 L
.83904 .00159 L
.84271 .00163 L
.84662 .00167 L
.85038 .00173 L
.85438 .00179 L
.85823 .00185 L
.86194 .00192 L
.86588 .002 L
.86968 .00209 L
.87333 .00219 L
.87722 .00231 L
.88096 .00244 L
.88494 .0026 L
.88877 .00278 L
.89246 .00299 L
.89638 .00325 L
.90016 .00355 L
.90417 .00396 L
.90803 .00446 L
.91176 .00509 L
.91364 .0055 L
.91571 .00603 L
.91952 .00734 L
.92141 .00825 L
.92342 .00952 L
.92441 .0103 L
.92547 .0113 L
.9264 .01235 L
.92741 .01377 L
Mistroke
.9284 .0155 L
.92932 .01757 L
.9303 .02048 L
.93085 .02259 L
.93135 .02494 L
.93181 .02757 L
.9323 .03107 L
.93276 .03531 L
.93318 .0403 L
.93367 .04835 L
.93395 .05449 L
.9342 .0617 L
.93443 .06977 L
.93468 .08145 L
.9348 .08892 L
.93493 .09859 L
.93517 .12241 L
.93529 .13846 L
.93542 .1615 L
.93556 .19436 L
.93568 .23757 L
.93591 .35813 L
.93603 .4196 L
.93615 .42366 L
.93622 .3937 L
.93629 .35109 L
.93642 .2775 L
.93655 .22221 L
.93667 .18585 L
.9368 .15498 L
.93695 .13077 L
.93709 .11372 L
.93722 .10139 L
.93745 .08476 L
.93767 .0734 L
.9379 .06395 L
.93816 .05615 L
.93843 .04978 L
.93868 .04492 L
.93916 .03795 L
.93964 .03276 L
.94008 .02914 L
.94055 .02603 L
.94107 .02334 L
.94198 .01969 L
.94284 .01715 L
.94376 .01508 L
.94476 .0133 L
.94582 .01183 L
.94679 .01074 L
Mistroke
.94867 .0091 L
.95069 .00781 L
.95253 .00691 L
.95453 .00614 L
.9564 .00556 L
.95847 .00503 L
.96225 .00427 L
.96613 .00369 L
.96986 .00327 L
.97382 .0029 L
.97619 .00272 L
Mfstroke
1 0 1 r
.0277 .61803 m
.02803 .56834 L
.02855 .50583 L
.02948 .42266 L
.03049 .35917 L
.03159 .30841 L
.03258 .27398 L
.03348 .24871 L
.03549 .20613 L
.03733 .1784 L
.03933 .15575 L
.04124 .13906 L
.04326 .12496 L
.0469 .10593 L
.05078 .09145 L
.0545 .0811 L
.05847 .07266 L
.06229 .0663 L
.06596 .06139 L
.06987 .05716 L
.07364 .05385 L
.07764 .05098 L
.08149 .04875 L
.0852 .04703 L
.08914 .04559 L
.0911 .04502 L
.09294 .04456 L
.09481 .04417 L
.09659 .04388 L
.09753 .04375 L
.09855 .04363 L
.09947 .04354 L
.10033 .04348 L
.10081 .04345 L
.10133 .04342 L
.1018 .04341 L
.10223 .04339 L
.10247 .04339 L
.1027 .04339 L
.10283 .04338 L
.10295 .04338 L
.10302 .04338 L
.10309 .04338 L
.10315 .04338 L
.10322 .04338 L
.10334 .04338 L
.10346 .04338 L
.10358 .04338 L
.10365 .04338 L
.10372 .04338 L
Mistroke
.10398 .04339 L
.10411 .04339 L
.10425 .04339 L
.10477 .04341 L
.10525 .04343 L
.10615 .04348 L
.10712 .04356 L
.10817 .04367 L
.11009 .04394 L
.11212 .04434 L
.11401 .04482 L
.11578 .04537 L
.11952 .0469 L
.12351 .0492 L
.12734 .05226 L
.13103 .05628 L
.1329 .05883 L
.13496 .0622 L
.13874 .07037 L
.14061 .07573 L
.14262 .08295 L
.14454 .09182 L
.14658 .1042 L
.14848 .12009 L
.15025 .14098 L
.15126 .15711 L
.15222 .17661 L
.15308 .19923 L
.15401 .23202 L
.15492 .27738 L
.15544 .31251 L
.15592 .35488 L
.15643 .41429 L
.1569 .48935 L
.15716 .54363 L
Mfstroke
.15716 .54363 m
.15744 .61803 L
s
.16104 .61803 m
.16128 .54953 L
.16172 .45471 L
.1622 .38151 L
.16264 .33227 L
.16315 .28875 L
.16363 .25669 L
.16448 .21387 L
.1654 .1807 L
.16631 .1563 L
.16731 .13584 L
.16836 .11928 L
.16934 .10692 L
.1713 .0883 L
.17309 .07593 L
.17492 .0662 L
.17692 .05794 L
.17898 .05121 L
.18085 .04626 L
.18462 .03851 L
.18849 .03273 L
.19222 .0285 L
.19618 .02499 L
.19999 .0223 L
.20366 .02017 L
.20756 .0183 L
.21132 .01678 L
.21531 .01542 L
.21916 .0143 L
.22286 .01336 L
.2268 .01249 L
.23059 .01176 L
.23423 .01114 L
.23811 .01055 L
.24185 .01004 L
.24582 .00956 L
.24965 .00914 L
.25333 .00878 L
.25725 .00844 L
.26102 .00813 L
.26502 .00784 L
.26888 .00758 L
.2726 .00736 L
.27655 .00714 L
.28035 .00694 L
.28401 .00677 L
.28791 .00661 L
.29166 .00646 L
.29564 .00632 L
.29948 .00619 L
Mistroke
.30317 .00608 L
.3071 .00597 L
.31089 .00588 L
.31453 .00579 L
.3184 .00571 L
.32213 .00564 L
.32609 .00558 L
.32991 .00552 L
.33358 .00547 L
.33749 .00542 L
.34125 .00539 L
.34525 .00535 L
.3491 .00533 L
.35281 .00531 L
.35472 .0053 L
.35675 .0053 L
.35766 .00529 L
.35864 .00529 L
.35955 .00529 L
.3604 .00529 L
.36091 .00529 L
.36138 .00529 L
.36189 .00529 L
.36218 .00529 L
.36244 .00529 L
.36268 .00529 L
.3628 .00529 L
.36287 .00529 L
.36293 .00529 L
.36304 .00529 L
.36316 .00529 L
.36327 .00529 L
.36337 .00529 L
.36349 .00529 L
.36356 .00529 L
.36362 .00529 L
.36386 .00529 L
.36399 .00529 L
.36413 .00529 L
.36438 .00529 L
.36486 .00529 L
.3653 .00529 L
.36631 .00529 L
.3673 .00529 L
.36835 .00529 L
.37041 .0053 L
.37235 .0053 L
.37606 .00532 L
.38001 .00535 L
.38381 .00538 L
Mistroke
.38747 .00542 L
.39136 .00547 L
.39511 .00552 L
.39909 .00559 L
.40293 .00566 L
.40662 .00574 L
.41054 .00584 L
.41432 .00595 L
.41796 .00607 L
.42183 .0062 L
.42555 .00635 L
.42951 .00653 L
.43333 .00673 L
.437 .00694 L
.4409 .0072 L
.44466 .00748 L
.44866 .00782 L
.45251 .00819 L
.45621 .00861 L
.46015 .00913 L
.46394 .00972 L
.46759 .0104 L
.47147 .01126 L
.47521 .01229 L
.47919 .01366 L
.48301 .01537 L
.4867 .01756 L
.48875 .01911 L
.49061 .02082 L
.49439 .02553 L
.49624 .02882 L
.49825 .03356 L
.50017 .03996 L
.50114 .04424 L
.5022 .05019 L
.50319 .05739 L
.50408 .06607 L
.50458 .07211 L
.50512 .0801 L
.50562 .08939 L
.5061 .10031 L
.50653 .11296 L
.507 .13064 L
.50726 .14264 L
.50753 .15778 L
.50801 .19397 L
.50825 .21868 L
.50851 .25186 L
.50897 .33559 L
.50926 .40194 L
Mistroke
.5094 .43458 L
.50946 .44762 L
.50953 .46032 L
.50964 .4765 L
.50977 .48293 L
.50983 .48135 L
.5099 .47593 L
.51003 .45765 L
.5105 .34943 L
.51076 .29541 L
.51101 .25446 L
.5113 .21654 L
.51156 .18987 L
.51181 .16956 L
.51207 .15209 L
.51256 .12741 L
.513 .11066 L
.51348 .09681 L
.51401 .08504 L
.51452 .07607 L
.515 .06912 L
.51589 .05897 L
.51686 .05085 L
.51791 .04419 L
.51982 .03561 L
.52079 .03241 L
.52185 .02946 L
.52372 .02537 L
.52573 .02203 L
.52776 .01941 L
.5297 .01742 L
.53338 .01454 L
.53729 .01232 L
.54106 .01071 L
.54507 .00938 L
.54893 .00837 L
.55264 .00756 L
.55659 .00685 L
.56039 .00627 L
.56405 .00579 L
.56795 .00535 L
.57169 .00498 L
.57568 .00463 L
.57952 .00434 L
.58321 .00408 L
.58714 .00384 L
.59092 .00363 L
.59456 .00345 L
.59843 .00327 L
.60215 .00312 L
Mistroke
.60612 .00297 L
.60993 .00284 L
.61361 .00272 L
.61751 .0026 L
.62127 .0025 L
.62527 .0024 L
.62912 .00231 L
.63283 .00223 L
.63677 .00215 L
.64056 .00208 L
.64421 .00201 L
.6481 .00195 L
.65184 .00189 L
.65582 .00184 L
.65965 .00178 L
.66333 .00174 L
.66725 .00169 L
.67102 .00165 L
.67503 .00161 L
.6789 .00157 L
.68262 .00154 L
.68657 .00151 L
.69038 .00148 L
.69404 .00145 L
.69794 .00142 L
.7017 .0014 L
.70568 .00138 L
.70953 .00136 L
.71322 .00134 L
.71716 .00132 L
.72095 .00131 L
.72459 .00129 L
.72846 .00128 L
.7322 .00127 L
.73616 .00126 L
.73814 .00126 L
.73999 .00126 L
.74188 .00126 L
.74366 .00125 L
.74461 .00125 L
.74564 .00125 L
.74656 .00125 L
.74743 .00125 L
.74791 .00125 L
.74834 .00125 L
.74883 .00125 L
.74909 .00125 L
.74935 .00125 L
.74947 .00125 L
.74959 .00125 L
Mistroke
.74966 .00125 L
.74973 .00125 L
.74985 .00125 L
.74997 .00125 L
.75009 .00125 L
.7502 .00125 L
.75032 .00125 L
.75039 .00125 L
.75045 .00125 L
.75058 .00125 L
.75072 .00125 L
.75086 .00125 L
.75113 .00125 L
.75137 .00125 L
.75182 .00125 L
.75231 .00125 L
.75318 .00125 L
.75422 .00125 L
.75517 .00125 L
.757 .00126 L
.75899 .00126 L
.76291 .00126 L
.76668 .00127 L
.77069 .00129 L
.77455 .0013 L
.77827 .00132 L
.78222 .00135 L
.78602 .00137 L
.78968 .00141 L
.79358 .00145 L
.79733 .00149 L
.80131 .00155 L
.80515 .00162 L
.80885 .00169 L
.81278 .00179 L
.81656 .0019 L
.8202 .00203 L
.82408 .0022 L
.8278 .00241 L
.83177 .0027 L
.83559 .00307 L
.83926 .00356 L
.84115 .00389 L
.84317 .00432 L
.84523 .00489 L
.84717 .0056 L
.8491 .00656 L
.85088 .0078 L
.85181 .00867 L
.85268 .0097 L
Mistroke
.85364 .01115 L
.85418 .01217 L
.85467 .0133 L
.85565 .0163 L
.85617 .01851 L
.85671 .02165 L
.85697 .02348 L
.85724 .02584 L
.85748 .02836 L
.85773 .03162 L
.85796 .03529 L
.85821 .04044 L
.85844 .04663 L
.85865 .0544 L
.85877 .06016 L
.8589 .06776 L
.85901 .07597 L
.85914 .08765 L
.85927 .10495 L
.85934 .11801 L
.85941 .13317 L
.85953 .17425 L
.85959 .2059 L
.85966 .25619 L
.85979 .44952 L
Mfstroke
.85979 .44952 m
.85983 .61803 L
s
.86 .61803 m
.86003 .49792 L
.86016 .2747 L
.86027 .18956 L
.8604 .14214 L
.8605 .11697 L
.86062 .09786 L
.86074 .08365 L
.86085 .07351 L
.86106 .05988 L
.86118 .05424 L
.86129 .04989 L
.86154 .04222 L
.86174 .0376 L
.86196 .03354 L
.86241 .02752 L
.86263 .02522 L
.86288 .0231 L
.86338 .01976 L
.86384 .01742 L
.86427 .01569 L
.86524 .0128 L
.86578 .0116 L
.86628 .01069 L
.86717 .00936 L
.86812 .00826 L
.86917 .00732 L
.87013 .00662 L
.87201 .00558 L
.87378 .00486 L
.87573 .00425 L
.87751 .00381 L
.8795 .00342 L
.88134 .00313 L
.88503 .00267 L
.8888 .00232 L
.89281 .00204 L
.89667 .00183 L
.90039 .00167 L
.90434 .00153 L
.90815 .00142 L
.91181 .00132 L
.91571 .00124 L
.91946 .00117 L
.92345 .00111 L
.92729 .00106 L
.93099 .00101 L
.93492 .00097 L
.93871 .00094 L
.94235 .00091 L
Mistroke
.94622 .00088 L
.94995 .00085 L
.95392 .00083 L
.95774 .00081 L
.96141 .00079 L
.96533 .00078 L
.96909 .00076 L
.97309 .00075 L
.97619 .00074 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Receiving Coil", "Section",
  InitializationCell->True],

Cell["\<\
Note that the effect of a receiving coil is not mentioned in the equations \
above. Therefore they are only valid for a low power consumption at the \
receiving coil.\
\>", "Text",
  InitializationCell->True],

Cell["Index 2 for the receiving coil.", "Text",
  InitializationCell->True],

Cell["Faraday again:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(U2[t] := \[ImaginaryI]\ w\ N2\ A\ B[t]\)], "Input",
  InitializationCell->True],

Cell["\<\
This shows that the voltage of the receiving coil is related to the voltage \
of exciting coil. This is the same equation like for a transformer. Therefore \
the magnetostrictive effect can only be measured because of the internal \
resistance of the voltage source.\
\>", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(U2[t]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ t\ w\)\ N2\ Ud\)\/N\)], "Output"]
}, Open  ]],

Cell["\<\
An other method to detect the magnetostrictive effect is by measuring the \
current at the receiving coil:\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(i2[t_] := \(Hq2[t]*lCoil2\)\/N2*K2\)], "Input",
  InitializationCell->True],

Cell["With the average field strength:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(Hq2[
        t_] := \[Integral]\_x2\%\(x2 + lCoil2\)\(H[x, 
                t]\/lCoil2\) \[DifferentialD]x\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(i2a[t_] = 
        Simplify[\(\(i2[t] /. rulea2\) /. rulea1\) /. ruleUd];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Now the power output of the receiving coil is calculated (complex - real part \
is active power, complex part is reactive power):\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(P2[t] = U2[t]*i2a[t];\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "This is the ",
  StyleBox["effective",
    FontWeight->"Bold"],
  " (time independent) apparent power:"
}], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(P2a = 
        1/2*Simplify[Abs[U2[t]], cond1]*Simplify[Abs[i2a[t]], cond1] /. 
          ruleUd;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Further simplification, with dividing every complex variable into real and \
imaginary part (and into absolute part and argument, respectively): \
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(P2as = 
        ComplexExpand[P2a /. ZC \[Rule] ZCr + \[ImaginaryI]\ ZCi, \ 
          TargetFunctions -> {Re, \ Im}];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Note that \"ComplexExpand\" assumes all vaiables to be real. This means we \
define the amplitude U0d to be real.\
\>", "Text"],

Cell[TextData[StyleBox["With:",
  FontSlant->"Italic"]], "Text",
  InitializationCell->True],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`ZC\_R\)]]], "Text",
  InitializationCell->True],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`ZC\_i\)]]], "Text",
  InitializationCell->True],

Cell["Further simplification:", "Text",
  InitializationCell->True],

Cell[BoxData[
    \( (*P2axs = 
        Simplify[P2ax, cond1, Trig \[Rule] False, 
          TimeConstraint \[Rule] 50\ ]*) \)], "Input",
  InitializationCell->True],

Cell["Zero Impedance - ", "Subsubsection",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 791}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowSize->{1040, 726},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
SpellingDictionaries->{"CorrectWords"->{
  "Gladwell's", "refering", "Gladwell", "Ud", "a2", "rulea1", "a1"}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 53, 0, 115, "Title"],
Cell[1783, 54, 657, 12, 125, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2465, 70, 77, 1, 59, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2567, 75, 83, 2, 30, "Input",
  InitializationCell->True],
Cell[2653, 79, 129, 2, 70, "Message"]
}, Open  ]],
Cell[2797, 84, 85, 2, 30, "Input",
  InitializationCell->True],
Cell[2885, 88, 81, 2, 30, "Input",
  InitializationCell->True],
Cell[2969, 92, 84, 2, 30, "Input",
  InitializationCell->True],
Cell[3056, 96, 96, 2, 30, "Input",
  InitializationCell->True],
Cell[3155, 100, 82, 2, 30, "Input",
  InitializationCell->True],
Cell[3240, 104, 80, 2, 30, "Input",
  InitializationCell->True],
Cell[3323, 108, 77, 2, 30, "Input",
  InitializationCell->True],
Cell[3403, 112, 87, 2, 30, "Input",
  InitializationCell->True],
Cell[3493, 116, 87, 2, 30, "Input",
  InitializationCell->True],
Cell[3583, 120, 87, 2, 30, "Input",
  InitializationCell->True],
Cell[3673, 124, 87, 2, 30, "Input",
  InitializationCell->True],
Cell[3763, 128, 117, 2, 30, "Input",
  InitializationCell->True],
Cell[3883, 132, 93, 2, 30, "Input",
  InitializationCell->True],
Cell[3979, 136, 93, 2, 30, "Input",
  InitializationCell->True],
Cell[4075, 140, 85, 2, 30, "Input",
  InitializationCell->True],
Cell[4163, 144, 369, 6, 50, "Input",
  InitializationCell->True],
Cell[4535, 152, 92, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4652, 157, 89, 2, 30, "Input",
  InitializationCell->True],
Cell[4744, 161, 52, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4845, 168, 64, 1, 39, "Section",
  InitializationCell->True],
Cell[4912, 171, 19777, 247, 117, 19679, 244, "GraphicsData", "Metafile", \
"Graphics"],

Cell[CellGroupData[{
Cell[24714, 422, 41, 0, 47, "Subsection"],
Cell[24758, 424, 73, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[24856, 428, 132, 2, 30, "Input"],
Cell[24991, 432, 408, 12, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25448, 450, 67, 1, 47, "Subsection",
  InitializationCell->True],
Cell[25518, 453, 139, 4, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[25682, 461, 104, 2, 30, "Input",
  InitializationCell->True],
Cell[25789, 465, 170, 5, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26008, 476, 65, 1, 47, "Subsection",
  InitializationCell->True],
Cell[26076, 479, 487, 10, 52, "Text",
  InitializationCell->True],
Cell[26566, 491, 118, 2, 30, "Input",
  InitializationCell->True],
Cell[26687, 495, 511, 12, 131, "Text",
  InitializationCell->True],
Cell[27201, 509, 100, 2, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[27326, 515, 77, 2, 30, "Input",
  InitializationCell->True],
Cell[27406, 519, 266, 7, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27721, 532, 64, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[27810, 536, 40, 1, 30, "Input"],
Cell[27853, 539, 439, 13, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28341, 558, 101, 1, 47, "Subsection",
  InitializationCell->True],
Cell[28445, 561, 140, 4, 33, "Text",
  InitializationCell->True],
Cell[28588, 567, 83, 2, 30, "Input",
  InitializationCell->True],
Cell[28674, 571, 61, 1, 33, "Text",
  InitializationCell->True],
Cell[28738, 574, 110, 2, 31, "Input",
  InitializationCell->True],
Cell[28851, 578, 72, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[28948, 583, 50, 1, 30, "Input"],
Cell[29001, 586, 379, 9, 30, "Output"]
}, Open  ]],
Cell[29395, 598, 197, 5, 33, "Text"],
Cell[29595, 605, 164, 4, 33, "Text",
  InitializationCell->True],
Cell[29762, 611, 97, 2, 30, "Input",
  InitializationCell->True],
Cell[29862, 615, 62, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[29949, 620, 69, 2, 30, "Input",
  InitializationCell->True],
Cell[30021, 624, 39, 1, 40, "Output"]
}, Open  ]],
Cell[30075, 628, 212, 6, 90, "Text",
  InitializationCell->True],
Cell[30290, 636, 72, 1, 33, "Text"],
Cell[30365, 639, 123, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[30513, 646, 76, 1, 33, "Input"],
Cell[30592, 649, 38, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30679, 656, 60, 1, 47, "Subsection",
  InitializationCell->True],
Cell[30742, 659, 127, 3, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[30894, 666, 96, 2, 30, "Input",
  InitializationCell->True],
Cell[30993, 670, 147, 2, 40, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31201, 679, 81, 1, 59, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[31307, 684, 132, 3, 43, "Subsubsection",
  InitializationCell->True],
Cell[31442, 689, 271, 10, 33, "Text",
  InitializationCell->True],
Cell[31716, 701, 104, 2, 42, "Input",
  InitializationCell->True],
Cell[31823, 705, 227, 6, 90, "Text",
  InitializationCell->True],
Cell[32053, 713, 170, 4, 33, "Text",
  InitializationCell->True],
Cell[32226, 719, 213, 5, 33, "Text",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[32476, 729, 74, 1, 43, "Subsubsection",
  InitializationCell->True],
Cell[32553, 732, 336, 6, 52, "Text",
  InitializationCell->True],
Cell[32892, 740, 77, 2, 30, "Input",
  InitializationCell->True],
Cell[32972, 744, 268, 8, 71, "Text",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33289, 758, 207, 8, 59, "Section",
  InitializationCell->True],
Cell[33499, 768, 58700, 727, 145, 58603, 724, "GraphicsData", "Metafile", \
"Graphics"],

Cell[CellGroupData[{
Cell[92224, 1499, 103, 1, 47, "Subsection",
  InitializationCell->True],
Cell[92330, 1502, 93, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[92448, 1507, 98, 2, 30, "Input",
  InitializationCell->True],
Cell[92549, 1511, 191, 3, 46, "Output"]
}, Open  ]],
Cell[92755, 1517, 87, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[92867, 1522, 93, 2, 30, "Input",
  InitializationCell->True],
Cell[92963, 1526, 113, 2, 42, "Output"]
}, Open  ]],
Cell[93091, 1531, 127, 3, 33, "Text",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[93255, 1539, 104, 1, 47, "Subsection",
  InitializationCell->True],
Cell[93362, 1542, 318, 8, 52, "Text",
  InitializationCell->True],
Cell[93683, 1552, 134, 3, 44, "Input",
  InitializationCell->True],
Cell[93820, 1557, 346, 11, 74, "Text",
  InitializationCell->True],
Cell[94169, 1570, 108, 2, 33, "Text",
  InitializationCell->True],
Cell[94280, 1574, 72, 2, 30, "Input",
  InitializationCell->True],
Cell[94355, 1578, 115, 3, 33, "Text",
  InitializationCell->True],
Cell[94473, 1583, 61, 1, 33, "Text",
  InitializationCell->True],
Cell[94537, 1586, 85, 2, 30, "Input",
  InitializationCell->True],
Cell[94625, 1590, 87, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[94737, 1595, 103, 2, 30, "Input",
  InitializationCell->True],
Cell[94843, 1599, 295, 5, 59, "Output"]
}, Open  ]],
Cell[95153, 1607, 92, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[95270, 1612, 86, 2, 30, "Input",
  InitializationCell->True],
Cell[95359, 1616, 312, 5, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95708, 1626, 86, 2, 30, "Input",
  InitializationCell->True],
Cell[95797, 1630, 268, 4, 59, "Output"]
}, Open  ]],
Cell[96080, 1637, 131, 4, 33, "Text",
  InitializationCell->True],
Cell[96214, 1643, 63, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[96302, 1648, 105, 2, 30, "Input",
  InitializationCell->True],
Cell[96410, 1652, 133, 2, 50, "Output"]
}, Open  ]],
Cell[96558, 1657, 219, 7, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[96802, 1668, 155, 4, 42, "Input",
  InitializationCell->True],
Cell[96960, 1674, 160, 4, 29, "Output"]
}, Open  ]],
Cell[97135, 1681, 220, 7, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[97380, 1692, 144, 3, 42, "Input",
  InitializationCell->True],
Cell[97527, 1697, 48, 1, 29, "Output"]
}, Open  ]],
Cell[97590, 1701, 103, 2, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[97718, 1707, 114, 2, 30, "Input",
  InitializationCell->True],
Cell[97835, 1711, 113, 2, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[97985, 1718, 135, 3, 30, "Input",
  InitializationCell->True],
Cell[98123, 1723, 113, 2, 50, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[98285, 1731, 85, 1, 47, "Subsection",
  InitializationCell->True],
Cell[98373, 1734, 95, 1, 33, "Text",
  InitializationCell->True],
Cell[98471, 1737, 105, 2, 32, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[98625, 1745, 89, 1, 59, "Section",
  InitializationCell->True],
Cell[98717, 1748, 31743, 395, 163, 31618, 391, "GraphicsData", "Metafile", \
"Graphics",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[130485, 2147, 75, 1, 47, "Subsection",
  InitializationCell->True],
Cell[130563, 2150, 356, 8, 52, "Text",
  InitializationCell->True],
Cell[130922, 2160, 117, 2, 44, "Input",
  InitializationCell->True],
Cell[131042, 2164, 263, 9, 55, "Text",
  InitializationCell->True],
Cell[131308, 2175, 100, 2, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[131433, 2181, 68, 2, 30, "Input",
  InitializationCell->True],
Cell[131504, 2185, 261, 4, 56, "Output"]
}, Open  ]],
Cell[131780, 2192, 311, 6, 52, "Text",
  InitializationCell->True],
Cell[132094, 2200, 157, 3, 42, "Input",
  InitializationCell->True],
Cell[132254, 2205, 286, 9, 90, "Text",
  InitializationCell->True],
Cell[132543, 2216, 80, 2, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[132648, 2222, 66, 2, 30, "Input",
  InitializationCell->True],
Cell[132717, 2226, 526, 9, 51, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[133292, 2241, 59, 1, 47, "Subsection",
  InitializationCell->True],
Cell[133354, 2244, 158, 4, 28, "SmallText",
  InitializationCell->True],
Cell[133515, 2250, 96, 2, 42, "Input",
  InitializationCell->True],
Cell[133614, 2254, 290, 8, 71, "Text",
  InitializationCell->True],
Cell[133907, 2264, 80, 2, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[134012, 2270, 65, 2, 30, "Input",
  InitializationCell->True],
Cell[134080, 2274, 527, 8, 56, "Output"]
}, Open  ]],
Cell[134622, 2285, 211, 5, 33, "Text",
  InitializationCell->True],
Cell[134836, 2292, 147, 4, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[135008, 2300, 117, 2, 30, "Input",
  InitializationCell->True],
Cell[135128, 2304, 889, 14, 144, "Output"]
}, Open  ]],
Cell[136032, 2321, 137, 5, 52, "Text",
  InitializationCell->True],
Cell[136172, 2328, 100, 2, 33, "Text",
  InitializationCell->True],
Cell[136275, 2332, 122, 3, 30, "Input",
  InitializationCell->True],
Cell[136400, 2337, 104, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[136541, 2344, 70, 1, 47, "Subsection",
  InitializationCell->True],
Cell[136614, 2347, 86, 2, 30, "Input",
  InitializationCell->True],
Cell[136703, 2351, 138, 5, 52, "Text",
  InitializationCell->True],
Cell[136844, 2358, 100, 2, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[136969, 2364, 106, 2, 30, "Input",
  InitializationCell->True],
Cell[137078, 2368, 233, 3, 60, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[137360, 2377, 72, 1, 47, "Subsection",
  InitializationCell->True],
Cell[137435, 2380, 168, 4, 33, "Text",
  InitializationCell->True],
Cell[137606, 2386, 84, 2, 30, "Input",
  InitializationCell->True],
Cell[137693, 2390, 162, 6, 33, "Text",
  InitializationCell->True],
Cell[137858, 2398, 131, 3, 30, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[138038, 2407, 65, 1, 59, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[138128, 2412, 67, 1, 47, "Subsection",
  InitializationCell->True],
Cell[138198, 2415, 178, 4, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[138401, 2423, 705, 13, 250, "Input",
  InitializationCell->True],
Cell[139109, 2438, 427, 7, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[139573, 2450, 173, 3, 72, "Input",
  InitializationCell->True],
Cell[139749, 2455, 151, 2, 70, "Output"]
}, Open  ]],
Cell[139915, 2460, 131, 4, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[140071, 2468, 208, 5, 30, "Input",
  InitializationCell->True],
Cell[140282, 2475, 142, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140461, 2482, 237, 5, 30, "Input",
  InitializationCell->True],
Cell[140701, 2489, 468, 7, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141206, 2501, 85, 2, 30, "Input",
  InitializationCell->True],
Cell[141294, 2505, 145, 2, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[141488, 2513, 70, 1, 31, "Subsection",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[141583, 2518, 59, 1, 43, "Subsubsection",
  InitializationCell->True],
Cell[141645, 2521, 128, 2, 33, "Text",
  InitializationCell->True],
Cell[141776, 2525, 79, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[141880, 2530, 169, 4, 50, "Input",
  InitializationCell->True],
Cell[142052, 2536, 65, 1, 70, "Output"]
}, Open  ]],
Cell[142132, 2540, 131, 4, 33, "Text",
  InitializationCell->True],
Cell[142266, 2546, 1411, 22, 210, "Input",
  InitializationCell->True],
Cell[143680, 2570, 81, 1, 33, "Text",
  InitializationCell->True],
Cell[143764, 2573, 369, 7, 70, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[144158, 2584, 187, 3, 72, "Input",
  InitializationCell->True],
Cell[144348, 2589, 98, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144483, 2596, 97, 2, 30, "Input",
  InitializationCell->True],
Cell[144583, 2600, 335, 6, 70, "Output"]
}, Open  ]],
Cell[144933, 2609, 135, 4, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[145093, 2617, 91, 2, 30, "Input",
  InitializationCell->True],
Cell[145187, 2621, 405, 7, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145629, 2633, 91, 2, 30, "Input",
  InitializationCell->True],
Cell[145723, 2637, 96, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145856, 2644, 109, 2, 30, "Input",
  InitializationCell->True],
Cell[145968, 2648, 447, 7, 70, "Output"]
}, Open  ]],
Cell[146430, 2658, 100, 2, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[146555, 2664, 168, 3, 30, "Input",
  InitializationCell->True],
Cell[146726, 2669, 125, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146888, 2676, 82, 2, 30, "Input",
  InitializationCell->True],
Cell[146973, 2680, 125, 2, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[147147, 2688, 103, 1, 43, "Subsubsection",
  InitializationCell->True],
Cell[147253, 2691, 53, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[147331, 2696, 91, 2, 30, "Input",
  InitializationCell->True],
Cell[147425, 2700, 39, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147501, 2706, 93, 2, 30, "Input",
  InitializationCell->True],
Cell[147597, 2710, 40, 1, 70, "Output"]
}, Open  ]],
Cell[147652, 2714, 54, 1, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[147731, 2719, 92, 2, 30, "Input",
  InitializationCell->True],
Cell[147826, 2723, 39, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147902, 2729, 94, 2, 30, "Input",
  InitializationCell->True],
Cell[147999, 2733, 39, 1, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[148111, 2742, 27, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[148163, 2746, 70, 0, 47, "Subsection"],
Cell[148236, 2748, 143, 2, 30, "Input"],
Cell[148382, 2752, 152, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[148559, 2758, 342, 6, 70, "Input"],
Cell[148904, 2766, 160, 3, 24, "Message"],
Cell[149067, 2771, 161, 3, 24, "Message"],
Cell[149231, 2776, 160, 3, 24, "Message"],
Cell[149394, 2781, 162, 3, 24, "Message"],
Cell[149559, 2786, 8440, 536, 186, 8208, 530, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[158002, 3324, 130, 3, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[158181, 3333, 37, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[158243, 3337, 114, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[158382, 3344, 156, 3, 30, "Input"],
Cell[158541, 3349, 269, 4, 70, "Output"]
}, Open  ]],
Cell[158825, 3356, 167, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[159017, 3363, 249, 5, 50, "Input"],
Cell[159269, 3370, 13666, 767, 70, 13543, 763, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[172938, 4139, 130, 3, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[173117, 4148, 103, 2, 29, "Subsubsection"],
Cell[173223, 4152, 165, 3, 30, "Input"],
Cell[173391, 4157, 204, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[173620, 4165, 343, 6, 50, "Input"],
Cell[173966, 4173, 13034, 813, 297, 12812, 807, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[187003, 4988, 130, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[187206, 4999, 82, 1, 59, "Section",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[187313, 5004, 87, 1, 43, "Subsubsection",
  InitializationCell->True],
Cell[187403, 5007, 141, 4, 33, "Text",
  InitializationCell->True],
Cell[187547, 5013, 112, 2, 30, "Input",
  InitializationCell->True],
Cell[187662, 5017, 235, 5, 33, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[187922, 5026, 78, 2, 30, "Input",
  InitializationCell->True],
Cell[188003, 5030, 79, 1, 30, "Output"]
}, Open  ]],
Cell[188097, 5034, 92, 1, 33, "Text",
  InitializationCell->True],
Cell[188192, 5037, 137, 3, 30, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[188354, 5044, 110, 2, 30, "Input",
  InitializationCell->True],
Cell[188467, 5048, 972, 15, 144, "Output"]
}, Open  ]],
Cell[189454, 5066, 73, 1, 33, "Text",
  InitializationCell->True],
Cell[189530, 5069, 147, 3, 30, "Input",
  InitializationCell->True],
Cell[189680, 5074, 150, 3, 30, "Input",
  InitializationCell->True],
Cell[189833, 5079, 141, 4, 33, "Text",
  InitializationCell->True],
Cell[189977, 5085, 115, 2, 30, "Input",
  InitializationCell->True],
Cell[190095, 5089, 66, 1, 33, "Text",
  InitializationCell->True],
Cell[190164, 5092, 176, 4, 30, "Input",
  InitializationCell->True],
Cell[190343, 5098, 70, 1, 33, "Text",
  InitializationCell->True],
Cell[190416, 5101, 179, 4, 30, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[190644, 5111, 36, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[190705, 5115, 41, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[190771, 5119, 146, 3, 30, "Input"],
Cell[190920, 5124, 277, 5, 45, "Output"]
}, Open  ]],
Cell[191212, 5132, 149, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[191386, 5139, 159, 3, 30, "Input"],
Cell[191548, 5144, 190, 3, 24, "Message"]
}, Open  ]],
Cell[191753, 5150, 149, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[191927, 5157, 840, 14, 130, "Input"],
Cell[192770, 5173, 221, 4, 24, "Message"],
Cell[192994, 5179, 221, 4, 24, "Message"],
Cell[193218, 5185, 220, 4, 24, "Message"],
Cell[193441, 5191, 162, 3, 24, "Message"],
Cell[193606, 5196, 22626, 1160, 186, 22393, 1154, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[216235, 6358, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[216402, 6366, 874, 15, 110, "Input"],
Cell[217279, 6383, 219, 4, 24, "Message"],
Cell[217501, 6389, 221, 4, 24, "Message"],
Cell[217725, 6395, 220, 4, 24, "Message"],
Cell[217948, 6401, 162, 3, 24, "Message"],
Cell[218113, 6406, 8445, 502, 186, 8210, 496, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[226561, 6910, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[226728, 6918, 196, 4, 30, "Input"],
Cell[226927, 6924, 21730, 676, 104, 7260, 493, "GraphicsData", "PostScript", \
"Graphics"],
Cell[248660, 7602, 130, 3, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[248839, 7611, 70, 0, 47, "Subsection"],
Cell[248912, 7613, 161, 3, 33, "Text"],
Cell[249076, 7618, 279, 5, 30, "Input"],
Cell[249358, 7625, 270, 5, 30, "Input"],

Cell[CellGroupData[{
Cell[249653, 7634, 205, 3, 50, "Input"],
Cell[249861, 7639, 52286, 1050, 286, 7585, 494, "GraphicsData", "PostScript", \
"Graphics"],
Cell[302150, 8691, 130, 3, 29, "Output"]
}, Open  ]],
Cell[302295, 8697, 46, 0, 33, "Text"],
Cell[302344, 8699, 77, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[302446, 8704, 120, 2, 30, "Input"],
Cell[302569, 8708, 222, 4, 42, "Message"],
Cell[302794, 8714, 241, 4, 42, "Message"],
Cell[303038, 8720, 241, 4, 42, "Message"],
Cell[303282, 8726, 164, 3, 24, "Message"],
Cell[303449, 8731, 167, 3, 24, "Message"],
Cell[303619, 8736, 167, 3, 24, "Message"],
Cell[303789, 8741, 167, 3, 24, "Message"],
Cell[303959, 8746, 164, 3, 24, "Message"],
Cell[304126, 8751, 52594, 1005, 425, 5833, 423, "GraphicsData", "PostScript", \
"Graphics"],
Cell[356723, 9758, 137, 3, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[356909, 9767, 56, 0, 47, "Subsection"],
Cell[356968, 9769, 21, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[357014, 9773, 59, 1, 30, "Input"],
Cell[357076, 9776, 539, 9, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[357652, 9790, 60, 1, 30, "Input"],
Cell[357715, 9793, 490, 8, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[358242, 9806, 374, 6, 50, "Input"],
Cell[358619, 9814, 37292, 1045, 243, 11183, 718, "GraphicsData", \
"PostScript", "Graphics"],
Cell[395914, 10861, 130, 3, 29, "Output"]
}, Open  ]],
Cell[396059, 10867, 295, 5, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[396391, 10877, 46, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[396462, 10881, 49, 0, 43, "Subsubsection"],
Cell[396514, 10883, 37, 0, 33, "Text"],
Cell[396554, 10885, 148, 2, 30, "Input"],
Cell[396705, 10889, 44, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[396774, 10893, 160, 3, 30, "Input"],
Cell[396937, 10898, 185, 3, 24, "Message"]
}, Open  ]],
Cell[397137, 10904, 58, 0, 33, "Text"],
Cell[397198, 10906, 296, 5, 30, "Input"],
Cell[397497, 10913, 61, 0, 33, "Text"],
Cell[397561, 10915, 338, 5, 43, "Input"],

Cell[CellGroupData[{
Cell[397924, 10924, 725, 13, 92, "Input"],
Cell[398652, 10939, 30301, 1904, 186, 30075, 1898, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[428956, 12845, 130, 3, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[429135, 12854, 65, 0, 43, "Subsubsection"],
Cell[429203, 12856, 37, 0, 33, "Text"],
Cell[429243, 12858, 149, 2, 30, "Input"],
Cell[429395, 12862, 49, 0, 33, "Text"],
Cell[429447, 12864, 166, 3, 30, "Input"],
Cell[429616, 12869, 58, 0, 33, "Text"],
Cell[429677, 12871, 184, 3, 30, "Input"],
Cell[429864, 12876, 61, 0, 33, "Text"],
Cell[429928, 12878, 189, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[430142, 12885, 768, 14, 112, "Input"],
Cell[430913, 12901, 26059, 1637, 70, 25936, 1633, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[456975, 14540, 130, 3, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[457142, 14548, 731, 13, 92, "Input"],
Cell[457876, 14563, 36210, 2289, 70, 36087, 2285, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[494089, 16854, 130, 3, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[494292, 16865, 61, 1, 59, "Section",
  InitializationCell->True],
Cell[494356, 16868, 218, 5, 33, "Text",
  InitializationCell->True],
Cell[494577, 16875, 75, 1, 33, "Text",
  InitializationCell->True],
Cell[494655, 16878, 58, 1, 33, "Text",
  InitializationCell->True],
Cell[494716, 16881, 99, 2, 30, "Input",
  InitializationCell->True],
Cell[494818, 16885, 318, 6, 52, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[495161, 16895, 66, 2, 30, "Input",
  InitializationCell->True],
Cell[495230, 16899, 89, 1, 46, "Output"]
}, Open  ]],
Cell[495334, 16903, 158, 4, 33, "Text",
  InitializationCell->True],
Cell[495495, 16909, 95, 2, 42, "Input",
  InitializationCell->True],
Cell[495593, 16913, 76, 1, 33, "Text",
  InitializationCell->True],
Cell[495672, 16916, 167, 4, 42, "Input",
  InitializationCell->True],
Cell[495842, 16922, 138, 3, 30, "Input",
  InitializationCell->True],
Cell[495983, 16927, 181, 4, 33, "Text",
  InitializationCell->True],
Cell[496167, 16933, 86, 2, 30, "Input",
  InitializationCell->True],
Cell[496256, 16937, 162, 6, 33, "Text",
  InitializationCell->True],
Cell[496421, 16945, 162, 4, 30, "Input",
  InitializationCell->True],
Cell[496586, 16951, 197, 4, 33, "Text",
  InitializationCell->True],
Cell[496786, 16957, 183, 4, 30, "Input",
  InitializationCell->True],
Cell[496972, 16963, 137, 3, 33, "Text"],
Cell[497112, 16968, 92, 2, 33, "Text",
  InitializationCell->True],
Cell[497207, 16972, 98, 2, 29, "Text",
  InitializationCell->True],
Cell[497308, 16976, 98, 2, 29, "Text",
  InitializationCell->True],
Cell[497409, 16980, 67, 1, 33, "Text",
  InitializationCell->True],
Cell[497479, 16983, 165, 4, 30, "Input",
  InitializationCell->True],
Cell[497647, 16989, 70, 1, 43, "Subsubsection",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

