(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     56882,       1566]*)
(*NotebookOutlinePosition[     57812,       1597]*)
(*  CellTagsIndexPosition[     57723,       1591]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Impedance and magnetic field strength", "Title"],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[
    \(Remove["\<Global`*\>"]\)], "Input"],

Cell[BoxData[
    \(<< Miscellaneous`Units`\)], "Input"],

Cell[BoxData[
    \(<< Miscellaneous`PhysicalConstants`\)], "Input"],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[BoxData[
    \(<< Graphics`Legend`\)], "Input"],

Cell[BoxData[
    \(<< Algebra`ReIm`\)], "Input"],

Cell[BoxData[
    \(Abs[Ampere]\  ^= Ampere; Im[Ampere] ^= 0;\)], "Input"],

Cell[BoxData[
    \(Abs[Meter] ^= Meter; Im[Meter] ^= 0;\)], "Input"],

Cell[BoxData[
    \(Abs[Ohm] ^= Ohm; Im[Ohm] ^= 0;\)], "Input"],

Cell[BoxData[
    \(Abs[\[Phi]] ^= \[Phi]; Im[\[Phi]] ^= 0;\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Checking Units and constants", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(VacuumPermeability\), "\[IndentingNewLine]", 
    \(% // N\)}], "Input"],

Cell[BoxData[
    \(\(\[Pi]\ Second\ Volt\)\/\(2500000\ Ampere\ Meter\)\)], "Output"],

Cell[BoxData[
    \(\(1.2566370614359173`*^-6\ Second\ Volt\)\/\(Ampere\ Meter\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Convert[Oersted, Ampere/Meter]\), "\[IndentingNewLine]", 
    \(% // N\)}], "Input"],

Cell[BoxData[
    \(\(250\ Ampere\)\/\(Meter\ \[Pi]\)\)], "Output"],

Cell[BoxData[
    \(\(79.57747154594767`\ Ampere\)\/Meter\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[VacuumPermeability]\)], "Input"],

Cell[BoxData[
    \(\(\[Pi]\ Abs[Second\ Volt]\)\/\(2500000\ Ampere\ Meter\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Formula derivation", "Section"],

Cell[CellGroupData[{

Cell["Power source", "Subsection"],

Cell["\<\
Complex Current i generated by a function generator (ideal voltage source \
with internal resistor)\
\>", "SmallText"],

Cell[BoxData[
    \(i := UOpenPP\/2*Exp[I\ \[Phi]]/\((RInt + ZLoad)\)\)], "Input"],

Cell["\<\
with 
UOpenPP: Peak-to-peak Voltage
RInt : Internal resistance of function generator
ZLoad : Complex Load Impedance\
\>", "SmallText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load", "Subsection"],

Cell["\<\
The Coil (with the magnetostrictive rod) is the only load for the generator\
\>", "SmallText"],

Cell[BoxData[
    \(ZLoad := ZCoil\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coil Impedance", "Subsection"],

Cell["Ideal coil but with resistive losses", "SmallText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZCoil := RCoil + ZCoilIdeal\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(RCoil\)\" is similar to \
existing symbol \"\!\(ZCoil\)\"."\)], "Message"]
}, Open  ]],

Cell[BoxData[
    \(ZCoilIdeal := I*2\ \[Pi]\ f\ *\ L\)], "Input"],

Cell["\<\
with
L
f\
\>", "SmallText"],

Cell[CellGroupData[{

Cell["Coil Inductance L", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L := N\^2\ *\ \[Mu]Air\ *\ ACoil\/lCoil\)], "Input"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(ACoil\)\" is similar to \
existing symbols \!\({RCoil, ZCoil}\)."\)], "Message"]
}, Open  ]],

Cell["\<\
with
lCoil
ACoil
N: Number of windings\
\>", "SmallText"],

Cell[BoxData[
    RowBox[{"\[Mu]Air", ":=", 
      StyleBox[\(\(\[Mu]0\)\(*\)\(1\)\(\ \)\),
        FormatType->StandardForm]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Magnetic field strength", "Subsection"],

Cell["Magnetic field strength of an IDEAL solenoid at symetry axis", \
"SmallText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HCoil := N*i/lCoil\)], "Input"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(HCoil\)\" is similar to \
existing symbols \!\({ACoil, RCoil, ZCoil}\)."\)], "Message"]
}, Open  ]],

Cell["\<\
with
lCoil
N\
\>", "SmallText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HCoil\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\)\ N\ UOpenPP\)\/\(2\ lCoil\ \
\((RCoil + RInt + \(2\ \[ImaginaryI]\ ACoil\ f\ N\^2\ \[Pi]\ \[Mu]0\)\/lCoil)\
\)\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Mu]0 = VacuumPermeability\)], "Input"],

Cell[BoxData[
    \(\(\[Pi]\ Second\ Volt\)\/\(2500000\ Ampere\ Meter\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Power Source", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RInt = 50\ Ohm\)], "Input"],

Cell[BoxData[
    \(50\ Ohm\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(UOpenPP = 20\ Volt\)], "Input"],

Cell[BoxData[
    \(20\ Volt\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coil", "Subsection"],

Cell["Belden Magnet Wire 36 AWG", "SmallText"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RCoil = \(414.8\ Ohm\)\/\(304.8\ Meter\)*lWire\)], "Input"],

Cell[BoxData[
    \(\(1.3608923884514437`\ lWire\ Ohm\)\/Meter\)], "Output"]
}, Open  ]],

Cell["Assumed formula for length of wire", "SmallText"],

Cell[BoxData[
    \(lWire := N*\ 2\ \[Pi]\ *\ \((rCoilIn*1.2)\)\)], "Input"],

Cell["\<\
with
lWire: length of the magnet wire
rCoilIn: Inner coil radius\
\>", "SmallText"],

Cell[BoxData[
    \(ACoil := \[Pi]\ rCoilIn\^2\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Further Quantities:", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a1 = {lCoil\  \[Rule] \ 5.3\ Milli\ Meter, 
        rCoilIn\  \[Rule] \ 4.5\ Milli\ Meter, \ N \[Rule] 100}\)], "Input"],

Cell[BoxData[
    \({lCoil \[Rule] 5.3`\ Meter\ Milli, rCoilIn \[Rule] 4.5`\ Meter\ Milli, 
      N \[Rule] 100}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a3 = {lCoil\  \[Rule] \ 10\ Milli\ Meter, 
        rCoilIn\  \[Rule] \ 4.5\ Milli\ Meter, \ N \[Rule] 300}\)], "Input"],

Cell[BoxData[
    \({lCoil \[Rule] 10\ Meter\ Milli, rCoilIn \[Rule] 4.5`\ Meter\ Milli, 
      N \[Rule] 300}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(b1 = {lCoil\  \[Rule] \ 32\ Milli\ Meter, 
        rCoilIn\  \[Rule] \ 4.74\ Milli\ Meter, \ N \[Rule] 800}\)], "Input"],

Cell[BoxData[
    \({lCoil \[Rule] 32\ Meter\ Milli, rCoilIn \[Rule] 4.74`\ Meter\ Milli, 
      N \[Rule] 800}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(c1 = {lCoil\  \[Rule] \ 15\ Milli\ Meter, 
        rCoilIn\  \[Rule] \ 2.55/2\ Milli\ Meter, \ N \[Rule] 300}\)], "Input"],

Cell[BoxData[
    \({lCoil \[Rule] 15\ Meter\ Milli, rCoilIn \[Rule] 1.275`\ Meter\ Milli, 
      N \[Rule] 300}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(L\)], "Input"],

Cell[BoxData[
    \(\(N\^2\ \[Pi]\^2\ rCoilIn\^2\ Second\ Volt\)\/\(2500000\ Ampere\ lCoil\ \
Meter\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(L /. a1; Convert[L /. a1, Henry]\)], "Input"],

Cell[BoxData[
    \(0.00015083735028079964`\ Henry\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(L /. a3; Convert[L /. a3, Henry]\)], "Input"],

Cell[BoxData[
    \(0.000719494160839414`\ Henry\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(L /. c1; Convert[L /. c1, Henry]\)], "Input"],

Cell[BoxData[
    \(0.000038506261570850124`\ Henry\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?L\)\)], "Input"],

Cell["Global`L", "Print",
  CellTags->"Info3249051946-3714562"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(L := \(N\^2\ \[Mu]Air\ ACoil\)\/lCoil\)}
                },
              GridBaseline->{Baseline, {1, 1}},
              ColumnWidths->0.999,
              ColumnAlignments->{Left}]}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      Definition[ "L"],
      Editable->False]], "Print",
  CellTags->"Info3249051946-3714562"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(HCoil\)], "Input"],

Cell[BoxData[
    \(\(10\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\)\ N\ Volt\)\/\(lCoil\ \
\((50\ Ohm + \(10.260886871724773`\ N\ Ohm\ rCoilIn\)\/Meter + \
\(\[ImaginaryI]\ f\ N\^2\ \[Pi]\^3\ rCoilIn\^2\ Second\ Volt\)\/\(1250000\ \
Ampere\ lCoil\ Meter\))\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(HCoil /. Flatten[{c1, \ f \[Rule] \ 130000\ Hertz}]\)], "Input"],

Cell[BoxData[
    \(\(200\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\)\ Volt\)\/\(Meter\ \
Milli\ \((50\ Ohm + 3924.7892284347254`\ Milli\ Ohm + \(31452.457001729326`\ \
\[ImaginaryI]\ Hertz\ Milli\ Second\ Volt\)\/Ampere)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Convert[%, Ampere/Meter]\)], "Input"],

Cell[BoxData[
    \(\(\((\(\(2767.4032748405166`\)\(\[InvisibleSpace]\)\) - \
1614.130231267903`\ \[ImaginaryI])\)\ Ampere\ \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\)\)\/Meter\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[%]\)], "Input"],

Cell[BoxData[
    \(\(3203.738018173613`\ Ampere\)\/Meter\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coil Impedance", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Abs[
      Convert[ZCoil /. Flatten[{a1, f \[Rule] \ 1000  Hertz}], 
        Ohm]]\)], "Input"],

Cell[BoxData[
    \(4.7136592614634285`\ Ohm\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(ZCoila1[f1_] := 
      Abs[Convert[ZCoil /. Flatten[{a1, f \[Rule] \ f1}], Ohm]]\)], "Input"],

Cell[BoxData[
    \(ZCoila3[f1_] := 
      Abs[Convert[ZCoil /. Flatten[{a3, f \[Rule] \ f1}], Ohm]]\)], "Input"],

Cell[BoxData[
    \(ZCoilc1[f1_] := 
      Abs[Convert[ZCoil /. Flatten[{c1, f \[Rule] \ f1}], Ohm]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ZCoilc1[130000*Hertz]/Ohm\)], "Input"],

Cell[BoxData[
    \(31.69638815280487`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LogLinearPlot[{ZCoila1[freq*Hertz]/\ Ohm, 
        ZCoilc1[freq*Hertz]/\ Ohm}, {freq, 100\ , 
        1*10^6\ }, \[IndentingNewLine]AxesLabel \[Rule] {"\<Frequency in \
Hertz\>", "\<Absolut Impedance in Ohm\>"}, \[IndentingNewLine]PlotRange \
\[Rule] {0, 300}, \[IndentingNewLine]PlotStyle \[Rule] {Hue[0.5], 
          RGBColor[1, 0, 0]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.452446 0.238106 0 0.00206011 [
[.02377 -0.0125 -11 -12.5625 ]
[.02377 -0.0125 11 0 ]
[.26187 -0.0125 -14 -12.5625 ]
[.26187 -0.0125 14 0 ]
[.49998 -0.0125 -17 -12.5625 ]
[.49998 -0.0125 17 0 ]
[.73808 -0.0125 -23 -12.5625 ]
[.73808 -0.0125 23 0 ]
[.97619 -0.0125 -21.1563 -13.375 ]
[.97619 -0.0125 21.1563 0 ]
[1.025 0 0 -6.28125 ]
[1.025 0 112 6.28125 ]
[-0.0125 .10301 -12 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -18 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -18 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -74 0 ]
[0 .64303 74 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02377 0 m
.02377 .00625 L
s
gsave
.02377 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.26187 0 m
.26187 .00625 L
s
gsave
.26187 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.49998 0 m
.49998 .00625 L
s
gsave
.49998 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.73808 0 m
.73808 .00625 L
s
gsave
.73808 -0.0125 -84 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100000.) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -82.1563 -17.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
75.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
76.813 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\264) show
84.625 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
96.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
100.813 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.09544 0 m
.09544 .00375 L
s
.13737 0 m
.13737 .00375 L
s
.16712 0 m
.16712 .00375 L
s
.1902 0 m
.1902 .00375 L
s
.20905 0 m
.20905 .00375 L
s
.22499 0 m
.22499 .00375 L
s
.2388 0 m
.2388 .00375 L
s
.25098 0 m
.25098 .00375 L
s
.33355 0 m
.33355 .00375 L
s
.37548 0 m
.37548 .00375 L
s
.40523 0 m
.40523 .00375 L
s
.4283 0 m
.4283 .00375 L
s
.44715 0 m
.44715 .00375 L
s
.4631 0 m
.4631 .00375 L
s
.4769 0 m
.4769 .00375 L
s
.48908 0 m
.48908 .00375 L
s
.57166 0 m
.57166 .00375 L
s
.61358 0 m
.61358 .00375 L
s
.64333 0 m
.64333 .00375 L
s
.66641 0 m
.66641 .00375 L
s
.68526 0 m
.68526 .00375 L
s
.7012 0 m
.7012 .00375 L
s
.71501 0 m
.71501 .00375 L
s
.72719 0 m
.72719 .00375 L
s
.80976 0 m
.80976 .00375 L
s
.85169 0 m
.85169 .00375 L
s
.88144 0 m
.88144 .00375 L
s
.90451 0 m
.90451 .00375 L
s
.92337 0 m
.92337 .00375 L
s
.93931 0 m
.93931 .00375 L
s
.95312 0 m
.95312 .00375 L
s
.9653 0 m
.9653 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Frequency) show
123.000 12.813 moveto
(in) show
141.000 12.813 moveto
(Hertz) show
171.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(50)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(100)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(150)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(200)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(250)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(300)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Absolut) show
111.000 12.813 moveto
(Impedance) show
171.000 12.813 moveto
(in) show
189.000 12.813 moveto
(Ohm) show
207.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 1 r
.5 Mabswid
.02381 .00951 m
.2917 .00986 L
.35484 .01065 L
.39865 .01201 L
.42786 .0136 L
.44907 .01526 L
.46541 .01691 L
.49493 .02089 L
.51804 .02512 L
.53865 .02993 L
.57086 .0399 L
.59483 .04978 L
.61561 .06049 L
.64503 .07996 L
.67146 .10296 L
.69155 .12486 L
.72116 .16604 L
.76116 .24424 L
.79153 .32751 L
.81419 .40769 L
.83383 .49291 L
.84977 .57503 L
s
.84977 .57503 m
.85702 .61803 L
s
1 0 0 r
.02381 .00809 m
.2917 .00811 L
.35484 .00818 L
.39865 .0083 L
.42786 .00846 L
.44907 .00864 L
.46541 .00884 L
.48079 .00908 L
.49493 .00938 L
.51935 .01008 L
.53794 .01082 L
.55511 .01173 L
.57086 .01278 L
.59645 .01503 L
.61603 .01731 L
.64503 .02182 L
.66973 .02697 L
.68834 .03185 L
.72116 .04308 L
.74454 .05367 L
.76197 .06331 L
.79176 .08415 L
.81408 .10425 L
.83348 .12565 L
.84926 .14628 L
.86245 .16612 L
.87486 .18725 L
.88554 .2076 L
.8958 .22923 L
.90481 .25006 L
.91279 .27011 L
.92066 .29145 L
.92771 .31199 L
.93406 .33173 L
.94042 .35277 L
.94619 .37301 L
.952 .39453 L
.95729 .41526 L
.96214 .4352 L
.96707 .45642 L
.9716 .47685 L
.97619 .49849 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{550.688, 340.375},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008V0001E2000`400?l00000o`00003oo`3ooooo
0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo
003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0
oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool0
0?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3o
oolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00
o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?oo
obP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o
0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo
:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0
ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX
0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3o
oooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0
oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooonC0?ooo`D000000P3oool2
000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`D000000P3oool2000007H0oooo001:
0?ooo`D000000P3oool2000000@0oooo0P0000120?ooo`D000000P3oool2000000@0oooo0P000004
0?ooo`800000?@3oool500000080oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000c
0?ooo`D000000P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P000004
0?ooo`800000<P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo07<0oooo001<0?ooo`050000003oool0
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0440oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`0l0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0b0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`1c0?ooo`00C03oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`110?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0?03oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0<P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`00
00001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0L`3oool004`0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0@@3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo03`0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0380oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`00001`0?ooo`00C03oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`11
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0?03oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0<P3oool01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0d0?ooo`800000
4`3oool2000000@0oooo0P0000030?ooo`030000003oool000000700oooo001;0?ooo`800000103o
ool2000000@0oooo0P0000130?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000?P3o
ool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00000d0?ooo`800000103o
ool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00001G0?ooo`800000L@3o
ool00?l0oooo]03oool300000700oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00
o`3oooo=0?ooo`<000006@3oool2000003`0oooo003o0?ooolh0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0j0?ooo`00o`3oooni0?ooo`<000000`3oool4000000<0oooo0`000003
0?ooo`<000000`3oool400000080oooo0`0000000`3oool00000000000020?ooo`8000000P3oool3
000000@0oooo00<000000?ooo`3oool0203oool3000000030?ooo`00000000000080oooo0P000006
0?ooo`<0000000<0oooo0000000000000P3oool300000080oooo100000030?ooo`8000000`3oool4
000000@0oooo001:0?ooool00000I000000<0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0103oool00`000000oooo0000000:0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`000000103oool004X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000006@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000001T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`@000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo100000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo0000
0080oooo100000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000050?ooo`00BP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000I0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000006@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
4P3oool2000000<0oooo100000030?ooo`800000103oool6000000030?ooo`000000000000<0oooo
0P0000020?ooo`@00000103oool3000000050?ooo`00000000000000003oool00P0000080?ooo`80
00000P3oool4000000T0oooo100000030?ooo`8000000`3oool4000000030?ooo`000000000000<0
00000P3oool4000000@0oooo001:0?ooo`030000003oool0oooo00D0ooooX03o00090?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0B0?ooo`040000
003oool0oooo000004T0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0;0?oo
o`00BP3oool00`000000oooo0?ooo`050?ooogh00?oo8P3ooolJ0?l00:`0oooo1@00000i0?ooo`03
0000003oool0oooo00`0oooo0P000000103oool0000000000000000K0?ooo`00BP3oool00`000000
oooo0?ooo`230?oooaH00?oo9P3oool=0?l00?l0oooo3P3oool004X0oooo00<000000?ooo`3oool0
V@3oool<003oobL0oooo3P3o003o0?ooo`00BP3oool00`000000oooo0?ooo`2U0?ooo`D00?oo<03o
ool50?l00?X0oooo001:0?ooo`800000Z`3oool7003oobh0oooo1@3o003e0?ooo`00BP3oool00`00
0000oooo0?ooo`2a0?ooo`H00?oo;@3oool40?l00?40oooo001:0?ooo`030000003oool0oooo0;L0
oooo1000ool]0?ooo`@0o`00k@3oool004X0oooo00<000000?ooo`3oool0^`3oool3003oobh0oooo
103o003Y0?ooo`00BP3oool00`000000oooo0?ooo`2n0?ooo`<00?oo;`3oool30?l00>H0oooo001:
0?ooo`030000003oool0oooo0<40oooo0P00ool`0?ooo`<0o`00h`3oool004X0oooo00<000000?oo
o`3oool0``3oool3003ooc00oooo0P3o003Q0?ooo`00BP3oool200000<L0oooo0`00ool_0?ooo`<0
o`00gP3oool004X0oooo00<000000?ooo`3oool0b@3oool3003oobl0oooo0`3o003K0?ooo`00BP3o
ool00`000000oooo0?ooo`3<0?ooo`<00?oo;`3oool30?l00=P0oooo001:0?ooo`030000003oool0
oooo0<l0oooo0P00ool`0?ooo`<0o`00e@3oool004X0oooo00<000000?ooo`3oool0d@3oool2003o
oc40oooo0P3o003C0?ooo`00BP3oool00`000000oooo0?ooo`3C0?ooo`800?oo<@3oool20?l00=40
oooo001:0?ooo`030000003oool0oooo0=D0oooo0P00oola0?ooo`030?l0003oool0oooo0<h0oooo
001:0?ooo`800000f03oool00`00ool0oooo0?ooo`0_0?ooo`80o`00cP3oool004X0oooo00<00000
0?ooo`3oool0f03oool2003ooc40oooo00<0o`000?ooo`3oool0b`3oool004X0oooo00<000000?oo
o`3oool0fP3oool00`00ool0oooo0?ooo`0_0?ooo`80o`00b`3oool004X0oooo00<000000?ooo`3o
ool0f`3oool2003ooc40oooo00<0o`000?ooo`3oool0b03oool004X0oooo00<000000?ooo`3oool0
g@3oool00`00ool0oooo0?ooo`0_0?ooo`80o`00b03oool004X0oooo00<000000?ooo`3oool0gP3o
ool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo0<D0oooo001:0?ooo`030000003oool0
oooo0=l0oooo0P00oola0?ooo`030?l0003oool0oooo0<@0oooo001:0?ooo`030000003oool0oooo
0>40oooo00<00?oo0?ooo`3oool0;`3oool20?l00<@0oooo001:0?ooo`800000h`3oool00`00ool0
oooo0?ooo`0`0?ooo`030?l0003oool0oooo0<40oooo001:0?ooo`030000003oool0oooo0><0oooo
0P00oola0?ooo`030?l0003oool0oooo0<00oooo001:0?ooo`030000003oool0oooo0>D0oooo00<0
0?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2o0?ooo`00BP3oool00`000000oooo0?ooo`3V
0?ooo`03003oo`3oool0oooo02l0oooo0P3o002o0?ooo`00BP3oool00`000000oooo0?ooo`3W0?oo
o`03003oo`3oool0oooo0300oooo00<0o`000?ooo`3oool0_03oool003/0oooo0P0000040?ooo`80
00001`3oool00`000000oooo0?ooo`3X0?ooo`800?oo<@3oool00`3o0000oooo0?ooo`2k0?ooo`00
>P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0jP3oool00`00ool0oooo0?ooo`0_0?ooo`030?l0003oool0oooo0;X0oooo000m0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool300000>/0oooo00<00?oo0?oo
o`3oool0;`3oool00`3o0000oooo0?ooo`2i0?ooo`00>`3oool2000000<0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`3/0?ooo`03003oo`3oool0oooo02l0oooo00<0o`000?oo
o`3oool0^03oool003/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo0>d0oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2g0?oo
o`00>`3oool3000000<0oooo0P0000070?ooo`030000003oool0oooo0>h0oooo00<00?oo0?ooo`3o
ool0;`3oool00`3o0000oooo0?ooo`2f0?ooo`00BP3oool00`000000oooo0?ooo`3_0?ooo`03003o
o`3oool0oooo02l0oooo00<0o`000?ooo`3oool0]@3oool004X0oooo00<000000?ooo`3oool0k`3o
ool00`00ool0oooo0?ooo`0_0?ooo`030?l0003oool0oooo0;D0oooo001:0?ooo`030000003oool0
oooo0?00oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2d0?ooo`00BP3oool20000
0?80oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2c0?ooo`00BP3oool00`000000
oooo0?ooo`3b0?ooo`03003oo`3oool0oooo02l0oooo00<0o`000?ooo`3oool0/P3oool004X0oooo
00<000000?ooo`3oool0l`3oool00`00ool0oooo0?ooo`0_0?ooo`030?l0003oool0oooo0;40oooo
001:0?ooo`030000003oool0oooo0?<0oooo00<00?oo0?ooo`3oool0<03oool00`3o0000oooo0?oo
o`2`0?ooo`00BP3oool00`000000oooo0?ooo`3d0?ooo`03003oo`3oool0oooo0300oooo00<0o`00
0?ooo`3oool0[`3oool004X0oooo00<000000?ooo`3oool0m@3oool00`00ool0oooo0?ooo`0_0?oo
o`030?l0003oool0oooo0:l0oooo001:0?ooo`030000003oool0oooo0?H0oooo00<00?oo0?ooo`3o
ool0;`3oool00`3o0000oooo0?ooo`2^0?ooo`00BP3oool00`000000oooo0?ooo`3f0?ooo`03003o
o`3oool0oooo0300oooo00<0o`000?ooo`3oool0[@3oool004X0oooo0P00003h0?ooo`03003oo`3o
ool0oooo0300oooo00<0o`000?ooo`3oool0[03oool004X0oooo00<000000?ooo`3oool0n03oool0
0`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo0:/0oooo001:0?ooo`030000003oool0oooo
0?P0oooo00<00?oo0?ooo`3oool0<03oool00`3o0000oooo0?ooo`2[0?ooo`00BP3oool00`000000
oooo0?ooo`3i0?ooo`03003oo`3oool0oooo0300oooo00<0o`000?ooo`3oool0ZP3oool004X0oooo
00<000000?ooo`3oool0nP3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo0:T0oooo
001:0?ooo`030000003oool0oooo0?/0oooo00<00?oo0?ooo`3oool0<03oool00`3o0000oooo0?oo
o`2X0?ooo`00BP3oool00`000000oooo0?ooo`3k0?ooo`03003oo`3oool0oooo0300oooo00<0o`00
0?ooo`3oool0Z03oool004X0oooo0P00003m0?ooo`03003oo`3oool0oooo0300oooo00<0o`000?oo
o`3oool0Y`3oool004X0oooo00<000000?ooo`3oool0o@3oool00`00ool0oooo0?ooo`0`0?ooo`03
0?l0003oool0oooo0:H0oooo001:0?ooo`030000003oool0oooo0?d0oooo00<00?oo0?ooo`3oool0
<03oool00`3o0000oooo0?ooo`2V0?ooo`00BP3oool00`000000oooo0?ooo`3n0?ooo`03003oo`3o
ool0oooo0300oooo00<0o`000?ooo`3oool0Y@3oool004X0oooo00<000000?ooo`3oool0oP3oool0
0`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo0:D0oooo001:0?ooo`030000003oool0oooo
0?l0oooo00<00?oo0?ooo`3oool0<03oool00`3o0000oooo0?ooo`2T0?ooo`00BP3oool00`000000
oooo0?ooo`3o0?ooo`03003oo`3oool0oooo0300oooo00<0o`000?ooo`3oool0Y03oool004X0oooo
0P00003o0?ooo`80oooo00<00?oo0?ooo`3oool0<03oool00`3o0000oooo0?ooo`2S0?ooo`00BP3o
ool00`000000oooo0?ooo`3o0?ooo`40oooo00<00?oo0?ooo`3oool0<03oool00`3o0000oooo0?oo
o`2S0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<00?oo0?ooo`3oool0<03oool0
0`3o0000oooo0?ooo`2R0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooo`80oooo00<00?oo0?oo
o`3oool0<03oool00`3o0000oooo0?ooo`2R0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooo`<0
oooo00<00?oo0?ooo`3oool0<03oool00`3o0000oooo0?ooo`2Q0?ooo`00=03oool500000080oooo
0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?ooo`<0oooo00<00?oo0?ooo`3oool0
<03oool00`3o0000oooo0?ooo`2Q0?ooo`00=P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0
oooo103oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo0:00oooo000f0?ooo`050000
003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00@0oooo0`00003o0?ooo`D0oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2P0?oo
o`00=P3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo1@3oool00`00ool0oooo0?ooo`0`
0?ooo`030?l0003oool0oooo09l0oooo000f0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3o
ool60?ooo`03003oo`3oool0oooo02l0oooo00<0o`000?ooo`3oool0W`3oool003D0oooo0P000004
0?ooo`800000103oool2000000L0oooo00<000000?ooo`3oool0o`3oool60?ooo`03003oo`3oool0
oooo0300oooo00<0o`000?ooo`3oool0WP3oool004X0oooo00<000000?ooo`3oool0o`3oool70?oo
o`03003oo`3oool0oooo02l0oooo00<0o`000?ooo`3oool0WP3oool004X0oooo00<000000?ooo`3o
ool0o`3oool70?ooo`03003oo`3oool0oooo0300oooo00<0o`000?ooo`3oool0W@3oool004X0oooo
00<000000?ooo`3oool0o`3oool80?ooo`03003oo`3oool0oooo02l0oooo00<0o`000?ooo`3oool0
W@3oool004X0oooo00<000000?ooo`3oool0o`3oool80?ooo`03003oo`3oool0oooo02l0oooo00<0
o`000?ooo`3oool0W@3oool004X0oooo0P00003o0?ooo`X0oooo00<00?oo0?ooo`3oool0;`3oool0
0`3o0000oooo0?ooo`2L0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooo`T0oooo00<00?oo0?oo
o`3oool0;`3oool00`3o0000oooo0?ooo`2L0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooo`X0
oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2K0?ooo`00BP3oool00`000000oooo
0?ooo`3o0?ooo`X0oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2K0?ooo`00BP3o
ool00`000000oooo0?ooo`3o0?ooo`/0oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?oo
o`2J0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00<00?oo0?ooo`3oool0;`3oool0
0`3o0000oooo0?ooo`2J0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooo``0oooo00<00?oo0?oo
o`3oool0;`3oool00`3o0000oooo0?ooo`2I0?ooo`00BP3oool200000?l0oooo3@3oool00`00ool0
oooo0?ooo`0_0?ooo`030?l0003oool0oooo09T0oooo001:0?ooo`030000003oool0oooo0?l0oooo
3@3oool00`00ool0oooo0?ooo`0_0?ooo`030?l0003oool0oooo09P0oooo001:0?ooo`030000003o
ool0oooo0?l0oooo3@3oool00`00ool0oooo0?ooo`0_0?ooo`030?l0003oool0oooo09P0oooo001:
0?ooo`030000003oool0oooo0?l0oooo3@3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0
oooo09L0oooo001:0?ooo`030000003oool0oooo0?l0oooo3P3oool00`00ool0oooo0?ooo`0_0?oo
o`030?l0003oool0oooo09L0oooo001:0?ooo`030000003oool0oooo0?l0oooo3P3oool00`00ool0
oooo0?ooo`0_0?ooo`030?l0003oool0oooo09L0oooo001:0?ooo`030000003oool0oooo0?l0oooo
3P3oool00`00ool0oooo0?ooo`0_0?ooo`030?l0003oool0oooo09L0oooo001:0?ooo`800000o`3o
ool@0?ooo`03003oo`3oool0oooo02l0oooo00<0o`000?ooo`3oool0UP3oool004X0oooo00<00000
0?ooo`3oool0o`3oool?0?ooo`03003oo`3oool0oooo02l0oooo00<0o`000?ooo`3oool0UP3oool0
04X0oooo00<000000?ooo`3oool0o`3oool?0?ooo`03003oo`3oool0oooo02l0oooo00<0o`000?oo
o`3oool0UP3oool004X0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03003oo`3oool0oooo02l0
oooo00<0o`000?ooo`3oool0U@3oool004X0oooo00<000000?ooo`3oool0o`3oool@0?ooo`03003o
o`3oool0oooo02l0oooo00<0o`000?ooo`3oool0U@3oool004X0oooo00<000000?ooo`3oool0o`3o
ool@0?ooo`03003oo`3oool0oooo0300oooo00<0o`000?ooo`3oool0U03oool004X0oooo00<00000
0?ooo`3oool0o`3ooolA0?ooo`03003oo`3oool0oooo02l0oooo00<0o`000?ooo`3oool0U03oool0
04X0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`03003oo`3oool0oooo02l0oooo00<0o`000?oo
o`3oool0U03oool004X0oooo0P00003o0?oooa80oooo00<00?oo0?ooo`3oool0<03oool00`3o0000
oooo0?ooo`2C0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooa80oooo00<00?oo0?ooo`3oool0
;`3oool00`3o0000oooo0?ooo`2C0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooa80oooo00<0
0?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2C0?ooo`00BP3oool00`000000oooo0?ooo`3o
0?oooa80oooo00<00?oo0?ooo`3oool0<03oool00`3o0000oooo0?ooo`2B0?ooo`00BP3oool00`00
0000oooo0?ooo`3o0?oooa<0oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2B0?oo
o`00=03oool500000080oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooa<0
oooo00<00?oo0?ooo`3oool0<03oool00`3o0000oooo0?ooo`2A0?ooo`00=P3oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0?l0oooo4`3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo
0940oooo000f0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`040?ooo`<00000o`3ooolD0?ooo`03003oo`3oool0oooo0300oooo00<0o`000?oo
o`3oool0T03oool003H0oooo00<000000?ooo`3oool00P3oool2000000<0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`3o0?oooa@0oooo00<00?oo0?ooo`3oool0<03oool00`3o
0000oooo0?ooo`2@0?ooo`00=P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooa@0oooo00<00?oo0?oo
o`3oool0<03oool00`3o0000oooo0?ooo`2@0?ooo`00=@3oool2000000@0oooo0`0000030?ooo`80
00001`3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<00?oo0?ooo`3oool0<03oool00`3o0000
oooo0?ooo`2?0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<00?oo0?ooo`3oool0
<03oool00`3o0000oooo0?ooo`2?0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooaD0oooo00<0
0?oo0?ooo`3oool0<03oool00`3o0000oooo0?ooo`2?0?ooo`00BP3oool00`000000oooo0?ooo`3o
0?oooaH0oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2?0?ooo`00BP3oool20000
0?l0oooo5`3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo08h0oooo001:0?ooo`03
0000003oool0oooo0?l0oooo5P3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo08h0
oooo001:0?ooo`030000003oool0oooo0?l0oooo5`3oool00`00ool0oooo0?ooo`0_0?ooo`030?l0
003oool0oooo08h0oooo001:0?ooo`030000003oool0oooo0?l0oooo5`3oool00`00ool0oooo0?oo
o`0`0?ooo`030?l0003oool0oooo08d0oooo001:0?ooo`030000003oool0oooo0?l0oooo5`3oool0
0`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo08d0oooo001:0?ooo`030000003oool0oooo
0?l0oooo5`3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo08d0oooo001:0?ooo`03
0000003oool0oooo0?l0oooo603oool00`00ool0oooo0?ooo`0_0?ooo`030?l0003oool0oooo08d0
oooo001:0?ooo`030000003oool0oooo0?l0oooo603oool00`00ool0oooo0?ooo`0`0?ooo`030?l0
003oool0oooo08`0oooo001:0?ooo`800000o`3ooolI0?ooo`03003oo`3oool0oooo0300oooo00<0
o`000?ooo`3oool0S03oool004X0oooo00<000000?ooo`3oool0o`3ooolI0?ooo`03003oo`3oool0
oooo02l0oooo00<0o`000?ooo`3oool0S03oool004X0oooo00<000000?ooo`3oool0o`3ooolI0?oo
o`03003oo`3oool0oooo02l0oooo00<0o`000?ooo`3oool0S03oool004X0oooo00<000000?ooo`3o
ool0o`3ooolI0?ooo`03003oo`3oool0oooo0300oooo00<0o`000?ooo`3oool0R`3oool004X0oooo
00<000000?ooo`3oool0o`3ooolI0?ooo`03003oo`3oool0oooo0300oooo00<0o`000?ooo`3oool0
R`3oool004X0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`03003oo`3oool0oooo02l0oooo00<0
o`000?ooo`3oool0R`3oool004X0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`03003oo`3oool0
oooo02l0oooo00<0o`000?ooo`3oool0R`3oool004X0oooo0P00003o0?oooa/0oooo00<00?oo0?oo
o`3oool0<03oool00`3o0000oooo0?ooo`2:0?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooa/0
oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2:0?ooo`00BP3oool00`000000oooo
0?ooo`3o0?oooa/0oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`2:0?ooo`00BP3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo00<00?oo0?ooo`3oool0<03oool00`3o0000oooo0?oo
o`290?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<00?oo0?ooo`3oool0<03oool0
0`3o0000oooo0?ooo`290?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooa`0oooo00<00?oo0?oo
o`3oool0;`3oool00`3o0000oooo0?ooo`290?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooa`0
oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`290?ooo`00BP3oool200000?l0oooo
7@3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo08P0oooo001:0?ooo`030000003o
ool0oooo0?l0oooo7@3oool00`00ool0oooo0?ooo`0_0?ooo`030?l0003oool0oooo08P0oooo001:
0?ooo`030000003oool0oooo0?l0oooo7@3oool00`00ool0oooo0?ooo`0_0?ooo`030?l0003oool0
oooo08P0oooo001:0?ooo`030000003oool0oooo0?l0oooo7@3oool00`00ool0oooo0?ooo`0`0?oo
o`030?l0003oool0oooo08L0oooo001:0?ooo`030000003oool0oooo0?l0oooo7@3oool00`00ool0
oooo0?ooo`0`0?ooo`030?l0003oool0oooo08L0oooo001:0?ooo`030000003oool0oooo0?l0oooo
7P3oool00`00ool0oooo0?ooo`0_0?ooo`030?l0003oool0oooo08L0oooo000d0?ooo`@000000`3o
ool2000000@0oooo0P0000070?ooo`030000003oool0oooo0?l0oooo7P3oool00`00ool0oooo0?oo
o`0_0?ooo`030?l0003oool0oooo08L0oooo000d0?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0?l0oooo
7P3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo08H0oooo000e0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060?ooo`<0
0000o`3ooolN0?ooo`03003oo`3oool0oooo0300oooo00<0o`000?ooo`3oool0QP3oool003H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3o0?oooal0oooo00<00?oo0?ooo`3oool0;`3oool00`3o
0000oooo0?ooo`260?ooo`00=03oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o0?oooal0oooo00<0
0?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`260?ooo`00=@3oool2000000@0oooo0P000004
0?ooo`8000001`3oool00`000000oooo0?ooo`3o0?oooal0oooo00<00?oo0?ooo`3oool0<03oool0
0`3o0000oooo0?ooo`250?ooo`00BP3oool00`000000oooo0?ooo`3o0?oooal0oooo00<00?oo0?oo
o`3oool0<03oool00`3o0000oooo0?ooo`250?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooob00
oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`250?ooo`00BP3oool00`000000oooo
0?ooo`3o0?ooob00oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`250?ooo`00BP3o
ool200000?l0oooo8@3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo08@0oooo001:
0?ooo`030000003oool0oooo0?l0oooo803oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0
oooo08@0oooo001:0?ooo`030000003oool0oooo0?l0oooo8@3oool00`00ool0oooo0?ooo`0_0?oo
o`030?l0003oool0oooo08@0oooo001:0?ooo`030000003oool0oooo0?l0oooo8@3oool00`00ool0
oooo0?ooo`0`0?ooo`030?l0003oool0oooo08<0oooo001:0?ooo`030000003oool0oooo0?l0oooo
8@3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo08<0oooo001:0?ooo`030000003o
ool0oooo0?l0oooo8@3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo08<0oooo001:
0?ooo`030000003oool0oooo0?l0oooo8P3oool00`00ool0oooo0?ooo`0_0?ooo`030?l0003oool0
oooo08<0oooo001:0?ooo`800000o`3ooolS0?ooo`03003oo`3oool0oooo0300oooo00<0o`000?oo
o`3oool0PP3oool004X0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`03003oo`3oool0oooo0300
oooo00<0o`000?ooo`3oool0PP3oool004X0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`03003o
o`3oool0oooo0300oooo00<0o`000?ooo`3oool0PP3oool004X0oooo00<000000?ooo`3oool0o`3o
oolR0?ooo`03003oo`3oool0oooo0300oooo00<0o`000?ooo`3oool0PP3oool004X0oooo00<00000
0?ooo`3oool0o`3ooolS0?ooo`03003oo`3oool0oooo02l0oooo00<0o`000?ooo`3oool0PP3oool0
04X0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`03003oo`3oool0oooo0300oooo00<0o`000?oo
o`3oool0P@3oool004X0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`03003oo`3oool0oooo0300
oooo00<0o`000?ooo`3oool0P@3oool004X0oooo0P00003o0?ooob@0oooo00<00?oo0?ooo`3oool0
<03oool00`3o0000oooo0?ooo`210?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<0
0?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`210?ooo`00BP3oool00`000000oooo0?ooo`3o
0?ooob@0oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`210?ooo`00BP3oool00`00
0000oooo0?ooo`3o0?ooob@0oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`210?oo
o`00BP3oool00`000000oooo0?ooo`3o0?ooob@0oooo00<00?oo0?ooo`3oool0<03oool00`3o0000
oooo0?ooo`200?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<00?oo0?ooo`3oool0
;`3oool00`3o0000oooo0?ooo`200?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooobD0oooo00<0
0?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`200?ooo`00BP3oool00`000000oooo0?ooo`3o
0?ooobD0oooo00<00?oo0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`200?ooo`00BP3oool20000
0?l0oooo9P3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo07l0oooo001:0?ooo`03
0000003oool0oooo0?l0oooo9@3oool00`00ool0oooo0?ooo`0`0?ooo`030?l0003oool0oooo07l0
oooo001:0?ooo`030000003oool0oooo0?l0oooo9P3oool00`00ool0oooo0?ooo`2a0?ooo`00BP3o
ool00`000000oooo0?ooo`3o0?ooobH0oooo00<00?oo0?ooo`3oool0/@3oool004X0oooo00<00000
0?ooo`3oool0o`3ooolV0?ooo`03003oo`3oool0oooo0;40oooo000d0?ooo`@000000`3oool20000
00@0oooo0P0000070?ooo`030000003oool0oooo0?l0oooo9P3oool00`00ool0oooo0?ooo`2a0?oo
o`00=03oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`3o0?ooobH0oooo00<00?oo0?ooo`3oool0/@3oool0
03D0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00@0oooo0`00003o0?ooobL0oooo00<00?oo0?ooo`3oool0/03oool003H0oooo00<000000?oo
o`3oool00P3oool2000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`3o
0?ooobL0oooo00<00?oo0?ooo`3oool0/03oool003@0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3o
oolW0?ooo`03003oo`3oool0oooo0;00oooo000e0?ooo`800000103oool3000000<0oooo0P000007
0?ooo`030000003oool0oooo0?l0oooo9`3oool00`00ool0oooo0?ooo`2`0?ooo`00BP3oool00`00
0000oooo0?ooo`3o0?ooobL0oooo00<00?oo0?ooo`3oool0/03oool004X0oooo00<000000?ooo`3o
ool0o`3ooolX0?ooo`03003oo`3oool0oooo0:l0oooo001:0?ooo`030000003oool0oooo0?l0oooo
:03oool00`00ool0oooo0?ooo`2_0?ooo`00BP3oool200000?l0oooo:@3oool00`00ool0oooo0?oo
o`2_0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooobP0oooo00<00?oo0?ooo`3oool0[`3oool0
04X0oooo00<000000?ooo`3oool0o`3ooolY0?ooo`03003oo`3oool0oooo0:h0oooo001:0?ooo`03
0000003oool0oooo0?l0oooo:@3oool00`00ool0oooo0?ooo`2^0?ooo`00BP3oool00`000000oooo
0?ooo`3o0?ooobT0oooo00<00?oo0?ooo`3oool0[P3oool004X0oooo00<000000?ooo`3oool0o`3o
oolY0?ooo`03003oo`3oool0oooo0:h0oooo001:0?ooo`030000003oool0oooo0?l0oooo:@3oool0
0`00ool0oooo0?ooo`2^0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooobX0oooo00<00?oo0?oo
o`3oool0[@3oool004X0oooo0P00003o0?ooob/0oooo00<00?oo0?ooo`3oool0[@3oool004X0oooo
00<000000?ooo`3oool0o`3ooolZ0?ooo`03003oo`3oool0oooo0:d0oooo001:0?ooo`030000003o
ool0oooo0?l0oooo:P3oool00`00ool0oooo0?ooo`2]0?ooo`00BP3oool00`000000oooo0?ooo`3o
0?ooobX0oooo00<00?oo0?ooo`3oool0[@3oool004X0oooo00<000000?ooo`3oool0o`3oool[0?oo
o`03003oo`3oool0oooo0:`0oooo001:0?ooo`030000003oool0oooo0?l0oooo:`3oool00`00ool0
oooo0?ooo`2/0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooob/0oooo00<00?oo0?ooo`3oool0
[03oool004X0oooo0P00003o0?ooob`0oooo00<00?oo0?ooo`3oool0[03oool004X0oooo00<00000
0?ooo`3oool0o`3oool[0?ooo`03003oo`3oool0oooo0:`0oooo001:0?ooo`030000003oool0oooo
0?l0oooo;03oool00`00ool0oooo0?ooo`2[0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooob`0
oooo00<00?oo0?ooo`3oool0Z`3oool004X0oooo00<000000?ooo`3oool0o`3oool/0?ooo`03003o
o`3oool0oooo0:/0oooo001:0?ooo`030000003oool0oooo0?l0oooo;03oool00`00ool0oooo0?oo
o`2[0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooob`0oooo00<00?oo0?ooo`3oool0Z`3oool0
04X0oooo0P00003o0?ooobh0oooo00<00?oo0?ooo`3oool0ZP3oool004X0oooo00<000000?ooo`3o
ool0o`3oool]0?ooo`03003oo`3oool0oooo0:X0oooo001:0?ooo`030000003oool0oooo0?l0oooo
;@3oool00`00ool0oooo0?ooo`2Z0?ooo`00BP3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<0
0?oo0?ooo`3oool0ZP3oool004X0oooo00<000000?ooo`3oool0o`3oool]0?ooo`03003oo`3oool0
oooo0:X0oooo001:0?ooo`030000003oool0oooo0?l0oooo;@3oool00`00ool0oooo0?ooo`2Z0?oo
o`00=@3oool2000000@0oooo0P0000040?ooo`8000001`3oool00`000000oooo0?ooo`3o0?ooobh0
oooo00<00?oo0?ooo`3oool0Z@3oool003@0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0o`3oool^
0?ooo`03003oo`3oool0oooo0:T0oooo000f0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo0`00003o0?ooobh0oooo00<0
0?oo0?ooo`3oool0Z@3oool003L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo0?l0ooooh@3oool003@0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000?l0ooooh`3oool003D0
oooo0P0000040?ooo`800000103oool200000?l0ooooi03oool00?l0ooooo`3ooolX0?ooo`00o`3o
oooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0
oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00?P3oool300000?l0ooooiP3oool0
03l0oooo00<000000?ooo`3oool0o`3ooooU0?ooo`000`3oool2000000030?ooo`000000000000@0
00000`3oool3000000@0oooo0P0000030?ooo`<00000103oool400000080oooo0P00000:0?ooo`<0
000000P0oooo000000000000oooo0000003oool000000?ooo`<00000103oool3000000<0oooo1000
00000`3oool000000000000500000080oooo0P0000020?ooo`<000000`3oool3000000T0oooo0`00
00000`3oool00000000000020?ooo`800000203oool200000080oooo0`0000000`3oool000000000
0002000000040?ooo`000000oooo00000?l0ooooU@3oool000<0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?oo
o`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000X0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
00020?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000000P3oool400000080
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool000000?ooo`00
0000o`3ooonE0?ooo`00103oool300000080oooo00@000000?ooo`3oool000000P3oool3000000<0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool02`3oool02`000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool000000080oooo00<000000?ooo`3oool0100000020?ooo`040000003oool0oooo
000000D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`@00000
2P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`000000oooo0000
003o0?oooiD0oooo00040?ooo`030000003oool000000080oooo0`0000030?ooo`@000000`3oool2
000000@0oooo00@000000?ooo`3oool0oooo0P000000103oool000000000003oool5000000X0oooo
00<000000?ooo`3oool00`0000000`3oool000000?ooo`04000000@0oooo0P0000040?ooo`<00000
0`3oool3000000030?ooo`000000000000800000103oool3000000<0oooo0P00000:0?ooo`800000
0P3oool4000000T0oooo00@000000?ooo`3oool000000P3oool300000080oooo0`0000000`3oool0
00000?ooo`3o0?oooiD0oooo00050?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0`0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3ooonM0?oo
o`00103oool200000080oooo0P00000A0?ooo`8000005`3oool3000001H0oooo0P00000R0?ooo`03
0000003oool0oooo00h0oooo0P0000020?ooo`800000o`3ooonO0?ooo`00o`3ooooo0?ooobP0oooo
003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0
oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool0
0?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3o
oolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00
o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?oo
obP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o
0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo
:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0
ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX
0?ooo`00o`3ooooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3o
oooo0?ooobP0oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0
oooo003o0?ooool0oooo:03oool00?l0ooooo`3ooolX0?ooo`00o`3ooooo0?ooobP0oooo0000\
\>"],
  ImageRangeCache->{{{0, 549.688}, {339.375, 0}} -> {1.02425, -79.6677, \
0.0118367, 1.36807}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 791}},
ScreenStyleEnvironment->"Presentation",
WindowSize->{1144, 764},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3249051946-3714562"->{
    Cell[9200, 414, 63, 1, 26, "Print",
      CellTags->"Info3249051946-3714562"],
    Cell[9266, 417, 455, 13, 41, "Print",
      CellTags->"Info3249051946-3714562"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3249051946-3714562", 57529, 1582}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 54, 0, 111, "Title"],

Cell[CellGroupData[{
Cell[1806, 56, 33, 0, 72, "Section"],
Cell[1842, 58, 55, 1, 38, "Input"],
Cell[1900, 61, 56, 1, 38, "Input"],
Cell[1959, 64, 68, 1, 38, "Input"],
Cell[2030, 67, 54, 1, 38, "Input"],
Cell[2087, 70, 52, 1, 38, "Input"],
Cell[2142, 73, 49, 1, 38, "Input"],
Cell[2194, 76, 74, 1, 38, "Input"],
Cell[2271, 79, 69, 1, 38, "Input"],
Cell[2343, 82, 63, 1, 38, "Input"],
Cell[2409, 85, 72, 1, 38, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2518, 91, 47, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[2590, 95, 93, 2, 61, "Input"],
Cell[2686, 99, 85, 1, 57, "Output"],
Cell[2774, 102, 96, 2, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2907, 109, 105, 2, 61, "Input"],
Cell[3015, 113, 67, 1, 54, "Output"],
Cell[3085, 116, 71, 1, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3193, 122, 56, 1, 38, "Input"],
Cell[3252, 125, 90, 1, 57, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3391, 132, 37, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[3453, 136, 34, 0, 68, "Subsection"],
Cell[3490, 138, 128, 3, 37, "SmallText"],
Cell[3621, 143, 82, 1, 53, "Input"],
Cell[3706, 146, 144, 5, 100, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3887, 156, 26, 0, 68, "Subsection"],
Cell[3916, 158, 104, 2, 37, "SmallText"],
Cell[4023, 162, 47, 1, 38, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4107, 168, 36, 0, 68, "Subsection"],
Cell[4146, 170, 57, 0, 37, "SmallText"],

Cell[CellGroupData[{
Cell[4228, 174, 60, 1, 38, "Input"],
Cell[4291, 177, 183, 3, 51, "Message"]
}, Open  ]],
Cell[4489, 183, 66, 1, 38, "Input"],
Cell[4558, 186, 37, 4, 79, "SmallText"],

Cell[CellGroupData[{
Cell[4620, 194, 42, 0, 57, "Subsubsection"],

Cell[CellGroupData[{
Cell[4687, 198, 72, 1, 54, "Input"],
Cell[4762, 201, 188, 3, 51, "Message"]
}, Open  ]],
Cell[4965, 207, 67, 5, 100, "SmallText"],
Cell[5035, 214, 138, 3, 38, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5222, 223, 45, 0, 68, "Subsection"],
Cell[5270, 225, 83, 1, 37, "SmallText"],

Cell[CellGroupData[{
Cell[5378, 230, 51, 1, 38, "Input"],
Cell[5432, 233, 195, 3, 51, "Message"]
}, Open  ]],
Cell[5642, 239, 41, 4, 79, "SmallText"],

Cell[CellGroupData[{
Cell[5708, 247, 38, 1, 38, "Input"],
Cell[5749, 250, 191, 3, 73, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6001, 260, 30, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[6056, 264, 60, 1, 38, "Input"],
Cell[6119, 267, 85, 1, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6241, 273, 34, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[6300, 277, 47, 1, 38, "Input"],
Cell[6350, 280, 41, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6428, 286, 51, 1, 38, "Input"],
Cell[6482, 289, 42, 1, 38, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6573, 296, 26, 0, 68, "Subsection"],
Cell[6602, 298, 46, 0, 37, "SmallText"],

Cell[CellGroupData[{
Cell[6673, 302, 79, 1, 54, "Input"],
Cell[6755, 305, 76, 1, 55, "Output"]
}, Open  ]],
Cell[6846, 309, 55, 0, 37, "SmallText"],
Cell[6904, 311, 76, 1, 38, "Input"],
Cell[6983, 314, 93, 4, 79, "SmallText"],
Cell[7079, 320, 59, 1, 40, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7175, 326, 41, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[7241, 330, 140, 2, 38, "Input"],
Cell[7384, 334, 126, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7547, 341, 139, 2, 38, "Input"],
Cell[7689, 345, 124, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7850, 352, 140, 2, 38, "Input"],
Cell[7993, 356, 125, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8155, 363, 142, 2, 38, "Input"],
Cell[8300, 367, 126, 2, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8463, 374, 34, 1, 38, "Input"],
Cell[8500, 377, 115, 2, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8652, 384, 65, 1, 38, "Input"],
Cell[8720, 387, 64, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8821, 393, 65, 1, 38, "Input"],
Cell[8889, 396, 62, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8988, 402, 65, 1, 38, "Input"],
Cell[9056, 405, 65, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9158, 411, 39, 1, 38, "Input"],
Cell[9200, 414, 63, 1, 26, "Print",
  CellTags->"Info3249051946-3714562"],
Cell[9266, 417, 455, 13, 41, "Print",
  CellTags->"Info3249051946-3714562"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9758, 435, 38, 1, 38, "Input"],
Cell[9799, 438, 275, 4, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10111, 447, 84, 1, 38, "Input"],
Cell[10198, 450, 239, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10474, 458, 57, 1, 38, "Input"],
Cell[10534, 461, 191, 3, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10762, 469, 39, 1, 38, "Input"],
Cell[10804, 472, 71, 1, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10912, 478, 39, 0, 57, "Subsubsection"],

Cell[CellGroupData[{
Cell[10976, 482, 115, 3, 38, "Input"],
Cell[11094, 487, 58, 1, 38, "Output"]
}, Open  ]],
Cell[11167, 491, 113, 2, 38, "Input"],
Cell[11283, 495, 113, 2, 38, "Input"],
Cell[11399, 499, 113, 2, 38, "Input"],

Cell[CellGroupData[{
Cell[11537, 505, 58, 1, 38, "Input"],
Cell[11598, 508, 52, 1, 38, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11687, 514, 372, 6, 107, "Input"],
Cell[12062, 522, 44623, 1032, 349, 11252, 616, "GraphicsData", "PostScript", \
"Graphics"],
Cell[56688, 1556, 130, 3, 38, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

