(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     72657,       1662]*)
(*NotebookOutlinePosition[     73310,       1685]*)
(*  CellTagsIndexPosition[     73266,       1681]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Geometric coil optimization", "Title"],

Cell["\<\
In this notebook the following geometric variables are under consideration:\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Alpha] = rci\/rco\)], "Input"],

Cell[BoxData[
    \(rci\/rco\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Beta] = lCoil\/\(2\ rci\)\)], "Input"],

Cell[BoxData[
    \(lCoil\/\(2\ rci\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Gamma] = rci/rrod\)], "Input"],

Cell[BoxData[
    \(rci\/rrod\)], "Output"]
}, Open  ]],

Cell["\<\
with:
rci: \tinner coil radius
rco:\touter coil radius
rrod:\tradius of magnetostrictive rod
lCoil:\tlength of the solenoid\
\>", "Text"],

Cell[BoxData[
    \(\(\(K[\[Alpha]_, \[Beta]_]\)\(:=\)\)\)], "Input"],

Cell[BoxData[
    \(G[\[Alpha]_, \[Beta]_] := 
      1/5*\((\(2\ \[Pi]\ \[Beta]\)\/\((\[Alpha]\^2 - 1)\))\)\^\(1/2\)*
        Log[\(\[Alpha] + \((\[Alpha]\^2 + \[Beta]\^2)\)\^\(1/2\)\)\/\(1 + \
\((1 + \[Beta]\^2)\)\^\(1/2\)\)]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(G[2, 2] // N\)], "Input"],

Cell[BoxData[
    \(0.16379848740501246`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowLegend[
      DensityPlot[G[\[Alpha], \[Beta]], {\[Alpha], 1, 8}, {\[Beta], 0, 5}, 
        Mesh \[Rule] False, PlotPoints \[Rule] 50, 
        PlotRange \[Rule] {0.1, 0.2}, 
        DisplayFunction \[Rule] Identity], {GrayLevel[1 - #] &, 
        10, "\<0.2\>", "\<0.1\>", 
        LegendPosition \[Rule] {1.1, \(- .4\)}}]\)], "Input"],

Cell[BoxData[
    \(Power::"infy" \(\(:\)\(\ \)\) 
      "Infinite expression \!\(1\/0.`\) encountered."\)], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0.`\\\\ \[Pi]\\\\ \\*InterpretationBox[\\\"ComplexInfinity\\\
\", DirectedInfinity[]]\\) encountered.\"\>"}]], "Message"],

Cell[BoxData[
    \(Power::"infy" \(\(:\)\(\ \)\) 
      "Infinite expression \!\(1\/0.`\) encountered."\)], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0.`\\\\ \[Pi]\\\\ \\*InterpretationBox[\\\"ComplexInfinity\\\
\", DirectedInfinity[]]\\) encountered.\"\>"}]], "Message"],

Cell[BoxData[
    \(Power::"infy" \(\(:\)\(\ \)\) 
      "Infinite expression \!\(1\/0.`\) encountered."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Power :: \"infy\"\) will be suppressed during \
this calculation."\)], "Message"],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0.`\\\\ \[Pi]\\\\ \\*InterpretationBox[\\\"ComplexInfinity\\\
\", DirectedInfinity[]]\\) encountered.\"\>"}]], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(\[Infinity] :: \"indet\"\) will be suppressed \
during this calculation."\)], "Message"],

Cell[BoxData[
    \(DensityPlot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(G[\(\(\[Alpha], \[Beta]\)\)]\) is not a machine-size real number \
at \!\({\[Alpha], \[Beta]}\) = \!\({1.`, 0.`}\)."\)], "Message"],

Cell[BoxData[
    \(DensityPlot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(G[\(\(\[Alpha], \[Beta]\)\)]\) is not a machine-size real number \
at \!\({\[Alpha], \[Beta]}\) = \!\({1.`, 0.10204081632653061`}\)."\)], \
"Message"],

Cell[BoxData[
    \(DensityPlot::"plnr" \(\(:\)\(\ \)\) 
      "\!\(G[\(\(\[Alpha], \[Beta]\)\)]\) is not a machine-size real number \
at \!\({\[Alpha], \[Beta]}\) = \!\({1.`, 0.20408163265306123`}\)."\)], \
"Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(DensityPlot :: \"plnr\"\) will be suppressed \
during this calculation."\)], "Message"],

Cell[BoxData[
    \(DensityGraphics::"zval" \(\(:\)\(\ \)\) 
      "Non-numerical value \!\(Indeterminate\) found at position \!\({1, 1}\) \
in first argument."\)], "Message"],

Cell[BoxData[
    \(DensityGraphics::"zval" \(\(:\)\(\ \)\) 
      "Non-numerical value \!\(Indeterminate\) found at position \!\({2, 1}\) \
in first argument."\)], "Message"],

Cell[BoxData[
    \(DensityGraphics::"zval" \(\(:\)\(\ \)\) 
      "Non-numerical value \!\(Indeterminate\) found at position \!\({3, 1}\) \
in first argument."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(DensityGraphics :: \"zval\"\) will be suppressed \
during this calculation."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83299 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.420473 0.396663 0.416497 0.396663 [
[ 0 0 0 0 ]
[ 1 .83299 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0198332 0.817136 0.81316 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.118132 0.137363 0.0192308 0.192308 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.15659 -0.0125 -3 -9 ]
[.15659 -0.0125 3 0 ]
[.29396 -0.0125 -3 -9 ]
[.29396 -0.0125 3 0 ]
[.43132 -0.0125 -3 -9 ]
[.43132 -0.0125 3 0 ]
[.56868 -0.0125 -3 -9 ]
[.56868 -0.0125 3 0 ]
[.70604 -0.0125 -3 -9 ]
[.70604 -0.0125 3 0 ]
[.84341 -0.0125 -3 -9 ]
[.84341 -0.0125 3 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -6 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -6 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -6 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(1)] .01923 -0.0125 0 1 Mshowa
.15659 0 m
.15659 .00625 L
s
[(2)] .15659 -0.0125 0 1 Mshowa
.29396 0 m
.29396 .00625 L
s
[(3)] .29396 -0.0125 0 1 Mshowa
.43132 0 m
.43132 .00625 L
s
[(4)] .43132 -0.0125 0 1 Mshowa
.56868 0 m
.56868 .00625 L
s
[(5)] .56868 -0.0125 0 1 Mshowa
.70604 0 m
.70604 .00625 L
s
[(6)] .70604 -0.0125 0 1 Mshowa
.84341 0 m
.84341 .00625 L
s
[(7)] .84341 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(8)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.0467 0 m
.0467 .00375 L
s
.07418 0 m
.07418 .00375 L
s
.10165 0 m
.10165 .00375 L
s
.12912 0 m
.12912 .00375 L
s
.18407 0 m
.18407 .00375 L
s
.21154 0 m
.21154 .00375 L
s
.23901 0 m
.23901 .00375 L
s
.26648 0 m
.26648 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.3489 0 m
.3489 .00375 L
s
.37637 0 m
.37637 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.45879 0 m
.45879 .00375 L
s
.48626 0 m
.48626 .00375 L
s
.51374 0 m
.51374 .00375 L
s
.54121 0 m
.54121 .00375 L
s
.59615 0 m
.59615 .00375 L
s
.62363 0 m
.62363 .00375 L
s
.6511 0 m
.6511 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.73352 0 m
.73352 .00375 L
s
.76099 0 m
.76099 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.81593 0 m
.81593 .00375 L
s
.87088 0 m
.87088 .00375 L
s
.89835 0 m
.89835 .00375 L
s
.92582 0 m
.92582 .00375 L
s
.9533 0 m
.9533 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(0)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(1)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(2)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(3)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(4)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(5)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.15659 .99375 m
.15659 1 L
s
.29396 .99375 m
.29396 1 L
s
.43132 .99375 m
.43132 1 L
s
.56868 .99375 m
.56868 1 L
s
.70604 .99375 m
.70604 1 L
s
.84341 .99375 m
.84341 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.0467 .99625 m
.0467 1 L
s
.07418 .99625 m
.07418 1 L
s
.10165 .99625 m
.10165 1 L
s
.12912 .99625 m
.12912 1 L
s
.18407 .99625 m
.18407 1 L
s
.21154 .99625 m
.21154 1 L
s
.23901 .99625 m
.23901 1 L
s
.26648 .99625 m
.26648 1 L
s
.32143 .99625 m
.32143 1 L
s
.3489 .99625 m
.3489 1 L
s
.37637 .99625 m
.37637 1 L
s
.40385 .99625 m
.40385 1 L
s
.45879 .99625 m
.45879 1 L
s
.48626 .99625 m
.48626 1 L
s
.51374 .99625 m
.51374 1 L
s
.54121 .99625 m
.54121 1 L
s
.59615 .99625 m
.59615 1 L
s
.62363 .99625 m
.62363 1 L
s
.6511 .99625 m
.6511 1 L
s
.67857 .99625 m
.67857 1 L
s
.73352 .99625 m
.73352 1 L
s
.76099 .99625 m
.76099 1 L
s
.78846 .99625 m
.78846 1 L
s
.81593 .99625 m
.81593 1 L
s
.87088 .99625 m
.87088 1 L
s
.89835 .99625 m
.89835 1 L
s
.92582 .99625 m
.92582 1 L
s
.9533 .99625 m
.9533 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of gray image
p
.01923 .01923 translate
.96154 .96154 scale
50 string
50 50 8 [50 0 0 50 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000
00000000000B11151617161513110E0C0906030000000000000000000000000000000000
0000000000000000000000000000
0000000F222E353A3C3D3C3B393734312E2B2724211D1A1713100D0A0704010000000000
0000000000000000000000000000
000003263B4952575A5B5B5A585553504C4945423E3A3733302C2925221F1B1815120F0C
0907040100000000000000000000
000012374F5F686F72747473716F6C6965625E5B57534F4B4844403D3936322F2C282522
1F1C191613110E0B090604010000
00001D445E6F7A81858788878583817E7A77736F6B6864605C5854514D4946423F3B3835
322E2B282522201D1A171512100D
0000244E697B878F949697979694928F8C8884817D7975716D6965625E5A56534F4C4845
423E3B3835322F2C292624211E1C
000028547084919A9FA3A4A4A3A2A09D9A96938F8B8884807C7874706C6965615E5A5653
504C494643403C3A3734312E2B29
00002B58758A98A1A8ACAEAEAEADABA8A5A29F9B9894908C8884807D7975716D6A66635F
5C5855524F4B4845423F3C3A3734
00002C5A788E9DA7AEB3B5B6B6B5B4B2AFACA9A5A29E9A97938F8B8783807C7874716D6A
66635F5C595653504C4A4744413E
00002B5A79909FABB2B7BBBCBDBCBBB9B7B4B1AEAAA7A39F9C9894908C8985817E7A7673
6F6C6965625F5C595552504D4A47
00002A597990A1ADB5BBBEC0C1C1C0BFBDBAB7B4B1AEAAA7A39F9C9894908D8985827E7B
7774716D6A6764605D5A5755524F
000028577890A1ADB6BDC1C3C5C5C4C3C1BFBCBAB7B3B0ADA9A6A29E9B9793908C898582
7E7B7874716E6B6764615E5C5956
00002555768EA0ADB6BDC2C5C7C7C7C6C5C3C0BEBBB8B5B2AEABA7A4A09D9996928F8B88
84817E7A7774716E6B6865625F5C
00002252748C9EACB6BDC2C6C8C9C9C8C7C6C3C1BEBCB9B6B2AFACA8A5A19E9A9794908D
898683807C797673706D6A676461
00001F4F71899CAAB4BCC2C6C8C9CACAC9C7C6C3C1BEBCB9B6B2AFACA9A5A29F9B989491
8E8B8784817E7B7875726F6C6966
00001C4B6D8699A8B2BBC1C5C8C9CACACAC9C7C5C3C1BEBBB8B5B2AFACA8A5A29F9B9895
928E8B8885827F7C797673706D6B
000018486A8396A5B0B8BFC3C7C9CACACAC9C8C6C4C2C0BDBAB7B4B1AEABA8A5A29E9B98
95928F8C898582807D7A7774716E
00001544667F93A2ADB6BDC2C5C8C9CACAC9C8C7C5C3C1BEBCB9B6B3B0ADAAA7A4A19E9B
9895928F8C898683807D7A777472
00001140627B8F9EAAB3BABFC3C6C8C9C9C9C8C7C5C3C1BFBCBAB7B5B2AFACA9A6A3A09D
9A9794918E8B888583807D7A7775
00000D3C5E778B9AA7B0B7BDC1C4C6C7C8C8C7C6C5C3C1BFBDBBB8B5B3B0ADAAA8A5A29F
9C999693908D8B8885827F7D7A77
00000A385A738797A3ADB4BABFC2C4C5C6C6C6C5C4C3C1BFBDBBB9B6B3B1AEABA9A6A3A0
9D9B9895928F8C8A8784827F7C7A
00000634566F83939FA9B1B7BCBFC2C3C4C5C5C4C3C2C1BFBDBBB9B6B4B1AFACA9A7A4A1
9F9C999694918E8B898683817E7C
00000330526B7F8F9CA6AEB4B9BDBFC1C2C3C3C3C2C1C0BEBCBAB8B6B4B2AFADAAA7A5A2
9F9D9A9795928F8D8A878582807D
0000002C4E677B8B98A2AAB1B6BABDBFC0C1C1C1C1C0BFBDBCBAB8B6B4B1AFADAAA8A5A3
A09E9B989693908E8B898684817F
000000294A637787949EA7ADB3B7BABCBEBFBFBFBFBEBDBCBBB9B7B5B3B1AFADAAA8A5A3
A09E9B999694918F8C8A87858280
00000025465F7383909BA3AAAFB4B7BABBBDBDBDBDBDBCBBB9B8B6B5B3B1AFACAAA8A5A3
A19E9C999794928F8D8B88868381
00000021425B6F7F8C979FA6ACB1B4B7B9BABBBBBBBBBAB9B8B7B5B4B2B0AEACAAA8A5A3
A19E9C9A979592908E8B89868482
0000001E3E576B7B88939CA3A9ADB1B4B6B7B8B9B9B9B8B8B7B5B4B2B1AFADABA9A7A5A3
A09E9C9A979593908E8C89878582
0000001A3A536777848F989FA5AAAEB1B3B5B6B7B7B7B7B6B5B4B3B1B0AEACAAA8A6A4A2
A09E9C9A979593908E8C8A878583
0000001737506374818C949CA2A7ABAEB0B2B3B4B5B5B5B4B3B2B1B0AEADABA9A8A6A4A2
A09E9B99979593908E8C8A888583
00000014334C60707D8891989EA4A8ABADAFB1B2B2B3B2B2B1B1B0AEADACAAA8A7A5A3A1
9F9D9B99979593908E8C8A888683
0000001130485C6C79848D959BA0A4A8AAADAEAFB0B0B0B0AFAFAEADACAAA9A7A6A4A2A0
9E9C9A98969492908E8C8A888683
0000000D2D45586876818A91989DA1A5A8AAABADADAEAEAEADADACABAAA9A7A6A4A3A19F
9D9C9A98969492908E8C8A888683
0000000A29415565727D868E949A9EA2A5A7A9AAABABACACABABAAA9A8A7A6A5A3A2A09E
9D9B99979593918F8D8B89878583
00000008263E51616F7A838A91969B9FA2A4A6A7A8A9A9A9A9A9A8A8A7A6A4A3A2A09F9D
9C9A98969493918F8D8B89878583
00000005233B4E5E6B767F878E93989C9FA1A3A5A6A7A7A7A7A7A6A6A5A4A3A2A09F9E9C
9A9997959492908E8C8A89878583
0000000220384B5B68737C848A9095989C9EA0A2A3A4A5A5A5A5A4A4A3A2A1A09F9E9C9B
9998969493918F8D8C8A88868482
000000001D344857646F7981878D9195999B9E9FA1A2A2A3A3A3A2A2A1A0A09E9D9C9B99
9897959392908E8D8B8987868482
000000001A314454616C757D848A8E9296999B9D9E9FA0A0A1A1A0A09F9F9E9D9C9B9998
97959492918F8D8C8A8887858381
00000000172E41515E69727A81878B8F9396989A9B9D9D9E9E9E9E9E9D9D9C9B9A999897
95949391908E8D8B898886848381
00000000152C3E4E5B666F777E83888C90939597999A9B9C9C9C9C9C9B9B9A9999989695
949391908F8D8B8A888785838280
0000000012293B4B58636C747B80858A8D909395969899999A9A9A9A9999989897969594
9391908F8D8C8A8987868483817F
000000000F26384855606971787D82878A8D909294959697979898989797979695949392
91908F8D8C8B898886858382807F
000000000D233645525D666E757A8084878B8D8F91939495959696969595959493939291
908F8D8C8B8A8887858482817F7E
000000000A2133424F5A636B72787D8185888B8D8F90919293939494939393929291908F
8E8D8C8B8A888786848381807F7D
00000000081E303F4C5760686F757A7E8285888A8C8E8F909191919191919190908F8E8E
8D8C8B89888786858382807F7E7C
00000000051B2E3D49545D656C72777B7F8285888A8B8C8E8E8F8F8F8F8F8F8F8E8D8D8C
8B8A89888786858382817F7E7D7B
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
0 g
.87664 .238 m
.87664 .55533 L
.97619 .55533 L
.97619 .238 L
F
1 g
.8568 .25783 m
.8568 .57516 L
.95636 .57516 L
.95636 .25783 L
F
0 g
.001 w
[ ] 0 setdash
.8568 .25783 m
.95636 .25783 L
.95636 .57516 L
.8568 .57516 L
.8568 .25783 L
s
% Start of sub-graphic
p
0.856803 0.257831 0.956357 0.575162 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.03125 0.3125 0.03125 0.3125 [
[ 0 0 0 0 ]
[ 1 3.1875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 3.1875 L
0 3.1875 L
closepath
clip
newpath
0 g
.03125 .03125 m
.03125 .34375 L
.34375 .34375 L
.34375 .03125 L
F
gsave
.35938 .1875 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.111 g
.03125 .34375 m
.03125 .65625 L
.34375 .65625 L
.34375 .34375 L
F
.222 g
.03125 .65625 m
.03125 .96875 L
.34375 .96875 L
.34375 .65625 L
F
.333 g
.03125 .96875 m
.03125 1.28125 L
.34375 1.28125 L
.34375 .96875 L
F
.444 g
.03125 1.28125 m
.03125 1.59375 L
.34375 1.59375 L
.34375 1.28125 L
F
.556 g
.03125 1.59375 m
.03125 1.90625 L
.34375 1.90625 L
.34375 1.59375 L
F
.667 g
.03125 1.90625 m
.03125 2.21875 L
.34375 2.21875 L
.34375 1.90625 L
F
.778 g
.03125 2.21875 m
.03125 2.53125 L
.34375 2.53125 L
.34375 2.21875 L
F
.889 g
.03125 2.53125 m
.03125 2.84375 L
.34375 2.84375 L
.34375 2.53125 L
F
1 g
.03125 2.84375 m
.03125 3.15625 L
.34375 3.15625 L
.34375 2.84375 L
F
0 g
gsave
.35938 3 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .83299 L
0 .83299 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{489.875, 408},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007Y0001V1000`40O003h00OogoojWoo003oOooZ
Ool00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00
ogoojWoo003oOooZOol001eoo`D002ioo`@0031oo`8003=oo`<002moo`80031oo`<003=oo`03001o
ogoo02moo`80069oo`007goo00<007ooOol0;Woo00<007ooOol0<7oo00@007ooOol003=oo`03001o
ogoo02eoo`04001oogoo000_Ool01000Oomoo`00<Woo00<007ooOol0;Woo00@007ooOol0065oo`00
7goo00<007ooOol0;goo00<007ooOol0<Goo00<007ooOol0;goo1@00<Goo00<007ooOol0;Goo00@0
07ooOol0039oo`03001oogoo02ioo`04001oogoo001QOol001moo`03001oogoo031oo`03001oogoo
035oo`03001oogoo02ioo`04001oogoo000`Ool2000`Ool3000dOol00`00Oomoo`0^Ool2001ROol0
01moo`03001oogoo02ioo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo0000<7oo00<007oo
Ool0<7oo00<007ooOol0<7oo00@007ooOol002moo`04001oogoo001QOol001ioo`80035oo`80035o
o`8003=oo`80031oo`<0031oo`<0031oo`@0031oo`80069oo`00ogoojWoo003oOooZOol00?moonYo
o`00ogoojWoo003oOooZOol00?moonYoo`00ogoojWoo000GOooo001h001KOol001Moo`03001oogoo
00Eoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Aoo`03001oogoo05Uoo`005goo00<007ooOol01Goo00<007ooOol0<7oo00<0
07ooOol0<7oo00<007ooOol0<Goo00<007ooOol0<7oo00<007ooOol0<7oo00<007ooOol0<Goo00<0
07ooOol0<7oo00<007ooOol017oo00<007ooOol0FGoo000GOol00`00Oomoo`3oOomdOol00`00Oomo
o`1IOol001Moo`03001oogoo0?moogAoo`03001oogoo05Uoo`003goo0P001Woo00<007ooOol0ogoo
M7oo00<007ooOol0FGoo000>Ool01000Oomoo`001Goo00<007ooOol0ogooM7oo00<007ooOol0FGoo
000>Ool01000Oomoo`001Goo1000ogooLGoo0`00Fgoo000>Ool01000Oomoo`001Goo00<007ooOol0
1Gooo`00J@001Woo00<007ooOol0FGoo000>Ool01000Oomoo`001Goo00<007ooOol01Gooo`00J@00
1Woo00<007ooOol0FGoo000?Ool20006Ool00`00Oomoo`05Oooo001Y0006Ool00`00Oomoo`1IOol0
01Moo`03001oogoo00Eoool006T000Ioo`03001oogoo05Uoo`005goo00<007ooOol01Gooo`00J@00
1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Oooo001Y0006Ool00`00Oomoo`1IOol001Moo`03
001oogoo00Eoool006T000Ioo`03001oogoo05Uoo`005goo00<007ooOol01Gooo`00J@001Woo00<0
07ooOol0FGoo000GOol00`00Oomoo`05Oooo001Y0006Ool00`00Oomoo`1IOol001Moo`03001oogoo
00Eoool006T000Ioo`03001oogoo05Uoo`005goo00<007ooOol01Gooo`00J@001Woo00<007ooOol0
FGoo000GOol00`00Oomoo`05Oooo001Y0006Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eoool0
06T000Ioo`03001oogoo05Uoo`005goo0`001Gooo`00J@001Goo0P00Fgoo000GOol00`00Oomoo`05
Oooo001Y0006Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eoool006T000Ioo`03001oogoo05Uo
o`005goo00<007ooOol01Gooo`00J@001Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Oooo001Y
0006Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eoool006T000Ioo`03001oogoo05Uoo`005goo
00<007ooOol01Gooo`00J@001Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Oooo001Y0006Ool0
0`00Oomoo`1IOol001Moo`03001oogoo00Eoool006T000Ioo`03001oogoo05Uoo`005goo00<007oo
Ool01Goo90001`@Q>PQ25@@QkP001Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolT0007124j
248E127^0006Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eoob@000L48CX8@QD48Nh000Ioo`03
001oogoo05Uoo`005goo00<007ooOol01Goo90001`@Q>PQ25@@QkP001Woo00<007ooOol0FGoo000G
Ool00`00Oomoo`05OolT0007124j248E127^0006Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eo
ob@000L48CX8@QD48Nh000Ioo`03001oogoo05Uoo`005goo0`001Goo90001`@Q>PQ25@@QkP001Goo
0P00Fgoo000GOol00`00Oomoo`05OolE0007124848@75:D76<H[7>LF6<H>5:DF48@>36<F248>126O
0006Ool00`00Oomoo`1IOol001Moo`03001oogoo00EooaD000L48@P@Q0LDY@LHaR/LiaHHaPhDYAH@
Q0h<HaH8@Ph48Il000Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo5@001`@Q21241aBU1aS6
:acW5QS63QBU5Q243PaS5PQ23P@QW`001Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolE0007
124848@75:D76<H[7>LF6<H>5:DF48@>36<F248>126O0006Ool00`00Oomoo`1IOol001Moo`03001o
ogoo00EooaD000L48@P@Q0LDY@LHaR/LiaHHaPhDYAH@Q0h<HaH8@Ph48Il000Ioo`03001oogoo05Uo
o`005goo00<007ooOol01Goo5@001`@Q21241aBU1aS6:acW5QS63QBU5Q243PaS5PQ23P@QW`001Woo
00<007ooOol0FGoo000GOol00`00Oomoo`05OolE0007124848@75:D76<H[7>LF6<H>5:DF48@>36<F
248>126O0006Ool00`00Oomoo`1IOol001Moo`03001oogoo00EooaD000L@Q0PLi`LU:@hYBR@]JaHY
BPhU:@lQ20hLiaHHaPhDY@l@Q1D<H`l8@QD48Eh000Ioo`03001oogoo05Uoo`005goo00<007ooOol0
1Goo5@001a2421cW1bDY3RU:92e[5RU:3RDY3b483QcW5QS63QBU3a245@aS3`Q25@@QGP001Woo00<0
07ooOol0FGoo000GOol00`00Oomoo`05OolE000748@87>L79BT>:DXT;F/F:DX>9BT?8@P>7>LF6<H>
5:D?48@E36<?248E125N0006Ool00`00Oomoo`1IOol001Moo`03001oogoo00EooaD000L@Q0PLi`LU
:@hYBR@]JaHYBPhU:@lQ20hLiaHHaPhDY@l@Q1D<H`l8@QD48Eh000Ioo`03001oogoo05Uoo`005goo
00<007ooOol01Goo5@001a2421cW1bDY3RU:92e[5RU:3RDY3b483QcW5QS63QBU3a245@aS3`Q25@@Q
GP001Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolE000748@87>L79BT>:DXT;F/F:DX>9BT?
8@P>7>LF6<H>5:D?48@E36<?248E125N0006Ool00`00Oomoo`1IOol001Moo`<000EooaD000L@Q0PL
i`LU:@hYBR@]JaHYBPhU:@lQ20hLiaHHaPhDY@l@Q1D<H`l8@QD48Eh000Eoo`8005]oo`005goo00<0
07ooOol01Goo3P001`Q21aS622DY1be[3SF]93W>5SF]3S6<3be[3RU:5RDY3R483acW3QS65QBU3Q24
5PaS5@Q25P@Q90001Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Ool>000724876<H89BT7;F/>
=JdT>LhF=Jd><H`?;F/>:DXF9BT>8@P?7>L>6<HF5:D>48@F36<E248F124T0006Ool00`00Oomoo`1I
Ool001Moo`03001oogoo00Eoo`h000L8@PLHaPPU:@L]J`he[B@icQHe[@haS0l]J`hYBQHU:@hQ20lL
i`hHaQHDY@h@Q1H<HaD8@QH48B@000Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo3P001`Q2
1aS622DY1be[3SF]93W>5SF]3S6<3be[3RU:5RDY3R483acW3QS65QBU3Q245PaS5@Q25P@Q90001Woo
00<007ooOol0FGoo000GOol00`00Oomoo`05Ool>000724876<H89BT7;F/>=JdT>LhF=Jd><H`?;F/>
:DXF9BT>8@P?7>L>6<HF5:D>48@F36<E248F124T0006Ool00`00Oomoo`1IOol001Moo`03001oogoo
00Eoo`h000L8@PLHaPPU:@L]J`he[B@icQHe[@haS0l]J`hYBQHU:@hQ20lLi`hHaQHDY@h@Q1H<HaD8
@QH48B@000Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo3P001`Q21aS622DY1be[3SF]93W>
5SF]3S6<3be[3RU:5RDY3R483acW3QS65QBU3Q245PaS5@Q25P@Q90001Woo00<007ooOol0FGoo000G
Ool00`00Oomoo`05Ool>000736<78@P8;F/7=Jd7?NlF@Q07AS4M@Q0>?Nl?>LhE=Jd?<H`>;F/>:DX?
9BT>8@PF7>L>6<HF5:DF48@>36<M24871246Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eoo`h0
00L<H`LQ20P]J`Le[@LmkaI240M6<Ae240hmk`licQDe[@laS0h]J`hYBPlU:@hQ21HLi`hHaQHDYAH@
Q0h<Had8@PL48@Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo3P001`aS1b4822e[1cF]1cg_
5T8@1dHa7D8@3Sg_3cW>5CF]3c6<3Re[3RU:3bDY3R485QcW3QS65QBU5Q243PaS7@Q21`@Q1Woo00<0
07ooOol0FGoo000GOol00`00Oomoo`05Ool>000736<78@P8;F/7=Jd7?NlF@Q07AS4M@Q0>?Nl?>LhE
=Jd?<H`>;F/>:DX?9BT>8@PF7>L>6<HF5:DF48@>36<M24871246Ool00`00Oomoo`1IOol001Moo`03
001oogoo00Eoo`h000L<H`LQ20P]J`Le[@LmkaI240M6<Ae240hmk`licQDe[@laS0h]J`hYBPlU:@hQ
21HLi`hHaQHDYAH@Q0h<Had8@PL48@Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo3P001`aS
1b4822e[1cF]1cg_5T8@1dHa7D8@3Sg_3cW>5CF]3c6<3Re[3RU:3bDY3R485QcW3QS65QBU5Q243PaS
7@Q21`@Q1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Ool>000736<78@P8;F/7=Jd7?NlF@Q07
AS4M@Q0>?Nl?>LhE=Jd?<H`>;F/>:DX?9BT>8@PF7>L>6<HF5:DF48@>36<M24871246Ool00`00Oomo
o`1IOol001Moo`<000Eoo`h000L@Q0LU:@Pe[@Lmk`M240M6<C=:DQE6<@m240hmk`licPhe[@haS0l]
J`hYBQHU:@hQ21HLi`hHaQHDYAH@Q0h<H`Eoo`8005]oo`005goo00<007ooOol01Goo3P001a241bDY
23F]1cg_1d8@1dHa<dYB5DHa3d8@3Sg_3cW>3SF]3S6<3be[3RU:5RDY3R485QcW3QS65QBU5Q243PaS
1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Ool>000748@79BT8=Jd7?Nl7@Q07AS4cBU8EAS4?
@Q0>?Nl?>Lh>=Jd><H`?;F/>:DXF9BT>8@PF7>L>6<HF5:DF48@>36<6Ool00`00Oomoo`1IOol001Mo
o`03001oogoo00Eoo`h000L@Q0LU:@Pe[@Lmk`M240M6<C=:DQE6<@m240hmk`licPhe[@haS0l]J`hY
BQHU:@hQ21HLi`hHaQHDYAH@Q0h<H`Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo3P001a24
1bDY23F]1cg_1d8@1dHa<dYB5DHa3d8@3Sg_3cW>3SF]3S6<3be[3RU:5RDY3R485QcW3QS65QBU5Q24
3PaS1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Ool>000748@79BT8=Jd7?Nl7@Q07AS4cBU8E
AS4?@Q0>?Nl?>Lh>=Jd><H`?;F/>:DXF9BT>8@PF7>L>6<HF5:DF48@>36<6Ool00`00Oomoo`1IOol0
01Moo`03001oogoo00Eoo`h000L@Q0LU:@Pe[@Lmk`M240M6<C=:DQE6<@m240hmk`licPhe[@haS0l]
J`hYBQHU:@hQ21HLi`hHaQHDYAH@Q0h<H`Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo3P00
1a241bDY23F]1cg_1d8@1dHa<dYB5DHa3d8@3Sg_3cW>3SF]3S6<3be[3RU:5RDY3R485QcW3QS65QBU
5Q243PaS1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Ool>00075:D7:DX8>Lh7@Q07BU8>CW</
DY@>CW<?BU8EAS4?@Q0>?Nl>>Lh?=Jd><H`?;F/E:DX?9BTE8@P?7>LE6<HF5:D6Ool00`00Oomoo`1I
Ool001Moo`03001oogoo00Eoo`h000LDY@LYBPPicPM240M:DPi>LbaBU0i>L`m:DQE6<@m240hmk`hi
cPle[@haS0l]JaDYBPlU:ADQ20lLiaDHaQHDY@Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo
3P001aBU1bU:23W>1d8@1dYB3Tic;5:D3Tic3dYB5DHa3d8@3Sg_3SW>3cF]3S6<3be[5BU:3bDY5B48
3acW5AS65QBU1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Ool>00075:D7:DX8>Lh7@Q07BU8>
CW</DY@>CW<?BU8EAS4?@Q0>?Nl>>Lh?=Jd><H`?;F/E:DX?9BTE8@P?7>LE6<HF5:D6Ool00`00Oomo
o`1IOol000ioo`D000Aoo`03001oogoo00Eoo`h000LDY@LYBPPicPM240M:DPi>LbaBU0i>L`m:DQE6
<@m240hmk`hicPle[@haS0l]JaDYBPlU:ADQ20lLiaDHaQHDY@Ioo`03001oogoo05Uoo`0047oo00<0
07ooOol017oo00<007ooOol01Goo3P001aBU1bU:23W>1d8@1dYB3Tic;5:D3Tic3dYB5DHa3d8@3Sg_
3SW>3cF]3S6<3be[5BU:3bDY5B483acW5AS65QBU1Woo00<007ooOol0FGoo000@Ool00`00Oomoo`04
Ool40004Ool>00075:D7:DX8>Lh7@Q07BU8>CW</DY@>CW<?BU8EAS4?@Q0>?Nl>>Lh?=Jd><H`?;F/E
:DX?9BTE8@P?7>LE6<HF5:D4Ool3001KOol0011oo`03001oogoo00Aoo`03001oogoo00Eoo`h000LD
Y@L]J`PicPM6<@M>L`MBU3YF]@iBU1I>L`i:DPm6<@i240lmk`hicPhe[@laS1H]J`hYBQHU:@hQ21HL
i`hHaPIoo`03001oogoo05Uoo`0047oo00<007ooOol017oo00<007ooOol01Goo3P001aBU1be[23W>
1dHa1dic1e:D>UJe3U:D5Tic3TYB3dHa3T8@3cg_3SW>3SF]3c6<5Re[3RU:5RDY3R485QcW3QS61Woo
00<007ooOol0FGoo000?Ool20006Ool00`00Oomoo`05Ool>00075:D7;F/8>Lh7AS47CW<7DY@jE[D>
DY@FCW<>BU8?AS4>@Q0??Nl>>Lh>=Jd?<H`F;F/>:DXF9BT>8@PF7>L>6<H6Ool00`00Oomoo`1IOol0
01Moo`03001oogoo00Eoo`h000LDY@L]J`PicPM6<@M>L`MBU3YF]@iBU1I>L`i:DPm6<@i240lmk`hi
cPhe[@laS1H]J`hYBQHU:@hQ21HLi`hHaPIoo`03001oogoo05Uoo`005goo00<007ooOol01Goo3P00
1aBU1be[23W>1dHa1dic1e:D>UJe3U:D5Tic3TYB3dHa3T8@3cg_3SW>3SF]3c6<5Re[3RU:5RDY3R48
5QcW3QS61Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Ool>00075:D7;F/8>Lh7AS47CW<7DY@j
E[D>DY@FCW<>BU8?AS4>@Q0??Nl>>Lh>=Jd?<H`F;F/>:DXF9BT>8@PF7>L>6<H6Ool00`00Oomoo`1I
Ool001Moo`03001oogoo00Eoo`h000LDY@L]J`PicPM6<@M>L`MBU3YF]@iBU1I>L`i:DPm6<@i240lm
k`hicPhe[@laS1H]J`hYBQHU:@hQ21HLi`hHaPIoo`03001oogoo05Uoo`005goo00<007ooOol01Goo
3P001aBU1be[23g_1dHa1dic1e:D1eJe<e[F5UJe3U:D3Tic3dYB3THa5T8@3Sg_3cW>3SF]3c6<5Be[
5RU:3RDY5R481acW1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Ool>00075:D7;F/8?Nl7AS47
CW<7DY@7E[DcF]HFE[D>DY@>CW<?BU8>AS4F@Q0>?Nl?>Lh>=Jd?<H`E;F/F:DX>9BTF8@P77>L6Ool0
0`00Oomoo`1IOol001Moo`03001oogoo00Eoo`h000LDY@L]J`Pmk`M6<@M>L`MBU0MF]C=JeQIF]@iB
U0i>L`m:DPi6<AI240hmk`licPhe[@laS1D]JaHYBPhU:AHQ20LLi`Ioo`03001oogoo05Uoo`005goo
00<007ooOol01Goo3P001aBU1be[23g_1dHa1dic1e:D1eJe<e[F5UJe3U:D3Tic3dYB3THa5T8@3Sg_
3cW>3SF]3c6<5Be[5RU:3RDY5R481acW1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05Ool>0007
5:D7;F/8?Nl7AS47CW<7DY@7E[DcF]HFE[D>DY@>CW<?BU8>AS4F@Q0>?Nl?>Lh>=Jd?<H`E;F/F:DX>
9BTF8@P77>L6Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eoo`h000LDY@L]J`Pmk`M6<@M>L`MB
U0MF]C=JeQIF]@iBU0i>L`m:DPi6<AI240hmk`licPhe[@laS1D]JaHYBPhU:AHQ20LLi`Ioo`03001o
ogoo05Uoo`005goo0`001Goo3P001aBU1be[23g_1dHa1dic1e:D1eJe<e[F5UJe3U:D3Tic3dYB3THa
5T8@3Sg_3cW>3SF]3c6<5Be[5RU:3RDY5R481acW1Goo0P00Fgoo000GOol00`00Oomoo`05Ool>0007
5:D7;F/8?Nl7BU87CW<7E[D?F]H[G_LFF]H>E[D>DY@FCW<>BU8?AS4>@Q0??Nl>>LhF=Jd><H`F;F/E
:DX?9BT78@P6Ool00`00Oomoo`0LOola000<Ool001Moo`03001oogoo00Eoo`h000LDY@L]J`Pmk`M:
DPM>L`MF]@mJeR]NmaIJePiF]@iBU1I>L`i:DPm6<@i240lmk`hicQHe[@haS1H]JaDYBPlU:@LQ20Io
o`03001oogoo01aooc4000aoo`005goo00<007ooOol01Goo3P001aBU1be[23g_1dYB1dic1eJe3e[F
:ekg5U[F3UJe3U:D5Tic3TYB3dHa3T8@3cg_3SW>5SF]3S6<5Re[5BU:3bDY1b481Woo00<007ooOol0
77oo<@0037oo000GOol00`00Oomoo`05Ool>00075:D7;F/8?Nl7BU87CW<7E[D?F]H[G_LFF]H>E[D>
DY@FCW<>BU8?AS4>@Q0??Nl>>LhF=Jd><H`F;F/E:DX?9BT78@P6Ool00`00Oomoo`0LOola000<Ool0
01Moo`03001oogoo00Eoo`h000LDY@L]J`Pmk`M:DPM>L`MF]@mJeR]NmaIJePiF]@iBU1I>L`i:DPm6
<@i240lmk`hicQHe[@haS1H]JaDYBPlU:@LQ20Ioo`03001oogoo01aooc4000aoo`005goo00<007oo
Ool01Goo3P001aBU1be[23g_1dYB1dic1eJe3e[F:ekg5U[F3UJe3U:D5Tic3TYB3dHa3T8@3cg_3SW>
5SF]3S6<5Re[5BU:3bDY1b481Woo00<007ooOol077oo<@0037oo000GOol00`00Oomoo`05Ool>0007
5:D7;F/8?Nl7BU87CW<7E[D?F]H[G_LFF]H>E[D>DY@FCW<>BU8?AS4>@Q0??Nl>>LhF=Jd><H`F;F/E
:DX?9BT78@P6Ool00`00Oomoo`0LOola000<Ool001Moo`03001oogoo00Eoo`h000LDY@L]J`Pmk`M:
DPMBU0MF]@MJePmNmaeS61ENmaIJePiF]@mBU1E>L`m:DPi6<@m240hmkaHicPhe[AHaS0h]JaHYBPLU
:@Ioo`03001oogoo01aooc4000aoo`005goo00<007ooOol01Goo3P001aBU1be[23g_1dYB1e:D1eJe
1e[F3ekg7F<H5Ekg5U[F3UJe3e:D5Dic3dYB3THa3d8@3Sg_5SW>3SF]5S6<3Re[5RU:1bDY1Woo00<0
07ooOol04Woo>`0037oo000GOol00`00Oomoo`05Ool>00075:D7;F/8?Nl7BU87DY@7E[D7F]H?G_LM
HaPEG_LFF]H>E[D?DY@ECW<?BU8>AS4?@Q0>?NlF>Lh>=JdF<H`>;F/F:DX79BT6Ool00`00Oomoo`0B
Ool00`00Oomoo`0^Ool:000<Ool001Moo`03001oogoo00Eoo`h000LDY@L]J`Pmk`M:DPMBU0MF]@MJ
ePmNmaeS61ENmaIJePiF]@mBU1E>L`m:DPi6<@m240hmkaHicPhe[AHaS0h]JaHYBPLU:@Ioo`03001o
ogoo019oo`03001oogoo02ioo`X000aoo`005goo00<007ooOol01Goo3P001aBU1be[23g_1dYB1e:D
1eJe1e[F3ekg7F<H5Ekg5U[F3UJe3e:D5Dic3dYB3THa3d8@3Sg_5SW>3SF]5S6<3Re[5RU:1bDY1Woo
00<007ooOol04Woo00<007oo00003P0087oo2P0037oo000GOol00`00Oomoo`05Ool>00075:D7;F/8
?Nl7BU87DY@7E[D7F]H?G_LMHaPEG_LFF]H>E[D?DY@ECW<?BU8>AS4?@Q0>?NlF>Lh>=JdF<H`>;F/F
:DX79BT6Ool00`00Oomoo`0BOol00`00Ool0000>000POol:000<Ool001Moo`03001oogoo00Eoo`h0
00LDY@L]J`Pmk`M:DPMBU0MF]@MJePmNmaeS61ENmaIJePiF]@mBU1E>L`m:DPi6<@m240hmkaHicPhe
[AHaS0h]JaHYBPLU:@Ioo`03001oogoo019oo`03001oo`0000h0021oo`X000aoo`005goo0`001Goo
3P001aBU1be[23g_1dYB1e:D1eJe1e[F3ekg7F<H5Ekg5U[F3UJe3e:D5Dic3dYB3THa3d8@3Sg_5SW>
3SF]5S6<3Re[5RU:1bDY1Goo0P0057oo00<007oo00003P0087oo2P0037oo000GOol00`00Oomoo`05
Ool>00075:D7:DX8?Nl7BU87DY@7E[D7F]H8G_LbHaPFG_LEF]H?E[D>DY@?CW<EBU8?AS4>@Q0F?Nl>
>Lh?=JdE<H`F;F/7:DX6Ool00`00Oomoo`0BOol00`00Ool0000>000POol:000<Ool001Moo`03001o
ogoo00Eoo`h000LDY@LYBPPmk`M:DPMBU0MF]@MJePQNmc9S61INmaEJePmF]@iBU0m>LaE:DPm6<@i2
41Hmk`hicPle[ADaS1H]J`LYBPIoo`03001oogoo019oo`03001oo`0000h000Eoo`8000Aoo`8000=o
o`D000]oo`X000aoo`005goo00<007ooOol01Goo3P001aBU1bU:23g_1dYB1e:D1eJe1e[F25kg<V<H
5Ukg5E[F3eJe3U:D3dic5DYB3dHa3T8@5Sg_3SW>3cF]5C6<5Re[1bU:1Woo00<007ooOol04Woo00<0
07oo00003P0017oo00@007ooOol000Yoo`03001oogoo00]oo`X000aoo`005goo00<007ooOol01Goo
3P001aBU1bU:23g_1dYB1e:D1eJe1e[F25kg<V<H5Ukg5E[F3eJe3U:D3dic5DYB3dHa3T8@5Sg_3SW>
3cF]5C6<5Re[1bU:1Woo00<007ooOol04Woo00<007oo00003P0017oo00@007ooOol000Yoo`03001o
ogoo00]oo`X000aoo`005goo00<007ooOol01Goo3P001aBU1bU:23g_1dYB1e:D1eJe1e[F25kg<V<H
5Ukg5E[F3eJe3U:D3dic5DYB3dHa3T8@5Sg_3SW>3cF]5C6<5Re[1bU:1Woo00<007ooOol04Woo00<0
07oo00003P0017oo00@007ooOol000Yoo`03001oogoo00]oo`X000aoo`005goo00<007ooOol01Goo
3P001aBU1bU:23g_1dYB1e:D1eJe1e[F25kg<V<H5Ukg5E[F3eJe3U:D3dic5DYB3dHa3T8@5Sg_3SW>
3cF]5C6<5Re[1bU:1Woo00<007ooOol04Woo00<007oo00003P0017oo00@007ooOol000Yoo`03001o
ogoo00]oo`X000aoo`005goo00<007ooOol01Goo3P001aBU1bU:23g_1dYB1e:D1eJe1e[F25kg<V<H
5Ukg5E[F3eJe3U:D3dic5DYB3dHa3T8@5Sg_3SW>3cF]5C6<5Re[1bU:1Woo00<007ooOol04Woo00<0
07oo00003P001Goo0P002Woo0P003Goo2P0037oo000GOol00`00Oomoo`05Ool>000748@7:DX8>Lh7
AS47DY@7E[D7F]H8G_M1HaPEG_L?F]H>E[DFDY@>CW<>BU8FAS4?@Q0>?NlF>LhE=Jd?<H`>;F/6Ool0
0`00Oomoo`0BOol00`00Ool0000>000POol:000<Ool001Moo`03001oogoo00Eoo`h000L@Q0LYBPPi
cPM6<@MBU0MF]@MJePQNmd5S61ENm`mJePiF]AIBU0i>L`i:DQI6<@m240hmkaHicQDe[@laS0h]J`Io
o`03001oogoo019oo`03001oo`0000h0021oo`X000aoo`005goo00<007ooOol01Goo3P001a241bU:
23W>1dHa1e:D1eJe1e[F25kg@F<H5Ekg3e[F3UJe5U:D3Tic3TYB5THa3d8@3Sg_5SW>5CF]3c6<3Re[
1Woo00<007ooOol04Woo00<007oo00003P0087oo2P0037oo000GOol00`00Oomoo`05Ool>000748@7
:DX8>Lh7AS47DY@7E[D7F]H8G_M1HaPEG_L?F]H>E[DFDY@>CW<>BU8FAS4?@Q0>?NlF>LhE=Jd?<H`>
;F/6Ool00`00Oomoo`0BOol00`00Ool0000>000POol:000<Ool001Moo`03001oogoo00Eoo`h000L@
Q0LYBPPicPM6<@MBU0MF]@MJePQNmd5S61ENm`mJePiF]AIBU0i>L`i:DQI6<@m240hmkaHicQDe[@la
S0h]J`Ioo`03001oogoo019oo`03001oo`aS00h<Hb1oo`X000aoo`005goo00<007ooOol01Goo3P00
1a241bU:23W>1dHa1e:D1eJe1e[F25kg@F<H5Ekg3e[F3UJe5U:D3Tic3TYB5THa3d8@3Sg_5SW>5CF]
3c6<3Re[1Woo00<007ooOol04Woo00<007oo36<03PaS87oo2P0037oo000GOol30005Ool>000748@7
:DX8>Lh7AS47DY@7E[D7F]H8G_M1HaPEG_L?F]H>E[DFDY@>CW<>BU8FAS4?@Q0>?NlF>LhE=Jd?<H`>
;F/5Ool2000DOol00`00Ool<H`0>36<POol:000<Ool001Moo`03001oogoo00Eoo`h000L@Q0LYBPPi
cPM6<@M>L`MF]@MJePQNm`iS61eW>AeS61ENm`mJeQEF]@mBU0i>LaI:DPi6<AI240hmkaHicPhe[AHa
S0Ioo`03001oogoo019oo`03001oo`aS00h<Hb1oo`X000aoo`005goo00<007ooOol01Goo3P001a24
1bU:23W>1dHa1dic1eJe1e[F25kg3V<H7FLi7F<H5Ekg3e[F5EJe3e:D3Tic5TYB3THa5T8@3Sg_5SW>
3SF]5S6<1Woo00<007ooOol04Woo00<007oo36<03PaS87oo2P0037oo000GOol00`00Oomoo`05Ool>
000748@7:DX8>Lh7AS47CW<7E[D7F]H8G_L>HaPMIcTMHaPEG_L?F]HEE[D?DY@>CW<FBU8>AS4F@Q0>
?NlF>Lh>=JdF<H`6Ool00`00Oomoo`0BOol00`00Ool<H`0>36<POol:000<Ool001Moo`03001oogoo
00Eoo`h000L@Q0LYBPPicPM6<@M>L`MF]@MJePQNm`iS61eW>AeS61ENm`mJeQEF]@mBU0i>LaI:DPi6
<AI240hmkaHicPhe[AHaS0Ioo`03001oogoo019oo`03001oo`aS00h<Hb1oo`X000aoo`005goo00<0
07ooOol01Goo3P001a241bU:23W>1dHa1dic1eJe1e[F25kg3V<H7FLi7F<H5Ekg3e[F5EJe3e:D3Tic
5TYB3THa5T8@3Sg_5SW>3SF]5S6<1Woo00<007ooOol04Woo00<007oo36<03PaS87oo2P0037oo000G
Ool00`00Oomoo`05Ool>000748@7:DX8>Lh7AS47CW<7E[D7F]H8G_L>HaPMIcTMHaPEG_L?F]HEE[D?
DY@>CW<FBU8>AS4F@Q0>?NlF>Lh>=JdF<H`6Ool00`00Oomoo`0BOol00`00Ool<H`0>36<POol:000<
Ool001Moo`03001oogoo00Eoo`h000L@Q0LYBPPicPM6<@M>L`MF]@MJePQNm`iS61eW>AeS61ENm`mJ
eQEF]@mBU0i>LaI:DPi6<AI240hmkaHicPhe[AHaS0Ioo`03001oogoo019oo`03001oo`aS00h<Hb1o
o`X000aoo`005goo00<007ooOol01Goo3P001`aS1bDY23W>1dHa1dic1eJe1e[F25kg3V<H96Li7F<H
5Ukg3U[F5UJe3U:D5Tic3TYB3dHa5D8@5Sg_3SW>5SF]1c6<1Woo00<007ooOol04Woo00<007oo36<0
3PaS87oo2P0037oo000GOol00`00Oomoo`05Ool>000736<79BT8>Lh7AS47CW<7E[D7F]H8G_L>HaPT
IcTMHaPFG_L>F]HFE[D>DY@FCW<>BU8?AS4E@Q0F?Nl>>LhF=Jd7<H`6Ool00`00Oomoo`0BOol00`00
Ool<H`0>36<POol:000<Ool001Moo`03001oogoo00Eoo`h000L<H`LU:@PicPM6<@M>L`MF]@MJePQN
m`iS62AW>AeS61INm`iJeQIF]@iBU1I>L`i:DPm6<AE241Hmk`hicQHe[@LaS0Ioo`03001oogoo019o
o`03001oo`aS00h<Hb1oo`X000aoo`005goo00<007ooOol01Goo3P001`aS1bDY23W>1dHa1dic1eJe
1e[F25kg3V<H96Li7F<H5Ukg3U[F5UJe3U:D5Tic3TYB3dHa5D8@5Sg_3SW>5SF]1c6<1Woo00<007oo
Ool04Woo00<007oo36<03PaS87oo2P0037oo000GOol00`00Oomoo`05Ool>000736<79BT8>Lh7AS47
CW<7E[D7F]H8G_L>HaPTIcTMHaPFG_L>F]HFE[D>DY@FCW<>BU8?AS4E@Q0F?Nl>>LhF=Jd7<H`6Ool0
0`00Oomoo`0BOol00`00Ool<H`0>36<POol:000<Ool001Moo`03001oogoo00Eoo`h000L<H`LU:@Pi
cPM6<@M>L`MF]@MJePQNm`iS62AW>AeS61INm`iJeQIF]@iBU1I>L`i:DPm6<AE241Hmk`hicQHe[@La
S0Ioo`03001oogoo019oo`03001ooacW00hLib1oo`X000aoo`005goo00<007ooOol01Goo3P001`aS
1bDY23W>1dHa1dic1eJe1e[F25kg3V<H96Li7F<H5Ukg3U[F5UJe3U:D5Tic3TYB3dHa5D8@5Sg_3SW>
5SF]1c6<1Woo00<007ooOol04Woo00<007oo7>L03QcW87oo2P0037oo000GOol30005Ool>000736<7
9BT8=Jd7@Q07CW<7E[D7F]H8G_L>HaP[IcTMHaPFG_L>F]HFE[D>DY@FCW<>BU8FAS4>@Q0F?NlF>Lh>
=Jd5Ool2000DOol00`00OolLi`0>7>LPOol:000<Ool001Moo`03001oogoo00Eoo`h000L<H`LU:@Pe
[@M240M>L`MF]@MJePQNm`iS62]W>AeS61INm`iJeQIF]@iBU1I>L`i:DQI6<@i241HmkaHicPhe[@Io
o`03001oogoo019oo`03001ooacW00hLib1oo`X000aoo`005goo00<007ooOol01Goo3P001`aS1bDY
23F]1d8@1dic1eJe1e[F25kg3V<H:fLi7F<H5Ukg3U[F5UJe3U:D5Tic3TYB5THa3T8@5Sg_5SW>3SF]
1Woo00<007ooOol04Woo00<007oo7>L03QcW87oo2P0037oo000GOol00`00Oomoo`05Ool>000736<7
9BT8=Jd7@Q07CW<7E[D7F]H8G_L>HaP[IcTMHaPFG_L>F]HFE[D>DY@FCW<>BU8FAS4>@Q0F?NlF>Lh>
=Jd6Ool00`00Oomoo`0BOol00`00OolLi`0>7>LPOol:000<Ool001Moo`03001oogoo00Eoo`h000L<
H`LU:@Pe[@M240M>L`MF]@MJePQNm`iS62]W>AeS61INm`iJeQIF]@iBU1I>L`i:DQI6<@i241HmkaHi
cPhe[@Ioo`03001oogoo019oo`03001ooacW00hLib1oo`X000aoo`005goo00<007ooOol01Goo3P00
1`aS1bDY23F]1d8@1dic1eJe1e[F25kg3V<H:fLi7F<H5Ukg3U[F5UJe3U:D5Tic3TYB5THa3T8@5Sg_
5SW>3SF]1Woo00<007ooOol04Woo00<007oo7>L03QcW87oo2P0037oo000GOol00`00Oomoo`05Ool>
000736<79BT8=Jd7@Q07CW<7E[D7F]H8G_L>HaP[IcTMHaPFG_L>F]HFE[D>DY@FCW<>BU8FAS4>@Q0F
?NlF>Lh>=Jd6Ool00`00Oomoo`0BOol00`00OolLi`0>7>LPOol:000<Ool001Moo`03001oogoo00Eo
o`h000L<H`LU:@Pe[@M240M:DPMBU0MJePmNm`iS62aW>AaS60mNmaEJeQIF]@iBU1I>L`m:DQE6<AI2
40hmkaHicPLe[@Ioo`03001oogoo019oo`03001ooacW00hLib1oo`X000aoo`005goo00<007ooOol0
1Goo3P001`aS1bDY23F]1d8@1dYB1e:D1e[F3ekg3V<H;6Li76<H3ekg5E[F5UJe3U:D5Tic3dYB5DHa
5T8@3Sg_5SW>1cF]1Woo00<007ooOol04Woo00<007oo7>L03QcW87oo2P0037oo000GOol00`00Oomo
o`05Ool>000736<79BT8=Jd7@Q07BU87DY@7F]H?G_L>HaP/IcTLHaP?G_LEF]HFE[D>DY@FCW<?BU8E
AS4F@Q0>?NlF>Lh7=Jd6Ool00`00Oomoo`0BOol00`00OolLi`0>7>LPOol:000<Ool001Moo`03001o
ogoo00Eoo`h000L<H`LU:@Pe[@M240M:DPMBU0MJePmNm`iS62aW>AaS60mNmaEJeQIF]@iBU1I>L`m:
DQE6<AI240hmkaHicPLe[@Ioo`03001oogoo019oo`03001ooacW00hLib1oo`X000aoo`005goo00<0
07ooOol01Goo3P001`aS1bDY23F]1d8@1dYB1e:D1e[F3ekg3V<H;6Li76<H3ekg5E[F5UJe3U:D5Tic
3dYB5DHa5T8@3Sg_5SW>1cF]1Woo00<007ooOol04Woo00<007oo7>L03QcW87oo2P0037oo000>Ool4
0005Ool00`00Oomoo`05Ool>000736<79BT8=Jd7@Q07BU87DY@7F]H?G_L>HaP/IcTLHaP?G_LEF]HF
E[D>DY@FCW<?BU8EAS4F@Q0>?NlF>Lh7=Jd6Ool00`00Oomoo`0BOol00`00OolLi`0>7>LPOol:000<
Ool000ioo`03001oogoo00Ioo`03001oogoo00Eoo`h000L<H`LU:@Pe[@M240M:DPMBU0MJePmNm`iS
62aW>AaS60mNmaEJeQIF]@iBU1I>L`m:DQE6<AI240hmkaHicPLe[@Ioo`03001oogoo019oo`03001o
oacW00hLib1oo`X000aoo`003goo00<007ooOol01Goo100017oo3P001`aS1bDY23F]1d8@1dYB1e:D
1e[F3ekg3V<H;6Li76<H3ekg5E[F5UJe3U:D5Tic3dYB5DHa5T8@3Sg_5SW>1cF]17oo0`0057oo00<0
07oo:DX03RU:87oo2P0037oo000@Ool00`00Oomoo`04Ool00`00Oomoo`05Ool>000724878@P8<H`7
?Nl7BU87DY@7E[D8F]H7G_L>HaP/IcTLHaPFG_LFF]H>E[DFDY@ECW<?BU8EAS4F@Q0>?NlF>Lh6Ool0
0`00Oomoo`0BOol00`00OolYBP0>:DXPOol:000<Ool000ioo`04001oogoo0005Ool00`00Oomoo`05
Ool>000724878@P8<H`7?Nl7BU87DY@7E[D8F]H7G_L>HaP/IcTLHaPFG_LFF]H>E[DFDY@ECW<?BU8E
AS4F@Q0>?NlF>Lh6Ool00`00Oomoo`0BOol00`00OolYBP0>:DXPOol:000<Ool000moo`8000Ioo`03
001oogoo00Eoo`h000L8@PLQ20PaS0Lmk`M:DPMBU0MF]@QJePMNm`iS62aW>AaS61INmaIJePiF]AIB
U1E>L`m:DQE6<AI240hmkaHicPIoo`03001oogoo019oo`03001oobU:00hYBR1oo`X000aoo`005goo
00<007ooOol01Goo3P001`Q21b48236<1cg_1dYB1e:D1eJe25[F1ekg3V<H;6Li76<H5Ukg5U[F3UJe
5U:D5Dic3dYB5DHa5T8@3Sg_5SW>1Woo00<007ooOol04Woo00<007oo:DX03RU:87oo2P0037oo000G
Ool00`00Oomoo`05Ool>000724878@P8<H`7?Nl7BU87DY@7E[D8F]H7G_L>HaP/IcTLHaPFG_LFF]H>
E[DFDY@ECW<?BU8EAS4F@Q0>?NlF>Lh6Ool00`00Oomoo`0BOol00`00OolYBP0>:DXPOol:000<Ool0
01Moo`03001oogoo00Eoo`h000L8@PLQ20PaS0Lmk`M:DPMBU0MF]@QJePMNm`iS62aW>AaS61INmaIJ
ePiF]AIBU1E>L`m:DQE6<AI240hmkaHicPIoo`03001oogoo019oo`03001oobU:00hYBR1oo`X000ao
o`005goo00<007ooOol01Goo3P001`Q21b48236<1cg_1dYB1e:D1eJe25[F1ekg3V<H;6Li76<H5Ukg
5U[F3UJe5U:D5Dic3dYB5DHa5T8@3Sg_5SW>1Woo00<007ooOol04Woo00<007oo:DX03RU:87oo2P00
37oo000GOol00`00Oomoo`05Ool>000724878@P8<H`7?Nl7AS47CW<7E[D8F]H>G_L?HaPTIcTLHaPF
G_LFF]HEE[DFDY@>CW<FBU8FAS4E@Q0??Nl>>Lh6Ool00`00Oomoo`0BOol00`00OolYBP0>:DXPOol:
000<Ool001Moo`03001oogoo00Eoo`h000L8@PLQ20PaS0Lmk`M6<@M>L`MF]@QJePiNm`mS62AW>AaS
61INmaIJeQEF]AIBU0i>LaI:DQI6<AE240lmk`hicPIoo`03001oogoo019oo`03001oobU:00hYBR1o
o`X000aoo`005goo00<007ooOol01Goo3P001`Q21b48236<1cg_1dHa1dic1eJe25[F3Ukg3f<H96Li
76<H5Ukg5U[F5EJe5U:D3Tic5TYB5THa5D8@3cg_3SW>1Woo00<007ooOol04Woo00<007oo:DX03RU:
87oo2P0037oo000GOol00`00Oomoo`05Ool>000724878@P8<H`7?Nl7AS47CW<7E[D8F]H>G_L?HaPT
IcTLHaPFG_LFF]HEE[DFDY@>CW<FBU8FAS4E@Q0??Nl>>Lh6Ool00`00Oomoo`0BOol00`00OolYBP0>
:DXPOol:000<Ool001Moo`03001oogoo00Eoo`h000L8@PLQ20PaS0Lmk`M6<@M>L`MF]@QJePiNm`mS
62AW>AaS61INmaIJeQEF]AIBU0i>LaI:DQI6<AE240lmk`hicPIoo`03001oogoo019oo`03001oobU:
00hYBR1oo`X000aoo`005goo00<007ooOol01Goo3P001`Q21b48236<1cg_1dHa1dic1eJe25[F3Ukg
3f<H96Li76<H5Ukg5U[F5EJe5U:D3Tic5TYB5THa5D8@3cg_3SW>1Woo00<007ooOol04Woo00<007oo
:DX03RU:87oo2P0037oo000GOol30005Ool>000724878@P8<H`7?Nl7AS47CW<7E[D8F]H>G_L?HaPT
IcTLHaPFG_LFF]HEE[DFDY@>CW<FBU8FAS4E@Q0??Nl>>Lh5Ool2000DOol00`00OolYBP0>:DXPOol:
000<Ool001Moo`03001oogoo00Eoo`h000L48@LLi`P]J`LicPM6<@M>L`MBU0mJePMNmaeS60iW>BAS
61eNmaIJeQEF]@mBU1I>LaE:DQI6<@i241Hmk`LicPIoo`03001oogoo019oo`03001oocW>00hicR1o
o`X000aoo`005goo00<007ooOol01Goo3P001`@Q1acW22e[1cW>1dHa1dic1e:D3e[F1ekg7F<H3VLi
96<H7Ekg5U[F5EJe3e:D5Tic5DYB5THa3T8@5Sg_1cW>1Woo00<007ooOol04Woo00<007oo>Lh03SW>
87oo2P0037oo000GOol00`00Oomoo`05Ool>000712477>L8;F/7>Lh7AS47CW<7DY@?F]H7G_LMHaP>
IcTTHaPMG_LFF]HEE[D?DY@FCW<EBU8FAS4>@Q0F?Nl7>Lh6Ool00`00Oomoo`0BOol00`00OolicP0>
>LhPOol:000<Ool001Moo`03001oogoo00Eoo`h000L48@LLi`P]J`LicPM6<@M>L`MBU0mJePMNmaeS
60iW>BAS61eNmaIJeQEF]@mBU1I>LaE:DQI6<@i241Hmk`LicPIoo`03001oogoo019oo`03001oocW>
00hicR1oo`X000aoo`005goo00<007ooOol01Goo3P001`@Q1acW22e[1cW>1dHa1dic1e:D3e[F1ekg
7F<H3VLi96<H7Ekg5U[F5EJe3e:D5Tic5DYB5THa3T8@5Sg_1cW>1Woo00<007ooOol04Woo00<007oo
>Lh03SW>87oo2P0037oo000GOol00`00Oomoo`05Ool>000712477>L8;F/7>Lh7AS47CW<7DY@?F]H7
G_LMHaP>IcTTHaPMG_LFF]HEE[D?DY@FCW<EBU8FAS4>@Q0F?Nl7>Lh6Ool00`00Oomoo`0BOol00`00
OolicP0>>LhPOol:000<Ool001Moo`03001oogoo00Eoo`h000L48@LLi`P]J`LicPM6<@M>L`MBU0mJ
ePMNmaeS60iW>BAS61eNmaIJeQEF]@mBU1I>LaE:DQI6<@i241Hmk`LicPIoo`03001oogoo019oo`03
001oocW>00hicR1oo`X000aoo`005goo00<007ooOol01Goo3P001`@Q1acW22e[1cW>1d8@1dYB1e:D
25Je1e[F3UkgB6<H7Ekg5U[F5EJe5U:D5Tic3TYB5THa5D8@5Sg_1Woo00<007ooOol04Woo00<007oo
>Lh03SW>87oo2P0037oo000GOol00`00Oomoo`05Ool>000712477>L8;F/7>Lh7@Q07BU87DY@8E[D7
F]H>G_M8HaPMG_LFF]HEE[DFDY@FCW<>BU8FAS4E@Q0F?Nl6Ool00`00Oomoo`0BOol00`00OolicP0>
>LhPOol:000<Ool001Moo`03001oogoo00Eoo`h000L48@LLi`P]J`LicPM240M:DPMBU0QF]@MJePiN
mdQS61eNmaIJeQEF]AIBU1I>L`i:DQI6<AE241Hmk`Ioo`03001oogoo019oo`03001oocW>00hicR1o
o`X000aoo`005goo00<007ooOol01Goo3P001`@Q1acW22e[1cW>1d8@1dYB1e:D25Je1e[F3UkgB6<H
7Ekg5U[F5EJe5U:D5Tic3TYB5THa5D8@5Sg_1Woo00<007ooOol04Woo00<007oo>Lh03SW>87oo2P00
37oo000GOol00`00Oomoo`05Ool>000712477>L8;F/7>Lh7@Q07BU87DY@8E[D7F]H>G_M8HaPMG_LF
F]HEE[DFDY@FCW<>BU8FAS4E@Q0F?Nl6Ool00`00Oomoo`0BOol00`00OolicP0>>LhPOol:000<Ool0
01Moo`03001oogoo00Eoo`h000L48@LLi`P]J`LicPM240M:DPMBU0QF]@MJePiNmdQS61eNmaIJeQEF
]AIBU1I>L`i:DQI6<AE241Hmk`Ioo`03001oogoo019oo`03001oocW>00hicR1oo`X000aoo`005goo
00<007ooOol01Goo3P001`@Q1acW22e[1cW>1d8@1dYB1e:D25Je1e[F3UkgB6<H7Ekg5U[F5EJe5U:D
5Tic3TYB5THa5D8@5Sg_1Woo00<007ooOol04Woo00<007oo>Lh03SW>87oo2P0037oo000GOol30005
OolE00076<H8:DX7=Jd7@Q07BU87CW<8E[D>F]H?G_M0HaPMG_LFF]HEE[DFDY@FCW<EBU8FAS4F@Q0>
?Nl5Ool2000DOol00`00OolicP0>>LhPOol:000<Ool001Moo`03001oogoo00EooaD000LHaPPYBPLe
[@M240M:DPM>L`QF]@iJePmNmd1S61eNmaIJeQEF]AIBU1I>LaE:DQI6<AI240hmk`Ioo`03001oogoo
019oo`03001oodHa00i6<B1oo`X000aoo`005goo00<007ooOol01Goo5@001aS622U:1cF]1d8@1dYB
1dic25Je3U[F3ekg@6<H7Ekg5U[F5EJe5U:D5Tic5DYB5THa5T8@3Sg_1Woo00<007ooOol04Woo00<0
07ooAS403THa87oo2P0037oo000GOol00`00Oomoo`05OolE00076<H8:DX7=Jd7@Q07BU87CW<8E[D>
F]H?G_M0HaPMG_LFF]HEE[DFDY@FCW<EBU8FAS4F@Q0>?Nl6Ool00`00Oomoo`0BOol00`00Oom6<@0>
AS4POol:000<Ool001Moo`03001oogoo00EooaD000LHaPPYBPLe[@M240M:DPM>L`QF]@iJePmNmd1S
61eNmaIJeQEF]AIBU1I>LaE:DQI6<AI240hmk`Ioo`03001oogoo019oo`03001oodHa00i6<B1oo`X0
00aoo`005goo00<007ooOol01Goo5@001aS622U:1cF]1d8@1dYB1dic25Je3U[F3ekg@6<H7Ekg5U[F
5EJe5U:D5Tic5DYB5THa5T8@3Sg_1Woo00<007ooOol04Woo00<007ooAS403THa87oo2P0037oo000G
Ool00`00Oomoo`05OolE00076<H8:DX7=Jd7@Q07BU87CW<8E[D>F]H?G_M0HaPMG_LFF]HEE[DFDY@F
CW<EBU8FAS4F@Q0>?Nl6Ool00`00Oomoo`0BOol00`00Oom6<@0>AS4POol:000<Ool001Moo`03001o
ogoo00EooaD000LHaPPYBPLe[@Lmk`M6<@M>L`QBU0MF]@MJeQINmcUS61eNmaIJeQEF]AIBU1I>LaE:
DQI6<Ae240Lmk`Ioo`03001oogoo019oo`03001oodHa00i6<B1oo`X000aoo`005goo00<007ooOol0
1Goo5@001aS622U:1cF]1cg_1dHa1dic25:D1eJe1e[F5Ukg>F<H7Ekg5U[F5EJe5U:D5Tic5DYB5THa
7D8@1cg_1Woo00<007ooOol04Woo00<007ooAS403THa87oo2P0037oo000GOol00`00Oomoo`05OolE
00076<H8:DX7=Jd7?Nl7AS47CW<8DY@7E[D7F]HFG_LiHaPMG_LFF]HEE[DFDY@FCW<EBU8FAS4M@Q07
?Nl6Ool00`00Oomoo`0BOol00`00Oom6<@0>AS4POol:000<Ool001Moo`03001oogoo00EooaD000LH
aPPYBPLe[@Lmk`M6<@M>L`QBU0MF]@MJeQINmcUS61eNmaIJeQEF]AIBU1I>LaE:DQI6<Ae240Lmk`Io
o`03001oogoo019oo`03001oodHa00i6<B1oo`X000aoo`005goo00<007ooOol01Goo5@001aS622U:
1cF]1cg_1dHa1dic25:D1eJe1e[F5Ukg>F<H7Ekg5U[F5EJe5U:D5Tic5DYB5THa7D8@1cg_1Woo00<0
07ooOol04Woo00<007ooAS403THa87oo2P0037oo000GOol00`00Oomoo`05OolE00076<H8:DX7=Jd7
?Nl7AS47CW<8DY@7E[D7F]HFG_LiHaPMG_LFF]HEE[DFDY@FCW<EBU8FAS4M@Q07?Nl6Ool00`00Oomo
o`0BOol00`00Oom6<@0>AS4POol:000<Ool001Moo`03001oogoo00EooaD000LHaPPYBPLe[@Lmk`M6
<@M>L`QBU0MF]@MJeQINmcUS61eNmaIJeQEF]AIBU1I>LaE:DQI6<Ae240Lmk`Ioo`03001oogoo019o
o`03001oodHa00i6<B1oo`X000aoo`005goo0`001Goo5@001aS622U:1cF]1cg_1dHa1dic25:D1eJe
1e[F5Ukg>F<H7Ekg5U[F5EJe5U:D5Tic5DYB5THa7D8@1cg_1Goo0P0057oo00<007ooAS403THa87oo
2P0037oo000GOol00`00Oomoo`05OolE00075:D89BT7<H`7?Nl7AS47CW<8DY@7E[D>F]HFG_L[HaPT
G_LFF]HME[DEDY@FCW<FBU8EAS4F@Q07?Nl6Ool00`00Oomoo`0BOol00`00Oom6<@0>AS4POol:000<
Ool001Moo`03001oogoo00EooaD000LDY@PU:@LaS0Lmk`M6<@M>L`QBU0MF]@iJeQINmb]S62ANmaIJ
eQeF]AEBU1I>LaI:DQE6<AI240Lmk`Ioo`03001oogoo019oo`03001ooeJe00iF]B1oo`X000aoo`00
5goo00<007ooOol01Goo5@001aBU22DY1c6<1cg_1dHa1dic25:D1eJe3U[F5Ukg:f<H95kg5U[F7EJe
5E:D5Tic5TYB5DHa5T8@1cg_1Woo00<007ooOol04Woo00<007ooE[D03UJe87oo2P0037oo000GOol0
0`00Oomoo`05OolE00075:D89BT7<H`7?Nl7AS47CW<8DY@7E[D>F]HFG_L[HaPTG_LFF]HME[DEDY@F
CW<FBU8EAS4F@Q07?Nl6Ool00`00Oomoo`0BOol00`00OomF]@0>E[DPOol:000<Ool001Moo`03001o
ogoo00EooaD000LDY@PU:@LaS0Lmk`M6<@M>L`QBU0MF]@iJeQINmb]S62ANmaIJeQeF]AEBU1I>LaI:
DQE6<AI240Lmk`Ioo`03001oogoo019oo`03001ooeJe00iF]B1oo`X000aoo`005goo00<007ooOol0
1Goo5@001aBU22DY1c6<1cg_1dHa1dic25:D1eJe3U[F5Ukg:f<H95kg5U[F7EJe5E:D5Tic5TYB5DHa
5T8@1cg_1Woo00<007ooOol04Woo00<007ooE[D03UJe87oo2P0037oo000GOol00`00Oomoo`05OolE
00075:D89BT7<H`7?Nl7AS47CW<8DY@7E[D>F]HFG_L[HaPTG_LFF]HME[DEDY@FCW<FBU8EAS4F@Q07
?Nl6Ool00`00Oomoo`0BOol00`00OomF]@0>E[DPOol:000<Ool001Moo`03001oogoo00EooaD000LD
Y@PU:@LaS0LicPM240M:DPQ>L`MBU0MF]@mJeUINmaeJeQeF]AEBU1I>LaI:DQE6<Ae240Ioo`03001o
ogoo019oo`03001ooeJe00iF]B1oo`X000aoo`005goo00<007ooOol01Goo5@001aBU22DY1c6<1cW>
1d8@1dYB24ic1e:D1eJe3e[FEUkg7E[F7EJe5E:D5Tic5TYB5DHa7D8@1Woo00<007ooOol04Woo00<0
07ooE[D03UJe87oo2P0037oo000GOol00`00Oomoo`05OolE00075:D89BT7<H`7>Lh7@Q07BU88CW<7
DY@7E[D?F]IFG_LMF]HME[DEDY@FCW<FBU8EAS4M@Q06Ool00`00Oomoo`0BOol00`00OomF]@0>E[DP
Ool:000<Ool001Moo`03001oogoo00EooaD000LDY@PU:@LaS0LicPM240M:DPQ>L`MBU0MF]@mJeUIN
maeJeQeF]AEBU1I>LaI:DQE6<Ae240Ioo`03001oogoo019oo`03001ooeJe00iF]B1oo`X000aoo`00
5goo00<007ooOol01Goo5@001aBU22DY1c6<1cW>1d8@1dYB24ic1e:D1eJe3e[FEUkg7E[F7EJe5E:D
5Tic5TYB5DHa7D8@1Woo00<007ooOol04Woo00<007ooE[D03UJe87oo2P0037oo000GOol00`00Oomo
o`05OolE00075:D89BT7<H`7>Lh7@Q07BU88CW<7DY@7E[D?F]IFG_LMF]HME[DEDY@FCW<FBU8EAS4M
@Q06Ool00`00Oomoo`0BOol00`00OomF]@0>E[DPOol:000<Ool001Moo`<000EooaD000LDY@PU:@La
S0LicPM240M:DPQ>L`MBU0MF]@mJeUINmaeJeQeF]AEBU1I>LaI:DQE6<Ae240Eoo`8001Aoo`03001o
oeJe00iF]B1oo`X000aoo`005goo00<007ooOol01Goo5@001a2422481be[1cW>1d8@1dYB24ic1e:D
3UJe3e[FCekg7E[F7EJe5E:D5Tic5TYB74Ha5T8@1Woo00<007ooOol04Woo00<007ooE[D03UJe87oo
2P0037oo000GOol00`00Oomoo`05OolE000748@88@P7;F/7>Lh7@Q07BU88CW<7DY@>E[D?F]I?G_LM
F]HME[DEDY@FCW<FBU8LAS4F@Q06Ool00`00Oomoo`0BOol00`00OomF]@0>E[DPOol:000<Ool001Mo
o`03001oogoo00EooaD000L@Q0PQ20L]J`LicPM240M:DPQ>L`MBU0iF]@mJeTmNmaeJeQeF]AEBU1I>
LaI:DQa6<AI240Ioo`03001oogoo019oo`03001oof<H00iS621oo`X000aoo`005goo00<007ooOol0
1Goo5@001a2422481be[1cW>1d8@1dYB24ic1e:D3UJe3e[FCekg7E[F7EJe5E:D5Tic5TYB74Ha5T8@
1Woo00<007ooOol04Woo00<007ooHaP03V<H87oo2P0037oo000GOol00`00Oomoo`05OolE000748@8
8@P7;F/7>Lh7@Q07BU88CW<7DY@>E[D?F]I?G_LMF]HME[DEDY@FCW<FBU8LAS4F@Q06Ool00`00Oomo
o`0BOol00`00OomS600>HaPPOol:000<Ool001Moo`03001oogoo00EooaD000L@Q0PQ20L]J`LicPM2
40M:DPQ>L`MBU0iF]@mJeTmNmaeJeQeF]AEBU1I>LaI:DQa6<AI240Ioo`03001oogoo019oo`03001o
of<H00iS621oo`X000aoo`005goo00<007ooOol01Goo5@001a2422481be[1cW>1d8@1dYB24ic1e:D
3UJe3e[FCekg7E[F7EJe5E:D5Tic5TYB74Ha5T8@1Woo00<007ooOol04Woo00<007ooHaP03V<H87oo
2P0037oo000GOol00`00Oomoo`05OolE000748@88@P7;F/7=Jd7?Nl7AS48BU87CW<7DY@7E[DFF]I1
G_LTF]HME[DEDY@FCW<MBU8EAS4F@Q06Ool00`00Oomoo`0BOol00`00OomS600>HaPPOol:000<Ool0
01Moo`03001oogoo00EooaD000L@Q0PQ20L]J`Le[@Lmk`M6<@Q:DPM>L`MBU0MF]AIJeT5NmbAJeQeF
]AEBU1I>Lae:DQE6<AI240Ioo`03001oogoo019oo`03001oof<H00iS621oo`X000aoo`005goo00<0
07ooOol01Goo5@001a2422481be[1cF]1cg_1dHa24YB1dic1e:D1eJe5U[F@Ekg95[F7EJe5E:D5Tic
7DYB5DHa5T8@1Woo00<007ooOol04Woo00<007ooHaP03V<H87oo2P0037oo000GOol00`00Oomoo`05
OolE000748@88@P7;F/7=Jd7?Nl7AS48BU87CW<7DY@7E[DFF]I1G_LTF]HME[DEDY@FCW<MBU8EAS4F
@Q06Ool00`00Oomoo`0BOol00`00OomS600>HaPPOol:000<Ool001Moo`03001oogoo00EooaD000L@
Q0PQ20L]J`Le[@Lmk`M6<@Q:DPM>L`MBU0MF]AIJeT5NmbAJeQeF]AEBU1I>Lae:DQE6<AI240Ioo`03
001oogoo019oo`03001oof<H00iS621oo`X000aoo`003goo0P001Woo00<007ooOol01Goo5@001a24
22481be[1cF]1cg_1dHa24YB1dic1e:D1eJe5U[F@Ekg95[F7EJe5E:D5Tic7DYB5DHa5T8@1Woo00<0
07ooOol04Woo00<007ooHaP03V<H87oo2P0037oo000>Ool01000Oomoo`001Goo00<007ooOol01Goo
5@001a2422481be[1cF]1cg_1dHa24YB1dic1e:D1eJe5U[F@Ekg95[F7EJe5E:D5Tic7DYB5DHa5T8@
1Woo00<007ooOol04Woo00<007ooHaP03V<H87oo2P0037oo000@Ool00`00Oomoo`04Ool40004OolE
000736<87>L7:DX7=Jd7?Nl7AS48BU87CW<7DY@?E[DLF]H/G_LTF]HLE[DMDY@FCW<MBU8EAS4F@Q04
Ool3000DOol00`00OomS600>HaPPOol:000<Ool0015oo`03001oogoo00=oo`03001oogoo00EooaD0
00L<H`PLi`LYBPLe[@Lmk`M6<@Q:DPM>L`MBU0mF]AaJeRaNmbAJeQaF]AeBU1I>Lae:DQE6<AI240Io
o`03001oogoo019oo`03001oof<H00iS621oo`X000aoo`003Woo00@007ooOol000Eoo`03001oogoo
00EooaD000L<H`PLi`LYBPLe[@Lmk`M6<@Q:DPM>L`MBU0mF]AaJeRaNmbAJeQaF]AeBU1I>Lae:DQE6
<AI240Ioo`03001oogoo019oo`03001oof<H00iS621oo`X000aoo`003goo0P001Woo00<007ooOol0
1Goo5@001`aS21cW1bU:1cF]1cg_1dHa24YB1dic1e:D3eJe75[F;5kg95[F75Je7E:D5Tic7DYB5DHa
5T8@1Woo00<007ooOol04Woo00<007ooHaP03V<H87oo2P0037oo000GOol00`00Oomoo`05OolE0007
36<87>L7:DX7=Jd7?Nl7AS48BU87CW<7DY@?E[DLF]H/G_LTF]HLE[DMDY@FCW<MBU8EAS4F@Q06Ool0
0`00Oomoo`0BOol00`00OomcW00>Li`POol:000<Ool001Moo`03001oogoo00EooaD000L<H`PLi`LY
BPLe[@Lmk`M6<@Q:DPM>L`MBU0mF]AaJeRaNmbAJeQaF]AeBU1I>Lae:DQE6<AI240Ioo`03001oogoo
019oo`03001oog>L00icW21oo`X000aoo`005goo00<007ooOol01Goo5@001`aS21cW1bU:1cF]1cg_
1dHa24YB1dic1e:D3eJe75[F;5kg95[F75Je7E:D5Tic7DYB5DHa5T8@1Woo00<007ooOol04Woo00<0
07ooLi`03W>L87oo2P0037oo000GOol00`00Oomoo`05OolE000736<87>L7:DX7<H`7>Lh7@Q08AS4>
CW<7DY@?E[EUF]HLE[DMDY@FCW<MBU8EAS4F@Q06Ool00`00Oomoo`0BOol00`00OomcW00>Li`POol:
000<Ool001Moo`03001oogoo00EooaD000L<H`PLi`LYBPLaS0LicPM240Q6<@i>L`MBU0mF]FEJeQaF
]AeBU1I>Lae:DQE6<AI240Ioo`03001oogoo019oo`03001oog>L00icW21oo`X000aoo`005goo00<0
07ooOol01Goo5@001`aS21cW1bU:1c6<1cW>1d8@24Ha3Tic1e:D3eJeIE[F75Je7E:D5Tic7DYB5DHa
5T8@1Woo00<007ooOol04Woo00<007ooLi`03W>L87oo2P0037oo000GOol00`00Oomoo`05OolE0007
36<87>L7:DX7<H`7>Lh7@Q08AS4>CW<7DY@?E[EUF]HLE[DMDY@FCW<MBU8EAS4F@Q06Ool00`00Oomo
o`0BOol00`00OomcW00>Li`POol:000<Ool001Moo`03001oogoo00EooaD000L<H`PLi`LYBPLaS0Li
cPM240Q6<@i>L`MBU0mF]FEJeQaF]AeBU1I>Lae:DQE6<AI240Ioo`03001oogoo019oo`03001oog>L
00icW21oo`X000aoo`005goo00<007ooOol01Goo5@001`aS21cW1bU:1c6<1cW>1d8@24Ha3Tic1e:D
3eJeIE[F75Je7E:D5Tic7DYB5DHa5T8@1Woo00<007ooOol04Woo00<007ooLi`03W>L87oo2P0037oo
000GOol00`00Oomoo`05OolE000736<87>L7:DX7<H`7>Lh7@Q08AS4>CW<7DY@?E[EUF]HLE[DMDY@F
CW<MBU8EAS4F@Q06Ool00`00Oomoo`0BOol00`00OomcW00>Li`POol:000<Ool001Moo`<000EooaD0
00L<H`PLi`LYBPLaS0LicPM240Q6<@i>L`MBU0mF]FEJeQaF]AeBU1I>Lae:DQE6<AI240Eoo`8001Ao
o`03001oog>L00icW21oo`X000aoo`005goo00<007ooOol01Goo5@001`Q221S61bU:1c6<1cW>1d8@
24Ha1dYB1dic3e:D3UJeEU[F95Je7E:D5Tic7DYB7DHa3T8@1Woo00<007ooOol04Woo00<007ooLi`0
3W>L87oo2P0037oo000GOol00`00Oomoo`05OolE000724886<H7:DX7<H`7>Lh7@Q08AS47BU87CW<?
DY@>E[EFF]HTE[DMDY@FCW<MBU8MAS4>@Q06Ool00`00Oomoo`0BOol00`00OomcW00>Li`POol:000<
Ool001Moo`03001oogoo00EooaD000L8@PPHaPLYBPLaS0LicPM240Q6<@M:DPM>L`mBU0iF]EIJeRAF
]AeBU1I>Lae:DQe6<@i240Ioo`03001oogoo019oo`03001oog>L00icW21oo`X000aoo`005goo00<0
07ooOol01Goo5@001`Q221S61bU:1c6<1cW>1d8@24Ha1dYB1dic3e:D3UJeEU[F95Je7E:D5Tic7DYB
7DHa3T8@1Woo00<007ooOol04Woo00<007ooLi`03W>L87oo2P0037oo000GOol00`00Oomoo`05OolE
000724886<H7:DX7<H`7>Lh7@Q08AS47BU87CW<?DY@>E[EFF]HTE[DMDY@FCW<MBU8MAS4>@Q06Ool0
0`00Oomoo`0BOol00`00Oomoo`0^Ool:000<Ool001Moo`03001oogoo00EooaD000L8@PPHaPLYBPLa
S0LicPM240Q6<@M:DPM>L`mBU0iF]EIJeRAF]AeBU1I>Lae:DQe6<@i240Ioo`03001oogoo019oo`03
001oogoo02ioo`X000aoo`005goo00<007ooOol01Goo5@001`Q221S61bU:1c6<1cW>1d8@24Ha1dYB
1dic3e:D3UJeEU[F95Je7E:D5Tic7DYB7DHa3T8@1Woo00<007ooOol04Woo00<007ooOol0;Woo2P00
37oo000GOol00`00Oomoo`05OolE000724886<H79BT7<H`7>Lh7?Nl8AS47BU8>CW<8DY@LE[E1F]HT
E[DMDY@MCW<MBU8MAS4>@Q06Ool00`00Oomoo`0BOol00`00Oomoo`0^Ool:000<Ool001Moo`03001o
ogoo00EooaD000L8@PPHaPLU:@LaS0LicPLmk`Q6<@M:DPi>L`QBU1aF]D5JeRAF]AeBU1e>Lae:DQe6
<@i240Ioo`03001oogoo019oo`03001oogoo02ioo`X000aoo`005goo00<007ooOol01Goo5@001`Q2
21S61bDY1c6<1cW>1cg_24Ha1dYB3Tic25:D75Je@E[F95Je7E:D7Dic7DYB7DHa3T8@1Woo00<007oo
Ool04Woo00<007ooOol04goo0P0017oo0P000goo100037oo2P0037oo000GOol00`00Oomoo`05OolE
000724886<H79BT7<H`7>Lh7?Nl8AS47BU8>CW<8DY@LE[E1F]HTE[DMDY@MCW<MBU8MAS4>@Q06Ool0
0`00Oomoo`0BOol00`00Oomoo`0BOol01000Oomoo`0027oo00<007ooOol03Goo2P0037oo000GOol0
0`00Oomoo`05OolE000724886<H79BT7<H`7>Lh7?Nl8AS47BU8>CW<8DY@LE[E1F]HTE[DMDY@MCW<M
BU8MAS4>@Q06Ool00`00Oomoo`0BOol00`00Oomoo`0BOol01000Oomoo`002Goo00<007ooOol037oo
00<007ooOol04goo000GOol00`00Oomoo`05OolE000724886<H79BT7<H`7>Lh7?Nl8AS47BU8>CW<8
DY@LE[E1F]HTE[DMDY@MCW<MBU8MAS4>@Q06Ool00`00Oomoo`0BOol00`00Oomoo`0BOol01000Oomo
o`002Woo00<007ooOol02goo00<007ooOol04goo000GOol00`00Oomoo`05OolE000724886<H79BT7
<H`7>Lh7?Nl8AS47BU8>CW<8DY@LE[E1F]HTE[DMDY@MCW<MBU8MAS4>@Q06Ool00`00Oomoo`0BOol0
0`00Oomoo`0BOol01000Oomoo`0027oo00@007ooOol000aoo`03001oogoo01=oo`005goo0`001Goo
5@001`Q221S61bDY1be[1cF]1cg_248@1dHa1dYB1dic3e:D95Je7E[F<UJe95:D7Dic7DYB7DHa3T8@
1Goo0P0057oo00<007ooOol04goo0P002Woo0P003Goo00<007ooOol04goo000GOol00`00Oomoo`05
OolE000724886<H79BT7;F/7=Jd7?Nl8@Q07AS47BU87CW<?DY@TE[DMF]HbE[DTDY@MCW<MBU8MAS4>
@Q06Ool00`00Oomoo`0BOol00`00Oomoo`0^Ool00`00Oomoo`0COol001Moo`03001oogoo00EooaD0
00L8@PPHaPLU:@L]J`Le[@Lmk`Q240M6<@M:DPM>L`mBU2AF]AeJeS9F]BABU1e>Lae:DQe6<@i240Io
o`03001oogoo019oo`03001oogoo02ioo`03001oogoo01=oo`005goo00<007ooOol01Goo5@001`Q2
21S61bDY1be[1cF]1cg_248@1dHa1dYB1dic3e:D95Je7E[F<UJe95:D7Dic7DYB7DHa3T8@1Woo00<0
07ooOol04Woo00<007ooOol0;Woo00<007ooOol04goo000GOol00`00Oomoo`05OolE000724886<H7
9BT7;F/7=Jd7?Nl8@Q07AS47BU87CW<?DY@TE[DMF]HbE[DTDY@MCW<MBU8MAS4>@Q06Ool00`00Oomo
o`0BOol00`00Oomoo`0^Ool00`00Oomoo`0COol001Moo`03001oogoo00EooaD000L8@PPHaPLU:@L]
J`Le[@Lmk`Q240M6<@M:DPM>L`mBU2AF]AeJeS9F]BABU1e>Lae:DQe6<@i240Ioo`03001oogoo019o
o`03001oogoo02ioo`03001oogoo01=oo`005goo00<007ooOol01Goo5@001`Q221S61bDY1be[1cF]
1cg_248@1dHa1dYB1dic3e:D95Je7E[F<UJe95:D7Dic7DYB7DHa3T8@1Woo00<007ooOol04Woo<P00
5Goo000GOol00`00Oomoo`05OolE000712485:D78@P7;F/7=Jd7>Lh8@Q07AS47BU8?CW<>DYAUE[DT
DY@TCW<MBU8MAS4>@Q06Ool00`00Oomoo`1IOol001Moo`03001oogoo00EooaD000L48@PDY@LQ20L]
J`Le[@LicPQ240M6<@M:DPm>L`iBU6EF]BABU2A>Lae:DQe6<@i240Ioo`03001oogoo05Uoo`005goo
00<007ooOol01Goo5@001`@Q21BU1b481be[1cF]1cW>248@1dHa1dYB3dic3U:DIEJe95:D94ic7DYB
7DHa3T8@1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolE000712485:D78@P7;F/7=Jd7>Lh8
@Q07AS47BU8?CW<>DYAUE[DTDY@TCW<MBU8MAS4>@Q06Ool00`00Oomoo`1IOol001Moo`03001oogoo
00EooaD000L48@PDY@LQ20L]J`Le[@LicPQ240M6<@M:DPm>L`iBU6EF]BABU2A>Lae:DQe6<@i240Io
o`03001oogoo05Uoo`005goo00<007ooOol01Goo5@001`@Q21BU1b481be[1cF]1cW>248@1dHa1dYB
3dic3U:DIEJe95:D94ic7DYB7DHa3T8@1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolE0007
12485:D78@P7;F/7=Jd7>Lh8@Q07AS47BU8?CW<>DYAUE[DTDY@TCW<MBU8MAS4>@Q06Ool00`00Oomo
o`1IOol001Moo`<000EooaD000L48@PDY@LQ20LYBPLaS0LicPPmk`M240M6<@M:DPm>LaEBU51F]B]B
U1e>Lae:DQa6<AI240Eoo`8005]oo`005goo00<007ooOol01Goo5@001`@Q21BU1b481bU:1c6<1cW>
23g_1d8@1dHa1dYB3dic5E:DD5Je:e:D7Dic7DYB74Ha5T8@1Woo00<007ooOol0FGoo000GOol00`00
Oomoo`05OolE000712485:D78@P7:DX7<H`7>Lh8?Nl7@Q07AS47BU8?CW<EDYA@E[D[DY@MCW<MBU8L
AS4F@Q06Ool00`00Oomoo`1IOol001Moo`03001oogoo00EooaD000L48@PDY@LQ20LYBPLaS0LicPPm
k`M240M6<@M:DPm>LaEBU51F]B]BU1e>Lae:DQa6<AI240Ioo`03001oogoo05Uoo`005goo00<007oo
Ool01Goo5@001`@Q21BU1b481bU:1c6<1cW>23g_1d8@1dHa1dYB3dic5E:DD5Je:e:D7Dic7DYB74Ha
5T8@1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolE000712485:D78@P7:DX7<H`7>Lh8?Nl7
@Q07AS47BU8?CW<EDYA@E[D[DY@MCW<MBU8LAS4F@Q06Ool00`00Oomoo`1IOol001Moo`03001oogoo
00EooaD000L48@PDY@LQ20LYBPLaS0LicPPmk`M240M6<@M:DPm>LaEBU51F]B]BU1e>Lae:DQa6<AI2
40Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo5@001`@Q21241acW1bU:1c6<1cF]23g_1d8@
1dHa3dYB3Tic7E:D>EJe;5:D94ic7DYB74Ha5T8@1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05
OolE0007124848@77>L7:DX7<H`7=Jd8?Nl7@Q07AS4?BU8>CW<MDY@iE[D/DY@TCW<MBU8LAS4F@Q06
Ool00`00Oomoo`1IOol001Moo`03001oogoo00EooaD000L48@P@Q0LLi`LYBPLaS0Le[@Pmk`M240M6
<@m:DPi>LaeBU3UF]BaBU2A>Lae:DQa6<AI240Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo
5@001`@Q21241acW1bU:1c6<1cF]23g_1d8@1dHa3dYB3Tic7E:D>EJe;5:D94ic7DYB74Ha5T8@1Woo
00<007ooOol0FGoo000GOol00`00Oomoo`05OolE0007124848@77>L7:DX7<H`7=Jd8?Nl7@Q07AS4?
BU8>CW<MDY@iE[D/DY@TCW<MBU8LAS4F@Q06Ool00`00Oomoo`1IOol001Moo`03001oogoo00EooaD0
00L48@P@Q0LLi`LYBPLaS0Le[@Pmk`M240M6<@m:DPi>LaeBU3UF]BaBU2A>Lae:DQa6<AI240Ioo`03
001oogoo05Uoo`005goo00<007ooOol01Goo5@001`@Q21241acW1bU:1c6<1cF]23g_1d8@1dHa3dYB
3Tic7E:D>EJe;5:D94ic7DYB74Ha5T8@1Woo00<007ooOol0FGoo000GOol30005OolE0007124848@7
7>L7:DX7<H`7=Jd8?Nl7@Q07AS4?BU8>CW<MDY@iE[D/DY@TCW<MBU8LAS4F@Q05Ool2001KOol001Mo
o`03001oogoo00Eooa`000P@Q0LLi`LU:@L]J`Le[@PicPLmk`M240M6<@Q:DQE>Lg=BU2E>LbA:DQa6
<AI240Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo700021241acW1bDY1be[1cF]23W>1cg_
1d8@1dHa24YB5DicLe:D9Dic94YB74Ha5T8@1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolL
000848@77>L79BT7;F/7=Jd8>Lh7?Nl7@Q07AS48BU8ECW=cDY@UCW<TBU8LAS4F@Q06Ool00`00Oomo
o`1IOol001Moo`03001oogoo00Eooa`000P@Q0LLi`LU:@L]J`Le[@PicPLmk`M240M6<@Q:DQE>Lg=B
U2E>LbA:DQa6<AI240Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo700021241acW1bDY1be[
1cF]23W>1cg_1d8@1dHa24YB5DicLe:D9Dic94YB74Ha5T8@1Woo00<007ooOol0FGoo000GOol00`00
Oomoo`05OolL000848@77>L79BT7;F/7=Jd8>Lh7?Nl7@Q07AS48BU8ECW=cDY@UCW<TBU8LAS4F@Q06
Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P@Q0LLi`LU:@L]J`Le[@PicPLmk`M240M6
<@Q:DQE>Lg=BU2E>LbA:DQa6<AI240Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo70002124
1acW1bDY1be[1cF]23W>1cg_1d8@1dHa3dYB5DicIE:D;4ic74YB94Ha5T8@1Woo00<007ooOol0FGoo
000GOol00`00Oomoo`05OolL000848@77>L79BT7;F/7=Jd8>Lh7?Nl7@Q07AS4?BU8ECW=UDY@/CW<L
BU8TAS4F@Q06Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P@Q0LLi`LU:@L]J`Le[@Pi
cPLmk`M240M6<@m:DQE>LfEBU2a>Laa:DRA6<AI240Ioo`03001oogoo05Uoo`005goo00<007ooOol0
1Goo700021241acW1bDY1be[1cF]23W>1cg_1d8@1dHa3dYB5DicIE:D;4ic74YB94Ha5T8@1Woo00<0
07ooOol0FGoo000GOol00`00Oomoo`05OolL000848@77>L79BT7;F/7=Jd8>Lh7?Nl7@Q07AS4?BU8E
CW=UDY@/CW<LBU8TAS4F@Q06Ool00`00Oomoo`1IOol0011oo`<000Aoo`03001oogoo00Eooa`000P@
Q0LLi`LU:@L]J`Le[@PicPLmk`M240M6<@m:DQE>LfEBU2a>Laa:DRA6<AI240Ioo`03001oogoo05Uo
o`004Goo00<007ooOol00goo00<007ooOol01Goo700021241acW1bDY1be[1cF]23W>1cg_1d8@1dHa
3dYB5DicIE:D;4ic74YB94Ha5T8@1Woo00<007ooOol0FGoo000>Ool50004Ool40004OolL000836<7
6<H79BT7:DX7<H`8=Jd7?Nl>@Q08AS4>BU8MCW=?DY@[CW<TBU8MAS4M@Q04Ool3001KOol000ioo`04
001oogoo0005Ool00`00Oomoo`05OolL000836<76<H79BT7:DX7<H`8=Jd7?Nl>@Q08AS4>BU8MCW=?
DY@[CW<TBU8MAS4M@Q06Ool00`00Oomoo`1IOol000moo`03001oo`0000Eoo`03001oogoo00Eooa`0
00P<H`LHaPLU:@LYBPLaS0Pe[@Lmk`i240Q6<@i:DQe>LdmBU2]>LbA:DQe6<Ae240Ioo`03001oogoo
05Uoo`0047oo0P001Goo00<007ooOol01Goo700020aS1aS61bDY1bU:1c6<23F]1cg_3T8@24Ha3TYB
7DicCe:D:dic94YB7DHa7D8@1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolL000836<76<H7
9BT7:DX7<H`8=Jd7?Nl>@Q08AS4>BU8MCW=?DY@[CW<TBU8MAS4M@Q06Ool00`00Oomoo`1IOol001Mo
o`03001oogoo00Eooa`000P<H`LHaPLU:@LYBPLaS0Pe[@Lmk`i240Q6<@i:DQe>LdmBU2]>LbA:DQe6
<Ae240Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo700020aS1aS61bDY1bU:1c6<23F]1cg_
3T8@24Ha3TYB7DicCe:D:dic94YB7DHa7D8@1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolL
000836<76<H78@P7:DX7<H`8=Jd7>Lh7?Nl7@Q0?AS4>BU8TCW<[DY@jCW<TBU8TAS4M@Q06Ool00`00
Oomoo`1IOol001Moo`03001oogoo00Eooa`000P<H`LHaPLQ20LYBPLaS0Pe[@LicPLmk`M240m6<@i:
DRA>Lb]BU3Y>LbA:DRA6<Ae240Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo700020aS1aS6
1b481bU:1c6<23F]1cW>1cg_1d8@3dHa3TYB94ic:e:D>Tic94YB94Ha7D8@1Woo00<007ooOol0FGoo
000GOol00`00Oomoo`05OolL000836<76<H78@P7:DX7<H`8=Jd7>Lh7?Nl7@Q0?AS4>BU8TCW<[DY@j
CW<TBU8TAS4M@Q06Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P<H`LHaPLQ20LYBPLa
S0Pe[@LicPLmk`M240m6<@i:DRA>Lb]BU3Y>LbA:DRA6<Ae240Ioo`03001oogoo05Uoo`005goo00<0
07ooOol01Goo700020aS1aS61b481bU:1c6<23F]1cW>1cg_1d8@3dHa3TYB94ic:e:D>Tic94YB94Ha
7D8@1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolL000836<76<H78@P7:DX7<H`8=Jd7>Lh7
?Nl7@Q0?AS4>BU8TCW<[DY@jCW<TBU8TAS4M@Q06Ool00`00Oomoo`1IOol001Moo`<000Eooa`000P8
@PLDY@LQ20LYBPL]J`Pe[@LicPLmk`m240i6<@i:DW]>Lb]:DRA6<Ae240Eoo`8005]oo`005goo00<0
07ooOol01Goo700020Q21aBU1b481bU:1be[23F]1cW>1cg_3d8@3THa3TYBNdic:dYB94Ha7D8@1Woo
00<007ooOol0FGoo000GOol00`00Oomoo`05OolL000824875:D78@P7:DX7;F/8=Jd7>Lh7?Nl?@Q0>
AS4>BU9kCW<[BU8TAS4M@Q06Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P8@PLDY@LQ
20LYBPL]J`Pe[@LicPLmk`m240i6<@i:DW]>Lb]:DRA6<Ae240Ioo`03001oogoo05Uoo`005goo00<0
07ooOol01Goo700020Q21aBU1b481bU:1be[23F]1cW>1cg_3d8@3THa3TYBNdic:dYB94Ha7D8@1Woo
00<007ooOol0FGoo000GOol00`00Oomoo`05OolL000824875:D78@P7:DX7;F/8=Jd7>Lh7?Nl?@Q0>
AS4>BU9kCW<[BU8TAS4M@Q06Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P8@PLDY@LQ
20LYBPL]J`Pe[@LicPLmk`m240i6<@i:DW]>Lb]:DRA6<Ae240Ioo`03001oogoo05Uoo`005goo00<0
07ooOol01Goo700020Q21aBU1acW1bDY1be[236<1cF]1cW>1cg_248@3THa7DYBIDic:dYB94Ha948@
1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolL000824875:D77>L79BT7;F/8<H`7=Jd7>Lh7
?Nl8@Q0>AS4MBU9UCW<[BU8TAS4T@Q06Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P8
@PLDY@LLi`LU:@L]J`PaS0Le[@LicPLmk`Q240i6<Ae:DVE>Lb]:DRA6<BA240Ioo`03001oogoo05Uo
o`005goo00<007ooOol01Goo700020Q21aBU1acW1bDY1be[236<1cF]1cW>1cg_248@3THa7DYBIDic
:dYB94Ha948@1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolL000824875:D77>L79BT7;F/8
<H`7=Jd7>Lh7?Nl8@Q0>AS4MBU9UCW<[BU8TAS4T@Q06Ool00`00Oomoo`1IOol001Moo`03001oogoo
00Eooa`000P8@PLDY@LLi`LU:@L]J`PaS0Le[@LicPLmk`Q240i6<Ae:DVE>Lb]:DRA6<BA240Ioo`03
001oogoo05Uoo`005goo00<007ooOol01Goo700020Q21aBU1acW1bDY1be[236<1cF]1cW>1cg_248@
3THa7DYBIDic:dYB94Ha948@1Woo00<007ooOol0FGoo000GOol30005OolL000824875:D77>L79BT7
;F/8<H`7=Jd7>Lh7?Nl8@Q0>AS4MBU9UCW<[BU8TAS4T@Q05Ool2001KOol001Moo`03001oogoo00Eo
oa`000P8@PLDY@LLi`LU:@L]J`PaS0Le[@LicPLmk`m240i6<Ae:DTm>Lc=:DRA6<BA240Lmk`Ioo`03
001oogoo05Uoo`005goo00<007ooOol01Goo700020Q21aBU1acW1bDY1be[236<1cF]1cW>1cg_3d8@
3THa7DYBCdic<dYB94Ha948@1cg_1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolL00082487
5:D77>L79BT7;F/8<H`7=Jd7>Lh7?Nl?@Q0>AS4MBU9?CW<cBU8TAS4T@Q07?Nl6Ool00`00Oomoo`1I
Ool001Moo`03001oogoo00Eooa`000P8@PLDY@LLi`LU:@L]J`PaS0Le[@LicPLmk`m240i6<Ae:DTm>
Lc=:DRA6<BA240Lmk`Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo700020Q21aBU1acW1bDY
1be[236<1cF]1cW>1cg_3d8@3THa7DYBCdic<dYB94Ha948@1cg_1Woo00<007ooOol0FGoo000GOol0
0`00Oomoo`05OolL000824875:D77>L79BT7;F/8<H`7=Jd7>Lh7?Nl?@Q0>AS4MBU9?CW<cBU8TAS4T
@Q07?Nl6Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P8@PLDY@LLi`LU:@L]J`PaS0Le
[@LicPLmk`m240i6<Ae:DTm>Lc=:DRA6<BA240Lmk`Ioo`03001oogoo05Uoo`005goo00<007ooOol0
1Goo700020@Q1a241acW1bDY1bU:236<1cF]1cW>3cg_3T8@3THa<dYB5DicBDYB:dHa948@1cg_1Woo
00<007ooOol0FGoo000GOol00`00Oomoo`05OolL0008124748@77>L79BT7:DX8<H`7=Jd7>Lh??Nl>
@Q0>AS4cBU8ECW=9BU8[AS4T@Q07?Nl6Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P4
8@L@Q0LLi`LU:@LYBPPaS0Le[@LicPlmk`i240i6<C=:DQE>LdU:DR]6<BA240Lmk`Ioo`03001oogoo
05Uoo`005goo00<007ooOol01Goo700020@Q1a241acW1bDY1bU:236<1cF]1cW>3cg_3T8@3THa<dYB
5DicBDYB:dHa948@1cg_1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolL0008124748@77>L7
9BT7:DX8<H`7=Jd7>Lh??Nl>@Q0>AS4cBU8ECW=9BU8[AS4T@Q07?Nl6Ool00`00Oomoo`1IOol001Mo
o`03001oogoo00Eooa`000P48@L@Q0LLi`LU:@LYBPPaS0Le[@LicPlmk`i240i6<C=:DQE>LdU:DR]6
<BA240Lmk`Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo700020@Q1a241acW1bDY1bU:236<
1cF]1cW>3cg_3T8@3THa<dYB5DicBDYB:dHa948@1cg_1Woo00<007ooOol0FGoo000GOol30005OolL
0008124748@76<H78@P7:DX8;F/7<H`7=Jd7>Lh8?NlE@Q0FAS5jBU8/AS4T@Q0>?Nl5Ool2001KOol0
01Moo`03001oogoo00Eooa`000P48@L@Q0LHaPLQ20LYBPP]J`LaS0Le[@LicPPmkaE241I6<GY:DRa6
<BA240hmk`Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo700020@Q1a241aS61b481bU:22e[
1c6<1cF]1cW>23g_5D8@5THaNTYB;4Ha948@3Sg_1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05
OolL0008124748@76<H78@P7:DX8;F/7<H`7=Jd7>Lh8?NlE@Q0FAS5jBU8/AS4T@Q0>?Nl6Ool00`00
Oomoo`1IOol001Moo`03001oogoo00Eooa`000P48@L@Q0LHaPLQ20LYBPP]J`LaS0Le[@LicPPmkaE2
41I6<GY:DRa6<BA240hmk`Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo700020@Q1a241aS6
1b481bU:22e[1c6<1cF]1cW>23g_5D8@5THaNTYB;4Ha948@3Sg_1Woo00<007ooOol0FGoo000GOol0
0`00Oomoo`05OolL0008124748@76<H78@P7:DX8;F/7<H`7=Jd7>Lh8?NlE@Q0FAS5jBU8/AS4T@Q0>
?Nl6Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P48@L@Q0LHaPLQ20LU:@P]J`LaS0Le
[@LicPlmk`i241e6<FE:DS96<Ba240hmk`Ioo`03001oogoo05Uoo`005goo00<007ooOol01Goo7000
20@Q1a241aS61b481bDY22e[1c6<1cF]1cW>3cg_3T8@7DHaIDYB<THa;48@3Sg_1Woo00<007ooOol0
FGoo000GOol00`00Oomoo`05OolL0008124748@76<H78@P79BT8;F/7<H`7=Jd7>Lh??Nl>@Q0MAS5U
BU8bAS4/@Q0>?Nl6Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P48@L@Q0LHaPLQ20LU
:@P]J`LaS0Le[@LicPlmk`i241e6<FE:DS96<Ba240hmk`Ioo`03001oogoo05Uoo`005goo00<007oo
Ool01Goo700020@Q1a241aS61b481bDY22e[1c6<1cF]1cW>3cg_3T8@7DHaIDYB<THa;48@3Sg_1Woo
00<007ooOol0FGoo000GOol00`00Oomoo`05OolL0008124748@76<H78@P79BT8;F/7<H`7=Jd7>Lh?
?Nl>@Q0MAS5UBU8bAS4/@Q0>?Nl6Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P48@L@
Q0LHaPLQ20LU:@P]J`LaS0Le[@LicPlmk`i241e6<FE:DS96<Ba240hmk`Ioo`03001oogoo05Uoo`00
5goo0`001Goo700020@Q1`aS1aS61acW1bDY22U:1c6<3SF]23W>3Sg_3T8@94HaB4YB>THa:d8@5Sg_
1Goo0P00Fgoo000GOol00`00Oomoo`05OolL0008124736<76<H77>L79BT8:DX7<H`>=Jd8>Lh>?Nl>
@Q0TAS58BU8jAS4[@Q0F?Nl6Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`000P48@L<H`LH
aPLLi`LU:@PYBPLaS0he[@PicPhmk`i242A6<DQ:DSY6<B]241Hmk`Ioo`03001oogoo05Uoo`005goo
00<007ooOol01Goo700020@Q1`aS1aS61acW1bDY22U:1c6<3SF]23W>3Sg_3T8@94HaB4YB>THa:d8@
5Sg_1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolL0008124736<76<H77>L79BT8:DX7<H`>
=Jd8>Lh>?Nl>@Q0TAS58BU8jAS4[@Q0F?Nl6Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eooa`0
00P48@L<H`LHaPLLi`LU:@PYBPLaS0he[@PicPhmk`i242A6<DQ:DSY6<B]241Hmk`Ioo`03001oogoo
05Uoo`005goo00<007ooOol01Goo700020@Q1`aS1aS61acW1bDY22U:1c6<3SF]23W>3Sg_3T8@94Ha
B4YB>THa:d8@5Sg_1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolT000736<75:D77>L79BT8
:DX7;F/7<H`7=Jd?>Lh>?Nl?@Q2GAS4[@Q0M?Nl6Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eo
ob@000L<H`LDY@LLi`LU:@PYBPL]J`LaS0Le[@licPhmk`m249M6<B]241dmk`Ioo`03001oogoo05Uo
o`005goo00<007ooOol01Goo90001`aS1aBU1acW1bDY22U:1be[1c6<1cF]3cW>3Sg_3d8@UdHa:d8@
7Cg_1Woo00<007ooOol0FGoo000GOol00`00Oomoo`05OolT000736<75:D77>L79BT8:DX7;F/7<H`7
=Jd?>Lh>?Nl?@Q2GAS4[@Q0M?Nl6Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eoob@000L<H`LD
Y@LLi`LU:@PYBPL]J`LaS0Le[@licPhmk`m249M6<B]241dmk`Ioo`03001oogoo05Uoo`005goo00<0
07ooOol01Goo90001`aS1aBU1acW1bDY22U:1be[1c6<1cF]3cW>3Sg_3d8@UdHa:d8@7Cg_1Woo00<0
07ooOol0FGoo000?Ool20006Ool00`00Oomoo`05OolT000736<75:D77>L79BT8:DX7;F/7<H`7=Jd?
>Lh>?Nl?@Q2GAS4[@Q0M?Nl6Ool00`00Oomoo`1IOol000ioo`04001oogoo0005Ool00`00Oomoo`05
OolT000736<75:D77>L79BT8:DX7;F/7<H`7=Jd?>Lh>?Nl?@Q2GAS4[@Q0M?Nl6Ool00`00Oomoo`1I
Ool0015oo`03001oogoo00=oo`@00?moog5oo`<005]oo`003goo0P001Woo00<007ooOol0ogooM7oo
00<007ooOol0FGoo000?Ool00`00Oomoo`05Ool00`00Oomoo`3oOomdOol00`00Oomoo`1IOol000mo
o`<000Eoo`03001oogoo0?moogAoo`03001oogoo05Uoo`005goo00<007ooOol01Goo00<007ooOol0
<7oo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol0<7oo00<007ooOol0<7oo00<007ooOol0
<Goo00<007ooOol0<7oo00<007ooOol017oo00<007ooOol0FGoo000GOol00`00Oomoo`05Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`1IOol001Moo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo05Uo
o`005gooo`00N000Fgoo003oOooZOol00?moonYoo`00ogoojWoo003oOooZOol00?moonYoo`00ogoo
jWoo003oOooZOol00?moonYoo`00ogoojWoo0000\
\>"],
  ImageRangeCache->{{{0, 488.875}, {407, 0}} -> {-1.06074, -1.05001, \
0.00515974, 0.00515974}, {{11.75, 399.375}, {397.25, 9.6875}} -> {0.394751, \
-0.425801, 0.0194712, 0.013908}, {{418.75, 467.375}, {281, 125.938}} -> \
{-27.6581, -8.39448, 0.0658104, 0.0658104}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{785, 614},
WindowMargins->{{7, Automatic}, {Automatic, 6}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 44, 0, 105, "Title"],
Cell[1786, 53, 106, 2, 53, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1917, 59, 52, 1, 42, "Input"],
Cell[1972, 62, 42, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2051, 68, 60, 1, 42, "Input"],
Cell[2114, 71, 51, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2202, 77, 52, 1, 30, "Input"],
Cell[2257, 80, 43, 1, 42, "Output"]
}, Open  ]],
Cell[2315, 84, 147, 6, 109, "Text"],
Cell[2465, 92, 69, 1, 30, "Input"],
Cell[2537, 95, 239, 4, 49, "Input"],

Cell[CellGroupData[{
Cell[2801, 103, 45, 1, 30, "Input"],
Cell[2849, 106, 54, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2940, 112, 360, 7, 70, "Input"],
Cell[3303, 121, 119, 2, 36, "Message"],
Cell[3425, 125, 228, 3, 24, "Message"],
Cell[3656, 130, 119, 2, 36, "Message"],
Cell[3778, 134, 228, 3, 24, "Message"],
Cell[4009, 139, 119, 2, 36, "Message"],
Cell[4131, 143, 163, 3, 24, "Message"],
Cell[4297, 148, 228, 3, 24, "Message"],
Cell[4528, 153, 170, 3, 24, "Message"],
Cell[4701, 158, 199, 3, 24, "Message"],
Cell[4903, 163, 218, 4, 24, "Message"],
Cell[5124, 169, 218, 4, 24, "Message"],
Cell[5345, 175, 169, 3, 24, "Message"],
Cell[5517, 180, 175, 3, 42, "Message"],
Cell[5695, 185, 175, 3, 42, "Message"],
Cell[5873, 190, 175, 3, 42, "Message"],
Cell[6051, 195, 173, 3, 42, "Message"],
Cell[6227, 200, 66269, 1453, 416, 14622, 811, "GraphicsData", "PostScript", \
"Graphics"],
Cell[72499, 1655, 130, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

